@@ -13,14 +13,6 @@
 
 #include "c64.h"
 
-#ifdef RUNTIME_LOADER
-# ifdef __cplusplus
-	extern "C" void c128_runtime_loader_init(void);
-# else
-	extern void c128_runtime_loader_init(void);
-# endif
-#endif
-
 #define C128_MAIN_MEMORY		(input_port_8_r(0)&0x300)
 #define RAM128KB (0)
 #define RAM256KB (0x100)
@@ -81,35 +73,31 @@ extern UINT8 *c128_internal_function;
 extern UINT8 *c128_external_function;
 extern UINT8 *c128_vdcram;
 
-WRITE_HANDLER(c128_m6510_port_w);
-READ_HANDLER(c128_m6510_port_r);
-WRITE_HANDLER(c128_mmu8722_port_w);
-READ_HANDLER(c128_mmu8722_port_r);
-WRITE_HANDLER(c128_mmu8722_ff00_w);
-READ_HANDLER(c128_mmu8722_ff00_r);
+WRITE8_HANDLER(c128_m6510_port_w);
+ READ8_HANDLER(c128_m6510_port_r);
+WRITE8_HANDLER(c128_mmu8722_port_w);
+ READ8_HANDLER(c128_mmu8722_port_r);
+WRITE8_HANDLER(c128_mmu8722_ff00_w);
+ READ8_HANDLER(c128_mmu8722_ff00_r);
 int c128_capslock_r (void);
-WRITE_HANDLER(c128_colorram_write);
-WRITE_HANDLER(c128_write_0000);
-WRITE_HANDLER(c128_write_1000);
-WRITE_HANDLER(c128_write_4000);
-WRITE_HANDLER(c128_write_8000);
-WRITE_HANDLER(c128_write_a000);
-WRITE_HANDLER(c128_write_d000);
-WRITE_HANDLER(c128_write_e000);
-WRITE_HANDLER(c128_write_ff00);
-WRITE_HANDLER(c128_write_ff05);
+WRITE8_HANDLER(c128_colorram_write);
+WRITE8_HANDLER(c128_write_0000);
+WRITE8_HANDLER(c128_write_1000);
+WRITE8_HANDLER(c128_write_4000);
+WRITE8_HANDLER(c128_write_8000);
+WRITE8_HANDLER(c128_write_a000);
+WRITE8_HANDLER(c128_write_c000);
+WRITE8_HANDLER(c128_write_d000);
+WRITE8_HANDLER(c128_write_e000);
+WRITE8_HANDLER(c128_write_ff00);
+WRITE8_HANDLER(c128_write_ff05);
 
-extern void c128_driver_init (void);
-extern void c128pal_driver_init (void);
-extern void c128_driver_shutdown (void);
-extern void c128_init_machine (void);
-extern void c128_shutdown_machine (void);
+extern DRIVER_INIT( c128 );
+extern DRIVER_INIT( c128pal );
+extern MACHINE_INIT( c128 );
 
-extern int c128_vh_start (void);
-extern void c128_vh_stop (void);
-extern void c128_vh_screenrefresh(struct mame_bitmap *bitmap, int full_refresh);
-
-extern void c128_state(void);
+extern VIDEO_START( c128 );
+extern VIDEO_UPDATE( c128 );
 
 /* private area */
 extern int c128;					   /* computer is commodore c128 */
