@@ -8,22 +8,14 @@
 
 #include "driver.h"
 
-#ifdef RUNTIME_LOADER
-# ifdef __cplusplus
-	extern "C" void pet_runtime_loader_init(void);
-# else
-	extern void pet_runtime_loader_init(void);
-# endif
-#endif
-
 /* call to init videodriver */
 extern void pet_vh_init (void);
 extern void pet80_vh_init (void);
 extern void superpet_vh_init (void);
-void pet_vh_screenrefresh (struct mame_bitmap *bitmap, int full_refresh);
-void pet40_vh_screenrefresh (struct mame_bitmap *bitmap, int full_refresh);
-void pet80_vh_screenrefresh (struct mame_bitmap *bitmap, int full_refresh);
-void superpet_vh_screenrefresh (struct mame_bitmap *bitmap, int full_refresh);
+extern VIDEO_UPDATE( pet );
+extern VIDEO_UPDATE( pet40 );
+extern VIDEO_UPDATE( pet80 );
+extern VIDEO_UPDATE( superpet );
 
 extern int pet_font;
 
@@ -202,12 +194,6 @@ extern int pet_font;
 
 #define BUSINESS_KEYBOARD (input_port_5_word_r(0,0)&0x200)
 
-#define MEMORY (input_port_5_word_r(0,0)&0x180)
-#define MEMORY_4 0
-#define MEMORY_8 0x80
-#define MEMORY_16 0x100
-#define MEMORY_32 0x180
-
 #define CBM8096_MEMORY (input_port_5_r(0)&8)
 #define M6809_SELECT (input_port_5_r(0)&4)
 #define IEEE8ON (input_port_5_r(0)&2)
@@ -217,21 +203,18 @@ extern UINT8 *pet_memory;
 extern UINT8 *pet_videoram;
 extern UINT8 *superpet_memory;
 
-WRITE_HANDLER(cbm8096_w);
-extern READ_HANDLER(superpet_r);
-extern WRITE_HANDLER(superpet_w);
+WRITE8_HANDLER(cbm8096_w);
+extern READ8_HANDLER(superpet_r);
+extern WRITE8_HANDLER(superpet_w);
 
-extern void pet_driver_init (void);
-extern void pet_basic1_driver_init (void);
-extern void pet40_driver_init (void);
-extern void cbm80_driver_init (void);
-extern void superpet_driver_init(void);
-extern void pet_driver_shutdown (void);
-extern void pet_init_machine (void);
-extern void pet_shutdown_machine (void);
-extern int pet_frame_interrupt (void);
+DRIVER_INIT( pet );
+DRIVER_INIT( pet1 );
+DRIVER_INIT( pet40 );
+DRIVER_INIT( cbm80 );
+DRIVER_INIT( superpet );
+MACHINE_INIT( pet );
+INTERRUPT_GEN( pet_frame_interrupt );
 
-int pet_rom_id (int id);
 void pet_rom_load(void);
 
 #endif
