@@ -1,14 +1,18 @@
 /***************************************************************************
-    commodore c128 home computer
+
+	commodore c128 home computer
 
 	peter.trauner@jk.uni-linz.ac.at
     documentation:
  	 iDOC (http://www.softwolves.pp.se/idoc)
            Christian Janoff  mepk@c64.org
+
 ***************************************************************************/
 #include <ctype.h>
 #include "driver.h"
 #include "cpu/m6502/m6502.h"
+#include "sound/sid6581.h"
+#include "mscommon.h"
 
 #define VERBOSE_DBG 1
 #include "includes/cbm.h"
@@ -18,8 +22,6 @@
 #include "includes/vc20tape.h"
 #include "includes/vic6567.h"
 #include "includes/vdc8563.h"
-#include "includes/sid6581.h"
-#include "includes/state.h"
 
 #include "includes/c128.h"
 
@@ -55,33 +57,49 @@ static int c64mode = 0, c128_write_io;
 static int c128_ram_bottom, c128_ram_top;
 static UINT8 *c128_ram;
 
+static void c128_set_m8502_read_handler(UINT16 start, UINT16 end, read8_handler rh)
+{
+	int cpunum;
+	cpunum = mame_find_cpu_index("m8502");
+	memory_install_read8_handler(cpunum, ADDRESS_SPACE_PROGRAM, start, end, 0, 0, rh);
+}
+
+
+
 int c128_capslock_r (void)
 {
 	return !KEY_DIN;
 }
 
-static WRITE_HANDLER(c128_dma8726_port_w)
+static WRITE8_HANDLER(c128_dma8726_port_w)
 {
 	DBG_LOG(1,"dma write",("%.3x %.2x\n",offset,data));
 }
 
-static READ_HANDLER(c128_dma8726_port_r)
+static  READ8_HANDLER(c128_dma8726_port_r)
 {
 	DBG_LOG(1,"dma read",("%.3x\n",offset));
 	return 0xff;
 }
 
-WRITE_HANDLER( c128_mmu8722_port_w );
-READ_HANDLER( c128_mmu8722_port_r );
-WRITE_HANDLER( c128_write_d000 )
+WRITE8_HANDLER( c128_mmu8722_port_w );
+READ8_HANDLER( c128_mmu8722_port_r );
+
+WRITE8_HANDLER( c128_write_d000 )
 {
-	if (!c128_write_io) {
+	UINT8 c64_port6510 = (UINT8) cpunum_get_info_int(0, CPUINFO_INT_M6510_PORT);
+
+	if (!c128_write_io)
+	{
 		if (offset + 0xd000 >= c128_ram_top)
 			c64_memory[0xd000 + offset] = data;
 		else
 			c128_ram[0xd000 + offset] = data;
-	} else {
-		switch ((offset&0xf00)>>8) {
+	}
+	else
+	{
+		switch ((offset&0xf00)>>8)
+		{
 		case 0:case 1: case 2: case 3:
 			vic2_port_w (offset & 0x3ff, data);
 			break;
@@ -96,9 +114,9 @@ WRITE_HANDLER( c128_write_d000 )
 			break;
 		case 8: case 9: case 0xa: case 0xb:
 		    if (c64mode)
-			c64_colorram[(offset & 0x3ff)] = data | 0xf0;
+				c64_colorram[(offset & 0x3ff)] = data | 0xf0;
 		    else
-			c64_colorram[(offset & 0x3ff)|((c64_port6510&3)<<10)] = data | 0xf0; /* maybe all 8 bit connected! */
+				c64_colorram[(offset & 0x3ff)|((c64_port6510&3)<<10)] = data | 0xf0; /* maybe all 8 bit connected! */
 		    break;
 		case 0xc:
 			cia6526_0_port_w (offset & 0xff, data);
@@ -116,7 +134,9 @@ WRITE_HANDLER( c128_write_d000 )
 	}
 }
 
-static READ_HANDLER( c128_read_io )
+
+
+static  READ8_HANDLER( c128_read_io )
 {
 	switch ((offset&0xf00)>>8) {
 	case 0:case 1: case 2: case 3:
@@ -145,11 +165,12 @@ void c128_bankswitch_64 (int reset)
 {
 	static int old, exrom, game;
 	int data, loram, hiram, charen;
+	read8_handler rh;
 
 	if (!c64mode)
 		return;
 
-	data = ((c64_port6510 & c64_ddr6510) | (c64_ddr6510 ^ 0xff)) & 7;
+	data = (UINT8) cpunum_get_info_int(0, CPUINFO_INT_M6510_PORT) & 7;
 	if ((data == old)&&(exrom==c64_exrom)&&(game==c64_game)&&!reset)
 		return;
 
@@ -161,66 +182,63 @@ void c128_bankswitch_64 (int reset)
 	if ((!c64_game && c64_exrom)
 		|| (loram && hiram && !c64_exrom))
 	{
-		cpu_setbank (8, c64_roml);
+		memory_set_bankptr (8, c64_roml);
 	}
 	else
 	{
-		cpu_setbank (8, c64_memory + 0x8000);
+		memory_set_bankptr (8, c64_memory + 0x8000);
 	}
 
 	if ((!c64_game && c64_exrom && hiram)
 		|| (!c64_exrom))
 	{
-		cpu_setbank (9, c64_romh);
+		memory_set_bankptr (9, c64_romh);
 	}
 	else if (loram && hiram)
 	{
-		cpu_setbank (9, c64_basic);
+		memory_set_bankptr (9, c64_basic);
 	}
 	else
 	{
-		cpu_setbank (9, c64_memory + 0xa000);
+		memory_set_bankptr (9, c64_memory + 0xa000);
 	}
 
 	if ((!c64_game && c64_exrom)
 		|| (charen && (loram || hiram)))
 	{
-		memory_set_bankhandler_r (13, 0, c128_read_io);
+		rh = c128_read_io;
 		c128_write_io = 1;
 	}
 	else
 	{
-		memory_set_bankhandler_r (13, 0, MRA_BANK5);
+		rh = MRA8_BANK5;
 		c128_write_io = 0;
 		if ((!charen && (loram || hiram)))
-		{
-			cpu_setbank (13, c64_chargen);
-		}
+			memory_set_bankptr (13, c64_chargen);
 		else
-		{
-			cpu_setbank (13, c64_memory + 0xd000);
-		}
+			memory_set_bankptr (13, c64_memory + 0xd000);
 	}
+	c128_set_m8502_read_handler(0xd000, 0xdfff, rh);
 
 	if (!c64_game && c64_exrom)
 	{
-		cpu_setbank (14, c64_romh);
-		cpu_setbank (15, c64_romh+0x1f00);
-		cpu_setbank (16, c64_romh+0x1f05);
+		memory_set_bankptr (14, c64_romh);
+		memory_set_bankptr (15, c64_romh+0x1f00);
+		memory_set_bankptr (16, c64_romh+0x1f05);
 	}
 	else
 	{
 		if (hiram)
 		{
-			cpu_setbank (14, c64_kernal);
-			cpu_setbank (15, c64_kernal+0x1f00);
-			cpu_setbank (16, c64_kernal+0x1f05);
+			memory_set_bankptr (14, c64_kernal);
+			memory_set_bankptr (15, c64_kernal+0x1f00);
+			memory_set_bankptr (16, c64_kernal+0x1f05);
 		}
 		else
 		{
-			cpu_setbank (14, c64_memory + 0xe000);
-			cpu_setbank (15, c64_memory + 0xff00);
-			cpu_setbank (16, c64_memory + 0xff05);
+			memory_set_bankptr (14, c64_memory + 0xe000);
+			memory_set_bankptr (15, c64_memory + 0xff00);
+			memory_set_bankptr (16, c64_memory + 0xff05);
 		}
 	}
 	old = data;
@@ -270,8 +288,8 @@ static int mmu_page0, mmu_page1;
 	 c128_ram = c64_memory + MMU_RAM_ADDR;
 	 c128_va1617 = MMU_VIC_ADDR;
 #if 1
-	 cpu_setbank (10, c128_z80);
-	 cpu_setbank (11, c128_ram+0x1000);
+	 memory_set_bankptr (10, c128_z80);
+	 memory_set_bankptr (11, c128_ram+0x1000);
 	 if ( ((C128_MAIN_MEMORY==RAM256KB)&&(MMU_RAM_ADDR>=0x40000))
 		  ||((C128_MAIN_MEMORY==RAM128KB)&&(MMU_RAM_ADDR>=0x20000)) )
 		 c128_ram=NULL;
@@ -282,32 +300,32 @@ static int mmu_page0, mmu_page1;
 		 c128_ram_bottom = 0;
 
 	 if (MMU_RAM_ADDR==0) { /* this is used in z80 mode for rom on/off switching !*/
-		 cpu_setbank (10, c128_z80);
-		 cpu_setbank (11, c128_z80+0x400);
+		 memory_set_bankptr (10, c128_z80);
+		 memory_set_bankptr (11, c128_z80+0x400);
 	 } else {
-		 cpu_setbank (10, (c128_ram_bottom > 0 ? c64_memory : c128_ram));
-		 cpu_setbank (11, (c128_ram_bottom > 0x400 ? c64_memory : c128_ram) + 0x400);
+		 memory_set_bankptr (10, (c128_ram_bottom > 0 ? c64_memory : c128_ram));
+		 memory_set_bankptr (11, (c128_ram_bottom > 0x400 ? c64_memory : c128_ram) + 0x400);
 	 }
-	 cpu_setbank (1, (c128_ram_bottom > 0 ? c64_memory : c128_ram));
-	 cpu_setbank (2, (c128_ram_bottom > 0x400 ? c64_memory : c128_ram) + 0x400);
+	 memory_set_bankptr (1, (c128_ram_bottom > 0 ? c64_memory : c128_ram));
+	 memory_set_bankptr (2, (c128_ram_bottom > 0x400 ? c64_memory : c128_ram) + 0x400);
 
-	 cpu_setbank (3, (c128_ram_bottom > 0x1000 ? c64_memory : c128_ram) + 0x1000);
-	 cpu_setbank (4, (c128_ram_bottom > 0x2000 ? c64_memory : c128_ram) + 0x2000);
-	 cpu_setbank (5, c128_ram + 0x4000);
+	 memory_set_bankptr (3, (c128_ram_bottom > 0x1000 ? c64_memory : c128_ram) + 0x1000);
+	 memory_set_bankptr (4, (c128_ram_bottom > 0x2000 ? c64_memory : c128_ram) + 0x2000);
+	 memory_set_bankptr (5, c128_ram + 0x4000);
 
 	 if (MMU_TOP)
 		 c128_ram_top = 0x10000 - MMU_SIZE;
 	 else
 		 c128_ram_top = 0x10000;
 
-	 if (c128_ram_top > 0xc000) { cpu_setbank (6, c128_ram + 0xc000); }
-	 else { cpu_setbank (6, c64_memory + 0xc000); }
-	 if (c128_ram_top > 0xe000) { cpu_setbank (7, c128_ram + 0xe000); }
-	 else { cpu_setbank (7, c64_memory + 0xd000); }
-	 if (c128_ram_top > 0xf000) { cpu_setbank (8, c128_ram + 0xf000); }
-	 else { cpu_setbank (8, c64_memory + 0xe000); }
-	 if (c128_ram_top > 0xff05) { cpu_setbank (9, c128_ram + 0xff05); }
-	 else { cpu_setbank (9, c64_memory + 0xff05); }
+	 if (c128_ram_top > 0xc000) { memory_set_bankptr (6, c128_ram + 0xc000); }
+	 else { memory_set_bankptr (6, c64_memory + 0xc000); }
+	 if (c128_ram_top > 0xe000) { memory_set_bankptr (7, c128_ram + 0xe000); }
+	 else { memory_set_bankptr (7, c64_memory + 0xd000); }
+	 if (c128_ram_top > 0xf000) { memory_set_bankptr (8, c128_ram + 0xf000); }
+	 else { memory_set_bankptr (8, c64_memory + 0xe000); }
+	 if (c128_ram_top > 0xff05) { memory_set_bankptr (9, c128_ram + 0xff05); }
+	 else { memory_set_bankptr (9, c64_memory + 0xff05); }
 
 	 if ( ((C128_MAIN_MEMORY==RAM256KB)&&(MMU_RAM_ADDR>=0x40000))
 		  ||((C128_MAIN_MEMORY==RAM128KB)&&(MMU_RAM_ADDR>=0x20000)) )
@@ -315,8 +333,10 @@ static int mmu_page0, mmu_page1;
 #endif
  }
 
- static void c128_bankswitch_128 (int reset)
- {
+static void c128_bankswitch_128 (int reset)
+{
+	read8_handler rh;
+
 	c64mode = MMU_64MODE;
 	if (c64mode)
 	{
@@ -326,17 +346,17 @@ static int mmu_page0, mmu_page1;
 		c128_ram_bottom = 0;
 		c128_ram_top = 0x10000;
 
-		cpu_setbank (1, c64_memory);
-		cpu_setbank (2, c64_memory + 0x100);
+		memory_set_bankptr (1, c64_memory);
+		memory_set_bankptr (2, c64_memory + 0x100);
 
-		cpu_setbank (3, c64_memory + 0x200);
-		cpu_setbank (4, c64_memory + 0x400);
-		cpu_setbank (5, c64_memory + 0x1000);
-		cpu_setbank (6, c64_memory + 0x2000);
+		memory_set_bankptr (3, c64_memory + 0x200);
+		memory_set_bankptr (4, c64_memory + 0x400);
+		memory_set_bankptr (5, c64_memory + 0x1000);
+		memory_set_bankptr (6, c64_memory + 0x2000);
 
-		cpu_setbank (7, c64_memory + 0x4000);
+		memory_set_bankptr (7, c64_memory + 0x4000);
 
-		cpu_setbank (12, c64_memory + 0xc000);
+		memory_set_bankptr (12, c64_memory + 0xc000);
 
 		c128_bankswitch_64 (reset);
 	}
@@ -344,138 +364,139 @@ static int mmu_page0, mmu_page1;
 	{
 		c128_ram = c64_memory + MMU_RAM_ADDR;
 		c128_va1617 = MMU_VIC_ADDR;
-		cpu_setbank (1, c64_memory + mmu_page0);
-		cpu_setbank (2, c64_memory + mmu_page1);
+		memory_set_bankptr (1, c64_memory + mmu_page0);
+		memory_set_bankptr (2, c64_memory + mmu_page1);
 		if (MMU_BOTTOM)
 			{
 				c128_ram_bottom = MMU_SIZE;
 			}
 		else
 			c128_ram_bottom = 0;
-		cpu_setbank (3, (c128_ram_bottom > 0x200 ? c64_memory : c128_ram) + 0x200);
-		cpu_setbank (4, (c128_ram_bottom > 0x400 ? c64_memory : c128_ram) + 0x400);
-		cpu_setbank (5, (c128_ram_bottom > 0x1000 ? c64_memory : c128_ram) + 0x1000);
-		cpu_setbank (6, (c128_ram_bottom > 0x2000 ? c64_memory : c128_ram) + 0x2000);
+		memory_set_bankptr (3, (c128_ram_bottom > 0x200 ? c64_memory : c128_ram) + 0x200);
+		memory_set_bankptr (4, (c128_ram_bottom > 0x400 ? c64_memory : c128_ram) + 0x400);
+		memory_set_bankptr (5, (c128_ram_bottom > 0x1000 ? c64_memory : c128_ram) + 0x1000);
+		memory_set_bankptr (6, (c128_ram_bottom > 0x2000 ? c64_memory : c128_ram) + 0x2000);
 
 		if (MMU_RAM_LO)
 			{
-				cpu_setbank (7, c128_ram + 0x4000);
+				memory_set_bankptr (7, c128_ram + 0x4000);
 			}
 		else
 			{
-				cpu_setbank (7, c128_basic);
+				memory_set_bankptr (7, c128_basic);
 			}
 
 		if (MMU_RAM_MID)
 			{
-				cpu_setbank (8, c128_ram + 0x8000);
-				cpu_setbank (9, c128_ram + 0xa000);
+				memory_set_bankptr (8, c128_ram + 0x8000);
+				memory_set_bankptr (9, c128_ram + 0xa000);
 			}
 		else if (MMU_ROM_MID)
 			{
-				cpu_setbank (8, c128_basic + 0x4000);
-				cpu_setbank (9, c128_basic + 0x6000);
+				memory_set_bankptr (8, c128_basic + 0x4000);
+				memory_set_bankptr (9, c128_basic + 0x6000);
 			}
 		else if (MMU_INTERNAL_ROM_MID)
 			{
-				cpu_setbank (8, c128_internal_function);
-				cpu_setbank (9, c128_internal_function + 0x2000);
+				memory_set_bankptr (8, c128_internal_function);
+				memory_set_bankptr (9, c128_internal_function + 0x2000);
 			}
 		else
 			{
-				cpu_setbank (8, c128_external_function);
-				cpu_setbank (9, c128_external_function + 0x2000);
+				memory_set_bankptr (8, c128_external_function);
+				memory_set_bankptr (9, c128_external_function + 0x2000);
 			}
 
 		if (MMU_TOP)
-			{
-				c128_ram_top = 0x10000 - MMU_SIZE;
-			}
+		{
+			c128_ram_top = 0x10000 - MMU_SIZE;
+		}
 		else
 			c128_ram_top = 0x10000;
 
-		memory_set_bankhandler_r (15, 0, c128_mmu8722_ff00_r);
+		c128_set_m8502_read_handler(0xff00, 0xff04, c128_mmu8722_ff00_r);
 
 		if (MMU_IO_ON)
-			{
-				memory_set_bankhandler_r (13, 0, c128_read_io);
-				c128_write_io = 1;
-			}
+		{
+			rh = c128_read_io;
+			c128_write_io = 1;
+		}
 		else
-			{
-				c128_write_io = 0;
-				memory_set_bankhandler_r (13, 0, MRA_BANK13);
-			}
+		{
+			c128_write_io = 0;
+			rh = MRA8_BANK13;
+		}
+		c128_set_m8502_read_handler(0xd000, 0xdfff, rh);
 
 		if (MMU_RAM_HI)
+		{
+			if (c128_ram_top > 0xc000)
 			{
-				if (c128_ram_top > 0xc000)
-					{
-						cpu_setbank (12, c128_ram + 0xc000);
-					}
-				else
-					{
-						cpu_setbank (12, c64_memory + 0xc000);
-					}
-				if (!MMU_IO_ON) {
-					if (c128_ram_top > 0xd000)
-						{
-							cpu_setbank (13, c128_ram + 0xd000);
-						}
-					else
-						{
-							cpu_setbank (13, c64_memory + 0xd000);
-						}
-				}
-				if (c128_ram_top > 0xe000)
-					{
-						cpu_setbank (14, c128_ram + 0xe000);
-					}
-				else
-					{
-						cpu_setbank (14, c64_memory + 0xe000);
-					}
-				if (c128_ram_top > 0xff05)
-					{
-						cpu_setbank (16, c128_ram + 0xff05);
-					}
-				else
-					{
-						cpu_setbank (16, c64_memory + 0xff05);
-					}
+				memory_set_bankptr (12, c128_ram + 0xc000);
 			}
+			else
+			{
+				memory_set_bankptr (12, c64_memory + 0xc000);
+			}
+			if (!MMU_IO_ON)
+			{
+				if (c128_ram_top > 0xd000)
+				{
+					memory_set_bankptr (13, c128_ram + 0xd000);
+				}
+				else
+				{
+					memory_set_bankptr (13, c64_memory + 0xd000);
+				}
+			}
+			if (c128_ram_top > 0xe000)
+			{
+				memory_set_bankptr (14, c128_ram + 0xe000);
+			}
+			else
+			{
+				memory_set_bankptr (14, c64_memory + 0xe000);
+			}
+			if (c128_ram_top > 0xff05)
+			{
+				memory_set_bankptr (16, c128_ram + 0xff05);
+			}
+			else
+			{
+				memory_set_bankptr (16, c64_memory + 0xff05);
+			}
+		}
 		else if (MMU_ROM_HI)
-			{
-				cpu_setbank (12, c128_editor);
-				if (!MMU_IO_ON) {
-					cpu_setbank (13, c128_chargen);
-				}
-				cpu_setbank (14, c128_kernal);
-				cpu_setbank (16, c128_kernal + 0x1f05);
+		{
+			memory_set_bankptr (12, c128_editor);
+			if (!MMU_IO_ON) {
+				memory_set_bankptr (13, c128_chargen);
 			}
+			memory_set_bankptr (14, c128_kernal);
+			memory_set_bankptr (16, c128_kernal + 0x1f05);
+		}
 		else if (MMU_INTERNAL_ROM_HI)
-			{
-				cpu_setbank (12, c128_internal_function);
-				if (!MMU_IO_ON) {
-					cpu_setbank (13, c128_internal_function + 0x1000);
-				}
-				cpu_setbank (14, c128_internal_function + 0x2000);
-				cpu_setbank (16, c128_internal_function + 0x3f05);
+		{
+			memory_set_bankptr (12, c128_internal_function);
+			if (!MMU_IO_ON) {
+				memory_set_bankptr (13, c128_internal_function + 0x1000);
 			}
+			memory_set_bankptr (14, c128_internal_function + 0x2000);
+			memory_set_bankptr (16, c128_internal_function + 0x3f05);
+		}
 		else					   /*if (MMU_EXTERNAL_ROM_HI) */
-			{
-				cpu_setbank (12, c128_external_function);
-				if (!MMU_IO_ON) {
-					cpu_setbank (13, c128_external_function + 0x1000);
-				}
-				cpu_setbank (14, c128_external_function + 0x2000);
-				cpu_setbank (16, c128_external_function + 0x3f05);
+		{
+			memory_set_bankptr (12, c128_external_function);
+			if (!MMU_IO_ON) {
+				memory_set_bankptr (13, c128_external_function + 0x1000);
 			}
+			memory_set_bankptr (14, c128_external_function + 0x2000);
+			memory_set_bankptr (16, c128_external_function + 0x3f05);
+		}
 		if ( ((C128_MAIN_MEMORY==RAM256KB)&&(MMU_RAM_ADDR>=0x40000))
 			 ||((C128_MAIN_MEMORY==RAM128KB)&&(MMU_RAM_ADDR>=0x20000)) ) c128_ram=NULL;
 	}
-
- }
+}
 
 
 static void c128_bankswitch (int reset)
@@ -489,8 +510,8 @@ static void c128_bankswitch (int reset)
 					memory_set_context(0);
 					c128_bankswitch_z80();
 					memory_set_context(1);
-					cpu_set_halt_line (0, 0);
-					cpu_set_halt_line (1, 1);
+					cpunum_set_input_line(0, INPUT_LINE_HALT, 0);
+					cpunum_set_input_line(1, INPUT_LINE_HALT, 1);
 				}
 			}
 		else
@@ -500,8 +521,8 @@ static void c128_bankswitch (int reset)
 				memory_set_context(1);
 				c128_bankswitch_128(reset);
 				memory_set_context(0);
-				cpu_set_halt_line (1, 0);
-				cpu_set_halt_line (0, 1);
+				cpunum_set_input_line(1, INPUT_LINE_HALT, 0);
+				cpunum_set_input_line(0, INPUT_LINE_HALT, 1);
 			}
 		mmu_cpu = MMU_CPU8502;
 		return;
@@ -513,28 +534,9 @@ static void c128_bankswitch (int reset)
 	}
 }
 
-void c128_mmu8722_reset (void)
+static void c128_mmu8722_reset (void)
 {
-#if 0
-	cpu_setbank (1, c64_memory);
-	cpu_setbank (2, c64_memory + 0x100);
-
-	cpu_setbank (3, c64_memory + 0x200);
-	cpu_setbank (4, c64_memory + 0x400);
-	cpu_setbank (5, c64_memory + 0x1000);
-	cpu_setbank (6, c64_memory + 0x2000);
-	cpu_setbank (7, c64_memory + 0x4000);
-
-	c128_mmu[0] &= ~1;
-	c128_mmu[1] = c128_mmu[2] = c128_mmu[3] = c128_mmu[4] = 0;
-	c128_mmu[5] &= ~9;
-	c128_mmu[6] &= ~3;
-	c128_mmu[7] = c128_mmu[8] = c128_mmu[9] = 0;
-	c128_mmu[10] = 1;
-	c128_va1617 = 0;
-#else
 	memset (c128_mmu, 0, sizeof (c128_mmu));
-#endif
 	c128_mmu[5] |= 0x38;
 	c128_mmu[10] = 1;
 	mmu_cpu=0;
@@ -543,7 +545,7 @@ void c128_mmu8722_reset (void)
 	c128_bankswitch (1);
 }
 
-WRITE_HANDLER( c128_mmu8722_port_w )
+WRITE8_HANDLER( c128_mmu8722_port_w )
 {
 	offset &= 0xf;
 	switch (offset)
@@ -581,7 +583,7 @@ WRITE_HANDLER( c128_mmu8722_port_w )
 	}
 }
 
-READ_HANDLER( c128_mmu8722_port_r )
+ READ8_HANDLER( c128_mmu8722_port_r )
 {
 	int data;
 
@@ -617,7 +619,7 @@ READ_HANDLER( c128_mmu8722_port_r )
 	return data;
 }
 
-WRITE_HANDLER( c128_mmu8722_ff00_w )
+WRITE8_HANDLER( c128_mmu8722_ff00_w )
 {
 	switch (offset)
 	{
@@ -639,42 +641,48 @@ WRITE_HANDLER( c128_mmu8722_ff00_w )
 	}
 }
 
-READ_HANDLER( c128_mmu8722_ff00_r )
+ READ8_HANDLER( c128_mmu8722_ff00_r )
 {
 	return c128_mmu[offset];
 }
 
-WRITE_HANDLER( c128_write_0000 )
+WRITE8_HANDLER( c128_write_0000 )
 {
 	if (c128_ram!=NULL)
 		c128_ram[0x0000 + offset] = data;
 }
 
-WRITE_HANDLER( c128_write_1000 )
+WRITE8_HANDLER( c128_write_1000 )
 {
 	if (c128_ram!=NULL)
 		c128_ram[0x1000 + offset] = data;
 }
 
-WRITE_HANDLER( c128_write_4000 )
+WRITE8_HANDLER( c128_write_4000 )
 {
 	if (c128_ram!=NULL)
 		c128_ram[0x4000 + offset] = data;
 }
 
-WRITE_HANDLER( c128_write_8000 )
+WRITE8_HANDLER( c128_write_8000 )
 {
 	if (c128_ram!=NULL)
 		c128_ram[0x8000 + offset] = data;
 }
 
-WRITE_HANDLER( c128_write_a000 )
+WRITE8_HANDLER( c128_write_a000 )
 {
 	if (c128_ram!=NULL)
 		c128_ram[0xa000 + offset] = data;
 }
 
-WRITE_HANDLER( c128_write_e000 )
+WRITE8_HANDLER( c128_write_c000 )
+{
+	if (c128_ram!=NULL)
+		c128_ram[0xc000 + offset] = data;
+}
+
+WRITE8_HANDLER( c128_write_e000 )
 {
 	if (offset + 0xe000 >= c128_ram_top)
 		c64_memory[0xe000 + offset] = data;
@@ -682,7 +690,7 @@ WRITE_HANDLER( c128_write_e000 )
 		c128_ram[0xe000 + offset] = data;
 }
 
-WRITE_HANDLER( c128_write_ff00 )
+WRITE8_HANDLER( c128_write_ff00 )
 {
 	if (!c64mode)
 		c128_mmu8722_ff00_w (offset, data);
@@ -690,7 +698,7 @@ WRITE_HANDLER( c128_write_ff00 )
 		c64_memory[0xff00 + offset] = data;
 }
 
-WRITE_HANDLER( c128_write_ff05 )
+WRITE8_HANDLER( c128_write_ff05 )
 {
 	if (offset + 0xff05 >= c128_ram_top)
 		c64_memory[0xff05 + offset] = data;
@@ -705,6 +713,8 @@ WRITE_HANDLER( c128_write_ff05 )
  */
 static int c128_dma_read(int offset)
 {
+	UINT8 c64_port6510 = (UINT8) cpunum_get_info_int(0, CPUINFO_INT_M6510_PORT);
+
 	/* main memory configuration to include */
 	if (c64mode)
 	{
@@ -726,8 +736,12 @@ static int c128_dma_read(int offset)
 
 static int c128_dma_read_color (int offset)
 {
-    if (c64mode) return c64_colorram[offset & 0x3ff] & 0xf;
-    return c64_colorram[(offset & 0x3ff)|((c64_port6510&0x3)<<10)] & 0xf;
+	UINT8 c64_port6510 = (UINT8) cpunum_get_info_int(0, CPUINFO_INT_M6510_PORT);
+
+	if (c64mode)
+		return c64_colorram[offset & 0x3ff] & 0xf;
+	else
+		return c64_colorram[(offset & 0x3ff)|((c64_port6510&0x3)<<10)] & 0xf;
 }
 
 static void c128_common_driver_init (void)
@@ -735,43 +749,30 @@ static void c128_common_driver_init (void)
 	UINT8 *gfx=memory_region(REGION_GFX1);
 	int i;
 
-#if 0
-	{0x100000, 0x107fff, MWA_ROM, &c128_basic},	/* maps to 0x4000 */
-	{0x108000, 0x109fff, MWA_ROM, &c64_basic},	/* maps to 0xa000 */
-	{0x10a000, 0x10bfff, MWA_ROM, &c64_kernal},	/* maps to 0xe000 */
-	{0x10c000, 0x10cfff, MWA_ROM, &c128_editor},
-	{0x10d000, 0x10dfff, MWA_ROM, &c128_z80},		/* maps to z80 0 */
-	{0x10e000, 0x10ffff, MWA_ROM, &c128_kernal},
-	{0x110000, 0x117fff, MWA_ROM, &c128_internal_function},
-	{0x118000, 0x11ffff, MWA_ROM, &c128_external_function},
-	{0x120000, 0x120fff, MWA_ROM, &c64_chargen},
-	{0x121000, 0x121fff, MWA_ROM, &c128_chargen},
-	{0x122000, 0x1227ff, MWA_RAM, &c64_colorram},
-	{0x122800, 0x1327ff, MWA_RAM, &c128_vdcram},
-#endif
-		c128_basic=memory_region(REGION_CPU1)+0x100000;
-		c64_basic=memory_region(REGION_CPU1)+0x108000;
-		c64_kernal=memory_region(REGION_CPU1)+0x10a000;
-		c128_editor=memory_region(REGION_CPU1)+0x10c000;
-		c128_z80=memory_region(REGION_CPU1)+0x10d000;
-		c128_kernal=memory_region(REGION_CPU1)+0x10e000;
-		c128_internal_function=memory_region(REGION_CPU1)+0x110000;
-		c128_external_function=memory_region(REGION_CPU1)+0x118000;
-		c64_chargen=memory_region(REGION_CPU1)+0x120000;
-		c128_chargen=memory_region(REGION_CPU1)+0x121000;
-		c64_colorram=memory_region(REGION_CPU1)+0x122000;
-		c128_vdcram=memory_region(REGION_CPU1)+0x122800;
+	/* configure the M6510 port */
+	cpunum_set_info_fct(1, CPUINFO_PTR_M6510_PORTREAD, (genf *) c64_m6510_port_read);
+	cpunum_set_info_fct(1, CPUINFO_PTR_M6510_PORTWRITE, (genf *) c64_m6510_port_write);
 
-	for (i=0; i<0x100; i++) gfx[i]=i;
+	c128_basic = memory_region(REGION_CPU1)+0x100000;
+	c64_basic = memory_region(REGION_CPU1)+0x108000;
+	c64_kernal = memory_region(REGION_CPU1)+0x10a000;
+	c128_editor = memory_region(REGION_CPU1)+0x10c000;
+	c128_z80 = memory_region(REGION_CPU1)+0x10d000;
+	c128_kernal = memory_region(REGION_CPU1)+0x10e000;
+	c128_internal_function = memory_region(REGION_CPU1)+0x110000;
+	c128_external_function = memory_region(REGION_CPU1)+0x118000;
+	c64_chargen = memory_region(REGION_CPU1)+0x120000;
+	c128_chargen = memory_region(REGION_CPU1)+0x121000;
+	c64_colorram = memory_region(REGION_CPU1)+0x122000;
+	c128_vdcram = memory_region(REGION_CPU1)+0x122800;
+
+	for (i=0; i<0x100; i++)
+		gfx[i]=i;
 
-	memset(c64_memory, 0xff, 0x100000);
 	c128 = 1;
 	vc20_tape_open (c64_tape_read);
 
-	cbm_drive_open ();
-
-	cbm_drive_attach_fs (0);
-	cbm_drive_attach_fs (1);
+	cia6526_init();
 
 	c64_cia0.todin50hz = c64_pal;
 	cia6526_config (0, &c64_cia0);
@@ -779,7 +780,7 @@ static void c128_common_driver_init (void)
 	cia6526_config (1, &c64_cia1);
 }
 
-void c128_driver_init (void)
+DRIVER_INIT( c128 )
 {
 	c128_common_driver_init ();
 	vic6567_init (1, c64_pal,
@@ -787,10 +788,9 @@ void c128_driver_init (void)
 	vic2_set_rastering(0);
 	vdc8563_init(0);
 	vdc8563_set_rastering(1);
-	state_add_function(c128_state);
 }
 
-void c128pal_driver_init (void)
+DRIVER_INIT( c128pal )
 {
 	c64_pal = 1;
 	c128_common_driver_init ();
@@ -799,89 +799,32 @@ void c128pal_driver_init (void)
 	vic2_set_rastering(1);
 	vdc8563_init(0);
 	vdc8563_set_rastering(0);
-	state_add_function(c128_state);
 }
 
-void c128_driver_shutdown (void)
-{
-	cbm_drive_close ();
-	vc20_tape_close ();
-}
-
-void c128_init_machine (void)
+MACHINE_INIT( c128 )
 {
 	logerror("reset\n");
 	c64_common_init_machine ();
 	c128_vicaddr = c64_vicaddr = c64_memory;
 
-	sid6581_reset(0);
+	sndti_reset(SOUND_SID6581, 0);
 
 	c64_rom_recognition ();
 	c64_rom_load();
 
-#if 1
 	c64mode = 0;
-#else
-	c64mode = 1;
-#endif
 	c128_mmu8722_reset ();
-	cpu_set_halt_line (0, 0);
-	cpu_set_halt_line (1, 1);
+	cpunum_set_input_line(0, INPUT_LINE_HALT, 0);
+	cpunum_set_input_line(1, INPUT_LINE_HALT, 1);
 }
 
-void c128_shutdown_machine (void)
+VIDEO_START( c128 )
 {
+	return video_start_vdc8563() || video_start_vic2();
 }
 
-int c128_vh_start (void)
+VIDEO_UPDATE( c128 )
 {
-	return vdc8563_vh_start()||vic2_vh_start();
-}
-
-void c128_vh_stop (void)
-{
-	vdc8563_vh_stop();
-	vic2_vh_stop();
-}
-
-void c128_vh_screenrefresh(struct mame_bitmap *bitmap, int full_refresh)
-{
-	vdc8563_vh_screenrefresh(bitmap, full_refresh);
-	vic2_vh_screenrefresh(bitmap,full_refresh);
-}
-
-void c128_state(void)
-{
-	char text[70];
-
-#if VERBOSE_DBG
-# if 0
-	cia6526_status (text, sizeof (text));
-	state_display_text (This, text, &y);
-
-#  if 1
-	snprintf (text, size, "c128 vic:%.5x m6510:%d exrom:%d game:%d",
-			  c128_vicaddr - c64_memory, c64_port6510 & 7,
-			  c64_exrom, c64_game);
-#  else
-	snprintf (text, size, "size:%.4x %s %s %.6x %s %.6x %.6x",
-			  MMU_SIZE, MMU_BOTTOM?"bottom":"", MMU_TOP?"top":"",MMU_RAM_ADDR, MMU_IO_ON?"io":"",
-			  MMU_PAGE0, MMU_PAGE1);
-#  endif
-	state_display_text (text);
-# endif
-
-#endif
-
-	vc20_tape_status (text, sizeof (text));
-	state_display_text (text);
-#ifdef VC1541
-	vc1541_drive_status (text, sizeof (text));
-#else
-	cbm_drive_0_status (text, sizeof (text));
-#endif
-	state_display_text (text);
-
-	cbm_drive_1_status (text, sizeof (text));
-	state_display_text (text);
+	video_update_vdc8563(screen, bitmap, cliprect, do_skip);
+	video_update_vic2(screen, bitmap, cliprect, do_skip);
 }
