@@ -16,6 +16,7 @@
 #include "driver.h"
 #include "cpu/m6502/m6502.h"
 #include "cpu/z80/z80.h"
+#include "sound/sid6581.h"
 
 #define VERBOSE_DBG 1
 #include "includes/cbm.h"
@@ -25,8 +26,7 @@
 #include "includes/vc20tape.h"
 #include "includes/vic6567.h"
 #include "includes/vdc8563.h"
-#include "includes/sid6581.h"
-#include "includes/state.h"
+#include "mscommon.h"
 
 #include "includes/c128.h"
 #include "includes/c65.h"
@@ -55,7 +55,6 @@ int c64_pal = 0;
 UINT8 c64_game=1, c64_exrom=1;
 
 /* cpu port */
-UINT8 c64_port6510, c64_ddr6510;
 int c128_va1617;
 UINT8 *c64_vicaddr, *c128_vicaddr;
 UINT8 *c64_memory;
@@ -87,13 +86,19 @@ static void c64_nmi(void)
     if (nmilevel != KEY_RESTORE||cia1irq)
     {
 	if (c128) {
-	    if (cpu_getactivecpu()==0) { /* z80 */
-		cpu_set_nmi_line (0, KEY_RESTORE||cia1irq);
-	    } else {
-		cpu_set_nmi_line (1, KEY_RESTORE||cia1irq);
+	    if (cpu_getactivecpu()==0) 
+		{
+			/* z80 */
+			cpunum_set_input_line(0, INPUT_LINE_NMI, KEY_RESTORE||cia1irq);
 	    }
-	} else {
-	    cpu_set_nmi_line (0, KEY_RESTORE||cia1irq);
+		else
+		{
+			cpunum_set_input_line(1, INPUT_LINE_NMI, KEY_RESTORE||cia1irq);
+	    }
+	}
+	else
+	{
+	    cpunum_set_input_line(0, INPUT_LINE_NMI, KEY_RESTORE||cia1irq);
 	}
 	nmilevel = KEY_RESTORE||cia1irq;
     }
@@ -276,18 +281,18 @@ static void c64_irq (int level)
 		DBG_LOG (3, "mos6510", ("irq %s\n", level ? "start" : "end"));
 		if (c128) {
 			if (0&&(cpu_getactivecpu()==0)) {
-				cpu_set_irq_line (0, Z80_IRQ_INT, level);
+				cpunum_set_input_line (0, 0, level);
 			} else {
-				cpu_set_irq_line (1, M6510_IRQ_LINE, level);
+				cpunum_set_input_line (1, M6510_IRQ_LINE, level);
 			}
 		} else {
-			cpu_set_irq_line (0, M6510_IRQ_LINE, level);
+			cpunum_set_input_line (0, M6510_IRQ_LINE, level);
 		}
 		old_level = level;
 	}
 }
 
-WRITE_HANDLER(c64_tape_read)
+WRITE8_HANDLER(c64_tape_read)
 {
 	cia6526_0_set_input_flag (data);
 }
@@ -362,19 +367,8 @@ static void c64_cia1_port_a_w (int offset, int data)
 
 static void c64_cia1_interrupt (int level)
 {
-	cia1irq=level;
+	cia1irq = level;
 	c64_nmi();
-#if 0
-	static int old_level = 0;
-
-	if (level != old_level)
-	{
-		DBG_LOG (1, "mos6510", ("nmi %s\n", level ? "start" : "end"));
-
-		/*      cpu_set_nmi_line(0, level); */
-		old_level = level;
-	}
-#endif
 }
 
 struct cia6526_interface c64_cia0 =
@@ -456,7 +450,7 @@ static void c64_supergames_w(int offset, int value)
 		c64_bankswitch (0);
 }
 
-WRITE_HANDLER( c64_write_io )
+WRITE8_HANDLER( c64_write_io )
 {
 	if (offset < 0x400) {
 		vic2_port_w (offset & 0x3ff, data);
@@ -495,7 +489,7 @@ WRITE_HANDLER( c64_write_io )
 	}
 }
 
-READ_HANDLER( c64_read_io )
+READ8_HANDLER( c64_read_io )
 {
 	if (offset < 0x400)
 		return vic2_port_r (offset & 0x3ff);
@@ -574,7 +568,7 @@ static void c64_bankswitch (int reset)
 	static int old = -1, exrom, game;
 	int data, loram, hiram, charen;
 
-	data = ((c64_port6510 & c64_ddr6510) | (c64_ddr6510 ^ 0xff)) & 7;
+	data = (UINT8) cpunum_get_info_int(0, CPUINFO_INT_M6510_PORT) & 7;
 	if ((data == old)&&(exrom==c64_exrom)&&(game==c64_game)&&!reset) return;
 
 	DBG_LOG (1, "bankswitch", ("%d\n", data & 7));
@@ -586,13 +580,13 @@ static void c64_bankswitch (int reset)
 	    || (loram && !c64_exrom)) /* for omega race cartridge */
 /*	    || (loram && hiram && !c64_exrom)) */
 	{
-		cpu_setbank (1, roml);
-		memory_set_bankhandler_w (2, 0, MWA_RAM); /* always ram: pitstop */
+		memory_set_bankptr (1, roml);
+		memory_install_write8_handler(0, ADDRESS_SPACE_PROGRAM, 0x8000, 0x9fff, 0, 0, MWA8_RAM);	/* always ram: pitstop */
 	}
 	else
 	{
-		cpu_setbank (1, c64_memory + 0x8000);
-		memory_set_bankhandler_w (2, 0, MWA_RAM);
+		memory_set_bankptr (1, c64_memory + 0x8000);
+		memory_install_write8_handler(0, ADDRESS_SPACE_PROGRAM, 0x8000, 0x9fff, 0, 0, MWA8_RAM);
 	}
 
 #if 1
@@ -603,57 +597,57 @@ static void c64_bankswitch (int reset)
 	    || (!c64_exrom) )
 #endif
 	{
-		cpu_setbank (3, romh);
+		memory_set_bankptr (3, romh);
 	}
 	else if (loram && hiram &&c64_game)
 	{
-		cpu_setbank (3, c64_basic);
+		memory_set_bankptr (3, c64_basic);
 	}
 	else
 	{
-		cpu_setbank (3, c64_memory + 0xa000);
+		memory_set_bankptr (3, c64_memory + 0xa000);
 	}
 
 	if ((!c64_game && c64_exrom)
 		|| (charen && (loram || hiram)))
 	{
-		memory_set_bankhandler_r (5, 0, c64_read_io);
-		memory_set_bankhandler_w (6, 0, c64_write_io);
+		memory_install_read8_handler(0, ADDRESS_SPACE_PROGRAM, 0xd000, 0xdfff, 0, 0, c64_read_io);
+		memory_install_write8_handler(0, ADDRESS_SPACE_PROGRAM, 0xd000, 0xdfff, 0, 0, c64_write_io);
 	}
 	else
 	{
-		memory_set_bankhandler_r (5, 0, MRA_BANK5);
-		memory_set_bankhandler_w (6, 0, MWA_BANK6);
-		cpu_setbank (6, c64_memory + 0xd000);
+		memory_install_read8_handler(0, ADDRESS_SPACE_PROGRAM, 0xd000, 0xdfff, 0, 0, MRA8_BANK5);
+		memory_install_write8_handler(0, ADDRESS_SPACE_PROGRAM, 0xd000, 0xdfff, 0, 0, MWA8_BANK6);
+		memory_set_bankptr (6, c64_memory + 0xd000);
 		if (!charen && (loram || hiram))
 		{
-			cpu_setbank (5, c64_chargen);
+			memory_set_bankptr (5, c64_chargen);
 		}
 		else
 		{
-			cpu_setbank (5, c64_memory + 0xd000);
+			memory_set_bankptr (5, c64_memory + 0xd000);
 		}
 	}
 
 	if (!c64_game && c64_exrom)
 	{
-		cpu_setbank (7, romh);
-		memory_set_bankhandler_w (8, 0, MWA_NOP);
+		memory_set_bankptr (7, romh);
+		memory_install_write8_handler(0, ADDRESS_SPACE_PROGRAM, 0xe000, 0xffff, 0, 0, MWA8_NOP);
 	}
 	else
 	{
-		memory_set_bankhandler_w (8, 0, MWA_RAM);
+		memory_install_write8_handler(0, ADDRESS_SPACE_PROGRAM, 0xe000, 0xffff, 0, 0, MWA8_RAM);
 		if (hiram)
 		{
-			cpu_setbank (7, c64_kernal);
+			memory_set_bankptr (7, c64_kernal);
 		}
 		else
 		{
-			cpu_setbank (7, c64_memory + 0xe000);
+			memory_set_bankptr (7, c64_memory + 0xe000);
 		}
 	}
-	game=c64_game;
-	exrom=c64_exrom;
+	game = c64_game;
+	exrom = c64_exrom;
 	old = data;
 }
 
@@ -669,54 +663,42 @@ static void c64_bankswitch (int reset)
   p5 output cassette motor
   p6,7 not available on M6510
  */
-WRITE_HANDLER(c64_m6510_port_w)
+void c64_m6510_port_write(UINT8 data)
 {
-	if (offset)
+	if (c64_tape_on)
 	{
-		if (c64_port6510 != data)
-			c64_port6510 = data;
-	}
-	else
-	{
-		if (c64_ddr6510 != data)
-			c64_ddr6510 = data;
-	}
-	data = (c64_port6510 & c64_ddr6510) | (c64_ddr6510 ^ 0xff);
-	if (c64_tape_on) {
 		vc20_tape_write (!(data & 8));
 		vc20_tape_motor (data & 0x20);
 	}
 	if (c128)
 		c128_bankswitch_64 (0);
 	else if (c65)
-		c65_bankswitch();
+	{
+		/* NPW 8-Feb-2004 - Don't know why I have to do this */
+		/*c65_bankswitch(); */
+	}
 	else if (!ultimax)
 		c64_bankswitch (0);
 }
 
-READ_HANDLER(c64_m6510_port_r)
+UINT8 c64_m6510_port_read(void)
 {
-	if (offset)
-	{
-		int data = (c64_ddr6510 & c64_port6510) | (c64_ddr6510 ^ 0xff);
+	UINT8 data = 0xFF;
 
-		if (c64_tape_on && !(c64_ddr6510 & 0x10) && !vc20_tape_switch ())
-			data &= ~0x10;
-		if (c128 && !c128_capslock_r ())
-			data &= ~0x40;
-		if (c65 && C65_KEY_DIN) data &= ~0x40; /*? */
-		return data;
-	}
-	else
-	{
-		return c64_ddr6510;
-	}
+	if (c64_tape_on && !vc20_tape_switch ())
+		data &= ~0x10;
+	if (c128 && !c128_capslock_r ())
+		data &= ~0x40;
+	if (c65 && C65_KEY_DIN)
+		data &= ~0x40; /*? */
+	return data;
 }
 
 int c64_paddle_read (int which)
 {
 	int pot1=0xff, pot2=0xff, pot3=0xff, pot4=0xff, temp;
-	if (PADDLES34) {
+	if (PADDLES34)
+	{
 		if (which) pot4=PADDLE4_VALUE;
 		else pot3=PADDLE3_VALUE;
 	}
@@ -754,12 +736,12 @@ int c64_paddle_read (int which)
 	}
 }
 
-READ_HANDLER(c64_colorram_read)
+ READ8_HANDLER(c64_colorram_read)
 {
 	return c64_colorram[offset & 0x3ff];
 }
 
-WRITE_HANDLER( c64_colorram_write )
+WRITE8_HANDLER( c64_colorram_write )
 {
 	c64_colorram[offset & 0x3ff] = data | 0xf0;
 }
@@ -796,6 +778,10 @@ static int c64_dma_read_color (int offset)
 
 static void c64_common_driver_init (void)
 {
+	/* configure the M6510 port */
+	cpunum_set_info_fct(0, CPUINFO_PTR_M6510_PORTREAD, (genf *) c64_m6510_port_read);
+	cpunum_set_info_fct(0, CPUINFO_PTR_M6510_PORTWRITE, (genf *) c64_m6510_port_write);
+
 	/*    memset(c64_memory, 0, 0xfd00); */
 	if (!ultimax) {
 		c64_basic=memory_region(REGION_CPU1)+0x10000;
@@ -805,24 +791,18 @@ static void c64_common_driver_init (void)
 		c64_roml=memory_region(REGION_CPU1)+0x15400;
 		c64_romh=memory_region(REGION_CPU1)+0x17400;
 #if 0
-	{0x10000, 0x11fff, MWA_ROM, &c64_basic},	/* basic at 0xa000 */
-	{0x12000, 0x13fff, MWA_ROM, &c64_kernal},	/* kernal at 0xe000 */
-	{0x14000, 0x14fff, MWA_ROM, &c64_chargen},	/* charrom at 0xd000 */
-	{0x15000, 0x153ff, MWA_RAM, &c64_colorram},		/* colorram at 0xd800 */
-	{0x15400, 0x173ff, MWA_ROM, &c64_roml},	/* basic at 0xa000 */
-	{0x17400, 0x193ff, MWA_ROM, &c64_romh},	/* kernal at 0xe000 */
+	{0x10000, 0x11fff, MWA8_ROM, &c64_basic},	/* basic at 0xa000 */
+	{0x12000, 0x13fff, MWA8_ROM, &c64_kernal},	/* kernal at 0xe000 */
+	{0x14000, 0x14fff, MWA8_ROM, &c64_chargen},	/* charrom at 0xd000 */
+	{0x15000, 0x153ff, MWA8_RAM, &c64_colorram},		/* colorram at 0xd800 */
+	{0x15400, 0x173ff, MWA8_ROM, &c64_roml},	/* basic at 0xa000 */
+	{0x17400, 0x193ff, MWA8_ROM, &c64_romh},	/* kernal at 0xe000 */
 #endif
 	}
 	if (c64_tape_on)
 		vc20_tape_open (c64_tape_read);
 
-	if (c64_cia1_on)
-	{
-		cbm_drive_open ();
-
-		cbm_drive_attach_fs (0);
-		cbm_drive_attach_fs (1);
-	}
+	cia6526_init();
 
 	c64_cia0.todin50hz = c64_pal;
 	cia6526_config (0, &c64_cia0);
@@ -842,7 +822,7 @@ static void c64_common_driver_init (void)
 		vic6567_init (0, c64_pal, c64_dma_read, c64_dma_read_color,
 					  c64_vic_interrupt);
 	}
-	state_add_function(c64_state);
+	cia6526_reset ();
 }
 
 void c64_driver_init (void)
@@ -861,10 +841,6 @@ void ultimax_driver_init (void)
 	ultimax = 1;
     c64_cia1_on = 0;
 	c64_common_driver_init ();
-	if (cbm_rom[0].size==0) {
-	  printf("no cartridge found\n");
-	  exit(1);
-	}
 }
 
 void c64gs_driver_init (void)
@@ -877,7 +853,7 @@ void c64gs_driver_init (void)
 
 void sx64_driver_init (void)
 {
-	VC1541_CONFIG vc1541= { 1, 8 };
+	VC1541_CONFIG vc1541 = { 1, 8 };
 	c64_tape_on = 0;
 	c64_pal = 1;
 	c64_common_driver_init ();
@@ -886,10 +862,6 @@ void sx64_driver_init (void)
 
 void c64_driver_shutdown (void)
 {
-	if (!ultimax)
-	{
-		cbm_drive_close ();
-	}
 	if (c64_tape_on)
 		vc20_tape_close ();
 }
@@ -899,8 +871,8 @@ void c64_common_init_machine (void)
 #ifdef VC1541
 	vc1541_reset ();
 #endif
-	sid6581_reset(0);
-	sid6581_set_type(0, SID8580);
+	sndti_reset(SOUND_SID6581, 0);
+
 	if (c64_cia1_on)
 	{
 		cbm_serial_reset_write (0);
@@ -908,14 +880,11 @@ void c64_common_init_machine (void)
 		cbm_drive_1_config (SERIAL9ON ? SERIAL : 0, c65?11:9);
 		serial_clock = serial_data = serial_atn = 1;
 	}
-	cia6526_reset ();
 	c64_vicaddr = c64_memory;
 	vicirq = cia0irq = 0;
-	c64_port6510 = 0xff;
-	c64_ddr6510 = 0;
 }
 
-void c64_init_machine (void)
+MACHINE_INIT( c64 )
 {
 	c64_common_init_machine ();
 
@@ -928,59 +897,7 @@ void c64_init_machine (void)
 		c64_bankswitch (1);
 }
 
-void c64_shutdown_machine (void)
-{
-}
 
-#ifdef VERIFY_IMAGE
-int c64_rom_id (int id)
-{
-	/* magic lowrom at offset 0x8003: $c3 $c2 $cd $38 $30 */
-	/* jumped to offset 0 (0x8000) */
-	int retval = 0;
-	unsigned char magic[] =
-	{0xc3, 0xc2, 0xcd, 0x38, 0x30}, buffer[sizeof (magic)];
-	FILE *romfile;
-	char *cp;
-
-	logerror("c64_rom_id %s\n", device_filename(IO_CARTSLOT,id));
-	retval = 0;
-	if (!(romfile = (FILE*)image_fopen (IO_CARTSLOT, id, OSD_FILETYPE_IMAGE, 0)))
-	{
-		logerror("rom %s not found\n", device_filename(IO_CARTSLOT,id));
-		return 0;
-	}
-
-	osd_fseek (romfile, 3, SEEK_SET);
-	osd_fread (romfile, buffer, sizeof (magic));
-	osd_fclose (romfile);
-
-	if (memcmp (magic, buffer, sizeof (magic)) == 0)
-	{
-		/* cartridgetype=CartridgeC64; */
-		retval = 1;
-	}
-	else if ((cp = strrchr (device_filename(IO_CARTSLOT,id), '.')) != NULL)
-	{
-		if ((stricmp (cp + 1, "prg") == 0)
-			|| (stricmp (cp + 1, "crt") == 0)
-			|| (stricmp (cp + 1, "80") == 0)
-			|| (stricmp (cp + 1, "90") == 0)
-			|| (stricmp (cp + 1, "e0") == 0)
-			|| (stricmp (cp + 1, "f0") == 0)
-			|| (stricmp (cp + 1, "a0") == 0)
-			|| (stricmp (cp + 1, "b0") == 0)
-			|| (stricmp (cp + 1, "lo") == 0) || (stricmp (cp + 1, "hi") == 0))
-			retval = 1;
-	}
-
-	if (retval)
-		logerror("rom %s recognized\n", device_filename(IO_CARTSLOT,id) );
-	else
-		logerror("rom %s not recognized\n", device_filename(IO_CARTSLOT,id));
-	return retval;
-}
-#endif
 
 #define BETWEEN(value1,value2,bottom,top) \
     ( ((value2)>=(bottom))&&((value1)<(top)) )
@@ -1074,7 +991,7 @@ void c64_rom_load(void)
 		}
 		if (!romh
 		    && (cbm_rom[i].addr==0x8000)
-		    &&(cbm_rom[i].size=0x4000) ){
+		    &&(cbm_rom[i].size==0x4000) ){
 		    romh=cbm_rom[i].chip+0x2000;
 		}
 	    }
@@ -1108,34 +1025,23 @@ void c64_rom_load(void)
     }
 }
 
-int c64_frame_interrupt (void)
+INTERRUPT_GEN( c64_frame_interrupt )
 {
-	static int quickload = 0;
 	static int monitor=-1;
 	int value, value2;
 
-	sid6581_update();
-
 	c64_nmi();
 
-	if (!quickload && QUICKLOAD) {
-		if (c65) {
-			cbm_c65_quick_open (0, 0, c64_memory);
-		} else
-			cbm_quick_open (0, 0, c64_memory);
-	}
-	quickload = QUICKLOAD;
-
 	if (c128) {
 		if (MONITOR_TV!=monitor) {
 			if (MONITOR_TV) {
 				vic2_set_rastering(0);
 				vdc8563_set_rastering(1);
-				osd_set_visible_area(0,655,0,215);
+				set_visible_area(0,655,0,215);
 			} else {
 				vic2_set_rastering(1);
 				vdc8563_set_rastering(0);
-				osd_set_visible_area(0,335,0,215);
+				set_visible_area(0,335,0,215);
 			}
 			monitor=MONITOR_TV;
 		}
@@ -1469,39 +1375,4 @@ int c64_frame_interrupt (void)
 	}
 	set_led_status (1 /*KB_CAPSLOCK_FLAG */ , KEY_SHIFTLOCK ? 1 : 0);
 	set_led_status (0 /*KB_NUMLOCK_FLAG */ , JOYSTICK_SWAP ? 1 : 0);
-
-	return ignore_interrupt ();
 }
-
-void c64_state(void)
-{
-	char text[70];
-
-#if VERBOSE_DBG
-#if 0
-	cia6526_status (text, sizeof (text));
-	state_display_text (text);
-
-	snprintf (text, sizeof(text), "c64 vic:%.4x m6510:%d exrom:%d game:%d",
-			  c64_vicaddr - c64_memory, c64_port6510 & 7,
-			  c64_exrom, c64_game);
-	state_display_text (text);
-#endif
-
-	vdc8563_state();
-/*	state_display_text (text); */
-#endif
-
-	vc20_tape_status (text, sizeof (text));
-	state_display_text (text);
-#ifdef VC1541
-	vc1541_drive_status (text, sizeof (text));
-#else
-	cbm_drive_0_status (text, sizeof (text));
-#endif
-	state_display_text (text);
-
-	cbm_drive_1_status (text, sizeof (text));
-	state_display_text (text);
-}
-
