@@ -1,41 +1,43 @@
-/* ORIC driver */
+/*********************************************************************
 
-/* By:
+	machine/oric.c
 
+	Paul Cook
+	Kev Thacker
 
-  - Paul Cook
-  - Kev Thacker
+	Thankyou to Fabrice Frances for his ORIC documentation which helped with this driver
+	http://oric.ifrance.com/oric/
 
-  Thankyou to Fabrice Frances for his ORIC documentation which helped with this driver
-  http://oric.ifrance.com/oric/
+	TODO:
+	- there are problems loading some .wav's. Try to fix these.
+	- fix more graphics display problems
+	- check the printer works
+	- fix more disc drive/wd179x problems so more software will run
 
-  TODO:
-   - there are problems loading some .wav's. Try to fix these.
-   - fix more graphics display problems
-   - check the printer works
-   - fix more disc drive/wd179x problems so more software will run
-*/
+*********************************************************************/
 
 
 #include <stdio.h>
 #include "driver.h"
 #include "includes/oric.h"
-#include "includes/basicdsk.h"
 #include "includes/wd179x.h"
 #include "machine/6522via.h"
-#include "includes/mfmdisk.h"
+#include "machine/applefdc.h"
 #include "includes/6551.h"
 #include "includes/centroni.h"
-#include "printer.h"
-#include "formats/orictap.h"
+#include "devices/basicdsk.h"
+#include "devices/mfmdisk.h"
+#include "devices/printer.h"
+#include "devices/cassette.h"
+#include "sound/ay8910.h"
+#include "image.h"
+
+UINT8 *oric_ram;
 
 static int enable_logging = 0;
 /* static int save_done = 0; */
 
 
-/* timer used to refresh via cb input, which will trigger ints on pulses
-from tape */
-static void *oric_tape_timer = NULL;
 /* ==0 if oric1 or oric atmos, !=0 if telestrat */
 static int oric_is_telestrat = 0;
 
@@ -81,16 +83,14 @@ static void oric_refresh_ints(void)
 	/* any irq set? */
 	if ((oric_irqs & 0x0f)!=0)
 	{
-		cpu_set_irq_line(0,0, HOLD_LINE);
+		cpunum_set_input_line(0,0, HOLD_LINE);
 	}
 	else
 	{
-		cpu_set_irq_line(0,0, CLEAR_LINE);
+		cpunum_set_input_line(0,0, CLEAR_LINE);
 	}
 }
 
-static int oric_floppy_type[4] = {ORIC_FLOPPY_NONE, ORIC_FLOPPY_NONE, ORIC_FLOPPY_NONE, ORIC_FLOPPY_NONE};
-
 static	char *oric_ram_0x0c000 = NULL;
 
 
@@ -104,86 +104,8 @@ static char oric_keyboard_mask;
 
 static unsigned char oric_via_port_a_data;
 
-#define ORIC_DUMP_RAM
 
 
-#ifdef ORIC_DUMP_RAM
-static int previous_input_port5;
-#endif
-
-
-
-#ifdef ORIC_DUMP_RAM
-/* load image */
-void oric_dump_ram(void)
-{
-	void *file;
-
-	file = osd_fopen(Machine->gamedrv->name, "oricram.bin", OSD_FILETYPE_MEMCARD,OSD_FOPEN_WRITE);
-
-	if (file)
-	{
-		int i;
-		for (i=0; i<65536; i++)
-		{
-			char data;
-
-			data = cpu_readmem16(i);
-
-			osd_fwrite(file, &data, 1);
-
-		}
-
-		/* close file */
-		osd_fclose(file);
-	}
-}
-
-void    oric_dump_video(void)
-{
-        FILE *fh;
-
-        fh = fopen("e:\\oricvid.txt","wb");
-
-        if (fh!=NULL)
-        {
-                int i,j, addr;
-
-                addr = 0x08000;
-                for (j=0; j<1024; j++)
-                {
-
-			fprintf(fh,"%04x: ",addr);
-
-                for (i=0; i<16; i++)
-                {
-                  fprintf(fh,"%02x ",cpu_readmem16(addr+i));
-                }
-		    fprintf(fh,"   ");
-		    for (i=0; i<16; i++)
-			{
-				int code;
-
-				code = cpu_readmem16(addr+i);
-
-				if ((code<32) || (code>127))
-				{
-					code = '.';
-				}
-
-				fprintf(fh,"%c",code);
-			}
-			addr+=16;
-                fprintf(fh,"\r\n");
-
-                }
-
-
-                fclose(fh);
-        }
-}
-
-#endif
 /* refresh keyboard sense */
 static void oric_keyboard_sense_refresh(void)
 {
@@ -227,7 +149,7 @@ static void oric_keyboard_sense_refresh(void)
 
 
 /* this is executed when a write to psg port a is done */
-WRITE_HANDLER (oric_psg_porta_write)
+WRITE8_HANDLER (oric_psg_porta_write)
 {
 	oric_keyboard_mask = data;
 }
@@ -239,7 +161,7 @@ WRITE_HANDLER (oric_psg_porta_write)
 static char oric_psg_control;
 
 /* this port is also used to read printer data */
-READ_HANDLER ( oric_via_in_a_func )
+static  READ8_HANDLER ( oric_via_in_a_func )
 {
 	/*logerror("port a read\r\n"); */
 
@@ -260,7 +182,7 @@ READ_HANDLER ( oric_via_in_a_func )
 	return oric_via_port_a_data;
 }
 
-READ_HANDLER ( oric_via_in_b_func )
+static  READ8_HANDLER ( oric_via_in_b_func )
 {
 	int data;
 
@@ -301,7 +223,7 @@ static void oric_psg_connection_refresh(void)
 	}
 }
 
-WRITE_HANDLER ( oric_via_out_a_func )
+static WRITE8_HANDLER ( oric_via_out_a_func )
 {
 	oric_via_port_a_data = data;
 
@@ -336,20 +258,26 @@ PB7
 
  */
 
+
+static mess_image *cassette_device_image(void)
+{
+	return image_from_devtype_and_index(IO_CASSETTE, 0);
+}
+
 /* not called yet - this will update the via with the state of the tape data.
 This allows the via to trigger on bit changes and issue interrupts */
-static void    oric_refresh_tape(int dummy)
+static void oric_refresh_tape(int dummy)
 {
 	int data;
 	int input_port_9;
 
 	data = 0;
 
-	if (device_input(IO_CASSETTE,0) > 255)
-		data |=1;
+	if (cassette_input(cassette_device_image()) > 0.0038)
+		data |= 1;
 
 	/* "A simple cable to catch the vertical retrace signal !
-	 This cable connects the video output for the television/monitor
+		This cable connects the video output for the television/monitor
 	to the via cb1 input. Interrupts can be generated from the vertical
 	sync, and flicker free games can be produced */
 
@@ -361,28 +289,11 @@ static void    oric_refresh_tape(int dummy)
 		data = input_port_9>>4;
 	}
 
-    via_set_input_cb1(0, data);
-
-#ifdef ORIC_DUMP_RAM
-	{
-		int input_port_data = readinputport(0);
-
-		if (((previous_input_port5^input_port_data) & 0x01)!=0)
-		{
-			if (input_port_data & 0x01)
-			{
-				logerror("do dump");
-                                oric_dump_video();
-			}
-		}
-		previous_input_port5 = input_port_data;
-	}
-#endif
-
+	via_set_input_cb1(0, data);
 }
 
 static unsigned char previous_portb_data = 0;
-WRITE_HANDLER ( oric_via_out_b_func )
+static WRITE8_HANDLER ( oric_via_out_b_func )
 {
 	int printer_handshake;
 
@@ -394,15 +305,16 @@ WRITE_HANDLER ( oric_via_out_b_func )
 	if ((previous_portb_data^data) & (1<<6))
 	{
 		if (data & (1<<6))
-		{
-                        enable_logging = 1;
-		}
+			enable_logging = 1;
 	}
 
-	device_status(IO_CASSETTE, 0, ((data>>6) & 0x01));
+	cassette_change_state(
+		cassette_device_image(),
+		(data & 0x40) ? CASSETTE_MOTOR_ENABLED : CASSETTE_MOTOR_DISABLED,
+		CASSETTE_MOTOR_DISABLED);
 
 	/* cassette data out */
-	device_output(IO_CASSETTE, 0, (data & (1<<7)) ? -32768 : 32767);
+	cassette_output(cassette_device_image(), (data & (1<<7)) ? -1.0 : +1.0);
 
 
 	/* PRINTER STROBE */
@@ -448,17 +360,17 @@ static CENTRONICS_CONFIG oric_cent_config[1]={
 };
 
 
-READ_HANDLER ( oric_via_in_ca2_func )
+static  READ8_HANDLER ( oric_via_in_ca2_func )
 {
 	return oric_psg_control & 1;
 }
 
-READ_HANDLER ( oric_via_in_cb2_func )
+static  READ8_HANDLER ( oric_via_in_cb2_func )
 {
 	return (oric_psg_control>>1) & 1;
 }
 
-WRITE_HANDLER ( oric_via_out_ca2_func )
+static WRITE8_HANDLER ( oric_via_out_ca2_func )
 {
 	oric_psg_control &=~1;
 
@@ -470,7 +382,7 @@ WRITE_HANDLER ( oric_via_out_ca2_func )
 	oric_psg_connection_refresh();
 }
 
-WRITE_HANDLER ( oric_via_out_cb2_func )
+static WRITE8_HANDLER ( oric_via_out_cb2_func )
 {
 	oric_psg_control &=~2;
 
@@ -483,7 +395,7 @@ WRITE_HANDLER ( oric_via_out_cb2_func )
 }
 
 
-void	oric_via_irq_func(int state)
+static void	oric_via_irq_func(int state)
 {
 	oric_irqs &= ~(1<<0);
 
@@ -550,13 +462,11 @@ struct via6522_interface oric_6522_interface=
 	oric_via_in_cb2_func,
 	oric_via_out_a_func,
 	oric_via_out_b_func,
+	NULL,
+	NULL,
 	oric_via_out_ca2_func,
 	oric_via_out_cb2_func,
 	oric_via_irq_func,
-	NULL,
-	NULL,
-	NULL,
-	NULL
 };
 
 
@@ -573,44 +483,41 @@ disk interface rom accessed through 0x0320-0x03ff (read only)
 CALL &320 to start, or use BOBY rom.
 */
 
-extern READ_HANDLER ( apple2_c0xx_slot6_r );
-extern WRITE_HANDLER ( apple2_c0xx_slot6_w );
-extern void apple2_slot6_init(void);
-extern void apple2_slot6_stop(void);
-
-static READ_HANDLER(apple2_interface_r)
-{
-	/*logerror("apple 2 interface r: %04x\n",offset); */
-
-	return apple2_c0xx_slot6_r(offset & 0x0f);
-}
-
-static WRITE_HANDLER(apple2_interface_w)
-{
-	/*logerror("apple 2 interface w: %04x %02x\n",offset,data); */
-
-	apple2_c0xx_slot6_w(offset & 0x0f, data);
-}
-
 static void oric_install_apple2_interface(void)
 {
-	install_mem_read_handler(0, 0x0300, 0x030f, oric_IO_r);
-	install_mem_read_handler(0, 0x0310, 0x031f, apple2_interface_r);
-	install_mem_read_handler(0, 0x0320, 0x03ff, MRA_BANK4);
-
-	install_mem_write_handler(0, 0x0300, 0x030f, oric_IO_w);
-	install_mem_write_handler(0, 0x0310, 0x031f, apple2_interface_w);
-	cpu_setbank(4, 	memory_region(REGION_CPU1) + 0x014000 + 0x020);
+	memory_install_read8_handler(0, ADDRESS_SPACE_PROGRAM, 0x0300, 0x030f, 0, 0, oric_IO_r);
+	memory_install_read8_handler(0, ADDRESS_SPACE_PROGRAM, 0x0310, 0x031f, 0, 0, applefdc_r);
+	memory_install_read8_handler(0, ADDRESS_SPACE_PROGRAM, 0x0320, 0x03ff, 0, 0, MRA8_BANK4);
 
+	memory_install_write8_handler(0, ADDRESS_SPACE_PROGRAM, 0x0300, 0x030f, 0, 0, oric_IO_w);
+	memory_install_write8_handler(0, ADDRESS_SPACE_PROGRAM, 0x0310, 0x031f, 0, 0, applefdc_w);
+	memory_set_bankptr(4, 	memory_region(REGION_CPU1) + 0x014000 + 0x020);
 }
 
-#if 0
-static void oric_uninstall_apple2_interface(void)
+
+static void oric_enable_memory(int low, int high, int rd, int wr)
 {
-
-
+	int i;
+	for (i = low; i <= high; i++)
+	{
+		switch(i) {
+		case 1:
+			memory_install_read8_handler(0,  ADDRESS_SPACE_PROGRAM, 0xc000, 0xdfff, 0, 0, rd ? MRA8_BANK1 : MRA8_NOP);
+			memory_install_write8_handler(0, ADDRESS_SPACE_PROGRAM, 0xc000, 0xdfff, 0, 0, wr ? MWA8_BANK5 : MWA8_ROM);
+			break;
+		case 2:
+			memory_install_read8_handler(0,  ADDRESS_SPACE_PROGRAM, 0xe000, 0xf7ff, 0, 0, rd ? MRA8_BANK2 : MRA8_NOP);
+			memory_install_write8_handler(0, ADDRESS_SPACE_PROGRAM, 0xe000, 0xf7ff, 0, 0, wr ? MWA8_BANK6 : MWA8_ROM);
+			break;
+		case 3:
+			memory_install_read8_handler(0,  ADDRESS_SPACE_PROGRAM, 0xf800, 0xffff, 0, 0, rd ? MRA8_BANK3 : MRA8_NOP);
+			memory_install_write8_handler(0, ADDRESS_SPACE_PROGRAM, 0xf800, 0xffff, 0, 0, wr ? MWA8_BANK7 : MWA8_ROM);
+			break;
+		}
+	}
 }
-#endif
+
+
 
 /************************/
 /* APPLE 2 INTERFACE V2 */
@@ -624,14 +531,16 @@ v2 registers accessed through 0x0380-0x0383 (write only)
 CALL &320 to start, or use BOBY rom.
 */
 
-static WRITE_HANDLER(apple2_v2_interface_w)
+static WRITE8_HANDLER(apple2_v2_interface_w)
 {
 	/* data is ignored, address is used to decode operation */
 
 /*	logerror("apple 2 interface v2 rom page: %01x\n",(offset & 0x02)>>1); */
 
 	/* bit 0 is 0 for page 0, 1 for page 1 */
-	cpu_setbank(4, memory_region(REGION_CPU1) + 0x014000 + 0x0100 + (((offset & 0x02)>>1)<<8));
+	memory_set_bankptr(4, memory_region(REGION_CPU1) + 0x014000 + 0x0100 + (((offset & 0x02)>>1)<<8));
+
+	oric_enable_memory(1, 3, TRUE, TRUE);
 
 	/* bit 1 is 0, rom enabled, bit 1 is 1 ram enabled */
 	if ((offset & 0x01)==0)
@@ -641,39 +550,25 @@ static WRITE_HANDLER(apple2_v2_interface_w)
 		/* logerror("apple 2 interface v2: rom enabled\n"); */
 
 		/* enable rom */
-		memory_set_bankhandler_r(1, 0, MRA_BANK1);
-		memory_set_bankhandler_r(2, 0, MRA_BANK2);
-		memory_set_bankhandler_r(3, 0, MRA_BANK3);
-		memory_set_bankhandler_w(5, 0, MWA_BANK5);
-		memory_set_bankhandler_w(6, 0, MWA_BANK6);
-		memory_set_bankhandler_w(7, 0, MWA_BANK7);
-
 		rom_ptr = memory_region(REGION_CPU1) + 0x010000;
-		cpu_setbank(1, rom_ptr);
-		cpu_setbank(2, rom_ptr+0x02000);
-		cpu_setbank(3, rom_ptr+0x03800);
-		cpu_setbank(5, oric_ram_0x0c000);
-		cpu_setbank(6, oric_ram_0x0c000+0x02000);
-		cpu_setbank(7, oric_ram_0x0c000+0x03800);
+		memory_set_bankptr(1, rom_ptr);
+		memory_set_bankptr(2, rom_ptr+0x02000);
+		memory_set_bankptr(3, rom_ptr+0x03800);
+		memory_set_bankptr(5, oric_ram_0x0c000);
+		memory_set_bankptr(6, oric_ram_0x0c000+0x02000);
+		memory_set_bankptr(7, oric_ram_0x0c000+0x03800);
 	}
 	else
 	{
 		/*logerror("apple 2 interface v2: ram enabled\n"); */
 
 		/* enable ram */
-		memory_set_bankhandler_r(1, 0, MRA_BANK1);
-		memory_set_bankhandler_r(2, 0, MRA_BANK2);
-		memory_set_bankhandler_r(3, 0, MRA_BANK3);
-		memory_set_bankhandler_w(5, 0, MWA_BANK5);
-		memory_set_bankhandler_w(6, 0, MWA_BANK6);
-		memory_set_bankhandler_w(7, 0, MWA_BANK7);
-
-		cpu_setbank(1, oric_ram_0x0c000);
-		cpu_setbank(2, oric_ram_0x0c000+0x02000);
-		cpu_setbank(3, oric_ram_0x0c000+0x03800);
-		cpu_setbank(5, oric_ram_0x0c000);
-		cpu_setbank(6, oric_ram_0x0c000+0x02000);
-		cpu_setbank(7, oric_ram_0x0c000+0x03800);
+		memory_set_bankptr(1, oric_ram_0x0c000);
+		memory_set_bankptr(2, oric_ram_0x0c000+0x02000);
+		memory_set_bankptr(3, oric_ram_0x0c000+0x03800);
+		memory_set_bankptr(5, oric_ram_0x0c000);
+		memory_set_bankptr(6, oric_ram_0x0c000+0x02000);
+		memory_set_bankptr(7, oric_ram_0x0c000+0x03800);
 	}
 }
 
@@ -681,25 +576,17 @@ static WRITE_HANDLER(apple2_v2_interface_w)
 /* APPLE 2 INTERFACE V2 */
 static void oric_install_apple2_v2_interface(void)
 {
-	install_mem_read_handler(0, 0x0300, 0x030f, oric_IO_r);
-	install_mem_read_handler(0, 0x0310, 0x031f, apple2_interface_r);
-	install_mem_read_handler(0, 0x0320, 0x03ff, MRA_BANK4);
+	memory_install_read8_handler(0, ADDRESS_SPACE_PROGRAM, 0x0300, 0x030f, 0, 0, oric_IO_r);
+	memory_install_read8_handler(0, ADDRESS_SPACE_PROGRAM, 0x0310, 0x031f, 0, 0, applefdc_r);
+	memory_install_read8_handler(0, ADDRESS_SPACE_PROGRAM, 0x0320, 0x03ff, 0, 0, MRA8_BANK4);
 
-	install_mem_write_handler(0, 0x0300, 0x030f, oric_IO_w);
-	install_mem_write_handler(0, 0x0310, 0x031f, apple2_interface_w);
-	install_mem_write_handler(0, 0x0380, 0x0383, apple2_v2_interface_w);
+	memory_install_write8_handler(0, ADDRESS_SPACE_PROGRAM, 0x0300, 0x030f, 0, 0, oric_IO_w);
+	memory_install_write8_handler(0, ADDRESS_SPACE_PROGRAM, 0x0310, 0x031f, 0, 0, applefdc_w);
+	memory_install_write8_handler(0, ADDRESS_SPACE_PROGRAM, 0x0380, 0x0383, 0, 0, apple2_v2_interface_w);
 
 	apple2_v2_interface_w(0,0);
 }
 
-#if 0
-static void oric_uninstall_apple2_v2_interface(void)
-{
-
-
-}
-#endif
-
 /********************/
 /* JASMIN INTERFACE */
 
@@ -735,35 +622,25 @@ static void oric_jasmin_set_mem_0x0c000(void)
 			/* no it is disabled */
 			/*logerror("&c000-&ffff is os rom\n"); */
 
-			memory_set_bankhandler_r(1, 0, MRA_BANK1);
-			memory_set_bankhandler_r(2, 0, MRA_BANK2);
-			memory_set_bankhandler_r(3, 0, MRA_BANK3);
-			memory_set_bankhandler_w(5, 0, MWA_NOP);
-			memory_set_bankhandler_w(6, 0, MWA_NOP);
-			memory_set_bankhandler_w(7, 0, MWA_NOP);
+			oric_enable_memory(1, 3, TRUE, FALSE);
 
 			rom_ptr = memory_region(REGION_CPU1) + 0x010000;
-			cpu_setbank(1, rom_ptr);
-			cpu_setbank(2, rom_ptr+0x02000);
-			cpu_setbank(3, rom_ptr+0x03800);
+			memory_set_bankptr(1, rom_ptr);
+			memory_set_bankptr(2, rom_ptr+0x02000);
+			memory_set_bankptr(3, rom_ptr+0x03800);
 		}
 		else
 		{
 			/*logerror("&c000-&ffff is ram\n"); */
 
-			memory_set_bankhandler_r(1, 0, MRA_BANK1);
-			memory_set_bankhandler_r(2, 0, MRA_BANK2);
-			memory_set_bankhandler_r(3, 0, MRA_BANK3);
-			memory_set_bankhandler_w(5, 0, MWA_BANK5);
-			memory_set_bankhandler_w(6, 0, MWA_BANK6);
-			memory_set_bankhandler_w(7, 0, MWA_BANK7);
+			oric_enable_memory(1, 3, TRUE, TRUE);
 
-			cpu_setbank(1, oric_ram_0x0c000);
-			cpu_setbank(2, oric_ram_0x0c000+0x02000);
-			cpu_setbank(3, oric_ram_0x0c000+0x03800);
-			cpu_setbank(5, oric_ram_0x0c000);
-			cpu_setbank(6, oric_ram_0x0c000+0x02000);
-			cpu_setbank(7, oric_ram_0x0c000+0x03800);
+			memory_set_bankptr(1, oric_ram_0x0c000);
+			memory_set_bankptr(2, oric_ram_0x0c000+0x02000);
+			memory_set_bankptr(3, oric_ram_0x0c000+0x03800);
+			memory_set_bankptr(5, oric_ram_0x0c000);
+			memory_set_bankptr(6, oric_ram_0x0c000+0x02000);
+			memory_set_bankptr(7, oric_ram_0x0c000+0x03800);
 		}
 	}
 	else
@@ -775,27 +652,17 @@ static void oric_jasmin_set_mem_0x0c000(void)
 			/* overlay ram disabled */
 
 			/*logerror("&c000-&f8ff is nothing!\n"); */
-
-			memory_set_bankhandler_r(1, 0, MRA_NOP);
-			memory_set_bankhandler_r(2, 0, MRA_NOP);
-			memory_set_bankhandler_r(3, 0, MRA_NOP);
-			memory_set_bankhandler_w(5, 0, MWA_NOP);
-			memory_set_bankhandler_w(6, 0, MWA_NOP);
-			memory_set_bankhandler_w(7, 0, MWA_NOP);
+			oric_enable_memory(1, 2, FALSE, FALSE);
 		}
 		else
 		{
 			/*logerror("&c000-&f8ff is ram!\n"); */
+			oric_enable_memory(1, 2, TRUE, TRUE);
 
-			memory_set_bankhandler_r(1, 0, MRA_BANK1);
-			memory_set_bankhandler_r(2, 0, MRA_BANK2);
-			memory_set_bankhandler_w(5, 0, MWA_BANK5);
-			memory_set_bankhandler_w(6, 0, MWA_BANK6);
-
-			cpu_setbank(1, oric_ram_0x0c000);
-			cpu_setbank(2, oric_ram_0x0c000+0x02000);
-			cpu_setbank(5, oric_ram_0x0c000);
-			cpu_setbank(6, oric_ram_0x0c000+0x02000);
+			memory_set_bankptr(1, oric_ram_0x0c000);
+			memory_set_bankptr(2, oric_ram_0x0c000+0x02000);
+			memory_set_bankptr(5, oric_ram_0x0c000);
+			memory_set_bankptr(6, oric_ram_0x0c000+0x02000);
 		}
 
 		{
@@ -804,11 +671,10 @@ static void oric_jasmin_set_mem_0x0c000(void)
 
 			/*logerror("&f800-&ffff is jasmin rom\n"); */
 			/* jasmin rom enabled */
-			memory_set_bankhandler_r(3, 0, MRA_BANK3);
-			memory_set_bankhandler_w(7, 0, MWA_BANK7);
+			oric_enable_memory(3, 3, TRUE, TRUE);
 			rom_ptr = memory_region(REGION_CPU1) + 0x010000+0x04000+0x02000;
-			cpu_setbank(3, rom_ptr);
-			cpu_setbank(7, rom_ptr);
+			memory_set_bankptr(3, rom_ptr);
+			memory_set_bankptr(7, rom_ptr);
 		}
 	}
 }
@@ -839,7 +705,7 @@ static void oric_jasmin_wd179x_callback(int State)
 	}
 }
 
-static READ_HANDLER (oric_jasmin_r)
+static  READ8_HANDLER (oric_jasmin_r)
 {
 	unsigned char data = 0x0ff;
 
@@ -859,8 +725,8 @@ static READ_HANDLER (oric_jasmin_r)
 			data = wd179x_data_r(0);
 			break;
 		default:
-			logerror("unhandled io read: %04x %02x\n",offset);
 			data = via_0_r(offset & 0x0f);
+			logerror("unhandled io read: %04x %02x\n", offset, data);
 			break;
 
 	}
@@ -868,7 +734,7 @@ static READ_HANDLER (oric_jasmin_r)
 	return data;
 }
 
-static WRITE_HANDLER(oric_jasmin_w)
+static WRITE8_HANDLER(oric_jasmin_w)
 {
 	switch (offset & 0x0f)
 	{
@@ -895,12 +761,12 @@ static WRITE_HANDLER(oric_jasmin_w)
 			wd179x_reset();
 			break;
 		case 0x0a:
-			logerror("jasmin overlay ram w: %02x PC: %04x\n",data,cpu_get_pc());
+			logerror("jasmin overlay ram w: %02x PC: %04x\n",data,activecpu_get_pc());
 			port_3fa_w = data;
 			oric_jasmin_set_mem_0x0c000();
 			break;
 		case 0x0b:
-			logerror("jasmin romdis w: %02x PC: %04x\n",data,cpu_get_pc());
+			logerror("jasmin romdis w: %02x PC: %04x\n",data,activecpu_get_pc());
 			port_3fb_w = data;
 			oric_jasmin_set_mem_0x0c000();
 			break;
@@ -925,11 +791,11 @@ static void oric_install_jasmin_interface(void)
 	port_3fb_w = 1;
 	oric_jasmin_set_mem_0x0c000();
 
-	install_mem_read_handler(0,0x0300, 0x03ef, oric_IO_r);
-	install_mem_read_handler(0,0x03f0, 0x03ff, oric_jasmin_r);
+	memory_install_read8_handler(0, ADDRESS_SPACE_PROGRAM, 0x0300, 0x03ef, 0, 0, oric_IO_r);
+	memory_install_read8_handler(0, ADDRESS_SPACE_PROGRAM, 0x03f0, 0x03ff, 0, 0, oric_jasmin_r);
 
-	install_mem_write_handler(0,0x0300, 0x03ef, oric_IO_w);
-	install_mem_write_handler(0,0x03f0, 0x03ff, oric_jasmin_w);
+	memory_install_write8_handler(0, ADDRESS_SPACE_PROGRAM, 0x0300, 0x03ef, 0, 0, oric_IO_w);
+	memory_install_write8_handler(0, ADDRESS_SPACE_PROGRAM, 0x03f0, 0x03ff, 0, 0, oric_jasmin_w);
 }
 
 /*********************************/
@@ -1002,7 +868,7 @@ static void oric_microdisc_wd179x_callback(int State)
 }
 
 
-void	oric_microdisc_set_mem_0x0c000(void)
+static void	oric_microdisc_set_mem_0x0c000(void)
 {
 	if (oric_is_telestrat)
 		return;
@@ -1014,21 +880,19 @@ void	oric_microdisc_set_mem_0x0c000(void)
 	{
 		/*logerror("&c000-&dfff is ram\n"); */
 		/* rom disabled enable ram */
-		memory_set_bankhandler_r(1, 0, MRA_BANK1);
-		memory_set_bankhandler_w(5, 0, MWA_BANK5);
-		cpu_setbank(1, oric_ram_0x0c000);
-		cpu_setbank(5, oric_ram_0x0c000);
+		oric_enable_memory(1, 1, TRUE, TRUE);
+		memory_set_bankptr(1, oric_ram_0x0c000);
+		memory_set_bankptr(5, oric_ram_0x0c000);
 	}
 	else
 	{
 		unsigned char *rom_ptr;
 		/*logerror("&c000-&dfff is os rom\n"); */
 		/* basic rom */
-		memory_set_bankhandler_r(1, 0, MRA_BANK1);
-		memory_set_bankhandler_w(5, 0, MWA_NOP);
+		oric_enable_memory(1, 1, TRUE, FALSE);
 		rom_ptr = memory_region(REGION_CPU1) + 0x010000;
-		cpu_setbank(1, rom_ptr);
-		cpu_setbank(5, rom_ptr);
+		memory_set_bankptr(1, rom_ptr);
+		memory_set_bankptr(5, rom_ptr);
 	}
 
 	/* for 0x0e000-0x0ffff */
@@ -1038,15 +902,12 @@ void	oric_microdisc_set_mem_0x0c000(void)
 		unsigned char *rom_ptr;
 		/*logerror("&e000-&ffff is os rom\n"); */
 		/* basic rom */
-		memory_set_bankhandler_r(2, 0, MRA_BANK2);
-		memory_set_bankhandler_r(3, 0, MRA_BANK3);
-		memory_set_bankhandler_w(6, 0, MWA_NOP);
-		memory_set_bankhandler_w(7, 0, MWA_NOP);
+		oric_enable_memory(2, 3, TRUE, FALSE);
 		rom_ptr = memory_region(REGION_CPU1) + 0x010000;
-		cpu_setbank(2, rom_ptr+0x02000);
-		cpu_setbank(3, rom_ptr+0x03800);
-		cpu_setbank(6, rom_ptr+0x02000);
-		cpu_setbank(7, rom_ptr+0x03800);
+		memory_set_bankptr(2, rom_ptr+0x02000);
+		memory_set_bankptr(3, rom_ptr+0x03800);
+		memory_set_bankptr(6, rom_ptr+0x02000);
+		memory_set_bankptr(7, rom_ptr+0x03800);
 
 	}
 	else
@@ -1056,34 +917,28 @@ void	oric_microdisc_set_mem_0x0c000(void)
 		{
 			unsigned char *rom_ptr;
 			/*logerror("&e000-&ffff is disk rom\n"); */
-			memory_set_bankhandler_r(2, 0, MRA_BANK2);
-			memory_set_bankhandler_r(3, 0, MRA_BANK3);
-			memory_set_bankhandler_w(6, 0, MWA_NOP);
-			memory_set_bankhandler_w(7, 0, MWA_NOP);
+			oric_enable_memory(2, 3, TRUE, FALSE);
 			/* enable rom of microdisc interface */
 			rom_ptr = memory_region(REGION_CPU1) + 0x014000;
-			cpu_setbank(2, rom_ptr);
-			cpu_setbank(3, rom_ptr+0x01800);
+			memory_set_bankptr(2, rom_ptr);
+			memory_set_bankptr(3, rom_ptr+0x01800);
 		}
 		else
 		{
 			/*logerror("&e000-&ffff is ram\n"); */
 			/* rom disabled enable ram */
-			memory_set_bankhandler_r(2, 0, MRA_BANK2);
-			memory_set_bankhandler_r(3, 0, MRA_BANK3);
-			memory_set_bankhandler_w(6, 0, MWA_BANK6);
-			memory_set_bankhandler_w(7, 0, MWA_BANK7);
-			cpu_setbank(2, oric_ram_0x0c000+0x02000);
-			cpu_setbank(3, oric_ram_0x0c000+0x03800);
-			cpu_setbank(6, oric_ram_0x0c000+0x02000);
-			cpu_setbank(7, oric_ram_0x0c000+0x03800);
+			oric_enable_memory(2, 3, TRUE, TRUE);
+			memory_set_bankptr(2, oric_ram_0x0c000+0x02000);
+			memory_set_bankptr(3, oric_ram_0x0c000+0x03800);
+			memory_set_bankptr(6, oric_ram_0x0c000+0x02000);
+			memory_set_bankptr(7, oric_ram_0x0c000+0x03800);
 		}
 	}
 }
 
 
 
-static READ_HANDLER (oric_microdisc_r)
+READ8_HANDLER (oric_microdisc_r)
 {
 	unsigned char data = 0x0ff;
 
@@ -1120,7 +975,7 @@ static READ_HANDLER (oric_microdisc_r)
 	return data;
 }
 
-static WRITE_HANDLER(oric_microdisc_w)
+WRITE8_HANDLER(oric_microdisc_w)
 {
 	switch (offset & 0x0ff)
 	{
@@ -1175,13 +1030,13 @@ static WRITE_HANDLER(oric_microdisc_w)
 
 static void oric_install_microdisc_interface(void)
 {
-	install_mem_read_handler(0,0x0300, 0x030f, oric_IO_r);
-	install_mem_read_handler(0,0x0310, 0x031f, oric_microdisc_r);
-	install_mem_read_handler(0,0x0320, 0x03ff, oric_IO_r);
+	memory_install_read8_handler(0, ADDRESS_SPACE_PROGRAM, 0x0300, 0x030f, 0, 0, oric_IO_r);
+	memory_install_read8_handler(0, ADDRESS_SPACE_PROGRAM, 0x0310, 0x031f, 0, 0, oric_microdisc_r);
+	memory_install_read8_handler(0, ADDRESS_SPACE_PROGRAM, 0x0320, 0x03ff, 0, 0, oric_IO_r);
 
-	install_mem_write_handler(0,0x0300, 0x030f, oric_IO_w);
-	install_mem_write_handler(0,0x0310, 0x031f, oric_microdisc_w);
-	install_mem_write_handler(0,0x0320, 0x03ff, oric_IO_w);
+	memory_install_write8_handler(0, ADDRESS_SPACE_PROGRAM, 0x0300, 0x030f, 0, 0, oric_IO_w);
+	memory_install_write8_handler(0, ADDRESS_SPACE_PROGRAM, 0x0310, 0x031f, 0, 0, oric_microdisc_w);
+	memory_install_write8_handler(0, ADDRESS_SPACE_PROGRAM, 0x0320, 0x03ff, 0, 0, oric_IO_w);
 
 	/* disable os rom, enable microdisc rom */
 	/* 0x0c000-0x0dfff will be ram, 0x0e000-0x0ffff will be microdisc rom */
@@ -1212,67 +1067,41 @@ static void oric_wd179x_callback(int State)
 	}
 }
 
-int oric_floppy_init(int id)
+DEVICE_INIT( oric_floppy )
 {
-	int result;
+	/* TODO - THIS DOES NOT MULTITASK BETWEEN ORIC BASICDSKs AND MFM DISKS */
+	return floppy_drive_init(image, NULL);
+}
 
-	if (device_filename(IO_FLOPPY, id)==NULL)
-		return INIT_PASS;
 
+
+DEVICE_LOAD( oric_floppy )
+{
 	/* attempt to open mfm disk */
-	result = mfm_disk_floppy_init(id);
-
-	if (result==INIT_PASS)
+	if (device_load_mfm_disk(image, file) == INIT_PASS)
 	{
-		oric_floppy_type[id] = ORIC_FLOPPY_MFM_DISK;
-
+		floppy_drive_set_disk_image_interface(image, &mfm_disk_floppy_interface);
 		return INIT_PASS;
 	}
 
-	if (basicdsk_floppy_init(id))
+	if (device_load_basicdsk_floppy(image, file) == INIT_PASS)
 	{
 		/* I don't know what the geometry of the disc image should be, so the
 		default is 80 tracks, 2 sides, 9 sectors per track */
-		basicdsk_set_geometry(id, 80, 2, 9, 512, 1, 0);
-
-		oric_floppy_type[id] = ORIC_FLOPPY_BASIC_DISK;
-
+		basicdsk_set_geometry(image, 80, 2, 9, 512, 1, 0, FALSE);
+		floppy_drive_set_disk_image_interface(image, &basicdsk_floppy_interface);
 		return INIT_PASS;
 	}
-
 	return INIT_FAIL;
 }
 
-void	oric_floppy_exit(int id)
-{
-	switch (oric_floppy_type[id])
-	{
-		case ORIC_FLOPPY_MFM_DISK:
-		{
-			mfm_disk_floppy_exit(id);
-		}
-		break;
-
-		case ORIC_FLOPPY_BASIC_DISK:
-		{
-			basicdsk_floppy_exit(id);
-		}
-		break;
-
-		default:
-			break;
-	}
-
-	oric_floppy_type[id] = ORIC_FLOPPY_NONE;
-}
-
-void oric_common_init_machine(void)
+static void oric_common_init_machine(void)
 {
     /* clear all irqs */
 	oric_irqs = 0;
 	oric_ram_0x0c000 = NULL;
 
-    oric_tape_timer = timer_pulse(TIME_IN_HZ(4800), 0, oric_refresh_tape);
+    timer_pulse(TIME_IN_HZ(4800), 0, oric_refresh_tape);
 
 	via_reset();
 	via_config(0, &oric_6522_interface);
@@ -1282,15 +1111,9 @@ void oric_common_init_machine(void)
 	/* assumption: select is tied low */
 	centronics_write_handshake(0, CENTRONICS_SELECT | CENTRONICS_NO_RESET, CENTRONICS_SELECT| CENTRONICS_NO_RESET);
     via_set_input_ca1(0, 1);
-
-
-#ifdef ORIC_DUMP_RAM
-	previous_input_port5 = readinputport(5);
-#endif
 }
 
-
-void oric_init_machine (void)
+MACHINE_INIT( oric )
 {
 	int disc_interface_id;
 
@@ -1298,7 +1121,7 @@ void oric_init_machine (void)
 	
 	oric_is_telestrat = 0;
 
-	oric_ram_0x0c000 = malloc(16384);
+	oric_ram_0x0c000 = auto_malloc(16384);
 
 	disc_interface_id = readinputport(9) & 0x07;
 
@@ -1313,19 +1136,14 @@ void oric_init_machine (void)
 			unsigned char *rom_ptr;
 
 			/* os rom */
-			memory_set_bankhandler_r(1, 0, MRA_BANK1);
-			memory_set_bankhandler_r(2, 0, MRA_BANK2);
-			memory_set_bankhandler_r(3, 0, MRA_BANK3);
-			memory_set_bankhandler_w(5, 0, MWA_NOP);
-			memory_set_bankhandler_w(6, 0, MWA_NOP);
-			memory_set_bankhandler_w(7, 0, MWA_NOP);
+			oric_enable_memory(1, 3, TRUE, FALSE);
 			rom_ptr = memory_region(REGION_CPU1) + 0x010000;
-			cpu_setbank(1, rom_ptr);
-			cpu_setbank(2, rom_ptr+0x02000);
-			cpu_setbank(3, rom_ptr+0x03800);
-			cpu_setbank(5, rom_ptr);
-			cpu_setbank(6, rom_ptr+0x02000);
-			cpu_setbank(7, rom_ptr+0x03800);
+			memory_set_bankptr(1, rom_ptr);
+			memory_set_bankptr(2, rom_ptr+0x02000);
+			memory_set_bankptr(3, rom_ptr+0x03800);
+			memory_set_bankptr(5, rom_ptr);
+			memory_set_bankptr(6, rom_ptr+0x02000);
+			memory_set_bankptr(7, rom_ptr+0x03800);
 
 
 			if (disc_interface_id==ORIC_FLOPPY_INTERFACE_APPLE2)
@@ -1334,8 +1152,8 @@ void oric_init_machine (void)
 			}
 			else
 			{
-				install_mem_read_handler(0,0x0300, 0x03ff, oric_IO_r);
-				install_mem_write_handler(0,0x0300, 0x03ff, oric_IO_w);
+				memory_install_read8_handler(0, ADDRESS_SPACE_PROGRAM, 0x0300, 0x03ff, 0, 0, oric_IO_r);
+				memory_install_write8_handler(0, ADDRESS_SPACE_PROGRAM, 0x0300, 0x03ff, 0, 0, oric_IO_w);
 			}
 		}
 		break;
@@ -1362,33 +1180,11 @@ void oric_init_machine (void)
 
 
 	wd179x_init(WD_TYPE_179X,oric_wd179x_callback);
-
-	apple2_slot6_init();
-
-}
-
-void oric_shutdown_machine (void)
-{
-#ifdef ORIC_DUMP_RAM
-	oric_dump_ram();
-#endif
-
-	if (oric_ram_0x0c000)
-		free(oric_ram_0x0c000);
-	oric_ram_0x0c000 = NULL;
-	wd179x_exit();
-
-	if (oric_tape_timer)
-	{
-		timer_remove(oric_tape_timer);
-		oric_tape_timer = NULL;
-	}
-
-	apple2_slot6_stop();
 }
 
 
-READ_HANDLER ( oric_IO_r )
+
+READ8_HANDLER ( oric_IO_r )
 {
 #if 0
 	switch (readinputport(9) & 0x07)
@@ -1420,14 +1216,14 @@ READ_HANDLER ( oric_IO_r )
 	{
 		if ((offset & 0x0f)!=0x0d)
 		{
-			logerror("via 0 r: %04x %04x\n",offset,cpunum_get_pc(0)); 
+			logerror("via 0 r: %04x %04x\n",offset, (unsigned) cpunum_get_reg(0, REG_PC)); 
 		}
 	}
 	/* it is repeated */
 	return via_0_r(offset & 0x0f);
 }
 
-WRITE_HANDLER ( oric_IO_w )
+WRITE8_HANDLER ( oric_IO_w )
 {
 #if 0
 	switch (readinputport(9) & 0x07)
@@ -1460,151 +1256,13 @@ WRITE_HANDLER ( oric_IO_w )
 #endif
 	if (enable_logging)
 	{
-		logerror("via 0 w: %04x %02x %04x\n",offset,data,cpunum_get_pc(0)); 
+		logerror("via 0 w: %04x %02x %04x\n",offset,data,(unsigned) cpunum_get_reg(0, REG_PC)); 
 	}
 
 	via_0_w(offset & 0x0f,data);
 }
 
 
-int oric_cassette_init(int id)
-{
-	void *file;
-	struct wave_args wa;
-
-	if (device_filename(IO_CASSETTE, id)==NULL)
-		return INIT_PASS;
-
-
-	file = image_fopen(IO_CASSETTE, id, OSD_FILETYPE_IMAGE, OSD_FOPEN_READ);
-	if( file )
-	{
-		int oric_tap_size;
-
-		/* get size of .tap file */
-		oric_tap_size = osd_fsize(file);
-
-		logerror("oric .tap size: %04x\n",oric_tap_size);
-
-		if (oric_tap_size!=0)
-		{
-			UINT8 *oric_tap_data;
-
-			/* allocate a temporary buffer to hold .tap image */
-			/* this is used to calculate the number of samples that would be filled when this
-			file is converted */
-			oric_tap_data = (UINT8 *)malloc(oric_tap_size);
-
-			if (oric_tap_data!=NULL)
-			{
-				/* number of samples to generate */
-				int size_in_samples;
-
-				/* read data into temporary buffer */
-				osd_fread(file, oric_tap_data, oric_tap_size);
-
-				/* calculate size in samples */
-				size_in_samples = oric_cassette_calculate_size_in_samples(oric_tap_size, oric_tap_data);
-
-				/* seek back to start */
-				osd_fseek(file, 0, SEEK_SET);
-
-				/* free temporary buffer */
-				free(oric_tap_data);
-
-				/* size of data in samples */
-				logerror("size in samples: %d\n",size_in_samples);
-
-
-				/* 30000, 416 */
-
-				/* internal calculation used in wave.c:
-
-				length =
-					wa->header_samples +
-					((osd_fsize(w->file) + wa->chunk_size - 1) / wa->chunk_size) * wa->chunk_samples +
-					wa->trailer_samples;
-				*/
-
-
-				memset(&wa, 0, sizeof(&wa));
-				wa.file = file;
-				wa.chunk_size = oric_tap_size;
-				wa.chunk_samples = size_in_samples;
-                                wa.smpfreq = ORIC_WAV_FREQUENCY;
-				wa.fill_wave = oric_cassette_fill_wave;
-				wa.header_samples = ORIC_WAVESAMPLES_HEADER;
-				wa.trailer_samples = ORIC_WAVESAMPLES_TRAILER;
-				wa.display = 1;
-				if( device_open(IO_CASSETTE,id,0,&wa) )
-					return INIT_FAIL;
-
-				return INIT_PASS;
-			}
-
-			return INIT_FAIL;
-		}
-	}
-
-	file = image_fopen(IO_CASSETTE, id, OSD_FILETYPE_IMAGE, OSD_FOPEN_RW_CREATE);
-	if( file )
-    {
-		memset(&wa, 0, sizeof(&wa));
-		wa.file = file;
-		wa.display = 1;
-		wa.smpfreq = 19200;
-		if( device_open(IO_CASSETTE,id,1,&wa) )
-            return INIT_FAIL;
-
-		/* immediately inhibit/mute/play the output */
-     /*   device_status(IO_CASSETTE,id, WAVE_STATUS_MOTOR_ENABLE|WAVE_STATUS_MUTED|WAVE_STATUS_MOTOR_INHIBIT); */
-		return INIT_PASS;
-    }
-
-	return INIT_FAIL;
-}
-#if 0
-
-int oric_cassette_init(int id)
-{
-	void *file;
-
-	file = image_fopen(IO_CASSETTE, id, OSD_FILETYPE_IMAGE, OSD_FOPEN_READ);
-	if (file)
-	{
-		struct wave_args wa = {0,};
-		wa.file = file;
-		wa.display = 1;
-
-		if (device_open(IO_CASSETTE, id, 0, &wa))
-			return INIT_FAIL;
-
-		return INIT_PASS;
-	}
-
-	/* HJB 02/18: no file, create a new file instead */
-	file = image_fopen(IO_CASSETTE, id, OSD_FILETYPE_IMAGE, OSD_FOPEN_WRITE);
-	if (file)
-	{
-		struct wave_args wa = {0,};
-		wa.file = file;
-		wa.display = 1;
-		wa.smpfreq = 22050; /* maybe 11025 Hz would be sufficient? */
-		/* open in write mode */
-        if (device_open(IO_CASSETTE, id, 1, &wa))
-            return INIT_FAIL;
-		return INIT_PASS;
-    }
-
-	return INIT_FAIL;
-}
-#endif
-
-void oric_cassette_exit(int id)
-{
-	device_close(IO_CASSETTE, id);
-}
-
 
 /**** TELESTRAT ****/
 
@@ -1678,45 +1336,50 @@ static struct telestrat_mem_block	telestrat_blocks[8];
 
 static void	telestrat_refresh_mem(void)
 {
+	read8_handler rh;
+	write8_handler wh;
+
 	struct telestrat_mem_block *mem_block = &telestrat_blocks[telestrat_bank_selection];
 
 	switch (mem_block->MemType)
 	{
 		case TELESTRAT_MEM_BLOCK_RAM:
 		{
-			memory_set_bankhandler_r(1, 0, MRA_BANK1);
-			memory_set_bankhandler_w(2, 0, MWA_BANK2);
-			cpu_setbank(1, mem_block->ptr);
-			cpu_setbank(2, mem_block->ptr);
+			rh = MRA8_BANK1;
+			wh = MWA8_BANK2;
+			memory_set_bankptr(1, mem_block->ptr);
+			memory_set_bankptr(2, mem_block->ptr);
 		}
 		break;
 
 		case TELESTRAT_MEM_BLOCK_ROM:
 		{
-			memory_set_bankhandler_r(1, 0, MRA_BANK1);
-			memory_set_bankhandler_w(2, 0, MWA_NOP);
-			cpu_setbank(1, mem_block->ptr);
+			rh = MRA8_BANK1;
+			wh = MWA8_NOP;
+			memory_set_bankptr(1, mem_block->ptr);
 		}
 		break;
 
 		default:
 		case TELESTRAT_MEM_BLOCK_UNDEFINED:
 		{
-			memory_set_bankhandler_r(1, 0, MRA_NOP);
-			memory_set_bankhandler_w(2, 0, MWA_NOP);
+			rh = MRA8_NOP;
+			wh = MWA8_NOP;
 		}
 		break;
 	}
+	memory_install_read8_handler(0, ADDRESS_SPACE_PROGRAM, 0xc000, 0xffff, 0, 0, rh);
+	memory_install_write8_handler(0, ADDRESS_SPACE_PROGRAM, 0xc000, 0xffff, 0, 0, wh);
 }
 
-static READ_HANDLER(telestrat_via2_in_a_func)
+static  READ8_HANDLER(telestrat_via2_in_a_func)
 {
 	logerror("via 2 - port a %02x\n",telestrat_via2_port_a_data);
 	return telestrat_via2_port_a_data;
 }
 
 
-static WRITE_HANDLER(telestrat_via2_out_a_func)
+static WRITE8_HANDLER(telestrat_via2_out_a_func)
 {
 	logerror("via 2 - port a w: %02x\n",data);
 
@@ -1730,7 +1393,7 @@ static WRITE_HANDLER(telestrat_via2_out_a_func)
 	}
 }
 
-static READ_HANDLER(telestrat_via2_in_b_func)
+static  READ8_HANDLER(telestrat_via2_in_b_func)
 {
 	unsigned char data = 0x01f;
 
@@ -1751,13 +1414,13 @@ static READ_HANDLER(telestrat_via2_in_b_func)
 	return data;
 }
 
-static WRITE_HANDLER(telestrat_via2_out_b_func)
+static WRITE8_HANDLER(telestrat_via2_out_b_func)
 {
 	telestrat_via2_port_b_data = data;
 }
 
 
-void	telestrat_via2_irq_func(int state)
+static void	telestrat_via2_irq_func(int state)
 {
     oric_irqs &=~(1<<2);
 
@@ -1782,13 +1445,12 @@ struct via6522_interface telestrat_via2_interface=
 	telestrat_via2_out_b_func,
 	NULL,
 	NULL,
+	NULL,
+	NULL,
 	telestrat_via2_irq_func,
-	NULL,
-	NULL,
-	NULL,
-	NULL
 };
 
+#if 0
 /* interrupt state from acia6551 */
 static void telestrat_acia_callback(int irq_state)
 {
@@ -1801,8 +1463,9 @@ static void telestrat_acia_callback(int irq_state)
 
 	oric_refresh_ints();
 }
+#endif
 
-void telestrat_init_machine(void)
+MACHINE_INIT( telestrat )
 {
 	oric_common_init_machine();
 
@@ -1810,19 +1473,19 @@ void telestrat_init_machine(void)
 
 	/* initialise overlay ram */
 	telestrat_blocks[0].MemType = TELESTRAT_MEM_BLOCK_RAM;
-	telestrat_blocks[0].ptr = (unsigned char *)malloc(16384);
+	telestrat_blocks[0].ptr = (unsigned char *) auto_malloc(16384);
 
 	telestrat_blocks[1].MemType = TELESTRAT_MEM_BLOCK_RAM;
-	telestrat_blocks[1].ptr = (unsigned char *)malloc(16384);
+	telestrat_blocks[1].ptr = (unsigned char *) auto_malloc(16384);
 	telestrat_blocks[2].MemType = TELESTRAT_MEM_BLOCK_RAM;
-	telestrat_blocks[2].ptr = (unsigned char *)malloc(16384);
+	telestrat_blocks[2].ptr = (unsigned char *) auto_malloc(16384);
 
 	/* initialise default cartridge */
 	telestrat_blocks[3].MemType = TELESTRAT_MEM_BLOCK_ROM;
 	telestrat_blocks[3].ptr = memory_region(REGION_CPU1)+0x010000;
 
 	telestrat_blocks[4].MemType = TELESTRAT_MEM_BLOCK_RAM;
-	telestrat_blocks[4].ptr = (unsigned char *)malloc(16384);
+	telestrat_blocks[4].ptr = (unsigned char *) auto_malloc(16384);
 
 	/* initialise default cartridge */
 	telestrat_blocks[5].MemType = TELESTRAT_MEM_BLOCK_ROM;
@@ -1850,85 +1513,3 @@ void telestrat_init_machine(void)
 
 	wd179x_init(WD_TYPE_179X,oric_wd179x_callback);
 }
-
-void	telestrat_shutdown_machine(void)
-{
-	int i;
-
-	/* this supports different cartridges now. In the init machine
-	a cartridge is hard-coded, but if other cartridges exist it could
-	be changed above */
-	for (i=0; i<8; i++)
-	{
-		if (telestrat_blocks[i].MemType == TELESTRAT_MEM_BLOCK_RAM)
-		{
-			if (telestrat_blocks[i].ptr!=NULL)
-			{
-				free(telestrat_blocks[i].ptr);
-				telestrat_blocks[i].ptr = NULL;
-			}
-		}
-	}
-
-	oric_shutdown_machine();
-
-	acia_6551_stop();
-}
-
-
-WRITE_HANDLER(telestrat_IO_w)
-{
-	if (offset<0x010)
-	{
-		via_0_w(offset & 0x0f,data);
-		return;
-	}
-
-	if ((offset>=0x020) && (offset<=0x02f))
-	{
-		via_1_w(offset & 0x0f,data);
-		return;
-	}
-
-	if ((offset>=0x010) && (offset<=0x01b))
-	{
-		oric_microdisc_w(offset & 0x0f, data);
-		return;
-	}
-
-	if ((offset>=0x01c) && (offset<=0x01f))
-	{
-		acia_6551_w(offset, data);
-		return;
-	}
-
-	logerror("null write %04x %02x\n",offset,data);
-
-}
-
-READ_HANDLER(telestrat_IO_r)
-{
-	if (offset<0x010)
-	{
-		return via_0_r(offset & 0x0f);
-	}
-
-	if ((offset>=0x020) && (offset<=0x02f))
-	{
-		return via_1_r(offset & 0x0f);
-	}
-
-	if ((offset>=0x010) && (offset<=0x01b))
-	{
-		return oric_microdisc_r(offset & 0x0f);
-	}
-
-	if ((offset>=0x01c) && (offset<=0x01f))
-	{
-		return acia_6551_r(offset);
-	}
-
-	logerror("null read %04x\n",offset);
-	return 0x0ff;
-}
-
