@@ -1,6 +1,6 @@
 /***************************************************************************
 
-  machine.c
+  mess/machine/spectrum.c
 
   Functions to emulate general aspects of the machine (RAM, ROM, interrupts,
   I/O ports)
@@ -29,159 +29,113 @@
 #include "includes/spectrum.h"
 #include "eventlst.h"
 #include "vidhrdw/border.h"
-#include "cassette.h"
+#include "devices/cassette.h"
+#include "devices/cartslot.h"
+#include "sound/ay8910.h"
+#include "image.h"
+#include "utils.h"
 
 #ifndef MIN
 #define MIN(x,y) ((x)<(y)?(x):(y))
 #endif
 
-static unsigned char *pSnapshotData = NULL;
-static unsigned long SnapshotDataSize = 0;
 static unsigned long TapePosition = 0;
 static void spectrum_setup_sna(unsigned char *pSnapshot, unsigned long SnapshotSize);
 static void spectrum_setup_z80(unsigned char *pSnapshot, unsigned long SnapshotSize);
-/*static int is48k_z80snapshot(unsigned char *pSnapshot, unsigned long SnapshotSize); */
-static OPBASE_HANDLER(spectrum_opbaseoverride);
-static OPBASE_HANDLER(spectrum_tape_opbaseoverride);
+static void spectrum_setup_sp(unsigned char *pSnapshot, unsigned long SnapshotSize);
+static int spectrum_setup_tap(offs_t address, UINT8 *snapshot_data, int snapshot_length);
 
 TIMEX_CART_TYPE timex_cart_type = TIMEX_CART_NONE;
 UINT8 timex_cart_chunks = 0x00;
 UINT8 * timex_cart_data;
+static UINT8 *cassette_snapshot;
+static int cassette_snapshot_size;
 
 typedef enum
 {
 	SPECTRUM_SNAPSHOT_NONE,
 	SPECTRUM_SNAPSHOT_SNA,
 	SPECTRUM_SNAPSHOT_Z80,
+	SPECTRUM_SNAPSHOT_SP,
 	SPECTRUM_TAPEFILE_TAP
 }
 SPECTRUM_SNAPSHOT_TYPE;
 
-static SPECTRUM_SNAPSHOT_TYPE spectrum_snapshot_type = SPECTRUM_SNAPSHOT_NONE;
-
-static struct
-{
-	const char *name;
-	unsigned short addr;
-	UINT8 *data;
-	int length;
-} quick;
-
-void spectrum_init_machine(void)
-{
-	if (pSnapshotData != NULL)
-	{
-		if (spectrum_snapshot_type == SPECTRUM_TAPEFILE_TAP)
-		{
-			logerror(".TAP file support enabled\n");
-			memory_set_opbase_handler(0, spectrum_tape_opbaseoverride);
-		}
-		else
-			memory_set_opbase_handler(0, spectrum_opbaseoverride);
-	}
-}
-
-void spectrum_shutdown_machine(void)
-{
-}
-
-int spectrum_snap_load(int id)
-{
-	void *file;
-
-	file = image_fopen(IO_SNAPSHOT, id, OSD_FILETYPE_IMAGE, OSD_FOPEN_READ);
-
-	if (file)
-	{
-		int datasize;
-		unsigned char *data;
-
-		datasize = osd_fsize(file);
-
-		if (datasize != 0)
-		{
-			data = malloc(datasize);
-
-			if (data != NULL)
-			{
-				pSnapshotData = data;
-				SnapshotDataSize = datasize;
-
-				osd_fread(file, data, datasize);
-				osd_fclose(file);
-
-				if (!stricmp(device_filename(IO_SNAPSHOT, id) + strlen(device_filename(IO_SNAPSHOT, id) ) - 4, ".sna"))
-				{
-					if ((SnapshotDataSize != 49179) && (SnapshotDataSize != 131103) && (SnapshotDataSize != 14787))
-					{
-						logerror("Invalid .SNA file size\n");
-						return 1;
-					}
-					spectrum_snapshot_type = SPECTRUM_SNAPSHOT_SNA;
-				}
-				else
-					spectrum_snapshot_type = SPECTRUM_SNAPSHOT_Z80;
-
-				logerror("File loaded!\n");
-				return 0;
-			}
-			osd_fclose(file);
-		}
-		return 1;
-	}
-	return 0;
-}
-
-void spectrum_snap_exit(int id)
-{
-	if (pSnapshotData != NULL)
-	{
-		/* free snapshot/tape data */
-		free(pSnapshotData);
-		pSnapshotData = NULL;
-
-		/* ensure op base is cleared */
-		memory_set_opbase_handler(0, 0);
-	}
-
-	/* reset type to none */
-	spectrum_snapshot_type = SPECTRUM_SNAPSHOT_NONE;
-}
-
-
 static OPBASE_HANDLER(spectrum_opbaseoverride)
 {
-	/* clear op base override */
-	memory_set_opbase_handler(0, 0);
+	if (cassette_snapshot_size > 0)
+		return spectrum_setup_tap(address, cassette_snapshot, cassette_snapshot_size);
 
-	if (pSnapshotData)
+	/* Execute code in spectrum 48k screen memory */
+	if ((spectrum_128_port_7ffd_data == -1) && (spectrum_plus3_port_1ffd_data == -1))
 	{
-		/* snapshot loaded setup */
-
-		switch (spectrum_snapshot_type)
+		if (address>=0x4000 && address<=0x57ff)
 		{
-		case SPECTRUM_SNAPSHOT_SNA:
-			{
-				/* .SNA */
-				spectrum_setup_sna(pSnapshotData, SnapshotDataSize);
-			}
-			break;
-
-		case SPECTRUM_SNAPSHOT_Z80:
-			{
-				/* .Z80 */
-				spectrum_setup_z80(pSnapshotData, SnapshotDataSize);
-			}
-			break;
-
-		default:
-			/* SPECTRUM_TAPEFILE_TAP is handled by spectrum_tape_opbaseoverride */
-			break;
+			opcode_base = opcode_arg_base = spectrum_characterram-0x4000;
+			return -1;
+		}
+		if (address>=0x5800 && address<=0x5aff)
+		{
+			opcode_base = opcode_arg_base = spectrum_colorram-0x5800;
+			return -1;
 		}
 	}
-	logerror("Snapshot loaded - new PC = %04x\n", cpu_get_reg(Z80_PC) & 0x0ffff);
 
-	return (cpu_get_reg(Z80_PC) & 0x0ffff);
+	/* Hack for correct handling 0xffff interrupt vector */
+	if (address == 0x0001)
+		if (cpunum_get_reg(0, REG_PREVIOUSPC)==0xffff)
+		{
+			cpunum_set_reg(0, Z80_PC, 0xfff4);
+			return 0xfff4;
+		}
+	return address;
+}
+
+MACHINE_INIT( spectrum )
+{
+	memory_set_opbase_handler(0, spectrum_opbaseoverride);
+}
+
+SNAPSHOT_LOAD(spectrum)
+{
+	UINT8 *snapshot_data = NULL;
+
+	snapshot_data = malloc(snapshot_size);
+	if (!snapshot_data)
+		goto error;
+
+	mame_fread(fp, snapshot_data, snapshot_size);
+
+	if (!mame_stricmp(file_type, "sna"))
+	{
+		if ((snapshot_size != 49179) && (snapshot_size != 131103) && (snapshot_size != 14787))
+		{
+			logerror("Invalid .SNA file size.\n");
+			goto error;
+		}
+		spectrum_setup_sna(snapshot_data, snapshot_size);
+	}
+	else if (!mame_stricmp(file_type, "sp"))
+	{
+		if (snapshot_data[0]!='S' && snapshot_data[1]!='P')
+		{
+			logerror("Invalid .SP signature.\n");
+			goto error;
+		}
+		spectrum_setup_sp(snapshot_data, snapshot_size);
+	}
+	else
+	{
+		spectrum_setup_z80(snapshot_data, snapshot_size);
+	}
+	free(snapshot_data);
+	logerror("Snapshot loaded - new PC = %04x\n", (unsigned) cpunum_get_reg(0, Z80_PC) & 0x0ffff);
+	return INIT_PASS;
+
+error:
+	if (snapshot_data)
+		free(snapshot_data);
+	return INIT_FAIL;
 }
 
 /*******************************************************************
@@ -205,7 +159,7 @@ static OPBASE_HANDLER(spectrum_opbaseoverride)
  *      load routine so things get rather messy!
  *
  *******************************************************************/
-static OPBASE_HANDLER(spectrum_tape_opbaseoverride)
+static int spectrum_setup_tap(offs_t address, UINT8 *snapshot_data, int snapshot_length)
 {
 	int i, tap_block_length, load_length;
 	unsigned char lo, hi, a_reg;
@@ -213,11 +167,31 @@ static OPBASE_HANDLER(spectrum_tape_opbaseoverride)
 	static int data_loaded = 0;			/* Whether any data files (not headers) were loaded */
 
 /*        logerror("PC=%02x\n", address); */
-
 	/* It is not always possible to trap the call to the actual load
 	 * routine so trap the LD-EDGE-1 and LD-EDGE-2 routines which
 	 * check the earphone socket.
 	 */
+
+	if ((spectrum_128_port_7ffd_data == -1) && (spectrum_plus3_port_1ffd_data == -1))
+	{
+		if (address>=0x4000 && address<=0x57ff)
+		{
+			opcode_base = opcode_arg_base = spectrum_characterram-0x4000;
+			return -1;
+		}
+		if (address>=0x5800 && address<=0x5aff)
+		{
+			opcode_base = opcode_arg_base = spectrum_colorram-0x5800;
+			return -1;
+		}
+	}
+	if (address == 0x0001)
+		if (cpunum_get_reg(0, REG_PREVIOUSPC)==0xffff)
+		{
+			cpunum_set_reg(0, Z80_PC, 0xfff4);
+			return 0xfff4;
+		}
+
 	if (ts2068_port_f4_data == -1)
 	{
 		if ((address < 0x05e3) || (address > 0x0604))
@@ -245,21 +219,20 @@ static OPBASE_HANDLER(spectrum_tape_opbaseoverride)
 		if ((address < 0x018d) || (address > 0x01aa))
 			return address;
 	}
-
-	lo = pSnapshotData[TapePosition] & 0x0ff;
-	hi = pSnapshotData[TapePosition + 1] & 0x0ff;
+	lo = snapshot_data[TapePosition] & 0x0ff;
+	hi = snapshot_data[TapePosition + 1] & 0x0ff;
 	tap_block_length = (hi << 8) | lo;
 
 	/* By the time that load has been trapped the block type and carry
 	 * flags are in the AF' register. */
-	af_reg = cpu_get_reg(Z80_AF2);
+	af_reg = cpunum_get_reg(0, Z80_AF2);
 	a_reg = (af_reg & 0xff00) >> 8;
 
-	if ((a_reg == pSnapshotData[TapePosition + 2]) && (af_reg & 0x0001))
+	if ((a_reg == snapshot_data[TapePosition + 2]) && (af_reg & 0x0001))
 	{
 		/* Correct flag byte and carry flag set so try loading */
-		load_addr = cpu_get_reg(Z80_IX);
-		de_reg = cpu_get_reg(Z80_DE);
+		load_addr = cpunum_get_reg(0, Z80_IX);
+		de_reg = cpunum_get_reg(0, Z80_DE);
 
 		load_length = MIN(de_reg, tap_block_length - 2);
 		load_length = MIN(load_length, 65536 - load_addr);
@@ -267,22 +240,22 @@ static OPBASE_HANDLER(spectrum_tape_opbaseoverride)
 		 * Don't try to load past the end of memory */
 
 		for (i = 0; i < load_length; i++)
-			cpu_writemem16(load_addr + i, pSnapshotData[TapePosition + i + 3]);
-		cpu_set_reg(Z80_IX, load_addr + load_length);
-		cpu_set_reg(Z80_DE, de_reg - load_length);
+			program_write_byte(load_addr + i, snapshot_data[TapePosition + i + 3]);
+		cpunum_set_reg(0, Z80_IX, load_addr + load_length);
+		cpunum_set_reg(0, Z80_DE, de_reg - load_length);
 		if (de_reg == (tap_block_length - 2))
 		{
 			/* Successful load - Set carry flag and A to 0 */
 			if ((de_reg != 17) || (a_reg))
 				data_loaded = 1;		/* Non-header file loaded */
-			cpu_set_reg(Z80_AF, (af_reg & 0x00ff) | 0x0001);
+			cpunum_set_reg(0, Z80_AF, (af_reg & 0x00ff) | 0x0001);
 			logerror("Loaded %04x bytes from address %04x onwards (type=%02x) using tape block at offset %ld\n", load_length,
 					 load_addr, a_reg, TapePosition);
 		}
 		else
 		{
 			/* Wrong tape block size - reset carry flag */
-			cpu_set_reg(Z80_AF, af_reg & 0xfffe);
+			cpunum_set_reg(0, Z80_AF, af_reg & 0xfffe);
 			logerror("Bad block length %04x bytes wanted starting at address %04x (type=%02x) , Data length of tape block at offset %ld is %04x bytes\n",
 					 de_reg, load_addr, a_reg, TapePosition, tap_block_length - 2);
 		}
@@ -290,16 +263,16 @@ static OPBASE_HANDLER(spectrum_tape_opbaseoverride)
 	else
 	{
 		/* Wrong flag byte or verify selected so reset carry flag to indicate failure */
-		cpu_set_reg(Z80_AF, af_reg & 0xfffe);
+		cpunum_set_reg(0, Z80_AF, af_reg & 0xfffe);
 		if (af_reg & 0x0001)
 			logerror("Failed to load tape block at offset %ld - type wanted %02x, got type %02x\n", TapePosition, a_reg,
-					 pSnapshotData[TapePosition + 2]);
+					 snapshot_data[TapePosition + 2]);
 		else
 			logerror("Failed to load tape block at offset %ld - verify selected\n", TapePosition);
 	}
 
 	TapePosition += (tap_block_length + 2);
-	if (TapePosition >= SnapshotDataSize)
+	if (TapePosition >= snapshot_length)
 	{
 		/* End of tape - either rewind or disable op base override */
 		if (readinputport(16) & 0x40)
@@ -313,14 +286,17 @@ static OPBASE_HANDLER(spectrum_tape_opbaseoverride)
 			else
 			{
 				/* Disable .TAP support if no files were loaded to avoid getting caught in infinite loop */
-				memory_set_opbase_handler(0, 0);
 				logerror("No valid data loaded! - disabling .TAP support\n");
+				cassette_snapshot = NULL;
+				cassette_snapshot_size = 0;
+
 			}
 		}
 		else
 		{
-			memory_set_opbase_handler(0, 0);
 			logerror("All tape blocks used! - disabling .TAP support\n");
+			cassette_snapshot = NULL;
+			cassette_snapshot_size = 0;
 		}
 	}
 
@@ -330,17 +306,20 @@ static OPBASE_HANDLER(spectrum_tape_opbaseoverride)
 	 */
 	do
 	{
-		return_addr = cpu_geturnpc();
-		cpu_set_reg(Z80_PC, (return_addr & 0x0ffff));
+		sp_reg = cpunum_get_reg(0, Z80_SP);
+		return_addr =
+			((UINT16) program_read_byte_8(sp_reg + 0) ) >> 8 |
+			((UINT16) program_read_byte_8(sp_reg + 1) ) >> 0;
 
-		sp_reg = cpu_get_reg(Z80_SP);
 		sp_reg += 2;
-		cpu_set_reg(Z80_SP, (sp_reg & 0x0ffff));
-		activecpu_set_sp((sp_reg & 0x0ffff));
+		cpunum_set_reg(0, Z80_SP, (sp_reg & 0x0ffff));
+		cpunum_set_reg(0, Z80_PC, (return_addr & 0x0ffff));
 	}
 	while (((return_addr != 0x053f) && (return_addr < 0x0605) && (ts2068_port_f4_data == -1)) ||
 		   ((return_addr != 0x00e5) && (return_addr < 0x01aa) && (ts2068_port_f4_data != -1)));
-	logerror("Load return address=%04x, SP=%04x\n", return_addr, sp_reg);
+
+       	logerror("Load return address=%04x, SP=%04x\n", return_addr, sp_reg);
+
 	return return_addr;
 }
 
@@ -363,6 +342,7 @@ static void spectrum_update_paging(void)
 		return;
 	if (spectrum_plus3_port_1ffd_data == -1)
 		spectrum_128_update_memory();
+
 	else
 	{
 		if (spectrum_128_port_7ffd_data & 0x10)
@@ -383,28 +363,144 @@ static void spectrum_page_basicrom(void)
 	spectrum_update_paging();
 }
 
-/* Dump the state of registers after loading a snapshot to the log file for debugging */
-static void dump_registers(void)
+/*******************************************************************
+ *
+ *      Load a .SP file.
+ *
+ *      There are only 48K .SP files and their format is as follows:
+ *      Offset  Size    Description (all registers stored with LSB first)
+ *      0       2       "SP" (signature)
+ *      2       2       Program length in bytes (normally 49152 for 48K snaps, or 16384 for 16K snaps)
+ *      4       2       Program location (normally 16384)
+ *      6       8       BC,DE,HL,AF
+ *      14      4       IX,IY
+ *      18      8       BC',DE',HL',AF'
+ *      26      2       R,I
+ *      28      4       SP,PC
+ *      32      2       0 (reserved for future use)
+ *      34      1	Border color
+ *      35      1       0 (reserved for future use)
+ *      36      2       Status word
+ *      38      -       RAM dump
+ *
+ *	Status word:
+ *	Bit	Description
+ *	15-8	Reserved for future use
+ *	7-6	Reserved for internal use (0)
+ *	5	Flash: 0=INK/1=PAPER
+ *	4	Interrupt pending for execution
+ *	3	If 1, IM 0; if 0, bit 1 determines interrupt mode
+ *	      	(Spectrum v 0.99e had this behaviour reversed, and this
+ *		bit was not used in versions previous to v 0.99e)
+ *	2	IFF2 (internal use)
+ *	1	Interrupt Mode (if bit 3 reset): 0=>IM1, 1=>IM2
+ *	0	IFF1: 0=DI/1=EI
+ *
+ *******************************************************************/
+void spectrum_setup_sp(unsigned char *pSnapshot, unsigned long SnapshotSize)
 {
-	logerror("PC   = %04x\n", cpu_get_reg(Z80_PC));
-	logerror("SP   = %04x\n", cpu_get_reg(Z80_SP));
-	logerror("AF   = %04x\n", cpu_get_reg(Z80_AF));
-	logerror("BC   = %04x\n", cpu_get_reg(Z80_BC));
-	logerror("DE   = %04x\n", cpu_get_reg(Z80_DE));
-	logerror("HL   = %04x\n", cpu_get_reg(Z80_HL));
-	logerror("IX   = %04x\n", cpu_get_reg(Z80_IX));
-	logerror("IY   = %04x\n", cpu_get_reg(Z80_IY));
-	logerror("AF'  = %04x\n", cpu_get_reg(Z80_AF2));
-	logerror("BC'  = %04x\n", cpu_get_reg(Z80_BC2));
-	logerror("DE'  = %04x\n", cpu_get_reg(Z80_DE2));
-	logerror("HL'  = %04x\n", cpu_get_reg(Z80_HL2));
-	logerror("I    = %02x\n", cpu_get_reg(Z80_I));
-	logerror("R    = %02x\n", cpu_get_reg(Z80_R));
-	logerror("IFF1 = %02x\n", cpu_get_reg(Z80_IFF1));
-	logerror("IFF2 = %02x\n", cpu_get_reg(Z80_IFF2));
-	logerror("IM   = %02x\n", cpu_get_reg(Z80_IM));
-	logerror("NMI  = %02x\n", cpu_get_reg(Z80_NMI_STATE));
-	logerror("IRQ  = %02x\n", cpu_get_reg(Z80_IRQ_STATE));
+	int i;
+	UINT8 lo, hi, data;
+	UINT16 offset, size;
+	UINT16 status;
+
+	lo = pSnapshot[2] & 0x0ff;
+	hi = pSnapshot[3] & 0x0ff;
+	size = (hi << 8) | lo;
+	logerror ("Snapshot data size: %d.\n", size);
+	lo = pSnapshot[4] & 0x0ff;
+	hi = pSnapshot[5] & 0x0ff;
+	offset = (hi << 8) | lo;
+	logerror ("Snapshot data offset: %d.\n", offset);
+
+	lo = pSnapshot[6] & 0x0ff;
+	hi = pSnapshot[7] & 0x0ff;
+	cpunum_set_reg(0, Z80_BC, (hi << 8) | lo);
+	lo = pSnapshot[8] & 0x0ff;
+	hi = pSnapshot[9] & 0x0ff;
+	cpunum_set_reg(0, Z80_DE, (hi << 8) | lo);
+	lo = pSnapshot[10] & 0x0ff;
+	hi = pSnapshot[11] & 0x0ff;
+	cpunum_set_reg(0, Z80_HL, (hi << 8) | lo);
+	lo = pSnapshot[12] & 0x0ff;
+	hi = pSnapshot[13] & 0x0ff;
+	cpunum_set_reg(0, Z80_AF, (hi << 8) | lo);
+
+	lo = pSnapshot[14] & 0x0ff;
+	hi = pSnapshot[15] & 0x0ff;
+	cpunum_set_reg(0, Z80_IX, (hi << 8) | lo);
+	lo = pSnapshot[16] & 0x0ff;
+	hi = pSnapshot[17] & 0x0ff;
+	cpunum_set_reg(0, Z80_IY, (hi << 8) | lo);
+
+	lo = pSnapshot[18] & 0x0ff;
+	hi = pSnapshot[19] & 0x0ff;
+	cpunum_set_reg(0, Z80_BC2, (hi << 8) | lo);
+	lo = pSnapshot[20] & 0x0ff;
+	hi = pSnapshot[21] & 0x0ff;
+	cpunum_set_reg(0, Z80_DE2, (hi << 8) | lo);
+	lo = pSnapshot[22] & 0x0ff;
+	hi = pSnapshot[23] & 0x0ff;
+	cpunum_set_reg(0, Z80_HL2, (hi << 8) | lo);
+	lo = pSnapshot[24] & 0x0ff;
+	hi = pSnapshot[25] & 0x0ff;
+	cpunum_set_reg(0, Z80_AF2, (hi << 8) | lo);
+
+	cpunum_set_reg(0, Z80_R, (pSnapshot[26] & 0x0ff));
+	cpunum_set_reg(0, Z80_I, (pSnapshot[27] & 0x0ff));
+
+	lo = pSnapshot[28] & 0x0ff;
+	hi = pSnapshot[29] & 0x0ff;
+	cpunum_set_reg(0, Z80_SP, (hi << 8) | lo);
+	lo = pSnapshot[30] & 0x0ff;
+	hi = pSnapshot[31] & 0x0ff;
+	cpunum_set_reg(0, Z80_PC, (hi << 8) | lo);
+
+	lo = pSnapshot[32] & 0x0ff;
+	hi = pSnapshot[33] & 0x0ff;
+	if (((hi << 8) | lo)!=0)
+		logerror("Unknown meaning of word on position 32: %04x.\n", (hi << 8) | lo);
+
+	/* Set border colour */
+	PreviousFE = (PreviousFE & 0xf8) | (pSnapshot[34] & 0x07);
+	EventList_Reset();
+	set_last_border_color(pSnapshot[34] & 0x07);
+	force_border_redraw();
+
+	if ((pSnapshot[35]&0x0ff)!=0)
+		logerror("Unknown meaning of byte on position 35: %02x.\n", pSnapshot[35]&0x0ff);
+
+        lo = pSnapshot[36] & 0x0ff;
+	hi = pSnapshot[37] & 0x0ff;
+	status = (hi << 8) | lo;
+
+	data = (status & 0x01);
+	cpunum_set_reg(0, Z80_IFF1, data);
+	data = (status & 0x04)>>2;
+	cpunum_set_reg(0, Z80_IFF2, data);
+
+	data = (status & 0x08)>>3;
+	if (data)
+		cpunum_set_reg(0, Z80_IM, 0);
+	else
+	{
+		data = (status & 0x02)>>1;
+		if (data)
+			cpunum_set_reg(0, Z80_IM, 2);
+		else
+			cpunum_set_reg(0, Z80_IM, 1);
+	}
+
+	data = (status & 0x10)>>4;
+	activecpu_set_input_line(0, data);
+	activecpu_set_input_line(INPUT_LINE_NMI, data);
+	cpunum_set_input_line(0, INPUT_LINE_HALT, 0);
+
+	spectrum_page_basicrom();
+
+	/* memory dump */
+	for (i = 0; i < size; i++)
+		program_write_byte(i + offset, pSnapshot[38 + i]);
 }
 
 /*******************************************************************
@@ -445,54 +541,53 @@ void spectrum_setup_sna(unsigned char *pSnapshot, unsigned long SnapshotSize)
 	unsigned char lo, hi, data;
 	unsigned short addr;
 
-	if ((SnapshotDataSize != 49179) && (spectrum_128_port_7ffd_data == -1))
+	if ((SnapshotSize != 49179) && (spectrum_128_port_7ffd_data == -1))
 	{
 		logerror("Can't load 128K .SNA file into 48K Machine\n");
 		return;
 	}
 
-	cpu_set_reg(Z80_I, (pSnapshot[0] & 0x0ff));
+	cpunum_set_reg(0, Z80_I, (pSnapshot[0] & 0x0ff));
 	lo = pSnapshot[1] & 0x0ff;
 	hi = pSnapshot[2] & 0x0ff;
-	cpu_set_reg(Z80_HL2, (hi << 8) | lo);
+	cpunum_set_reg(0, Z80_HL2, (hi << 8) | lo);
 	lo = pSnapshot[3] & 0x0ff;
 	hi = pSnapshot[4] & 0x0ff;
-	cpu_set_reg(Z80_DE2, (hi << 8) | lo);
+	cpunum_set_reg(0, Z80_DE2, (hi << 8) | lo);
 	lo = pSnapshot[5] & 0x0ff;
 	hi = pSnapshot[6] & 0x0ff;
-	cpu_set_reg(Z80_BC2, (hi << 8) | lo);
+	cpunum_set_reg(0, Z80_BC2, (hi << 8) | lo);
 	lo = pSnapshot[7] & 0x0ff;
 	hi = pSnapshot[8] & 0x0ff;
-	cpu_set_reg(Z80_AF2, (hi << 8) | lo);
+	cpunum_set_reg(0, Z80_AF2, (hi << 8) | lo);
 	lo = pSnapshot[9] & 0x0ff;
 	hi = pSnapshot[10] & 0x0ff;
-	cpu_set_reg(Z80_HL, (hi << 8) | lo);
+	cpunum_set_reg(0, Z80_HL, (hi << 8) | lo);
 	lo = pSnapshot[11] & 0x0ff;
 	hi = pSnapshot[12] & 0x0ff;
-	cpu_set_reg(Z80_DE, (hi << 8) | lo);
+	cpunum_set_reg(0, Z80_DE, (hi << 8) | lo);
 	lo = pSnapshot[13] & 0x0ff;
 	hi = pSnapshot[14] & 0x0ff;
-	cpu_set_reg(Z80_BC, (hi << 8) | lo);
+	cpunum_set_reg(0, Z80_BC, (hi << 8) | lo);
 	lo = pSnapshot[15] & 0x0ff;
 	hi = pSnapshot[16] & 0x0ff;
-	cpu_set_reg(Z80_IY, (hi << 8) | lo);
+	cpunum_set_reg(0, Z80_IY, (hi << 8) | lo);
 	lo = pSnapshot[17] & 0x0ff;
 	hi = pSnapshot[18] & 0x0ff;
-	cpu_set_reg(Z80_IX, (hi << 8) | lo);
+	cpunum_set_reg(0, Z80_IX, (hi << 8) | lo);
 	data = (pSnapshot[19] & 0x04) >> 2;
-	cpu_set_reg(Z80_IFF2, data);
-	cpu_set_reg(Z80_IFF1, data);
+	cpunum_set_reg(0, Z80_IFF2, data);
+	cpunum_set_reg(0, Z80_IFF1, data);
 	data = (pSnapshot[20] & 0x0ff);
-	cpu_set_reg(Z80_R, data);
+	cpunum_set_reg(0, Z80_R, data);
 	lo = pSnapshot[21] & 0x0ff;
 	hi = pSnapshot[22] & 0x0ff;
-	cpu_set_reg(Z80_AF, (hi << 8) | lo);
+	cpunum_set_reg(0, Z80_AF, (hi << 8) | lo);
 	lo = pSnapshot[23] & 0x0ff;
 	hi = pSnapshot[24] & 0x0ff;
-	cpu_set_reg(Z80_SP, (hi << 8) | lo);
-	activecpu_set_sp((hi << 8) | lo);
+	cpunum_set_reg(0, Z80_SP, (hi << 8) | lo);
 	data = (pSnapshot[25] & 0x0ff);
-	cpu_set_reg(Z80_IM, data);
+	cpunum_set_reg(0, Z80_IM, data);
 
 	/* Set border colour */
 	PreviousFE = (PreviousFE & 0xf8) | (pSnapshot[26] & 0x07);
@@ -500,11 +595,11 @@ void spectrum_setup_sna(unsigned char *pSnapshot, unsigned long SnapshotSize)
 	set_last_border_color(pSnapshot[26] & 0x07);
 	force_border_redraw();
 
-	cpu_set_reg(Z80_NMI_STATE, 0);
-	cpu_set_reg(Z80_IRQ_STATE, 0);
-	cpu_set_reg(Z80_HALT, 0);
+	activecpu_set_input_line(0, data);
+	activecpu_set_input_line(INPUT_LINE_NMI, data);
+	cpunum_set_input_line(0, INPUT_LINE_HALT, 0);
 
-	if (SnapshotDataSize == 49179)
+	if (SnapshotSize == 49179)
 		/* 48K Snapshot */
 		spectrum_page_basicrom();
 	else
@@ -517,19 +612,22 @@ void spectrum_setup_sna(unsigned char *pSnapshot, unsigned long SnapshotSize)
 	/* memory dump */
 	for (i = 0; i < 49152; i++)
 	{
-		cpu_writemem16(i + 16384, pSnapshot[27 + i]);
+		program_write_byte(i + 16384, pSnapshot[27 + i]);
 	}
 
-	if (SnapshotDataSize == 49179)
+	if (SnapshotSize == 49179)
 	{
 		/* get pc from stack */
-		addr = cpu_geturnpc();
-		cpu_set_reg(Z80_PC, (addr & 0x0ffff));
+		addr = cpunum_get_reg(0, Z80_SP) & 0xFFFF;
+
+		cpunum_set_reg(0, Z80_PC,
+			((UINT16) program_read_byte_8(addr + 0) ) >> 8 |
+			((UINT16) program_read_byte_8(addr + 1) ) >> 0);
 
-		addr = cpu_get_reg(Z80_SP);
 		addr += 2;
-		cpu_set_reg(Z80_SP, (addr & 0x0ffff));
-		activecpu_set_sp((addr & 0x0ffff));
+		cpunum_set_reg(0, Z80_SP, (addr & 0x0ffff));
+
+
 	}
 	else
 	{
@@ -551,7 +649,7 @@ void spectrum_setup_sna(unsigned char *pSnapshot, unsigned long SnapshotSize)
 				spectrum_128_port_7ffd_data += i;
 				spectrum_update_paging();
 				for (j = 0; j < 16384; j++)
-					cpu_writemem16(j + 49152, pSnapshot[bank_offset + j]);
+					program_write_byte(j + 49152, pSnapshot[bank_offset + j]);
 				bank_offset += 16384;
 			}
 		}
@@ -563,9 +661,8 @@ void spectrum_setup_sna(unsigned char *pSnapshot, unsigned long SnapshotSize)
 		/* program counter */
 		lo = pSnapshot[49179] & 0x0ff;
 		hi = pSnapshot[49180] & 0x0ff;
-		cpu_set_reg(Z80_PC, (hi << 8) | lo);
+		cpunum_set_reg(0, Z80_PC, (hi << 8) | lo);
 	}
-	dump_registers();
 }
 
 
@@ -608,14 +705,14 @@ static void spectrum_z80_decompress_block(unsigned char *pSource, int Dest, int
 
 				for (i = 0; i < count; i++)
 				{
-					cpu_writemem16(Dest, data);
+					program_write_byte(Dest, data);
 					Dest++;
 				}
 			}
 			else
 			{
 				/* single 0x0ed */
-				cpu_writemem16(Dest, ch);
+				program_write_byte(Dest, ch);
 				Dest++;
 				pSource++;
 				size--;
@@ -625,7 +722,7 @@ static void spectrum_z80_decompress_block(unsigned char *pSource, int Dest, int
 		else
 		{
 			/* not 0x0ed */
-			cpu_writemem16(Dest, ch);
+			program_write_byte(Dest, ch);
 			Dest++;
 			pSource++;
 			size--;
@@ -645,7 +742,7 @@ typedef enum {
 }
 SPECTRUM_Z80_SNAPSHOT_TYPE;
 
-SPECTRUM_Z80_SNAPSHOT_TYPE spectrum_identify_z80 (unsigned char *pSnapshot, unsigned long SnapshotSize)
+static SPECTRUM_Z80_SNAPSHOT_TYPE spectrum_identify_z80 (unsigned char *pSnapshot, unsigned long SnapshotSize)
 {
 	unsigned char lo, hi, data;
 
@@ -668,7 +765,7 @@ SPECTRUM_Z80_SNAPSHOT_TYPE spectrum_identify_z80 (unsigned char *pSnapshot, unsi
 			case 0:
 			case 1:	return SPECTRUM_Z80_SNAPSHOT_48K;
 			case 2:	return SPECTRUM_Z80_SNAPSHOT_SAMRAM;
-			case 3:	
+			case 3:
 			case 4:	return SPECTRUM_Z80_SNAPSHOT_128K;
 			case 128: return SPECTRUM_Z80_SNAPSHOT_TS2068;
 		}
@@ -699,7 +796,7 @@ void spectrum_setup_z80(unsigned char *pSnapshot, unsigned long SnapshotSize)
 	unsigned char lo, hi, data;
 	SPECTRUM_Z80_SNAPSHOT_TYPE z80_type;
 
-	z80_type = spectrum_identify_z80(pSnapshotData, SnapshotDataSize);
+	z80_type = spectrum_identify_z80(pSnapshot, SnapshotSize);
 
 	switch (z80_type)
 	{
@@ -738,28 +835,27 @@ void spectrum_setup_z80(unsigned char *pSnapshot, unsigned long SnapshotSize)
 	/* AF */
 	hi = pSnapshot[0] & 0x0ff;
 	lo = pSnapshot[1] & 0x0ff;
-	cpu_set_reg(Z80_AF, (hi << 8) | lo);
+	cpunum_set_reg(0, Z80_AF, (hi << 8) | lo);
 	/* BC */
 	lo = pSnapshot[2] & 0x0ff;
 	hi = pSnapshot[3] & 0x0ff;
-	cpu_set_reg(Z80_BC, (hi << 8) | lo);
+	cpunum_set_reg(0, Z80_BC, (hi << 8) | lo);
 	/* HL */
 	lo = pSnapshot[4] & 0x0ff;
 	hi = pSnapshot[5] & 0x0ff;
-	cpu_set_reg(Z80_HL, (hi << 8) | lo);
+	cpunum_set_reg(0, Z80_HL, (hi << 8) | lo);
 
 	/* SP */
 	lo = pSnapshot[8] & 0x0ff;
 	hi = pSnapshot[9] & 0x0ff;
-	cpu_set_reg(Z80_SP, (hi << 8) | lo);
-	activecpu_set_sp((hi << 8) | lo);
+	cpunum_set_reg(0, Z80_SP, (hi << 8) | lo);
 
 	/* I */
-	cpu_set_reg(Z80_I, (pSnapshot[10] & 0x0ff));
+	cpunum_set_reg(0, Z80_I, (pSnapshot[10] & 0x0ff));
 
 	/* R */
 	data = (pSnapshot[11] & 0x07f) | ((pSnapshot[12] & 0x01) << 7);
-	cpu_set_reg(Z80_R, data);
+	cpunum_set_reg(0, Z80_R, data);
 
 	/* Set border colour */
 	PreviousFE = (PreviousFE & 0xf8) | ((pSnapshot[12] & 0x0e) >> 1);
@@ -769,47 +865,47 @@ void spectrum_setup_z80(unsigned char *pSnapshot, unsigned long SnapshotSize)
 
 	lo = pSnapshot[13] & 0x0ff;
 	hi = pSnapshot[14] & 0x0ff;
-	cpu_set_reg(Z80_DE, (hi << 8) | lo);
+	cpunum_set_reg(0, Z80_DE, (hi << 8) | lo);
 
 	lo = pSnapshot[15] & 0x0ff;
 	hi = pSnapshot[16] & 0x0ff;
-	cpu_set_reg(Z80_BC2, (hi << 8) | lo);
+	cpunum_set_reg(0, Z80_BC2, (hi << 8) | lo);
 
 	lo = pSnapshot[17] & 0x0ff;
 	hi = pSnapshot[18] & 0x0ff;
-	cpu_set_reg(Z80_DE2, (hi << 8) | lo);
+	cpunum_set_reg(0, Z80_DE2, (hi << 8) | lo);
 
 	lo = pSnapshot[19] & 0x0ff;
 	hi = pSnapshot[20] & 0x0ff;
-	cpu_set_reg(Z80_HL2, (hi << 8) | lo);
+	cpunum_set_reg(0, Z80_HL2, (hi << 8) | lo);
 
 	hi = pSnapshot[21] & 0x0ff;
 	lo = pSnapshot[22] & 0x0ff;
-	cpu_set_reg(Z80_AF2, (hi << 8) | lo);
+	cpunum_set_reg(0, Z80_AF2, (hi << 8) | lo);
 
 	lo = pSnapshot[23] & 0x0ff;
 	hi = pSnapshot[24] & 0x0ff;
-	cpu_set_reg(Z80_IY, (hi << 8) | lo);
+	cpunum_set_reg(0, Z80_IY, (hi << 8) | lo);
 
 	lo = pSnapshot[25] & 0x0ff;
 	hi = pSnapshot[26] & 0x0ff;
-	cpu_set_reg(Z80_IX, (hi << 8) | lo);
+	cpunum_set_reg(0, Z80_IX, (hi << 8) | lo);
 
 	/* Interrupt Flip/Flop */
 	if (pSnapshot[27] == 0)
 	{
-		cpu_set_reg(Z80_IFF1, 0);
-		/*cpu_set_reg(Z80_IRQ_STATE, 0); */
+		cpunum_set_reg(0, Z80_IFF1, 0);
+		/* cpunum_set_reg(0, Z80_IRQ_STATE, 0); */
 	}
 	else
 	{
-		cpu_set_reg(Z80_IFF1, 1);
-		/*cpu_set_reg(Z80_IRQ_STATE, 1); */
+		cpunum_set_reg(0, Z80_IFF1, 1);
+		/* cpunum_set_reg(0, Z80_IRQ_STATE, 1); */
 	}
 
-	cpu_set_reg(Z80_NMI_STATE, 0);
-	cpu_set_reg(Z80_IRQ_STATE, 0);
-	cpu_set_reg(Z80_HALT, 0);
+	activecpu_set_input_line(0, data);
+	activecpu_set_input_line(INPUT_LINE_NMI, data);
+	cpunum_set_input_line(0, INPUT_LINE_HALT, 0);
 
 	/* IFF2 */
 	if (pSnapshot[28] != 0)
@@ -820,24 +916,24 @@ void spectrum_setup_z80(unsigned char *pSnapshot, unsigned long SnapshotSize)
 	{
 		data = 0;
 	}
-	cpu_set_reg(Z80_IFF2, data);
+	cpunum_set_reg(0, Z80_IFF2, data);
 
 	/* Interrupt Mode */
-	cpu_set_reg(Z80_IM, (pSnapshot[29] & 0x03));
+	cpunum_set_reg(0, Z80_IM, (pSnapshot[29] & 0x03));
 
 	if (z80_type == SPECTRUM_Z80_SNAPSHOT_48K_OLD)
 	{
 		lo = pSnapshot[6] & 0x0ff;
 		hi = pSnapshot[7] & 0x0ff;
-		cpu_set_reg(Z80_PC, (hi << 8) | lo);
+		cpunum_set_reg(0, Z80_PC, (hi << 8) | lo);
 
 		spectrum_page_basicrom();
-                
+
 		if ((pSnapshot[12] & 0x020) == 0)
 		{
 			logerror("Not compressed\n");	/* not compressed */
 			for (i = 0; i < 49152; i++)
-				cpu_writemem16(i + 16384, pSnapshot[30 + i]);
+				program_write_byte(i + 16384, pSnapshot[30 + i]);
 		}
 		else
 		{
@@ -854,7 +950,7 @@ void spectrum_setup_z80(unsigned char *pSnapshot, unsigned long SnapshotSize)
 
 		lo = pSnapshot[32] & 0x0ff;
 		hi = pSnapshot[33] & 0x0ff;
-		cpu_set_reg(Z80_PC, (hi << 8) | lo);
+		cpunum_set_reg(0, Z80_PC, (hi << 8) | lo);
 
 		if ((z80_type == SPECTRUM_Z80_SNAPSHOT_128K) || ((z80_type == SPECTRUM_Z80_SNAPSHOT_TS2068) && !strcmp(Machine->gamedrv->name,"ts2068")))
 		{
@@ -916,7 +1012,7 @@ void spectrum_setup_z80(unsigned char *pSnapshot, unsigned long SnapshotSize)
 
 					/* not compressed */
 					for (i = 0; i < 16384; i++)
-						cpu_writemem16(i + Dest, pSource[i]);
+						program_write_byte(i + Dest, pSource[i]);
 				}
 				else
 				{
@@ -930,7 +1026,7 @@ void spectrum_setup_z80(unsigned char *pSnapshot, unsigned long SnapshotSize)
 			/* go to next block */
 			pSource += (3 + length);
 		}
-		while (((unsigned long) pSource - (unsigned long) pSnapshot) < SnapshotDataSize);
+		while (((unsigned long) pSource - (unsigned long) pSnapshot) < SnapshotSize);
 
 		if ((spectrum_128_port_7ffd_data != -1) && (z80_type != SPECTRUM_Z80_SNAPSHOT_48K))
 		{
@@ -951,164 +1047,50 @@ void spectrum_setup_z80(unsigned char *pSnapshot, unsigned long SnapshotSize)
 			ts2068_update_memory();
 		}
 	}
-	dump_registers();
 }
 
 /*-----------------27/02/00 10:54-------------------
  SPECTRUM WAVE CASSETTE SUPPORT
 --------------------------------------------------*/
 
-int spectrum_cassette_init(int id)
-{
-	void *file;
-	struct cassette_args args;
-
-	if ((device_filename(IO_CASSETTE, id) != NULL) &&
-		!stricmp(device_filename(IO_CASSETTE, id) + strlen(device_filename(IO_CASSETTE, id) ) - 4, ".tap"))
-	{
-		int datasize;
-		unsigned char *data;
-
-		file = image_fopen(IO_CASSETTE, id, OSD_FILETYPE_IMAGE, OSD_FOPEN_READ);
-		logerror(".TAP file found\n");
-		if (file)
-			datasize = osd_fsize(file);
-		else
-			datasize = 0;
-		if (datasize != 0)
-		{
-			data = malloc(datasize);
-
-			if (data != NULL)
-			{
-				pSnapshotData = data;
-				SnapshotDataSize = datasize;
-
-				osd_fread(file, data, datasize);
-				osd_fclose(file);
-
-				/* Always reset tape position when loading new tapes */
-				TapePosition = 0;
-				memory_set_opbase_handler(0, spectrum_tape_opbaseoverride);
-				spectrum_snapshot_type = SPECTRUM_TAPEFILE_TAP;
-				logerror(".TAP file successfully loaded\n");
-				return INIT_PASS;
-			}
-		}
-		osd_fclose(file);
-		return INIT_FAIL;
-	}
-
-	memset(&args, 0, sizeof(args));
-	args.create_smpfreq = 22050;	/* maybe 11025 Hz would be sufficient? */
-	return cassette_init(id, &args);
-}
-
-void spectrum_cassette_exit(int id)
-{
-	device_close(IO_CASSETTE, id);
-	spectrum_snap_exit(id);
-}
-
 /*************************************
  *
  *      Interrupt handlers.
  *
  *************************************/
 
-void spectrum_nmi_generate(int param)
-{
-	cpu_cause_interrupt(0, Z80_NMI_INT);
-}
-
-int spec_quick_init(int id)
-{
-	FILE *fp;
-	int read;
-
-	memset(&quick, 0, sizeof (quick));
-
-	if (device_filename(IO_QUICKLOAD, id) == NULL)
-		return INIT_PASS;
-
-/*	quick.name = name; */
-
-	fp = image_fopen(IO_QUICKLOAD, id, OSD_FILETYPE_IMAGE, 0);
-	if (!fp)
-		return INIT_FAIL;
-
-	quick.length = osd_fsize(fp);
-	quick.addr = 0x4000;
-
-	if ((quick.data = malloc(quick.length)) == NULL)
-	{
-		osd_fclose(fp);
-		return INIT_FAIL;
-	}
-	read = osd_fread(fp, quick.data, quick.length);
-	osd_fclose(fp);
-	return read != quick.length;
-}
-
-void spec_quick_exit(int id)
-{
-	if (quick.data != NULL)
-		free(quick.data);
-}
-
-int spec_quick_open(int id, int mode, void *arg)
+QUICKLOAD_LOAD(spectrum)
 {
 	int i;
+	int quick_addr = 0x4000;
+	int quick_length;
+	UINT8 *quick_data;
+	int read_;
 
-	if (quick.data == NULL)
-		return 1;
+	quick_length = mame_fsize(fp);
+	quick_data = malloc(quick_length);
+	if (!quick_data)
+		return INIT_FAIL;
 
-	for (i = 0; i < quick.length; i++)
-	{
-		cpu_writemem16(i + quick.addr, quick.data[i]);
-	}
-	logerror("quick loading %s at %.4x size:%.4x\n",
-			 device_filename(IO_QUICKLOAD, id), quick.addr, quick.length);
+	read_ = mame_fread(fp, quick_data, quick_length);
+	if (read_ != quick_length)
+		return INIT_FAIL;
 
-	return 0;
+	for (i = 0; i < quick_length; i++)
+		program_write_byte(i + quick_addr, quick_data[i]);
+
+	logerror("quick loading at %.4x size:%.4x\n", quick_addr, quick_length);
+	return INIT_PASS;
 }
 
-int spectrum_cart_load(int id)
+DEVICE_LOAD( spectrum_cart )
 {
-	void *file;
-
-	logerror("Trying to load cartridge!\n");
-	file = image_fopen(IO_CARTSLOT, id, OSD_FILETYPE_IMAGE, OSD_FOPEN_READ);
-	if (file)
-	{
-		int datasize;
-		unsigned char *data, *ROM = memory_region(REGION_CPU1);
-
-		datasize = osd_fsize(file);
-
-		/* Cartridges are always 16K in size (as they replace the BASIC ROM)*/
-		if (datasize == 0x4000)
-		{
-			data = malloc(datasize);
-			if (data != NULL)
-			{
-				osd_fread(file, data, datasize);
-				osd_fclose(file);
-				memcpy(ROM, data, 0x4000);
-				free(data);
-				logerror("Cart loaded!\n");
-				return 0;
-			}
-			osd_fclose(file);
-		}
-		return 1;
-	}
-	return 0;
+	/* Cartridges are always 16K in size (as they replace the BASIC ROM)*/
+	return cartslot_load_generic(file, REGION_CPU1, 0, 0x4000, 0x4000, 0);
 }
 
-int timex_cart_load(int id)
+DEVICE_LOAD( timex_cart )
 {
-	void *file;
 	int file_size;
 	UINT8 * file_data;
 
@@ -1116,39 +1098,24 @@ int timex_cart_load(int id)
 
 	int i;
 
-	if (device_filename(IO_CARTSLOT, id) == NULL)
-	{
-		return INIT_PASS;
-	}
-
 	logerror ("Trying to load cart\n");
 
-	file = image_fopen(IO_CARTSLOT, id, OSD_FILETYPE_IMAGE, OSD_FOPEN_READ);
-	if (file==NULL)
-	{
-		logerror ("Error opening cart file\n");
-		return INIT_FAIL;
-	}
-
-	file_size = osd_fsize(file);
+	file_size = mame_fsize(file);
 
 	if (file_size < 0x09)
 	{
-		osd_fclose(file);
 		logerror ("Bad file size\n");
 		return INIT_FAIL;
 	}
 
 	file_data = malloc(file_size);
 	if (file_data == NULL)
-        {
-		osd_fclose(file);
+	{
 		logerror ("Memory allocating error\n");
 		return INIT_FAIL;
 	}
 
-	osd_fread(file, file_data, file_size);
-	osd_fclose(file);
+	mame_fread(file, file_data, file_size);
 
 	for (i=0; i<8; i++)
 		if(file_data[i+1]&0x02)	chunks_in_file++;
@@ -1203,7 +1170,7 @@ int timex_cart_load(int id)
 	return INIT_PASS;
 }
 
-void timex_cart_exit(int id)
+DEVICE_UNLOAD( timex_cart )
 {
 	if (timex_cart_data)
 	{
