@@ -8,20 +8,17 @@
 
 #include "driver.h"
 #include "cpu/apexc/apexc.h"
+#include "vidhrdw/generic.h"
 
 static void apexc_teletyper_init(void);
 static void apexc_teletyper_putchar(int character);
 
 
-static void apexc_init_machine(void)
+static void machine_init_apexc(void)
 {
 	apexc_teletyper_init();
 }
 
-static void apexc_stop_machine(void)
-{
-}
-
 
 /*
 	APEXC RAM loading/saving from cylinder image
@@ -36,7 +33,7 @@ static void apexc_stop_machine(void)
 
 typedef struct cylinder
 {
-	void *fd;
+	mame_file *fd;
 	int writable;
 } cylinder;
 
@@ -45,23 +42,17 @@ cylinder apexc_cylinder;
 /*
 	Open cylinder image and read RAM
 */
-static int apexc_cylinder_init(int id)
+static DEVICE_LOAD(apexc_cylinder)
 {
 	/* open file */
-	/* first try read/write mode */
-	apexc_cylinder.fd = image_fopen(IO_CYLINDER, id, OSD_FILETYPE_IMAGE, OSD_FOPEN_RW);
-	if (apexc_cylinder.fd)
-		apexc_cylinder.writable = 1;
-	else
-	{	/* else try read-only mode */
-		apexc_cylinder.writable = 0;
-		apexc_cylinder.fd = image_fopen(IO_CYLINDER, id, OSD_FILETYPE_IMAGE, OSD_FOPEN_READ);
-	}
+	apexc_cylinder.fd = file;
+	/* tell whether the image is writable */
+	apexc_cylinder.writable = image_is_writable(image);
 
 	if (apexc_cylinder.fd)
 	{	/* load RAM contents */
 
-		osd_fread(apexc_cylinder.fd, memory_region(REGION_CPU1), /*0x8000*/0x1000);
+		mame_fread(apexc_cylinder.fd, memory_region(REGION_CPU1), /*0x8000*/0x1000);
 #ifdef LSB_FIRST
 		{	/* fix endianness */
 			UINT32 *RAM;
@@ -81,12 +72,12 @@ static int apexc_cylinder_init(int id)
 /*
 	Save RAM to cylinder image and close it
 */
-static void apexc_cylinder_exit(int id)
+static DEVICE_UNLOAD(apexc_cylinder)
 {
 	if (apexc_cylinder.fd && apexc_cylinder.writable)
 	{	/* save RAM contents */
 		/* rewind file */
-		osd_fseek(apexc_cylinder.fd, 0, SEEK_SET);
+		mame_fseek(apexc_cylinder.fd, 0, SEEK_SET);
 #ifdef LSB_FIRST
 		{	/* fix endianness */
 			UINT32 *RAM;
@@ -99,11 +90,7 @@ static void apexc_cylinder_exit(int id)
 		}
 #endif
 		/* write */
-		osd_fwrite(apexc_cylinder.fd, memory_region(REGION_CPU1), /*0x8000*/0x1000);
-	}
-	if (apexc_cylinder.fd)
-	{
-		osd_fclose(apexc_cylinder.fd);
+		mame_fwrite(apexc_cylinder.fd, memory_region(REGION_CPU1), /*0x8000*/0x1000);
 	}
 }
 
@@ -155,53 +142,70 @@ static void apexc_cylinder_exit(int id)
 
 typedef struct tape
 {
-	void *fd;
+	mame_file *fd;
 } tape;
 
 tape apexc_tapes[2];
 
+
+
+static void apexc_get_open_mode(const struct IODevice *dev, int id,
+	unsigned int *readable, unsigned int *writeable, unsigned int *creatable)
+{
+	/* unit 0 is read-only, unit 1 is write-only */
+	if (id)
+	{
+		*readable = 0;
+		*writeable = 1;
+		*creatable = 1;
+	}
+	else
+	{
+		*readable = 1;
+		*writeable = 1;
+		*creatable = 1;
+	}
+}
+
+
+
+static DEVICE_INIT(apexc_tape)
+{
+	return INIT_PASS;
+}
+
+
+
 /*
 	Open a tape image
 */
-static int apexc_tape_init(int id)
+static DEVICE_LOAD(apexc_tape)
 {
+	int id = image_index_in_device(image);
 	tape *t = &apexc_tapes[id];
 
 	/* open file */
-	/* unit 0 is read-only, unit 1 is write-only */
-	t->fd = image_fopen(IO_PUNCHTAPE, id, OSD_FILETYPE_IMAGE,
-							(id==0) ? OSD_FOPEN_READ : OSD_FOPEN_WRITE);
+	t->fd = file;
 
 	return INIT_PASS;
 }
 
-/*
-	Close a tape image
-*/
-static void apexc_tape_exit(int id)
-{
-	tape *t = &apexc_tapes[id];
-
-	if (t->fd)
-		osd_fclose(t->fd);
-}
-
-static READ32_HANDLER(tape_read)
+static  READ8_HANDLER(tape_read)
 {
 	UINT8 reply;
 
-	if (apexc_tapes[0].fd && (osd_fread(apexc_tapes[0].fd, & reply, 1) == 1))
+	if (apexc_tapes[0].fd && (mame_fread(apexc_tapes[0].fd, & reply, 1) == 1))
 		return reply & 0x1f;
 	else
 		return 0;	/* unit not ready - I don't know what we should do */
 }
 
-static WRITE32_HANDLER(tape_write)
+static WRITE8_HANDLER(tape_write)
 {
 	UINT8 data5 = (data & 0x1f);
 
 	if (apexc_tapes[1].fd)
-		osd_fwrite(apexc_tapes[1].fd, & data5, 1);
+		mame_fwrite(apexc_tapes[1].fd, & data5, 1);
 
 	apexc_teletyper_putchar(data & 0x1f);	/* display on screen */
 }
@@ -264,50 +268,50 @@ enum
 INPUT_PORTS_START(apexc)
 
 	PORT_START	/* 0 : panel control */
-	PORT_BITX(panel_run, IP_ACTIVE_HIGH, IPT_KEYBOARD, "run/stop", KEYCODE_ENTER, IP_JOY_NONE)
-	PORT_BITX(panel_CR,  IP_ACTIVE_HIGH, IPT_KEYBOARD, "read CR",  KEYCODE_1_PAD, IP_JOY_NONE)
-	PORT_BITX(panel_A,   IP_ACTIVE_HIGH, IPT_KEYBOARD, "read A",   KEYCODE_2_PAD, IP_JOY_NONE)
-	PORT_BITX(panel_R,   IP_ACTIVE_HIGH, IPT_KEYBOARD, "read R",   KEYCODE_3_PAD, IP_JOY_NONE)
-	PORT_BITX(panel_HB,  IP_ACTIVE_HIGH, IPT_KEYBOARD, "read HB",  KEYCODE_4_PAD, IP_JOY_NONE)
-	PORT_BITX(panel_ML,  IP_ACTIVE_HIGH, IPT_KEYBOARD, "read ML",  KEYCODE_5_PAD, IP_JOY_NONE)
-	PORT_BITX(panel_mem, IP_ACTIVE_HIGH, IPT_KEYBOARD, "read mem", KEYCODE_6_PAD, IP_JOY_NONE)
-	PORT_BITX(panel_write, IP_ACTIVE_HIGH, IPT_KEYBOARD, "write instead of reading", KEYCODE_LSHIFT, IP_JOY_NONE)
+	PORT_BIT(panel_run, IP_ACTIVE_HIGH, IPT_KEYBOARD) PORT_NAME("Run/Stop") PORT_CODE(KEYCODE_ENTER)
+	PORT_BIT(panel_CR,  IP_ACTIVE_HIGH, IPT_KEYBOARD) PORT_NAME("Read CR") PORT_CODE(KEYCODE_1_PAD)
+	PORT_BIT(panel_A,   IP_ACTIVE_HIGH, IPT_KEYBOARD) PORT_NAME("Read A") PORT_CODE(KEYCODE_2_PAD)
+	PORT_BIT(panel_R,   IP_ACTIVE_HIGH, IPT_KEYBOARD) PORT_NAME("Read R") PORT_CODE(KEYCODE_3_PAD)
+	PORT_BIT(panel_HB,  IP_ACTIVE_HIGH, IPT_KEYBOARD) PORT_NAME("Read HB") PORT_CODE(KEYCODE_4_PAD)
+	PORT_BIT(panel_ML,  IP_ACTIVE_HIGH, IPT_KEYBOARD) PORT_NAME("Read ML") PORT_CODE(KEYCODE_5_PAD)
+	PORT_BIT(panel_mem, IP_ACTIVE_HIGH, IPT_KEYBOARD) PORT_NAME("Read mem") PORT_CODE(KEYCODE_6_PAD)
+	PORT_BIT(panel_write, IP_ACTIVE_HIGH, IPT_KEYBOARD) PORT_NAME("Write instead of read") PORT_CODE(KEYCODE_LSHIFT)
 
 	PORT_START	/* 1 : data edit #1 */
-	PORT_BITX(0x8000, IP_ACTIVE_HIGH, IPT_KEYBOARD, "toggle bit #1", KEYCODE_1, IP_JOY_NONE)
-	PORT_BITX(0x4000, IP_ACTIVE_HIGH, IPT_KEYBOARD, "toggle bit #2", KEYCODE_2, IP_JOY_NONE)
-	PORT_BITX(0x2000, IP_ACTIVE_HIGH, IPT_KEYBOARD, "toggle bit #3", KEYCODE_3, IP_JOY_NONE)
-	PORT_BITX(0x1000, IP_ACTIVE_HIGH, IPT_KEYBOARD, "toggle bit #4", KEYCODE_4, IP_JOY_NONE)
-	PORT_BITX(0x0800, IP_ACTIVE_HIGH, IPT_KEYBOARD, "toggle bit #5", KEYCODE_5, IP_JOY_NONE)
-	PORT_BITX(0x0400, IP_ACTIVE_HIGH, IPT_KEYBOARD, "toggle bit #6", KEYCODE_6, IP_JOY_NONE)
-	PORT_BITX(0x0200, IP_ACTIVE_HIGH, IPT_KEYBOARD, "toggle bit #7", KEYCODE_7, IP_JOY_NONE)
-	PORT_BITX(0x0100, IP_ACTIVE_HIGH, IPT_KEYBOARD, "toggle bit #8", KEYCODE_8, IP_JOY_NONE)
-	PORT_BITX(0x0080, IP_ACTIVE_HIGH, IPT_KEYBOARD, "toggle bit #9", KEYCODE_9, IP_JOY_NONE)
-	PORT_BITX(0x0040, IP_ACTIVE_HIGH, IPT_KEYBOARD, "toggle bit #10", KEYCODE_0, IP_JOY_NONE)
-	PORT_BITX(0x0020, IP_ACTIVE_HIGH, IPT_KEYBOARD, "toggle bit #11", KEYCODE_Q, IP_JOY_NONE)
-	PORT_BITX(0x0010, IP_ACTIVE_HIGH, IPT_KEYBOARD, "toggle bit #12", KEYCODE_W, IP_JOY_NONE)
-	PORT_BITX(0x0008, IP_ACTIVE_HIGH, IPT_KEYBOARD, "toggle bit #13", KEYCODE_E, IP_JOY_NONE)
-	PORT_BITX(0x0004, IP_ACTIVE_HIGH, IPT_KEYBOARD, "toggle bit #14", KEYCODE_R, IP_JOY_NONE)
-	PORT_BITX(0x0002, IP_ACTIVE_HIGH, IPT_KEYBOARD, "toggle bit #15", KEYCODE_T, IP_JOY_NONE)
-	PORT_BITX(0x0001, IP_ACTIVE_HIGH, IPT_KEYBOARD, "toggle bit #16", KEYCODE_Y, IP_JOY_NONE)
+	PORT_BIT(0x8000, IP_ACTIVE_HIGH, IPT_KEYBOARD) PORT_NAME("Toggle bit #1") PORT_CODE(KEYCODE_1)
+	PORT_BIT(0x4000, IP_ACTIVE_HIGH, IPT_KEYBOARD) PORT_NAME("Toggle bit #2") PORT_CODE(KEYCODE_2)
+	PORT_BIT(0x2000, IP_ACTIVE_HIGH, IPT_KEYBOARD) PORT_NAME("Toggle bit #3") PORT_CODE(KEYCODE_3)
+	PORT_BIT(0x1000, IP_ACTIVE_HIGH, IPT_KEYBOARD) PORT_NAME("Toggle bit #4") PORT_CODE(KEYCODE_4)
+	PORT_BIT(0x0800, IP_ACTIVE_HIGH, IPT_KEYBOARD) PORT_NAME("Toggle bit #5") PORT_CODE(KEYCODE_5)
+	PORT_BIT(0x0400, IP_ACTIVE_HIGH, IPT_KEYBOARD) PORT_NAME("Toggle bit #6") PORT_CODE(KEYCODE_6)
+	PORT_BIT(0x0200, IP_ACTIVE_HIGH, IPT_KEYBOARD) PORT_NAME("Toggle bit #7") PORT_CODE(KEYCODE_7)
+	PORT_BIT(0x0100, IP_ACTIVE_HIGH, IPT_KEYBOARD) PORT_NAME("Toggle bit #8") PORT_CODE(KEYCODE_8)
+	PORT_BIT(0x0080, IP_ACTIVE_HIGH, IPT_KEYBOARD) PORT_NAME("Toggle bit #9") PORT_CODE(KEYCODE_9)
+	PORT_BIT(0x0040, IP_ACTIVE_HIGH, IPT_KEYBOARD) PORT_NAME("Toggle bit #10") PORT_CODE(KEYCODE_0)
+	PORT_BIT(0x0020, IP_ACTIVE_HIGH, IPT_KEYBOARD) PORT_NAME("Toggle bit #11") PORT_CODE(KEYCODE_Q)
+	PORT_BIT(0x0010, IP_ACTIVE_HIGH, IPT_KEYBOARD) PORT_NAME("Toggle bit #12") PORT_CODE(KEYCODE_W)
+	PORT_BIT(0x0008, IP_ACTIVE_HIGH, IPT_KEYBOARD) PORT_NAME("Toggle bit #13") PORT_CODE(KEYCODE_E)
+	PORT_BIT(0x0004, IP_ACTIVE_HIGH, IPT_KEYBOARD) PORT_NAME("Toggle bit #14") PORT_CODE(KEYCODE_R)
+	PORT_BIT(0x0002, IP_ACTIVE_HIGH, IPT_KEYBOARD) PORT_NAME("Toggle bit #15") PORT_CODE(KEYCODE_T)
+	PORT_BIT(0x0001, IP_ACTIVE_HIGH, IPT_KEYBOARD) PORT_NAME("Toggle bit #16") PORT_CODE(KEYCODE_Y)
 
 	PORT_START	/* 2 : data edit #2 */
-	PORT_BITX(0x8000, IP_ACTIVE_HIGH, IPT_KEYBOARD, "toggle bit #17", KEYCODE_U, IP_JOY_NONE)
-	PORT_BITX(0x4000, IP_ACTIVE_HIGH, IPT_KEYBOARD, "toggle bit #18", KEYCODE_I, IP_JOY_NONE)
-	PORT_BITX(0x2000, IP_ACTIVE_HIGH, IPT_KEYBOARD, "toggle bit #19", KEYCODE_O, IP_JOY_NONE)
-	PORT_BITX(0x1000, IP_ACTIVE_HIGH, IPT_KEYBOARD, "toggle bit #20", KEYCODE_P, IP_JOY_NONE)
-	PORT_BITX(0x0800, IP_ACTIVE_HIGH, IPT_KEYBOARD, "toggle bit #21", KEYCODE_A, IP_JOY_NONE)
-	PORT_BITX(0x0400, IP_ACTIVE_HIGH, IPT_KEYBOARD, "toggle bit #22", KEYCODE_S, IP_JOY_NONE)
-	PORT_BITX(0x0200, IP_ACTIVE_HIGH, IPT_KEYBOARD, "toggle bit #23", KEYCODE_D, IP_JOY_NONE)
-	PORT_BITX(0x0100, IP_ACTIVE_HIGH, IPT_KEYBOARD, "toggle bit #24", KEYCODE_F, IP_JOY_NONE)
-	PORT_BITX(0x0080, IP_ACTIVE_HIGH, IPT_KEYBOARD, "toggle bit #25", KEYCODE_G, IP_JOY_NONE)
-	PORT_BITX(0x0040, IP_ACTIVE_HIGH, IPT_KEYBOARD, "toggle bit #26", KEYCODE_H, IP_JOY_NONE)
-	PORT_BITX(0x0020, IP_ACTIVE_HIGH, IPT_KEYBOARD, "toggle bit #27", KEYCODE_J, IP_JOY_NONE)
-	PORT_BITX(0x0010, IP_ACTIVE_HIGH, IPT_KEYBOARD, "toggle bit #28", KEYCODE_K, IP_JOY_NONE)
-	PORT_BITX(0x0008, IP_ACTIVE_HIGH, IPT_KEYBOARD, "toggle bit #29", KEYCODE_L, IP_JOY_NONE)
-	PORT_BITX(0x0004, IP_ACTIVE_HIGH, IPT_KEYBOARD, "toggle bit #30", KEYCODE_COLON, IP_JOY_NONE)
-	PORT_BITX(0x0002, IP_ACTIVE_HIGH, IPT_KEYBOARD, "toggle bit #31", KEYCODE_Z, IP_JOY_NONE)
-	PORT_BITX(0x0001, IP_ACTIVE_HIGH, IPT_KEYBOARD, "toggle bit #32", KEYCODE_X, IP_JOY_NONE)
+	PORT_BIT(0x8000, IP_ACTIVE_HIGH, IPT_KEYBOARD) PORT_NAME("Toggle bit #17") PORT_CODE(KEYCODE_U)
+	PORT_BIT(0x4000, IP_ACTIVE_HIGH, IPT_KEYBOARD) PORT_NAME("Toggle bit #18") PORT_CODE(KEYCODE_I)
+	PORT_BIT(0x2000, IP_ACTIVE_HIGH, IPT_KEYBOARD) PORT_NAME("Toggle bit #19") PORT_CODE(KEYCODE_O)
+	PORT_BIT(0x1000, IP_ACTIVE_HIGH, IPT_KEYBOARD) PORT_NAME("Toggle bit #20") PORT_CODE(KEYCODE_P)
+	PORT_BIT(0x0800, IP_ACTIVE_HIGH, IPT_KEYBOARD) PORT_NAME("Toggle bit #21") PORT_CODE(KEYCODE_A)
+	PORT_BIT(0x0400, IP_ACTIVE_HIGH, IPT_KEYBOARD) PORT_NAME("Toggle bit #22") PORT_CODE(KEYCODE_S)
+	PORT_BIT(0x0200, IP_ACTIVE_HIGH, IPT_KEYBOARD) PORT_NAME("Toggle bit #23") PORT_CODE(KEYCODE_D)
+	PORT_BIT(0x0100, IP_ACTIVE_HIGH, IPT_KEYBOARD) PORT_NAME("Toggle bit #24") PORT_CODE(KEYCODE_F)
+	PORT_BIT(0x0080, IP_ACTIVE_HIGH, IPT_KEYBOARD) PORT_NAME("Toggle bit #25") PORT_CODE(KEYCODE_G)
+	PORT_BIT(0x0040, IP_ACTIVE_HIGH, IPT_KEYBOARD) PORT_NAME("Toggle bit #26") PORT_CODE(KEYCODE_H)
+	PORT_BIT(0x0020, IP_ACTIVE_HIGH, IPT_KEYBOARD) PORT_NAME("Toggle bit #27") PORT_CODE(KEYCODE_J)
+	PORT_BIT(0x0010, IP_ACTIVE_HIGH, IPT_KEYBOARD) PORT_NAME("Toggle bit #28") PORT_CODE(KEYCODE_K)
+	PORT_BIT(0x0008, IP_ACTIVE_HIGH, IPT_KEYBOARD) PORT_NAME("Toggle bit #29") PORT_CODE(KEYCODE_L)
+	PORT_BIT(0x0004, IP_ACTIVE_HIGH, IPT_KEYBOARD) PORT_NAME("Toggle bit #30") PORT_CODE(KEYCODE_COLON)
+	PORT_BIT(0x0002, IP_ACTIVE_HIGH, IPT_KEYBOARD) PORT_NAME("Toggle bit #31") PORT_CODE(KEYCODE_Z)
+	PORT_BIT(0x0001, IP_ACTIVE_HIGH, IPT_KEYBOARD) PORT_NAME("Toggle bit #32") PORT_CODE(KEYCODE_X)
 
 INPUT_PORTS_END
 
@@ -319,7 +323,7 @@ static UINT32 panel_data_reg;	/* value of a data register on the control panel w
 /*
 	Not a real interrupt - just handle keyboard input
 */
-static int apexc_interrupt(void)
+static void apexc_interrupt(void)
 {
 	UINT32 edit_keys;
 	int control_keys;
@@ -412,9 +416,6 @@ static int apexc_interrupt(void)
 
 	/* remember new state of control keys */
 	old_control_keys = control_keys;
-
-
-	return ignore_interrupt();
 }
 
 /*
@@ -441,64 +442,61 @@ static unsigned short apexc_colortable[] =
 #define APEXC_PALETTE_SIZE sizeof(apexc_palette)/3
 #define APEXC_COLORTABLE_SIZE sizeof(apexc_colortable)/2
 
-static struct mame_bitmap *apexc_bitmap1;
-static struct mame_bitmap *apexc_bitmap2;
+static mame_bitmap *apexc_bitmap;
 
-static const struct rectangle panel_window =
+enum
 {
-	0,	256-1,	/* min_x, max_x */
-	0,	64-1,	/* min_y, max_y */
+	/* size and position of panel window */
+	panel_window_width = 256,
+	panel_window_height = 64,
+	panel_window_offset_x = 0,
+	panel_window_offset_y = 0,
+	/* size and position of teletyper window */
+	teletyper_window_width = 256,
+	teletyper_window_height = 128,
+	teletyper_window_offset_x = 0,
+	teletyper_window_offset_y = panel_window_height
 };
-static const struct rectangle teletyper_window =
+
+static const rectangle panel_window =
 {
-	0,	256-1,	/* min_x, max_x */
-	64,	192-1,	/* min_y, max_y */
+	panel_window_offset_x,	panel_window_offset_x+panel_window_width-1,	/* min_x, max_x */
+	panel_window_offset_y,	panel_window_offset_y+panel_window_height-1,/* min_y, max_y */
+};
+static const rectangle teletyper_window =
+{
+	teletyper_window_offset_x,	teletyper_window_offset_x+teletyper_window_width-1,	/* min_x, max_x */
+	teletyper_window_offset_y,	teletyper_window_offset_y+teletyper_window_height-1,/* min_y, max_y */
 };
 enum
 {
 	teletyper_scroll_step = 8
 };
-static const struct rectangle teletyper_scroll_clear_window =
+static const rectangle teletyper_scroll_clear_window =
 {
-	0,	256-1,	/* min_x, max_x */
-	192-teletyper_scroll_step,	192-1,	/* min_y, max_y */
+	teletyper_window_offset_x,	teletyper_window_offset_x+teletyper_window_width-1,	/* min_x, max_x */
+	teletyper_window_offset_y+teletyper_window_height-teletyper_scroll_step,	teletyper_window_offset_y+teletyper_window_height-1,	/* min_y, max_y */
 };
 static const int var_teletyper_scroll_step = - teletyper_scroll_step;
 
-static void apexc_init_palette(unsigned char *palette, unsigned short *colortable, const unsigned char *dummy)
+static PALETTE_INIT( apexc )
 {
-	memcpy(palette, & apexc_palette, sizeof(apexc_palette));
+	palette_set_colors(0, apexc_palette, APEXC_PALETTE_SIZE);
+
 	memcpy(colortable, & apexc_colortable, sizeof(apexc_colortable));
 }
 
-static int apexc_vh_start(void)
+static VIDEO_START( apexc )
 {
-	if ((apexc_bitmap1 = bitmap_alloc(Machine->drv->screen_width,Machine->drv->screen_height)) == NULL)
+	if ((apexc_bitmap = auto_bitmap_alloc(Machine->drv->screen_width,Machine->drv->screen_height)) == NULL)
 		return 1;
-	if ((apexc_bitmap2 = bitmap_alloc(Machine->drv->screen_width,Machine->drv->screen_height)) == NULL)
-	{
-		bitmap_free(apexc_bitmap1);
-		apexc_bitmap1 = NULL;
-		return 1;
-	}
-
-	fillbitmap(apexc_bitmap1, Machine->pens[0], &/*Machine->visible_area*/teletyper_window);
 
+	fillbitmap(apexc_bitmap, Machine->pens[0], &/*Machine->visible_area*/teletyper_window);
 	return 0;
 }
 
-/*#define apexc_vh_stop generic_vh_stop*/
-
-static void apexc_vh_stop(void)
-{
-	bitmap_free(apexc_bitmap1);
-	apexc_bitmap1 = NULL;
-	bitmap_free(apexc_bitmap2);
-	apexc_bitmap2 = NULL;
-}
-
 /* draw a small 8*8 LED (well, there were no LEDs at the time, so let's call this a lamp ;-) ) */
-static void apexc_draw_led(struct mame_bitmap *bitmap, int x, int y, int state)
+static void apexc_draw_led(mame_bitmap *bitmap, int x, int y, int state)
 {
 	int xx, yy;
 
@@ -508,14 +506,14 @@ static void apexc_draw_led(struct mame_bitmap *bitmap, int x, int y, int state)
 }
 
 /* write a single char on screen */
-static void apexc_draw_char(struct mame_bitmap *bitmap, char character, int x, int y, int color)
+static void apexc_draw_char(mame_bitmap *bitmap, char character, int x, int y, int color)
 {
 	drawgfx(bitmap, Machine->gfx[0], character-32, color, 0, 0,
 				x+1, y, &Machine->visible_area, TRANSPARENCY_PEN, 0);
 }
 
 /* write a string on screen */
-static void apexc_draw_string(struct mame_bitmap *bitmap, const char *buf, int x, int y, int color)
+static void apexc_draw_string(mame_bitmap *bitmap, const char *buf, int x, int y, int color)
 {
 	while (* buf)
 	{
@@ -527,12 +525,13 @@ static void apexc_draw_string(struct mame_bitmap *bitmap, const char *buf, int x
 }
 
 
-static void apexc_vh_refresh(struct mame_bitmap *bitmap, int full_refresh)
+static VIDEO_UPDATE( apexc )
 {
 	int i;
 	char the_char;
 
-	if (full_refresh)
+
+	/*if (full_refresh)*/
 	{
 		fillbitmap(bitmap, Machine->pens[0], &/*Machine->visible_area*/panel_window);
 		apexc_draw_string(bitmap, "power", 8, 0, 0);
@@ -540,7 +539,7 @@ static void apexc_vh_refresh(struct mame_bitmap *bitmap, int full_refresh)
 		apexc_draw_string(bitmap, "data :", 0, 24, 0);
 	}
 
-	copybitmap(bitmap, apexc_bitmap1, 0, 0, 0, 0, &teletyper_window, TRANSPARENCY_NONE, 0);
+	copybitmap(bitmap, apexc_bitmap, 0, 0, 0, 0, &teletyper_window, TRANSPARENCY_NONE, 0);
 
 
 	apexc_draw_led(bitmap, 0, 0, 1);
@@ -571,17 +570,16 @@ static void apexc_teletyper_init(void)
 
 static void apexc_teletyper_linefeed(void)
 {
-	struct mame_bitmap *tmp;
+	UINT8 buf[teletyper_window_width];
+	int y;
 
-	copyscrollbitmap(apexc_bitmap2, apexc_bitmap1, 0, NULL, 1, &var_teletyper_scroll_step,
-						&Machine->visible_area, TRANSPARENCY_NONE, 0);
+	for (y=teletyper_window_offset_y; y<teletyper_window_offset_y+teletyper_window_height-teletyper_scroll_step; y++)
+	{
+		extract_scanline8(apexc_bitmap, teletyper_window_offset_x, y+teletyper_scroll_step, teletyper_window_width, buf);
+		draw_scanline8(apexc_bitmap, teletyper_window_offset_x, y, teletyper_window_width, buf, Machine->pens, -1);
+	}
 
-	fillbitmap(apexc_bitmap2, Machine->pens[0], &teletyper_scroll_clear_window);
-
-	/* swap apexc_bitmap1 & apexc_bitmap2 (goofy, but faster than calling copybitmap) */
-	tmp = apexc_bitmap1;
-	apexc_bitmap1 = apexc_bitmap2;
-	apexc_bitmap2 = tmp;
+	fillbitmap(apexc_bitmap, Machine->pens[0], &teletyper_scroll_clear_window);
 }
 
 static void apexc_teletyper_putchar(int character)
@@ -648,7 +646,7 @@ static void apexc_teletyper_putchar(int character)
 		/* print character */
 		buffer[0] = ascii_table[letters][character];	/* lookup ASCII equivalent in table */
 		buffer[1] = '\0';								/* terminate string */
-		apexc_draw_string(apexc_bitmap1, buffer, 8*pos, 176, 0);	/* print char */
+		apexc_draw_string(apexc_bitmap, buffer, 8*pos, 176, 0);	/* print char */
 		pos++;											/* step carriage forward */
 
 		break;
@@ -686,7 +684,7 @@ static void init_apexc(void)
 		0x00,0x00,0x30,0x30,0x00,0x30,0x30,0x00,0x00,0x00,0x30,0x30,0x00,0x30,0x30,0x60,
 		0x10,0x20,0x40,0x80,0x40,0x20,0x10,0x00,0x00,0x00,0xf8,0x00,0xf8,0x00,0x00,0x00,
 		0x40,0x20,0x10,0x08,0x10,0x20,0x40,0x00,0x70,0x88,0x08,0x10,0x20,0x00,0x20,0x00,
-		0x30,0x48,0x94,0xa4,0xa4,0x94,0x48,0x30,0x70,0x88,0x88,0xf8,0x88,0x88,0x88,0x00,
+		0x70,0x88,0xb8,0xa8,0xb8,0x80,0x70,0x00,0x70,0x88,0x88,0xf8,0x88,0x88,0x88,0x00,
 		0xf0,0x88,0x88,0xf0,0x88,0x88,0xf0,0x00,0x70,0x88,0x80,0x80,0x80,0x88,0x70,0x00,
 		0xf0,0x88,0x88,0x88,0x88,0x88,0xf0,0x00,0xf8,0x80,0x80,0xf0,0x80,0x80,0xf8,0x00,
 		0xf8,0x80,0x80,0xf0,0x80,0x80,0x80,0x00,0x70,0x88,0x80,0x98,0x88,0x88,0x70,0x00,
@@ -765,7 +763,7 @@ static void init_apexc(void)
 	memcpy(dst, fontdata6x8, apexcfontdata_size);
 }
 
-static struct GfxLayout fontlayout =
+static gfx_layout fontlayout =
 {
 	6, 8,			/* 6*8 characters */
 	apexc_charnum,	/* 96+4 characters */
@@ -776,127 +774,63 @@ static struct GfxLayout fontlayout =
 	8*8 /* every char takes 8 consecutive bytes */
 };
 
-static struct GfxDecodeInfo gfxdecodeinfo[] =
+static gfx_decode gfxdecodeinfo[] =
 {
 	{ REGION_GFX1, 0, &fontlayout, 0, 1 },
 	{ -1 }	/* end of array */
 };
 
 
-static MEMORY_READ32_START(readmem)
-#ifdef SUPPORT_ODD_WORD_SIZES
-	{ 0x0000, 0x03ff, MRA32_RAM },	/* 1024 32-bit words (expandable to 8192) */
-	{ 0x0400, 0x1fff, MRA32_NOP },
+static ADDRESS_MAP_START(apexc_mem_map, ADDRESS_SPACE_PROGRAM, 32)
+#if 0
+	AM_RANGE(0x0000, 0x03ff) AM_READWRITE(MRA32_RAM, MWA32_RAM)	/* 1024 32-bit words (expandable to 8192) */
+	AM_RANGE(0x0400, 0x1fff) AM_READWRITE(MRA32_NOP, MWA32_NOP)
 #else
-	{ 0x0000, 0x0fff, MRA32_RAM },
-	{ 0x1000, 0x7fff, MRA32_NOP },
+	AM_RANGE(0x0000, 0x0fff) AM_READWRITE(MRA32_RAM, MWA32_RAM)
+	AM_RANGE(0x1000, 0x7fff) AM_READWRITE(MRA32_NOP, MWA32_NOP)
 #endif
-MEMORY_END
+ADDRESS_MAP_END
 
-static MEMORY_WRITE32_START(writemem)
-#ifdef SUPPORT_ODD_WORD_SIZES
-	{ 0x0000, 0x03ff, MWA32_RAM },	/* 1024 32-bit words (expandable to 8192) */
-	{ 0x0400, 0x1fff, MWA32_NOP },
-#else
-	{ 0x0000, 0x0fff, MWA32_RAM },
-	{ 0x1000, 0x7fff, MWA32_NOP },
-#endif
-MEMORY_END
+static ADDRESS_MAP_START(apexc_io_map, ADDRESS_SPACE_IO, 8)
+	AM_RANGE(0, 0) AM_READWRITE(tape_read, tape_write)
+ADDRESS_MAP_END
 
-static PORT_READ32_START(readport)
-	{0, 0, tape_read},
-PORT_END
 
-static PORT_WRITE32_START(writeport)
-	{0, 0, tape_write},
-PORT_END
+static MACHINE_DRIVER_START(apexc)
 
-static struct MachineDriver machine_driver_apexc =
-{
 	/* basic machine hardware */
-	{
-		{
-			CPU_APEXC,
-			2000,	/* 2.0 kHz (memory word clock frequency) */
-			readmem, writemem, readport, writeport,
-			apexc_interrupt, 1,	/* handles the control panel */
-			0, 0,
-			0
-		},
-	},
-	60, DEFAULT_REAL_60HZ_VBLANK_DURATION,	/* frames per second, vblank duration : meaningless */
-	1,
-	apexc_init_machine,
-	apexc_stop_machine,
+	/* APEXC CPU @ 2.0 kHz (memory word clock frequency) */
+	MDRV_CPU_ADD(APEXC, 2000)
+	/*MDRV_CPU_CONFIG(NULL)*/
+	MDRV_CPU_PROGRAM_MAP(apexc_mem_map, 0)
+	MDRV_CPU_IO_MAP(apexc_io_map, 0)
+	/* dummy interrupt: handles the control panel */
+	MDRV_CPU_VBLANK_INT(apexc_interrupt, 1)
+	/*MDRV_CPU_PERIODIC_INT(func, rate)*/
 
-	/* video hardware */
-	256,						/* screen width */
-	192,						/* screen height */
-	{ 0, 256-1, 0, 192-1},		/* visible_area */
-	gfxdecodeinfo,				/* graphics decode info (???)*/
-	APEXC_PALETTE_SIZE,			/* palette is 3*total_colors bytes long */
-	APEXC_COLORTABLE_SIZE,		/* length in shorts of the color lookup table */
-	apexc_init_palette,			/* palette init */
+	/* video hardware does not exist, but we display a control panel and the typewriter output */
+	MDRV_FRAMES_PER_SECOND(60)
+	MDRV_VBLANK_DURATION(DEFAULT_REAL_60HZ_VBLANK_DURATION)
+	/*MDRV_INTERLEAVE(interleave)*/
 
-	VIDEO_TYPE_RASTER,
-	0,
-	apexc_vh_start,
-	apexc_vh_stop,
-	apexc_vh_refresh,
+	MDRV_MACHINE_INIT( apexc )
+	/*MDRV_NVRAM_HANDLER( NULL )*/
 
-	/* sound hardware */
-	0,
-	0,0,0,
-	{
-		{(int)NULL,},
-	},
+	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER)
+	/*MDRV_ASPECT_RATIO(num, den)*/
+	MDRV_SCREEN_SIZE(256, 192)
+	MDRV_VISIBLE_AREA(0, 256-1, 0, 192-1)
 
-	/* NVRAM handler */
-	NULL
-};
+	MDRV_GFXDECODE(gfxdecodeinfo)
+	MDRV_PALETTE_LENGTH(APEXC_PALETTE_SIZE)
+	MDRV_COLORTABLE_LENGTH(APEXC_COLORTABLE_SIZE)
 
-static const struct IODevice io_apexc[] =
-{
-	{
-		IO_CYLINDER,			/* type */
-		1,						/* count */
-		"apc\0",				/* file extensions */
-		IO_RESET_ALL,			/* reset if file changed */
-		NULL,					/* id */
-		apexc_cylinder_init,	/* init */
-		apexc_cylinder_exit,	/* exit */
-		NULL,					/* info */
-		NULL,					/* open */
-		NULL,					/* close */
-		NULL,					/* status */
-		NULL,					/* seek */
-		NULL,					/* tell */
-		NULL,					/* input */
-		NULL,					/* output */
-		NULL,					/* input_chunk */
-		NULL					/* output_chunk */
-	},
-	{
-		IO_PUNCHTAPE,			/* type */
-		2,						/* count */
-		"tap\0",				/* file extensions */
-		IO_RESET_NONE,			/* reset if file changed */
-		NULL,					/* id */
-		apexc_tape_init,		/* init */
-		apexc_tape_exit,		/* exit */
-		NULL,					/* info */
-		NULL,					/* open */
-		NULL,					/* close */
-		NULL,					/* status */
-		NULL,					/* seek */
-		NULL,					/* tell */
-		NULL,					/* input */
-		NULL,					/* output */
-		NULL,					/* input_chunk */
-		NULL					/* output_chunk */
-	},
-	{ IO_END }
-};
+	MDRV_PALETTE_INIT(apexc)
+	MDRV_VIDEO_START(apexc)
+	/*MDRV_VIDEO_EOF(name)*/
+	MDRV_VIDEO_UPDATE(apexc)
+
+MACHINE_DRIVER_END
 
 ROM_START(apexc)
 	/*CPU memory space*/
@@ -907,6 +841,36 @@ ROM_START(apexc)
 		/* space filled with our font */
 ROM_END
 
-/*		YEAR	NAME		PARENT	MACHINE		INPUT	INIT	COMPANY		FULLNAME */
-/*COMP( c. 1951,	apexc53,	0,		apexc53,	apexc,	apexc,	"Booth",	"APEXC (as described in 1953)" )*/
-COMP( 1955,	apexc,		/*apexc53*/0,		apexc,		apexc,	apexc,	"Booth",	"APEXC (as described in 1957)" )
+static void apexc_cylinder_getinfo(struct IODevice *dev)
+{
+	/* cylinder */
+	dev->type = IO_CYLINDER;
+	dev->count = 1;
+	dev->file_extensions = "apc\0";
+	dev->reset_on_load = 1;
+	dev->readable = 1;
+	dev->writeable = 1;
+	dev->creatable = 0;
+	dev->load = device_load_apexc_cylinder;
+	dev->unload = device_unload_apexc_cylinder;
+}
+
+static void apexc_punchtape_getinfo(struct IODevice *dev)
+{
+	/* punchtape */
+	dev->type = IO_PUNCHTAPE;
+	dev->count = 2;
+	dev->file_extensions = "tap\0";
+	dev->getdispositions = apexc_get_open_mode;
+	dev->init = device_init_apexc_tape;
+	dev->load = device_load_apexc_tape;
+}
+
+SYSTEM_CONFIG_START(apexc)
+	CONFIG_DEVICE(apexc_cylinder_getinfo)
+	CONFIG_DEVICE(apexc_punchtape_getinfo)
+SYSTEM_CONFIG_END
+
+/*		   YEAR		NAME		PARENT			COMPAT	MACHINE		INPUT	INIT	CONFIG	COMPANY		FULLNAME */
+/*COMP( c. 1951,	apexc53,	0,				0,		apexc53,	apexc,	apexc,	apexc,	"Booth",	"APEXC (as described in 1953)" , 0)*/
+COMP(      1955,	apexc,		/*apexc53*/0,	0,		apexc,		apexc,	apexc,	apexc,	"Booth",	"APEXC (as described in 1957)" , 0)
