@@ -6,33 +6,34 @@
 
 #include <assert.h>
 #include "driver.h"
+#include "image.h"
 #include "cpu/s2650/s2650.h"
-
 #include "includes/arcadia.h"
+#include "devices/cartslot.h"
 
-static MEMORY_READ_START( arcadia_readmem )
-{ 0x0000, 0x0fff, MRA_ROM },
-{ 0x1800, 0x1aff, arcadia_video_r },
-{ 0x2000, 0x2fff, MRA_ROM },
-MEMORY_END
+static ADDRESS_MAP_START( arcadia_readmem , ADDRESS_SPACE_PROGRAM, 8)
+	AM_RANGE( 0x0000, 0x0fff) AM_READ( MRA8_ROM )
+	AM_RANGE( 0x1800, 0x1aff) AM_READ( arcadia_video_r )
+	AM_RANGE( 0x2000, 0x2fff) AM_READ( MRA8_ROM )
+ADDRESS_MAP_END
 
-static MEMORY_WRITE_START( arcadia_writemem )
-/*	{ 0x0000, 0x0fff, MWA_ROM }, */
-	{ 0x1800, 0x1aff, arcadia_video_w },
-/*	{ 0x2000, 0x2fff, MWA_ROM }, */
-MEMORY_END
+static ADDRESS_MAP_START( arcadia_writemem , ADDRESS_SPACE_PROGRAM, 8)
+/*	{ 0x0000, 0x0fff, MWA8_ROM }, */
+	AM_RANGE( 0x1800, 0x1aff) AM_WRITE( arcadia_video_w )
+/*	{ 0x2000, 0x2fff, MWA8_ROM }, */
+ADDRESS_MAP_END
 
-static PORT_READ_START( arcadia_readport )
+static ADDRESS_MAP_START( arcadia_readport , ADDRESS_SPACE_IO, 8)
 /*{ S2650_CTRL_PORT,S2650_CTRL_PORT, }, */
 /*{ S2650_DATA_PORT,S2650_DATA_PORT, }, */
-{ S2650_SENSE_PORT,S2650_SENSE_PORT, arcadia_vsync_r},
-PORT_END
+AM_RANGE( S2650_SENSE_PORT,S2650_SENSE_PORT) AM_READ( arcadia_vsync_r)
+ADDRESS_MAP_END
 
-static PORT_WRITE_START( arcadia_writeport )
-PORT_END
+static ADDRESS_MAP_START( arcadia_writeport , ADDRESS_SPACE_IO, 8)
+ADDRESS_MAP_END
 
 #define DIPS_HELPER(bit, name, keycode, r) \
-   PORT_BITX(bit, IP_ACTIVE_HIGH, IPT_KEYBOARD, name, keycode, r)
+   PORT_BIT(bit, IP_ACTIVE_HIGH, IPT_KEYBOARD) PORT_NAME(name) PORT_CODE(keycode) PORT_CODE(r)
 
 INPUT_PORTS_START( arcadia )
 	PORT_START
@@ -82,13 +83,13 @@ INPUT_PORTS_START( arcadia )
 #if 0
     /* shit, auto centering too slow, so only using 5 bits, and scaling at videoside */
     PORT_START
-PORT_ANALOGX(0x1ff,0x10,IPT_AD_STICK_X|IPF_CENTER,1,2000,0,0x1f,KEYCODE_LEFT,KEYCODE_RIGHT,JOYCODE_1_LEFT,JOYCODE_1_RIGHT)
+PORT_BIT(0x1ff,0x10,IPT_AD_STICK_X) PORT_SENSITIVITY(1) PORT_KEYDELTA(2000) PORT_MINMAX(0,0x1f) PORT_CODE_DEC(KEYCODE_LEFT) PORT_CODE_INC(KEYCODE_RIGHT) PORT_CODE_DEC(JOYCODE_1_LEFT) PORT_CODE_INC(JOYCODE_1_RIGHT) PORT_RESET
     PORT_START
-PORT_ANALOGX(0x1ff,0x10,IPT_AD_STICK_Y|IPF_CENTER,1,2000,0,0x1f,KEYCODE_UP,KEYCODE_DOWN,JOYCODE_1_UP,JOYCODE_1_DOWN)
+PORT_BIT(0x1ff,0x10,IPT_AD_STICK_Y) PORT_SENSITIVITY(1) PORT_KEYDELTA(2000) PORT_MINMAX(0,0x1f) PORT_CODE_DEC(KEYCODE_UP) PORT_CODE_INC(KEYCODE_DOWN) PORT_CODE_DEC(JOYCODE_1_UP) PORT_CODE_INC(JOYCODE_1_DOWN) PORT_RESET
     PORT_START
-PORT_ANALOGX(0x1ff,0x10,IPT_AD_STICK_X|IPF_CENTER|IPF_PLAYER2,100,10,0,0x1f,KEYCODE_DEL,KEYCODE_PGDN,JOYCODE_2_LEFT,JOYCODE_2_RIGHT)
+PORT_BIT(0x1ff,0x10,IPT_AD_STICK_X) PORT_SENSITIVITY(100) PORT_KEYDELTA(10) PORT_MINMAX(0,0x1f) PORT_CODE_DEC(KEYCODE_DEL) PORT_CODE_INC(KEYCODE_PGDN) PORT_CODE_DEC(JOYCODE_2_LEFT) PORT_CODE_INC(JOYCODE_2_RIGHT) PORT_PLAYER(2) PORT_RESET
     PORT_START
-PORT_ANALOGX(0x1ff,0x10,IPT_AD_STICK_Y|IPF_CENTER|IPF_PLAYER2,100,10,0,0x1f,KEYCODE_HOME,KEYCODE_END,JOYCODE_2_UP,JOYCODE_2_DOWN)
+PORT_BIT(0x1ff,0x10,IPT_AD_STICK_Y) PORT_SENSITIVITY(100) PORT_KEYDELTA(10) PORT_MINMAX(0,0x1f) PORT_CODE_DEC(KEYCODE_HOME) PORT_CODE_INC(KEYCODE_END) PORT_CODE_DEC(JOYCODE_2_UP) PORT_CODE_INC(JOYCODE_2_DOWN) PORT_PLAYER(2) PORT_RESET
 #else
 	PORT_START
 	DIPS_HELPER( 0x01, "Player 1/left", KEYCODE_LEFT, CODE_NONE)
@@ -158,13 +159,13 @@ PORT_BIT ( 0xf0, 0xf0,	 IPT_UNUSED ) /* some bits must be high */
 #if 0
     /* shit, auto centering too slow, so only using 5 bits, and scaling at videoside */
     PORT_START
-PORT_ANALOGX(0x1ff,0x10,IPT_AD_STICK_X|IPF_CENTER,1,2000,0,0x1f,KEYCODE_LEFT,KEYCODE_RIGHT,JOYCODE_1_LEFT,JOYCODE_1_RIGHT)
+PORT_BIT(0x1ff,0x10,IPT_AD_STICK_X) PORT_SENSITIVITY(1) PORT_KEYDELTA(2000) PORT_MINMAX(0,0x1f) PORT_CODE_DEC(KEYCODE_LEFT) PORT_CODE_INC(KEYCODE_RIGHT) PORT_CODE_DEC(JOYCODE_1_LEFT) PORT_CODE_INC(JOYCODE_1_RIGHT) PORT_RESET
     PORT_START
-PORT_ANALOGX(0x1ff,0x10,IPT_AD_STICK_Y|IPF_CENTER,1,2000,0,0x1f,KEYCODE_UP,KEYCODE_DOWN,JOYCODE_1_UP,JOYCODE_1_DOWN)
+PORT_BIT(0x1ff,0x10,IPT_AD_STICK_Y) PORT_SENSITIVITY(1) PORT_KEYDELTA(2000) PORT_MINMAX(0,0x1f) PORT_CODE_DEC(KEYCODE_UP) PORT_CODE_INC(KEYCODE_DOWN) PORT_CODE_DEC(JOYCODE_1_UP) PORT_CODE_INC(JOYCODE_1_DOWN) PORT_RESET
     PORT_START
-PORT_ANALOGX(0x1ff,0x10,IPT_AD_STICK_X|IPF_CENTER|IPF_PLAYER2,100,10,0,0x1f,KEYCODE_DEL,KEYCODE_PGDN,JOYCODE_2_LEFT,JOYCODE_2_RIGHT)
+PORT_BIT(0x1ff,0x10,IPT_AD_STICK_X) PORT_SENSITIVITY(100) PORT_KEYDELTA(10) PORT_MINMAX(0,0x1f) PORT_CODE_DEC(KEYCODE_DEL) PORT_CODE_INC(KEYCODE_PGDN) PORT_CODE_DEC(JOYCODE_2_LEFT) PORT_CODE_INC(JOYCODE_2_RIGHT) PORT_PLAYER(2) PORT_RESET
     PORT_START
-PORT_ANALOGX(0x1ff,0x10,IPT_AD_STICK_Y|IPF_CENTER|IPF_PLAYER2,100,10,0,0x1f,KEYCODE_HOME,KEYCODE_END,JOYCODE_2_UP,JOYCODE_2_DOWN)
+PORT_BIT(0x1ff,0x10,IPT_AD_STICK_Y) PORT_SENSITIVITY(100) PORT_KEYDELTA(10) PORT_MINMAX(0,0x1f) PORT_CODE_DEC(KEYCODE_HOME) PORT_CODE_INC(KEYCODE_END) PORT_CODE_DEC(JOYCODE_2_UP) PORT_CODE_INC(JOYCODE_2_DOWN) PORT_PLAYER(2) PORT_RESET
 #else
 	PORT_START
 	DIPS_HELPER( 0x01, "Player 1/left", KEYCODE_LEFT, CODE_NONE)
@@ -178,7 +179,7 @@ PORT_ANALOGX(0x1ff,0x10,IPT_AD_STICK_Y|IPF_CENTER|IPF_PLAYER2,100,10,0,0x1f,KEYC
 #endif
 INPUT_PORTS_END
 
-static struct GfxLayout arcadia_charlayout =
+static gfx_layout arcadia_charlayout =
 {
         8,1,
         256,                                    /* 256 characters */
@@ -200,85 +201,62 @@ static struct GfxLayout arcadia_charlayout =
         1*8
 };
 
-static struct GfxDecodeInfo arcadia_gfxdecodeinfo[] = {
+static gfx_decode arcadia_gfxdecodeinfo[] = {
     { REGION_GFX1, 0x0000, &arcadia_charlayout,                     0, 2 },
     { -1 } /* end of array */
 };
 
-static int arcadia_frame_int(void)
+static unsigned char arcadia_palette[] =
 {
-	return 0;
-}
-
-static unsigned char arcadia_palette[8][3] =
-{
-    { 255, 255, 255 }, /* white */
-    { 255, 255, 0 }, /* yellow */
-    { 0, 255, 255 }, /* cyan */
-    { 0, 255, 0 }, /* green */
-    { 255, 0, 255 }, /* magenta */
-    { 255, 0, 0 }, /* red */
-    { 0, 0, 255, }, /* blue */
-    { 0, 0, 0 } /* black */
+	255, 255, 255,	/* white */
+	255, 255, 0,	/* yellow */
+	0, 255, 255,	/* cyan */
+	0, 255, 0,		/* green */
+	255, 0, 255,	/* magenta */
+	255, 0, 0,		/* red */
+	0, 0, 255,		/* blue */
+	0, 0, 0			/* black */
 };
 
 static unsigned short arcadia_colortable[1][2] = {
 	{ 0, 1 },
 };
 
-static void arcadia_init_colors (unsigned char *sys_palette,
-				 unsigned short *sys_colortable,
-				 const unsigned char *color_prom)
+static PALETTE_INIT( arcadia )
 {
-    memcpy (sys_palette, arcadia_palette, sizeof (arcadia_palette));
-    memcpy(sys_colortable, arcadia_colortable,sizeof(arcadia_colortable));
+	palette_set_colors(0, arcadia_palette, sizeof (arcadia_palette)/3);
+    memcpy(colortable, arcadia_colortable,sizeof(arcadia_colortable));
 }
 
-static void arcadia_machine_init(void)
-{
-}
-
-static struct MachineDriver machine_driver_arcadia =
-{
+static MACHINE_DRIVER_START( arcadia )
 	/* basic machine hardware */
-	{
-		{
-			CPU_S2650,
-			3580000/3,
-			arcadia_readmem,arcadia_writemem,
-			arcadia_readport,arcadia_writeport,
-			arcadia_frame_int, 1,
-			arcadia_video_line,262*60,
-			NULL
-		}
-	},
-	/* frames per second, VBL duration */
-	60, DEFAULT_60HZ_VBLANK_DURATION,
-	1,				/* single CPU */
-	arcadia_machine_init,
-	0,/*pc1401_machine_stop, */
-#if arcadia_DEBUG
-	128+2*XPOS+40, 262, { 0, 2*XPOS+128-1+40, 0, 262-1},
-#else
-	128+2*XPOS, 262, { 0, 2*XPOS+128-1, 0, 262-1},
-#endif
-	arcadia_gfxdecodeinfo,			   /* graphics decode info */
-	sizeof (arcadia_palette) / sizeof (arcadia_palette[0]) ,
-	sizeof (arcadia_colortable) / sizeof(arcadia_colortable[0][0]),
-	arcadia_init_colors,		/* convert color prom */
+	MDRV_CPU_ADD_TAG("main", S2650, 3580000/3)        /* 1.796 Mhz */
+	MDRV_CPU_PROGRAM_MAP(arcadia_readmem,arcadia_writemem)
+	MDRV_CPU_IO_MAP(arcadia_readport,arcadia_writeport)
+	MDRV_CPU_PERIODIC_INT(arcadia_video_line, TIME_IN_HZ(262*60))
+	MDRV_FRAMES_PER_SECOND(60)
+	MDRV_VBLANK_DURATION(DEFAULT_60HZ_VBLANK_DURATION)
+	MDRV_INTERLEAVE(1)
 
-	VIDEO_TYPE_RASTER,	/* video flags */
-	0,						/* obsolete */
-	arcadia_vh_start,
-	arcadia_vh_stop,
-	arcadia_vh_screenrefresh,
+    /* video hardware */
+	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER)
+	MDRV_SCREEN_SIZE(128+2*XPOS, 262)
+	MDRV_VISIBLE_AREA(0, 2*XPOS+128-1, 0, 262-1)
+	MDRV_GFXDECODE( arcadia_gfxdecodeinfo )
+	MDRV_PALETTE_LENGTH(sizeof (arcadia_palette) / sizeof (arcadia_palette[0]))
+	MDRV_COLORTABLE_LENGTH(sizeof (arcadia_colortable) / sizeof(arcadia_colortable[0][0]))
+	MDRV_PALETTE_INIT( arcadia )
+
+	MDRV_VIDEO_START( arcadia )
+	MDRV_VIDEO_UPDATE( arcadia )
 
 	/* sound hardware */
-	0,0,0,0,
-	{
-	    {SOUND_CUSTOM, &arcadia_sound_interface},
-	}
-};
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+	MDRV_SOUND_ADD(CUSTOM, 0)
+	MDRV_SOUND_CONFIG(arcadia_sound_interface)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.00)
+MACHINE_DRIVER_END
+
 
 ROM_START(arcadia)
 	ROM_REGION(0x8000,REGION_CPU1, 0)
@@ -290,33 +268,23 @@ ROM_START(vcg)
 	ROM_REGION(0x100,REGION_GFX1, 0)
 ROM_END
 
-static int arcadia_init_cart(int id)
+static DEVICE_LOAD( arcadia_cart )
 {
-	FILE *cartfile;
 	UINT8 *rom = memory_region(REGION_CPU1);
 	int size;
 
-	if (device_filename(IO_CARTSLOT, id) == NULL)
-	{
-		printf("%s requires Cartridge!\n", Machine->gamedrv->name);
-		return INIT_FAIL;
-	}
-
 	memset(rom, 0, 0x8000);
-	if (!(cartfile = (FILE*)image_fopen(IO_CARTSLOT, id, OSD_FILETYPE_IMAGE, 0)))
-	{
-		logerror("%s not found\n",device_filename(IO_CARTSLOT,id));
-		return INIT_FAIL;
-	}
-	size=osd_fsize(cartfile);
+	size = mame_fsize(file);
 
-	if (osd_fread(cartfile, rom, size)!=size) {
-		logerror("%s load error\n",device_filename(IO_CARTSLOT,id));
-		osd_fclose(cartfile);
+	if (size > memory_region_length(REGION_CPU1))
+		size = memory_region_length(REGION_CPU1);
+
+	if (mame_fread(file, rom, size) != size)
 		return INIT_FAIL;
-	}
-	osd_fclose(cartfile);
-	if (size>0x1000) memmove(rom+0x2000, rom+0x1000, size-0x1000);
+
+	if (size > 0x1000)
+		memmove(rom + 0x2000, rom + 0x1000, size - 0x1000);
+
 #if 1
 	/* golf cartridge support */
 	/* 4kbyte at 0x0000 */
@@ -349,32 +317,27 @@ static int arcadia_init_cart(int id)
 	return INIT_PASS;
 }
 
-static const struct IODevice io_arcadia[] = {
-	{
-		IO_CARTSLOT,					/* type */
-		1,								/* count */
-		"bin\0",                        /* file extensions */
-		IO_RESET_ALL,					/* reset if file changed */
-		0,
-		arcadia_init_cart, 				/* init */
-		NULL,							/* exit */
-		NULL,							/* info */
-		NULL,							/* open */
-		NULL,							/* close */
-		NULL,							/* status */
-		NULL,							/* seek */
-		NULL,							/* tell */
-		NULL,							/* input */
-		NULL,							/* output */
-		NULL,							/* input_chunk */
-		NULL							/* output_chunk */
-	},
-    { IO_END }
-};
+static void arcadia_cartslot_getinfo(struct IODevice *dev)
+{
+	/* cartslot */
+	cartslot_device_getinfo(dev);
+	dev->count = 1;
+	dev->file_extensions = "bin\0";
+	dev->must_be_loaded = 1;
+	dev->load = device_load_arcadia_cart;
+}
 
-#define io_vcg io_arcadia
+SYSTEM_CONFIG_START(arcadia)
+	CONFIG_DEVICE(arcadia_cartslot_getinfo)
+SYSTEM_CONFIG_END
 
-void init_arcadia(void)
+/***************************************************************************
+
+  Game driver(s)
+
+***************************************************************************/
+
+static void init_arcadia(void)
 {
 	int i;
 	UINT8 *gfx=memory_region(REGION_GFX1);
@@ -508,10 +471,10 @@ void init_arcadia(void)
 #endif
 }
 
-/*    YEAR  NAME      PARENT    MACHINE   INPUT     INIT      COMPANY   FULLNAME */
+/*    YEAR	NAME		PARENT		COMPAT	MACHINE   INPUT     INIT		COMPANY		FULLNAME */
 /* marketed from several firms/names */
 
-CONSX( 1982, arcadia,	0,	arcadia,  arcadia,  arcadia,		"Emerson",		"Arcadia 2001", GAME_IMPERFECT_SOUND )
+CONS(1982,	arcadia,	0,			0,		arcadia,  arcadia,  arcadia,	arcadia,	"Emerson",		"Arcadia 2001", GAME_IMPERFECT_SOUND )
 /* schmid tvg 2000 (developer? PAL) */
 
 /* different cartridge connector */
@@ -519,16 +482,4 @@ CONSX( 1982, arcadia,	0,	arcadia,  arcadia,  arcadia,		"Emerson",		"Arcadia 2001
 
 /* different cartridge connector (same size as mpt03, but different pinout!) */
 /* 16 keys instead of 12 */
-CONSX( 198?, vcg,	arcadia,arcadia,  vcg,  arcadia,		"Palladium",		"VIDEO - COMPUTER - GAME", GAME_IMPERFECT_SOUND )
-
-
-#ifdef RUNTIME_LOADER
-extern void arcadia_runtime_loader_init(void)
-{
-	int i;
-	for (i=0; drivers[i]; i++) {
-		if ( strcmp(drivers[i]->name,"arcadia")==0) drivers[i]=&driver_arcadia;
-		if ( strcmp(drivers[i]->name,"vcg")==0) drivers[i]=&driver_vcg;
-	}
-}
-#endif
+CONS(198?, vcg,		arcadia,	0,		arcadia,  vcg,		arcadia,	arcadia,	"Palladium",		"VIDEO - COMPUTER - GAME", GAME_IMPERFECT_SOUND )
