@@ -44,11 +44,13 @@
 #include "devices/cartslot.h"
 
 static ADDRESS_MAP_START( sms_mem, ADDRESS_SPACE_PROGRAM, 8 )
-	AM_RANGE(0x0000, 0x3FFF) AM_ROM									/* ROM bank #1 */
-	AM_RANGE(0x4000, 0x7FFF) AM_ROM									/* ROM bank #2 */
-	AM_RANGE(0x8000, 0xBFFF) AM_READWRITE(MRA8_RAM, sms_cartram_w)	/* ROM bank #3 / On-cart RAM */
-	AM_RANGE(0xC000, 0xDFFB) AM_MIRROR(0x2000) AM_RAM				/* RAM (mirror at 0xE000) */
-	AM_RANGE(0xFFFC, 0xFFFF) AM_MIRROR(0x2000) AM_READWRITE(MRA8_RAM, sms_mapper_w)	/* Bankswitch control (mirrored at 0xDFFC???) */
+	AM_RANGE(0x0000, 0x03FF) AM_ROMBANK(1)					/* First 0x0400 part always points to first page */
+	AM_RANGE(0x0400, 0x3FFF) AM_ROMBANK(2)					/* switchable rom bank */
+	AM_RANGE(0x4000, 0x7FFF) AM_ROMBANK(3)					/* switchable rom bank */
+	AM_RANGE(0x8000, 0xBFFF) AM_READWRITE(MRA8_BANK4, sms_cartram_w)	/* ROM bank / on-cart RAM */
+	AM_RANGE(0xC000, 0xDFFB) AM_MIRROR(0x2000) AM_RAM			/* RAM (mirror at 0xE000) */
+	AM_RANGE(0xDFFC, 0xDFFF) AM_RAM						/* RAM "underneath" frame registers */
+	AM_RANGE(0xFFFC, 0xFFFF) AM_READWRITE(sms_mapper_r, sms_mapper_w)	/* Bankswitch control */
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( sms_io, ADDRESS_SPACE_IO, 8 )
@@ -224,88 +226,76 @@ ROM_END
 
 ROM_START(smsj21)
 	ROM_REGION(CPU_ADDRESSABLE_SIZE, REGION_CPU1, 0)
-	ROM_REGION(0x2000, REGION_USER1, 0)
-	ROM_LOAD("jbios21.rom", 0x0000, 0x2000, CRC(48D44A13))
+	ROM_REGION(0x4000, REGION_USER1, 0)
+	ROM_LOAD("jbios21.rom", 0x0000, 0x2000, CRC(48D44A13) SHA1(a8c1b39a2e41137835eda6a5de6d46dd9fadbaf2))
 ROM_END
 
 ROM_START(smsm3)
 	ROM_REGION(CPU_ADDRESSABLE_SIZE, REGION_CPU1, 0)
-	ROM_REGION(0x2000, REGION_USER1, 0)
-	ROM_LOAD("jbios21.rom", 0x0000, 0x2000, CRC(48D44A13))
+	ROM_REGION(0x4000, REGION_USER1, 0)
+	ROM_LOAD("jbios21.rom", 0x0000, 0x2000, CRC(48D44A13) SHA1(a8c1b39a2e41137835eda6a5de6d46dd9fadbaf2))
 ROM_END
 
 #define rom_smsss rom_smsj21
 
 ROM_START(smsu13)
 	ROM_REGION(CPU_ADDRESSABLE_SIZE, REGION_CPU1, 0)
-	ROM_REGION(0x2000, REGION_USER1, 0)
-	ROM_LOAD("bios13.rom", 0x0000, 0x2000, CRC(5AD6EDAC))
+	ROM_REGION(0x4000, REGION_USER1, 0)
+	ROM_LOAD("bios13fx.rom", 0x0000, 0x2000, CRC(0072ED54) SHA1(c315672807d8ddb8d91443729405c766dd95cae7))
 ROM_END
 
 ROM_START(smse13)
 	ROM_REGION(CPU_ADDRESSABLE_SIZE, REGION_CPU1, 0)
-	ROM_REGION(0x2000, REGION_USER1, 0)
-	ROM_LOAD("bios13.rom", 0x0000, 0x2000, CRC(5AD6EDAC))
-ROM_END
-
-ROM_START(smsu13h)
-	ROM_REGION(CPU_ADDRESSABLE_SIZE, REGION_CPU1, 0)
-	ROM_REGION(0x2000, REGION_USER1, 0)
-	ROM_LOAD("bios13fx.rom", 0x0000, 0x2000, CRC(0072ED54))
-ROM_END
-
-ROM_START(smse13h)
-	ROM_REGION(CPU_ADDRESSABLE_SIZE, REGION_CPU1, 0)
-	ROM_REGION(0x2000, REGION_USER1, 0)
-	ROM_LOAD("bios13fx.rom", 0x0000, 0x2000, CRC(0072ED54))
+	ROM_REGION(0x4000, REGION_USER1, 0)
+	ROM_LOAD("bios13fx.rom", 0x0000, 0x2000, CRC(0072ED54) SHA1(c315672807d8ddb8d91443729405c766dd95cae7))
 ROM_END
 
 ROM_START(smsuam)
 	ROM_REGION(CPU_ADDRESSABLE_SIZE, REGION_CPU1, 0)
 	ROM_REGION(0x20000, REGION_USER1, 0)
-	ROM_LOAD("akbios.rom", 0x0000, 0x20000, CRC(CF4A09EA))
+	ROM_LOAD("akbios.rom", 0x0000, 0x20000, CRC(CF4A09EA) SHA1(3af7b66248d34eb26da40c92bf2fa4c73a46a051))
 ROM_END
 
 ROM_START(smseam)
 	ROM_REGION(CPU_ADDRESSABLE_SIZE, REGION_CPU1, 0)
 	ROM_REGION(0x20000, REGION_USER1, 0)
-	ROM_LOAD("akbios.rom", 0x0000, 0x20000, CRC(CF4A09EA))
+	ROM_LOAD("akbios.rom", 0x0000, 0x20000, CRC(CF4A09EA) SHA1(3af7b66248d34eb26da40c92bf2fa4c73a46a051))
 ROM_END
 
 ROM_START(smsesh)
 	ROM_REGION(CPU_ADDRESSABLE_SIZE, REGION_CPU1, 0)
 	ROM_REGION(0x40000, REGION_USER1, 0)
-	ROM_LOAD("sonbios.rom", 0x0000, 0x40000, CRC(81C3476B))
+	ROM_LOAD("sonbios.rom", 0x0000, 0x40000, CRC(81C3476B) SHA1(6aca0e3dffe461ba1cb11a86cd4caf5b97e1b8df))
 ROM_END
 
 ROM_START(smsbsh)
 	ROM_REGION(CPU_ADDRESSABLE_SIZE, REGION_CPU1, 0)
 	ROM_REGION(0x40000, REGION_USER1, 0)
-	ROM_LOAD("sonbios.rom", 0x0000, 0x40000, CRC(81C3476B))
+	ROM_LOAD("sonbios.rom", 0x0000, 0x40000, CRC(81C3476B) SHA1(6aca0e3dffe461ba1cb11a86cd4caf5b97e1b8df))
 ROM_END
 
 ROM_START(smsuhs24)
 	ROM_REGION(CPU_ADDRESSABLE_SIZE, REGION_CPU1, 0)
 	ROM_REGION(0x20000, REGION_USER1, 0)
-	ROM_LOAD("hshbios.rom", 0x0000, 0x20000, CRC(91E93385))
+	ROM_LOAD("hshbios.rom", 0x0000, 0x20000, CRC(91E93385) SHA1(9e179392cd416af14024d8f31c981d9ee9a64517))
 ROM_END
 
 ROM_START(smsehs24)
 	ROM_REGION(CPU_ADDRESSABLE_SIZE, REGION_CPU1, 0)
 	ROM_REGION(0x20000, REGION_USER1, 0)
-	ROM_LOAD("hshbios.rom", 0x0000, 0x20000, CRC(91E93385))
+	ROM_LOAD("hshbios.rom", 0x0000, 0x20000, CRC(91E93385) SHA1(9e179392cd416af14024d8f31c981d9ee9a64517))
 ROM_END
 
 ROM_START(smsuh34)
 	ROM_REGION(CPU_ADDRESSABLE_SIZE, REGION_CPU1, 0)
 	ROM_REGION(0x20000, REGION_USER1, 0)
-	ROM_LOAD("hangbios.rom", 0x0000, 0x20000, CRC(8EDF7AC6))
+	ROM_LOAD("hangbios.rom", 0x0000, 0x20000, CRC(8EDF7AC6) SHA1(51fd6d7990f62cd9d18c9ecfc62ed7936169107e))
 ROM_END
 
 ROM_START(smseh34)
 	ROM_REGION(CPU_ADDRESSABLE_SIZE, REGION_CPU1, 0)
 	ROM_REGION(0x20000, REGION_USER1, 0)
-	ROM_LOAD("hangbios.rom", 0x0000, 0x20000, CRC(8EDF7AC6))
+	ROM_LOAD("hangbios.rom", 0x0000, 0x20000, CRC(8EDF7AC6) SHA1(51fd6d7990f62cd9d18c9ecfc62ed7936169107e))
 ROM_END
 
 ROM_START(gamegear)
@@ -316,7 +306,7 @@ ROM_END
 
 ROM_START(gamg)
 	ROM_REGION(CPU_ADDRESSABLE_SIZE, REGION_CPU1,0)
-	ROM_REGION(0x0400, REGION_USER1, 0)
+	ROM_REGION(0x4000, REGION_USER1, 0)
 	ROM_LOAD("majbios.rom", 0x0000, 0x0400, CRC(0EBEA9D4))
 ROM_END
 
@@ -329,6 +319,7 @@ static void sms_cartslot_getinfo(struct IODevice *dev)
 	dev->count = 1;
 	dev->file_extensions = "sms\0";
 	dev->must_be_loaded = 1;
+	dev->init = device_init_sms_cart;
 	dev->load = device_load_sms_cart;
 }
 
@@ -338,11 +329,8 @@ SYSTEM_CONFIG_END
 
 static void smso_cartslot_getinfo(struct IODevice *dev)
 {
-	/* cartslot */
-	cartslot_device_getinfo(dev);
-	dev->count = 1;
-	dev->file_extensions = "sms\0";
-	dev->load = device_load_sms_cart;
+	sms_cartslot_getinfo(dev);
+	dev->must_be_loaded = 0;
 }
 
 SYSTEM_CONFIG_START(smso)
@@ -351,12 +339,8 @@ SYSTEM_CONFIG_END
 
 static void gamegear_cartslot_getinfo(struct IODevice *dev)
 {
-	/* cartslot */
-	cartslot_device_getinfo(dev);
-	dev->count = 1;
+	sms_cartslot_getinfo(dev);
 	dev->file_extensions = "gg\0";
-	dev->must_be_loaded = 1;
-	dev->load = device_load_sms_cart;
 }
 
 SYSTEM_CONFIG_START(gamegear)
@@ -365,11 +349,8 @@ SYSTEM_CONFIG_END
 
 static void gamegearo_cartslot_getinfo(struct IODevice *dev)
 {
-	/* cartslot */
-	cartslot_device_getinfo(dev);
-	dev->count = 1;
-	dev->file_extensions = "gg\0";
-	dev->load = device_load_sms_cart;
+	gamegear_cartslot_getinfo(dev);
+	dev->must_be_loaded = 0;
 }
 
 SYSTEM_CONFIG_START(gamegearo)
@@ -383,28 +364,25 @@ SYSTEM_CONFIG_END
 ***************************************************************************/
 
 /*		YEAR	NAME		PARENT		COMPATIBLE	MACHINE		INPUT	INIT	CONFIG		COMPANY			FULLNAME */
-CONS(	1987,	sms,		0,			0,			sms,		sms,	0,		sms,		"Sega",			"Master System - (NTSC)" )
-CONS(	1986,	smsu13,		sms,		0,			sms,		sms,	0,		smso,		"Sega",			"Master System - (NTSC) US/European BIOS v1.3" )
-CONS(	1986,	smse13,		sms,		0,			smsm3,		sms,	0,		smso,		"Sega",			"Master System - (PAL) US/European BIOS v1.3" )
-CONS(	1986,	smsu13h,	sms,		0,			sms,		sms,	0,		smso,		"Sega",			"Master System - (NTSC) Hacked US/European BIOS v1.3" )
-CONS(	1986,	smse13h,	sms,		0,			smsm3,		sms,	0,		smso,		"Sega",			"Master System - (PAL) Hacked US/European BIOS v1.3" )
-/* next two systems are disabled because of missing bios roms */
-/*CONS(	1986,	smsumd3d,	sms,		0,			sms,		sms,	0,		smso,		"Sega",			"Super Master System - (NTSC) US/European Missile Defense 3D BIOS" ) */
-/*CONS(	1986,	smsemd3d,	sms,		0,			smsm3,		sms,	0,		smso,		"Sega",			"Super Master System - (PAL) US/European Missile Defense 3D BIOS" ) */
-CONS(	1990,	smsuam,		sms,		0,			sms,		sms,	0,		smso,		"Sega",			"Master System II - (NTSC) US/European BIOS with Alex Kidd in Miracle World" )
-CONS(	1990,	smseam,		sms,		0,			smsm3,		sms,	0,		smso,		"Sega",			"Master System II - (PAL) US/European BIOS with Alex Kidd in Miracle World" )
-CONS(	1990,	smsesh,		sms,		0,			smsm3,		sms,	0,		smso,		"Sega",			"Master System II - (PAL) European BIOS with Sonic The Hedgehog" )
-CONS(	1990,	smsbsh,		sms,		0,			smsm3,		sms,	0,		smso,		"Tec Toy",		"Master System III Compact (Brazil) - (PAL) European BIOS with Sonic The Hedgehog" )
-CONS(	1988,	smsuhs24,	sms,		0,			sms,		sms,	0,		smso,		"Sega",			"Master System Plus - (NTSC) US/European BIOS v2.4 with Hang On and Safari Hunt" )
-CONS(	1988,	smsehs24,	sms,		0,			smsm3,		sms,	0,		smso,		"Sega",			"Master System Plus - (PAL) US/European BIOS v2.4 with Hang On and Safari Hunt" )
-CONS(	1988,	smsuh34,	sms,		0,			sms,		sms,	0,		smso,		"Sega",			"Master System - (NTSC) US/European BIOS v3.4 with Hang On" )
-CONS(	1988,	smseh34,	sms,		0,			smsm3,		sms,	0,		smso,		"Sega",			"Master System - (PAL) US/European BIOS v3.4 with Hang On" )
-CONS(	1985,	smspal,		sms,		0,			smspal,		sms,	0,		sms,		"Sega",			"Master System - (PAL)" )
-CONS(	1985,	smsj21,		sms,		0,			smsj21,		sms,	0,		sms,		"Sega",			"Master System - (PAL) Japanese SMS BIOS v2.1" )
-CONS(	1984,	smsm3,		sms,		0,			smsm3,		sms,	0,		smso,		"Sega",			"Mark III - (PAL) Japanese SMS BIOS v2.1" )
-CONS(	198?,	smsss,		sms,		0,			smsj21,		sms,	0,		smso,		"Samsung",		"Gamboy - (PAL) Japanese SMS BIOS v2.1" )
-CONS(	1990,	gamegear,	0,			sms,		gamegear,	sms,	0,		gamegear,	"Sega",			"Game Gear - European/American" )
-CONS(	1990,	gamegj,		gamegear,	0,			gamegear,	sms,	0,		gamegear,	"Sega",			"Game Gear - Japanese" )
-CONS(	1990,	gamg,		gamegear,	0,			gamegear,	sms,	0,		gamegearo,	"Majesco",		"Game Gear - European/American Majesco Game Gear BIOS" )
-CONS(	1990,	gamgj,		gamegear,	0,			gamegear,	sms,	0,		gamegearo,	"Majesco",		"Game Gear - Japanese Majesco Game Gear BIOS" )
+CONS(	1987,	sms,		0,			0,			sms,		sms,	0,		sms,		"Sega",			"Master System - (NTSC)" , 0)
+CONS(	1986,	smsu13,		sms,		0,			sms,		sms,	0,		smso,		"Sega",			"Master System - (NTSC) US/European BIOS v1.3" , 0)
+CONS(	1986,	smse13,		sms,		0,			smsm3,		sms,	0,		smso,		"Sega",			"Master System - (PAL) US/European BIOS v1.3" , 0)
+/*CONS(	1986,	smsumd3d,	sms,		0,			sms,		sms,	0,		smso,		"Sega",			"Super Master System - (NTSC) US/European Missile Defense 3D BIOS" , 0) */
+/*CONS(	1986,	smsemd3d,	sms,		0,			smsm3,		sms,	0,		smso,		"Sega",			"Super Master System - (PAL) US/European Missile Defense 3D BIOS" , 0) */
+CONS(	1990,	smsuam,		sms,		0,			sms,		sms,	0,		smso,		"Sega",			"Master System II - (NTSC) US/European BIOS with Alex Kidd in Miracle World" , 0)
+CONS(	1990,	smseam,		sms,		0,			smsm3,		sms,	0,		smso,		"Sega",			"Master System II - (PAL) US/European BIOS with Alex Kidd in Miracle World" , 0)
+CONS(	1990,	smsesh,		sms,		0,			smsm3,		sms,	0,		smso,		"Sega",			"Master System II - (PAL) European BIOS with Sonic The Hedgehog" , 0)
+CONS(	1990,	smsbsh,		sms,		0,			smsm3,		sms,	0,		smso,		"Tec Toy",		"Master System III Compact (Brazil) - (PAL) European BIOS with Sonic The Hedgehog" , 0)
+CONS(	1988,	smsuhs24,	sms,		0,			sms,		sms,	0,		smso,		"Sega",			"Master System Plus - (NTSC) US/European BIOS v2.4 with Hang On and Safari Hunt" , 0)
+CONS(	1988,	smsehs24,	sms,		0,			smsm3,		sms,	0,		smso,		"Sega",			"Master System Plus - (PAL) US/European BIOS v2.4 with Hang On and Safari Hunt" , 0)
+CONS(	1988,	smsuh34,	sms,		0,			sms,		sms,	0,		smso,		"Sega",			"Master System - (NTSC) US/European BIOS v3.4 with Hang On" , 0)
+CONS(	1988,	smseh34,	sms,		0,			smsm3,		sms,	0,		smso,		"Sega",			"Master System - (PAL) US/European BIOS v3.4 with Hang On" , 0)
+CONS(	1985,	smspal,		sms,		0,			smspal,		sms,	0,		sms,		"Sega",			"Master System - (PAL)" , 0)
+CONS(	1985,	smsj21,		sms,		0,			smsj21,		sms,	0,		smso,		"Sega",			"Master System - (PAL) Japanese SMS BIOS v2.1" , 0)
+CONS(	1984,	smsm3,		sms,		0,			smsm3,		sms,	0,		smso,		"Sega",			"Mark III - (PAL) Japanese SMS BIOS v2.1" , 0)
+CONS(	198?,	smsss,		sms,		0,			smsj21,		sms,	0,		smso,		"Samsung",		"Gamboy - (PAL) Japanese SMS BIOS v2.1" , 0)
+CONS(	1990,	gamegear,	0,			sms,		gamegear,	sms,	0,		gamegear,	"Sega",			"Game Gear - European/American" , 0)
+CONS(	1990,	gamegj,		gamegear,	0,			gamegear,	sms,	0,		gamegear,	"Sega",			"Game Gear - Japanese" , 0)
+CONS(	1990,	gamg,		gamegear,	0,			gamegear,	sms,	0,		gamegearo,	"Majesco",		"Game Gear - European/American Majesco Game Gear BIOS" , 0)
+CONS(	1990,	gamgj,		gamegear,	0,			gamegear,	sms,	0,		gamegearo,	"Majesco",		"Game Gear - Japanese Majesco Game Gear BIOS" , 0)
 
