@@ -1897,7 +1897,7 @@ static imgtoolerr_t fat_lookup_path(imgtool_image *image, const char *path,
 
 			LOG(("fat_lookup_path(): %s/%s: %d\n", ent.short_filename, ent.long_filename, ent.dirent_sector_offset));
 		}
-		while(!ent.eof && stricmp(path, ent.short_filename) && stricmp(path, ent.long_filename));
+		while(!ent.eof && mame_stricmp(path, ent.short_filename) && mame_stricmp(path, ent.long_filename));
 
 		parent_first_cluster = file->first_cluster;
 
@@ -1929,7 +1929,7 @@ static imgtoolerr_t fat_lookup_path(imgtool_image *image, const char *path,
 						if (err)
 							goto done;
 
-						if (!stricmp(sfn, ent.short_filename))
+						if (!mame_stricmp(sfn, ent.short_filename))
 						{
 							bumped_sfn = TRUE;
 							fat_bump_dirent(created_entry, created_entry_len);
