@@ -2,13 +2,10 @@
 #include "driver.h"
 #include "vidhrdw/generic.h"
 
-WRITE_HANDLER ( vdc_w );
-READ_HANDLER ( vdc_r );
-READ_HANDLER ( vce_r );
-WRITE_HANDLER ( vce_w );
-int pce_vh_start(void);
-void pce_vh_stop(void);
-void pce_vh_screenrefresh(struct mame_bitmap *bitmap, int full_refresh);
+WRITE8_HANDLER ( vdc_w );
+ READ8_HANDLER ( vdc_r );
+ READ8_HANDLER ( vce_r );
+WRITE8_HANDLER ( vce_w );
 
 /* Screen timing stuff */
 
@@ -76,7 +73,7 @@ typedef struct
     UINT8 vdc_latch;
     pair vdc_data[32];
     int status;
-    struct mame_bitmap *bmp;
+    mame_bitmap *bmp;
 }VDC;
 
 
@@ -85,11 +82,10 @@ typedef struct
 /* from vidhrdw\vdc.c */
 
 extern VDC vdc;
-extern int pce_vh_start(void);
-extern void pce_vh_stop(void);
-extern void pce_vh_screenrefresh(struct mame_bitmap *bitmap, int full_refresh);
-extern WRITE_HANDLER ( vdc_w );
-extern READ_HANDLER ( vdc_r );
-extern WRITE_HANDLER ( vce_w );
-extern READ_HANDLER ( vce_r );
+extern VIDEO_START( pce );
+extern VIDEO_UPDATE( pce );
+extern WRITE8_HANDLER ( vdc_w );
+extern  READ8_HANDLER ( vdc_r );
+extern WRITE8_HANDLER ( vce_w );
+extern  READ8_HANDLER ( vce_r );
 extern void pce_refresh_line(int line);
