@@ -118,7 +118,7 @@ void showdisclaimer(void)   /* MAURY_BEGIN: dichiarazione */
     region
 -------------------------------------------------*/
 
-unsigned char *memory_region(int num)
+UINT8 *memory_region(int num)
 {
 	int i;
 
@@ -368,6 +368,7 @@ void *nvram_select(void)
 	return 0;
 }
 
+
 /*-------------------------------------------------
     nvram_handler_generic_0fill - generic NVRAM
     with a 0 fill
@@ -400,6 +401,28 @@ void nvram_handler_generic_1fill(mame_file *file, int read_or_write)
 }
 
 
+/*-------------------------------------------------
+    nvram_handler_generic_randfill - generic NVRAM
+    with a random fill
+-------------------------------------------------*/
+
+void nvram_handler_generic_randfill(mame_file *file, int read_or_write)
+{
+	int i;
+
+	if (read_or_write)
+		mame_fwrite(file, nvram_select(), generic_nvram_size);
+	else if (file)
+		mame_fread(file, nvram_select(), generic_nvram_size);
+	else
+	{
+		UINT8 *nvram = nvram_select();
+		for (i = 0; i < generic_nvram_size; i++)
+			nvram[i] = rand();
+	}
+}
+
+
 
 /***************************************************************************
 
@@ -431,7 +454,7 @@ mame_bitmap *bitmap_alloc_core(int width,int height,int depth,int use_auto)
 	if (bitmap != NULL)
 	{
 		int i, rowlen, rdwidth, bitmapsize, linearraysize, pixelsize;
-		unsigned char *bm;
+		UINT8 *bm;
 
 		/* initialize the basic parameters */
 		bitmap->depth = depth;
@@ -456,7 +479,7 @@ mame_bitmap *bitmap_alloc_core(int width,int height,int depth,int use_auto)
 
 		/* determine total memory for bitmap and line arrays */
 		bitmapsize = (height + 2 * BITMAP_SAFETY) * rowlen;
-		linearraysize = (height + 2 * BITMAP_SAFETY) * sizeof(unsigned char *);
+		linearraysize = (height + 2 * BITMAP_SAFETY) * sizeof(UINT8 *);
 
 		/* align to 16 bytes */
 		linearraysize = (linearraysize + 15) & ~15;
@@ -470,7 +493,7 @@ mame_bitmap *bitmap_alloc_core(int width,int height,int depth,int use_auto)
 		}
 
 		/* clear ALL bitmap, including safety area, to avoid garbage on right */
-		bm = (unsigned char *)bitmap->line + linearraysize;
+		bm = (UINT8 *)bitmap->line + linearraysize;
 		memset(bm, 0, (height + 2 * BITMAP_SAFETY) * rowlen);
 
 		/* initialize the line pointers */
@@ -544,9 +567,15 @@ void bitmap_free(mame_bitmap *bitmap)
 
 void *auto_malloc(size_t size)
 {
-	void *result = malloc(size);
+	void *result;
 	malloc_info *info;
 
+	/* malloc-ing zero bytes is inherently unportable; hence this check */
+	if (size == 0)
+		osd_die("Attempted to auto_malloc zero bytes");
+
+	result = malloc(size);
+
 	/* fail horribly if it doesn't work */
 	if (!result)
 		osd_die("Out of memory attempting to allocate %d bytes\n", (int)size);
@@ -1787,10 +1816,6 @@ int rom_load(const rom_entry *romp)
 			return 1;
 		}
 
-		/* if sound is disabled and it's a sound-only region, skip it */
-		if (Machine->sample_rate == 0 && ROMREGION_ISSOUNDONLY(region))
-			continue;
-
 		/* allocate memory for the region */
 		if (new_memory_region(regiontype, ROMREGION_GETLENGTH(region), ROMREGION_GETFLAGS(region)))
 		{
