@@ -1,68 +1,71 @@
 /*********************************************************************
 
-	common.h
+    common.h
 
-	Generic functions, mostly ROM related.
+    Generic functions, mostly ROM related.
 
 *********************************************************************/
 
-#ifndef COMMON_H
-#define COMMON_H
+#pragma once
 
-#ifdef __cplusplus
-extern "C" {
-#endif
+#ifndef __COMMON_H__
+#define __COMMON_H__
+
+#include "hash.h"
+#include "xmlfile.h"
+#include "chd.h"
 
 
 
 /***************************************************************************
 
-	Type definitions
+    Type definitions
 
 ***************************************************************************/
 
-struct mame_bitmap
-{
-	int width,height;	/* width and height of the bitmap */
-	int depth;			/* bits per pixel */
-	void **line;		/* pointers to the start of each line - can be UINT8 **, UINT16 ** or UINT32 ** */
-
-	/* alternate way of accessing the pixels */
-	void *base;			/* pointer to pixel (0,0) (adjusted for padding) */
-	int rowpixels;		/* pixels per row (including padding) */
-	int rowbytes;		/* bytes per row (including padding) */
-};
-
-
-struct RomModule
+struct _rom_entry
 {
 	const char *_name;	/* name of the file to load */
 	UINT32 _offset;		/* offset to load it to */
 	UINT32 _length;		/* length of the file */
-	UINT32 _crc;		/* standard CRC-32 checksum */
+	UINT32 _flags;		/* flags */
+	const char *_hashdata; /* hashing informations (checksums) */
 };
+typedef struct _rom_entry rom_entry;
 
 
-struct GameSample
+struct _bios_entry
 {
-	int length;
-	int smpfreq;
-	int resolution;
-	signed char data[1];	/* extendable */
+	int value;			/* value of mask to apply to ROM_BIOSFLAGS is chosen */
+	const char *_name;	/* name of the bios, e.g "default","japan" */
+	const char *_description;	/* long name of the bios, e.g "Europe MVS (Ver. 2)" */
 };
+typedef struct _bios_entry bios_entry;
 
 
-struct GameSamples
+struct _rom_load_data
 {
-	int total;	/* total number of samples */
-	struct GameSample *sample[1];	/* extendable */
+	int warnings;				/* warning count during processing */
+	int errors;				/* error count during processing */
+
+	int romsloaded;				/* current ROMs loaded count */
+	int romstotal;				/* total number of ROMs to read */
+
+	void * file;				/* current file */
+
+	UINT8 *	regionbase;			/* base of current region */
+	UINT32 regionlength;			/* length of current region */
+
+	char errorbuf[4096];			/* accumulated errors */
+	UINT8 tempbuf[65536];			/* temporary buffer */
 };
+/* In mamecore.h: typedef struct _rom_load_data rom_load_data; */
 
 
 
 /***************************************************************************
 
-	Constants and macros
+    Constants and macros
 
 ***************************************************************************/
 
@@ -102,33 +105,18 @@ enum
 	REGION_USER6,
 	REGION_USER7,
 	REGION_USER8,
+	REGION_DISKS,
 	REGION_MAX
 };
 
-#define BADCRC( crc ) (~(crc))
-
 
 
 /***************************************************************************
 
-	Core macros for the ROM loading system
+    Core macros for the ROM loading system
 
 ***************************************************************************/
 
-/* ----- length compaction macros ----- */
-#define INVALID_LENGTH 				0x7ff
-#define COMPACT_LENGTH(x)									\
-	((((x) & 0xffffff00) == 0) ? (0x000 | ((x) >> 0)) :		\
-	 (((x) & 0xfffff00f) == 0) ? (0x100 | ((x) >> 4)) :		\
-	 (((x) & 0xffff00ff) == 0) ? (0x200 | ((x) >> 8)) :		\
-	 (((x) & 0xfff00fff) == 0) ? (0x300 | ((x) >> 12)) : 	\
-	 (((x) & 0xff00ffff) == 0) ? (0x400 | ((x) >> 16)) : 	\
-	 (((x) & 0xf00fffff) == 0) ? (0x500 | ((x) >> 20)) : 	\
-	 (((x) & 0x00ffffff) == 0) ? (0x600 | ((x) >> 24)) : 	\
-	 INVALID_LENGTH)
-#define UNCOMPACT_LENGTH(x)	(((x) == INVALID_LENGTH) ? 0 : (((x) & 0xff) << (((x) & 0x700) >> 6)))
-
-
 /* ----- per-entry constants ----- */
 #define ROMENTRYTYPE_REGION			1					/* this entry marks the start of a region */
 #define ROMENTRYTYPE_END			2					/* this entry marks the end of a region */
@@ -177,10 +165,6 @@ enum
 #define		ROMREGION_NODISPOSE		0x00000000
 #define		ROMREGION_DISPOSE		0x00000010
 
-#define ROMREGION_SOUNDONLYMASK		0x00000020			/* load only if sound is enabled */
-#define		ROMREGION_NONSOUND		0x00000000
-#define		ROMREGION_SOUNDONLY		0x00000020
-
 #define ROMREGION_LOADUPPERMASK		0x00000040			/* load into the upper part of CPU space */
 #define		ROMREGION_LOADLOWER		0x00000000			/*     (CPU regions only) */
 #define		ROMREGION_LOADUPPER		0x00000040
@@ -194,24 +178,31 @@ enum
 #define		ROMREGION_ERASE00		ROMREGION_ERASEVAL(0)
 #define		ROMREGION_ERASEFF		ROMREGION_ERASEVAL(0xff)
 
+#define ROMREGION_DATATYPEMASK		0x00010000			/* inherit all flags from previous definition */
+#define		ROMREGION_DATATYPEROM	0x00000000
+#define		ROMREGION_DATATYPEDISK	0x00010000
+
 /* ----- per-region macros ----- */
-#define ROMREGION_GETTYPE(r)		((r)->_crc)
+#define ROMREGION_GETTYPE(r)		((UINT32)(r)->_hashdata)
 #define ROMREGION_GETLENGTH(r)		((r)->_length)
-#define ROMREGION_GETFLAGS(r)		((r)->_offset)
+#define ROMREGION_GETFLAGS(r)		((r)->_flags)
 #define ROMREGION_GETWIDTH(r)		(8 << (ROMREGION_GETFLAGS(r) & ROMREGION_WIDTHMASK))
 #define ROMREGION_ISLITTLEENDIAN(r)	((ROMREGION_GETFLAGS(r) & ROMREGION_ENDIANMASK) == ROMREGION_LE)
 #define ROMREGION_ISBIGENDIAN(r)	((ROMREGION_GETFLAGS(r) & ROMREGION_ENDIANMASK) == ROMREGION_BE)
 #define ROMREGION_ISINVERTED(r)		((ROMREGION_GETFLAGS(r) & ROMREGION_INVERTMASK) == ROMREGION_INVERT)
 #define ROMREGION_ISDISPOSE(r)		((ROMREGION_GETFLAGS(r) & ROMREGION_DISPOSEMASK) == ROMREGION_DISPOSE)
-#define ROMREGION_ISSOUNDONLY(r)	((ROMREGION_GETFLAGS(r) & ROMREGION_SOUNDONLYMASK) == ROMREGION_SOUNDONLY)
 #define ROMREGION_ISLOADUPPER(r)	((ROMREGION_GETFLAGS(r) & ROMREGION_LOADUPPERMASK) == ROMREGION_LOADUPPER)
 #define ROMREGION_ISERASE(r)		((ROMREGION_GETFLAGS(r) & ROMREGION_ERASEMASK) == ROMREGION_ERASE)
 #define ROMREGION_GETERASEVAL(r)	((ROMREGION_GETFLAGS(r) & ROMREGION_ERASEVALMASK) >> 8)
+#define ROMREGION_GETDATATYPE(r)	(ROMREGION_GETFLAGS(r) & ROMREGION_DATATYPEMASK)
+#define ROMREGION_ISROMDATA(r)		(ROMREGION_GETDATATYPE(r) == ROMREGION_DATATYPEROM)
+#define ROMREGION_ISDISKDATA(r)		(ROMREGION_GETDATATYPE(r) == ROMREGION_DATATYPEDISK)
 
 
 /* ----- per-ROM constants ----- */
-#define ROM_LENGTHMASK				0x000007ff			/* the compacted length of the ROM */
-#define		ROM_INVALIDLENGTH		INVALID_LENGTH
+#define DISK_READONLYMASK			0x00000400			/* is the disk read-only? */
+#define		DISK_READWRITE			0x00000000
+#define		DISK_READONLY			0x00000400
 
 #define ROM_OPTIONALMASK			0x00000800			/* optional - won't hurt if it's not there */
 #define		ROM_REQUIRED			0x00000000
@@ -245,15 +236,18 @@ enum
 #define ROM_INHERITFLAGSMASK		0x08000000			/* inherit all flags from previous definition */
 #define		ROM_INHERITFLAGS		0x08000000
 
-#define ROM_INHERITEDFLAGS			(ROM_GROUPMASK | ROM_SKIPMASK | ROM_REVERSEMASK | ROM_BITWIDTHMASK | ROM_BITSHIFTMASK)
+#define ROM_BIOSFLAGSMASK			0xf0000000			/* only loaded if value matches global bios value */
+#define 	ROM_BIOS(n)				(((n) & 15) << 28)
+
+#define ROM_INHERITEDFLAGS			(ROM_GROUPMASK | ROM_SKIPMASK | ROM_REVERSEMASK | ROM_BITWIDTHMASK | ROM_BITSHIFTMASK | ROM_BIOSFLAGSMASK)
 
 /* ----- per-ROM macros ----- */
 #define ROM_GETNAME(r)				((r)->_name)
 #define ROM_SAFEGETNAME(r)			(ROMENTRY_ISFILL(r) ? "fill" : ROMENTRY_ISCOPY(r) ? "copy" : ROM_GETNAME(r))
 #define ROM_GETOFFSET(r)			((r)->_offset)
-#define ROM_GETCRC(r)				((r)->_crc)
-#define ROM_GETLENGTH(r)			(UNCOMPACT_LENGTH((r)->_length & ROM_LENGTHMASK))
-#define ROM_GETFLAGS(r)				((r)->_length & ~ROM_LENGTHMASK)
+#define ROM_GETLENGTH(r)			((r)->_length)
+#define ROM_GETFLAGS(r)				((r)->_flags)
+#define ROM_GETHASHDATA(r)          ((r)->_hashdata)
 #define ROM_ISOPTIONAL(r)			((ROM_GETFLAGS(r) & ROM_OPTIONALMASK) == ROM_OPTIONAL)
 #define ROM_GETGROUPSIZE(r)			(((ROM_GETFLAGS(r) & ROM_GROUPMASK) >> 12) + 1)
 #define ROM_GETSKIPCOUNT(r)			((ROM_GETFLAGS(r) & ROM_SKIPMASK) >> 16)
@@ -261,176 +255,188 @@ enum
 #define ROM_GETBITWIDTH(r)			(((ROM_GETFLAGS(r) & ROM_BITWIDTHMASK) >> 21) + 8 * ((ROM_GETFLAGS(r) & ROM_BITWIDTHMASK) == 0))
 #define ROM_GETBITSHIFT(r)			((ROM_GETFLAGS(r) & ROM_BITSHIFTMASK) >> 24)
 #define ROM_INHERITSFLAGS(r)		((ROM_GETFLAGS(r) & ROM_INHERITFLAGSMASK) == ROM_INHERITFLAGS)
-#define ROM_NOGOODDUMP(r)			(ROM_GETCRC(r) == 0)
+#define ROM_GETBIOSFLAGS(r)			((ROM_GETFLAGS(r) & ROM_BIOSFLAGSMASK) >> 28)
+#define ROM_NOGOODDUMP(r)			(hash_data_has_info((r)->_hashdata, HASH_INFO_NO_DUMP))
+
+/* ----- per-disk macros ----- */
+#define DISK_GETINDEX(r)			((r)->_offset)
+#define DISK_ISREADONLY(r)			((ROM_GETFLAGS(r) & DISK_READONLYMASK) == DISK_READONLY)
 
 
 
 /***************************************************************************
 
-	Derived macros for the ROM loading system
+    Derived macros for the ROM loading system
 
 ***************************************************************************/
 
 /* ----- start/stop macros ----- */
-#define ROM_START(name)								static const struct RomModule rom_##name[] = {
-#define ROM_END										{ ROMENTRY_END, 0, 0, 0 } };
+#define ROM_START(name)								static const rom_entry rom_##name[] = {
+#define ROM_END                                      { ROMENTRY_END, 0, 0, 0, NULL } };
 
 /* ----- ROM region macros ----- */
-#define ROM_REGION(length,type,flags)				{ ROMENTRY_REGION, flags, length, type },
+#define ROM_REGION(length,type,flags)                { ROMENTRY_REGION, 0, length, flags, (const char*)type },
 #define ROM_REGION16_LE(length,type,flags)			ROM_REGION(length, type, (flags) | ROMREGION_16BIT | ROMREGION_LE)
 #define ROM_REGION16_BE(length,type,flags)			ROM_REGION(length, type, (flags) | ROMREGION_16BIT | ROMREGION_BE)
 #define ROM_REGION32_LE(length,type,flags)			ROM_REGION(length, type, (flags) | ROMREGION_32BIT | ROMREGION_LE)
 #define ROM_REGION32_BE(length,type,flags)			ROM_REGION(length, type, (flags) | ROMREGION_32BIT | ROMREGION_BE)
+#define ROM_REGION64_LE(length,type,flags)			ROM_REGION(length, type, (flags) | ROMREGION_64BIT | ROMREGION_LE)
+#define ROM_REGION64_BE(length,type,flags)			ROM_REGION(length, type, (flags) | ROMREGION_64BIT | ROMREGION_BE)
 
 /* ----- core ROM loading macros ----- */
-#define ROMX_LOAD(name,offset,length,crc,flags)		{ name, offset, (flags) | COMPACT_LENGTH(length), crc },
-#define ROM_LOAD(name,offset,length,crc)			ROMX_LOAD(name, offset, length, crc, 0)
-#define ROM_LOAD_OPTIONAL(name,offset,length,crc)	ROMX_LOAD(name, offset, length, crc, ROM_OPTIONAL)
+#define ROMMD5_LOAD(name,offset,length,hash,flags)   { name, offset, length, flags, hash },
+#define ROMX_LOAD(name,offset,length,hash,flags)     { name, offset, length, flags, hash },
+#define ROM_LOAD(name,offset,length,hash)            ROMX_LOAD(name, offset, length, hash, 0)
+#define ROM_LOAD_OPTIONAL(name,offset,length,hash)   ROMX_LOAD(name, offset, length, hash, ROM_OPTIONAL)
 #define ROM_CONTINUE(offset,length)					ROMX_LOAD(ROMENTRY_CONTINUE, offset, length, 0, ROM_INHERITFLAGS)
 #define ROM_RELOAD(offset,length)					ROMX_LOAD(ROMENTRY_RELOAD, offset, length, 0, ROM_INHERITFLAGS)
-#define ROM_FILL(offset,length,value)				ROM_LOAD(ROMENTRY_FILL, offset, length, value)
-#define ROM_COPY(rgn,srcoffset,offset,length)		ROMX_LOAD(ROMENTRY_COPY, offset, length, srcoffset, (rgn) << 24)
+#define ROM_FILL(offset,length,value)                ROM_LOAD(ROMENTRY_FILL, offset, length, (const char*)value)
+#define ROM_COPY(rgn,srcoffset,offset,length)        ROMX_LOAD(ROMENTRY_COPY, offset, length, (const char*)srcoffset, (rgn) << 24)
 
 /* ----- nibble loading macros ----- */
-#define ROM_LOAD_NIB_HIGH(name,offset,length,crc)	ROMX_LOAD(name, offset, length, crc, ROM_NIBBLE | ROM_SHIFT_NIBBLE_HI)
-#define ROM_LOAD_NIB_LOW(name,offset,length,crc)	ROMX_LOAD(name, offset, length, crc, ROM_NIBBLE | ROM_SHIFT_NIBBLE_LO)
+#define ROM_LOAD_NIB_HIGH(name,offset,length,hash)   ROMX_LOAD(name, offset, length, hash, ROM_NIBBLE | ROM_SHIFT_NIBBLE_HI)
+#define ROM_LOAD_NIB_LOW(name,offset,length,hash)    ROMX_LOAD(name, offset, length, hash, ROM_NIBBLE | ROM_SHIFT_NIBBLE_LO)
 
 /* ----- new-style 16-bit loading macros ----- */
-#define ROM_LOAD16_BYTE(name,offset,length,crc)		ROMX_LOAD(name, offset, length, crc, ROM_SKIP(1))
-#define ROM_LOAD16_WORD(name,offset,length,crc)		ROM_LOAD(name, offset, length, crc)
-#define ROM_LOAD16_WORD_SWAP(name,offset,length,crc)ROMX_LOAD(name, offset, length, crc, ROM_GROUPWORD | ROM_REVERSE)
+#define ROM_LOAD16_BYTE(name,offset,length,hash)     ROMX_LOAD(name, offset, length, hash, ROM_SKIP(1))
+#define ROM_LOAD16_WORD(name,offset,length,hash)     ROM_LOAD(name, offset, length, hash)
+#define ROM_LOAD16_WORD_SWAP(name,offset,length,hash)ROMX_LOAD(name, offset, length, hash, ROM_GROUPWORD | ROM_REVERSE)
 
 /* ----- new-style 32-bit loading macros ----- */
-#define ROM_LOAD32_BYTE(name,offset,length,crc)		ROMX_LOAD(name, offset, length, crc, ROM_SKIP(3))
-#define ROM_LOAD32_WORD(name,offset,length,crc)		ROMX_LOAD(name, offset, length, crc, ROM_GROUPWORD | ROM_SKIP(2))
-#define ROM_LOAD32_WORD_SWAP(name,offset,length,crc)ROMX_LOAD(name, offset, length, crc, ROM_GROUPWORD | ROM_REVERSE | ROM_SKIP(2))
+#define ROM_LOAD32_BYTE(name,offset,length,hash)     ROMX_LOAD(name, offset, length, hash, ROM_SKIP(3))
+#define ROM_LOAD32_WORD(name,offset,length,hash)     ROMX_LOAD(name, offset, length, hash, ROM_GROUPWORD | ROM_SKIP(2))
+#define ROM_LOAD32_WORD_SWAP(name,offset,length,hash)ROMX_LOAD(name, offset, length, hash, ROM_GROUPWORD | ROM_REVERSE | ROM_SKIP(2))
+#define ROM_LOAD32_DWORD(name,offset,length,hash)    ROMX_LOAD(name, offset, length, hash, ROM_GROUPDWORD)
+
+/* ----- disk loading macros ----- */
+#define DISK_REGION(type)							ROM_REGION(1, type, ROMREGION_DATATYPEDISK)
+#define DISK_IMAGE(name,idx,hash)                    ROMMD5_LOAD(name, idx, 0, hash, DISK_READWRITE)
+#define DISK_IMAGE_READONLY(name,idx,hash)           ROMMD5_LOAD(name, idx, 0, hash, DISK_READONLY)
+
+/* ----- hash macros ----- */
+#define CRC(x)                                       "c:" #x "#"
+#define SHA1(x)                                      "s:" #x "#"
+#define MD5(x)                                       "m:" #x "#"
+#define NO_DUMP                                      "$ND$"
+#define BAD_DUMP                                     "$BD$"
 
 
 
 /***************************************************************************
 
-	Function prototypes
+    Derived macros for the alternate BIOS loading system
+
+***************************************************************************/
+
+#define BIOSENTRY_ISEND(b)		((b)->_name == NULL)
+
+/* ----- start/stop macros ----- */
+#define SYSTEM_BIOS_START(name)			static const bios_entry system_bios_##name[] = {
+#define SYSTEM_BIOS_END					{ 0, NULL } };
+
+/* ----- ROM region macros ----- */
+#define SYSTEM_BIOS_ADD(value,name,description)		{ (int)value, (const char*)name, (const char*)description },
+#define BIOS_DEFAULT			"default"
+
+
+
+/***************************************************************************
+
+    Global variables
+
+***************************************************************************/
+
+#define COIN_COUNTERS	8	/* total # of coin counters */
+
+extern unsigned int dispensed_tickets;
+extern unsigned int coin_count[COIN_COUNTERS];
+extern unsigned int coinlockedout[COIN_COUNTERS];
+
+
+
+/***************************************************************************
+
+    Function prototypes
 
 ***************************************************************************/
 
 void showdisclaimer(void);
 
-const struct RomModule *rom_first_region(const struct GameDriver *drv);
-const struct RomModule *rom_next_region(const struct RomModule *romp);
-const struct RomModule *rom_first_file(const struct RomModule *romp);
-const struct RomModule *rom_next_file(const struct RomModule *romp);
-const struct RomModule *rom_first_chunk(const struct RomModule *romp);
-const struct RomModule *rom_next_chunk(const struct RomModule *romp);
-
-
-/* LBO 042898 - added coin counters */
-#define COIN_COUNTERS	4	/* total # of coin counters */
-void coin_counter_w(int num,int on);
-void coin_lockout_w(int num,int on);
-void coin_lockout_global_w(int on);  /* Locks out all coin inputs */
-
-
-int readroms(void);
-void printromlist(const struct RomModule *romp,const char *name);
-
-/* helper function that reads samples from disk - this can be used by other */
-/* drivers as well (e.g. a sound chip emulator needing drum samples) */
-struct GameSamples *readsamples(const char **samplenames,const char *name);
-void freesamples(struct GameSamples *samples);
-
 /* return a pointer to the specified memory region - num can be either an absolute */
 /* number, or one of the REGION_XXX identifiers defined above */
 UINT8 *memory_region(int num);
 size_t memory_region_length(int num);
+
 /* allocate a new memory region - num can be either an absolute */
 /* number, or one of the REGION_XXX identifiers defined above */
 int new_memory_region(int num, size_t length, UINT32 flags);
 void free_memory_region(int num);
 
-extern int flip_screen_x, flip_screen_y;
+/* common coin counter helpers */
+void counters_load(int config_type, xml_data_node *parentnode);
+void counters_save(int config_type, xml_data_node *parentnode);
+void coin_counter_reset(void);
+void coin_counter_w(int num,int on);
+void coin_lockout_w(int num,int on);
+void coin_lockout_global_w(int on);  /* Locks out all coin inputs */
 
-void flip_screen_set(int on);
-void flip_screen_x_set(int on);
-void flip_screen_y_set(int on);
-#define flip_screen flip_screen_x
+/* generic NVRAM handler */
+extern size_t generic_nvram_size;
+extern UINT8 *generic_nvram;
+extern UINT16 *generic_nvram16;
+extern UINT32 *generic_nvram32;
+void nvram_handler_generic_0fill(mame_file *file, int read_or_write);
+void nvram_handler_generic_1fill(mame_file *file, int read_or_write);
+void nvram_handler_generic_randfill(mame_file *file, int read_or_write);
 
-/* sets a variable and schedules a full screen refresh if it changed */
-void set_vh_global_attribute( int *addr, int data );
+/* bitmap allocation */
+mame_bitmap *bitmap_alloc(int width,int height);
+mame_bitmap *bitmap_alloc_depth(int width,int height,int depth);
+void bitmap_free(mame_bitmap *bitmap);
 
-void set_visible_area(int min_x,int max_x,int min_y,int max_y);
-
-struct mame_bitmap *bitmap_alloc(int width,int height);
-struct mame_bitmap *bitmap_alloc_depth(int width,int height,int depth);
-void bitmap_free(struct mame_bitmap *bitmap);
-
-void save_screen_snapshot_as(void *fp,struct mame_bitmap *bitmap);
-void save_screen_snapshot(struct mame_bitmap *bitmap);
-
-
-
-/***************************************************************************
-
-	Useful macros to deal with bit shuffling encryptions
-
-***************************************************************************/
-
-#define BITSWAP8(val,B7,B6,B5,B4,B3,B2,B1,B0) \
-		(((((val) >> (B7)) & 1) << 7) | \
-		 ((((val) >> (B6)) & 1) << 6) | \
-		 ((((val) >> (B5)) & 1) << 5) | \
-		 ((((val) >> (B4)) & 1) << 4) | \
-		 ((((val) >> (B3)) & 1) << 3) | \
-		 ((((val) >> (B2)) & 1) << 2) | \
-		 ((((val) >> (B1)) & 1) << 1) | \
-		 ((((val) >> (B0)) & 1) << 0))
-
-#define BITSWAP16(val,B15,B14,B13,B12,B11,B10,B9,B8,B7,B6,B5,B4,B3,B2,B1,B0) \
-		(((((val) >> (B15)) & 1) << 15) | \
-		 ((((val) >> (B14)) & 1) << 14) | \
-		 ((((val) >> (B13)) & 1) << 13) | \
-		 ((((val) >> (B12)) & 1) << 12) | \
-		 ((((val) >> (B11)) & 1) << 11) | \
-		 ((((val) >> (B10)) & 1) << 10) | \
-		 ((((val) >> ( B9)) & 1) <<  9) | \
-		 ((((val) >> ( B8)) & 1) <<  8) | \
-		 ((((val) >> ( B7)) & 1) <<  7) | \
-		 ((((val) >> ( B6)) & 1) <<  6) | \
-		 ((((val) >> ( B5)) & 1) <<  5) | \
-		 ((((val) >> ( B4)) & 1) <<  4) | \
-		 ((((val) >> ( B3)) & 1) <<  3) | \
-		 ((((val) >> ( B2)) & 1) <<  2) | \
-		 ((((val) >> ( B1)) & 1) <<  1) | \
-		 ((((val) >> ( B0)) & 1) <<  0))
-
-#define BITSWAP24(val,B23,B22,B21,B20,B19,B18,B17,B16,B15,B14,B13,B12,B11,B10,B9,B8,B7,B6,B5,B4,B3,B2,B1,B0) \
-		(((((val) >> (B23)) & 1) << 23) | \
-		 ((((val) >> (B22)) & 1) << 22) | \
-		 ((((val) >> (B21)) & 1) << 21) | \
-		 ((((val) >> (B20)) & 1) << 20) | \
-		 ((((val) >> (B19)) & 1) << 19) | \
-		 ((((val) >> (B18)) & 1) << 18) | \
-		 ((((val) >> (B17)) & 1) << 17) | \
-		 ((((val) >> (B16)) & 1) << 16) | \
-		 ((((val) >> (B15)) & 1) << 15) | \
-		 ((((val) >> (B14)) & 1) << 14) | \
-		 ((((val) >> (B13)) & 1) << 13) | \
-		 ((((val) >> (B12)) & 1) << 12) | \
-		 ((((val) >> (B11)) & 1) << 11) | \
-		 ((((val) >> (B10)) & 1) << 10) | \
-		 ((((val) >> ( B9)) & 1) <<  9) | \
-		 ((((val) >> ( B8)) & 1) <<  8) | \
-		 ((((val) >> ( B7)) & 1) <<  7) | \
-		 ((((val) >> ( B6)) & 1) <<  6) | \
-		 ((((val) >> ( B5)) & 1) <<  5) | \
-		 ((((val) >> ( B4)) & 1) <<  4) | \
-		 ((((val) >> ( B3)) & 1) <<  3) | \
-		 ((((val) >> ( B2)) & 1) <<  2) | \
-		 ((((val) >> ( B1)) & 1) <<  1) | \
-		 ((((val) >> ( B0)) & 1) <<  0))
-
-
-#ifdef __cplusplus
+/* automatic resource management */
+void begin_resource_tracking(void);
+void end_resource_tracking(void);
+INLINE int get_resource_tag(void)
+{
+	extern int resource_tracking_tag;
+	return resource_tracking_tag;
 }
-#endif
 
-#endif
+/* automatically-freeing memory */
+void *auto_malloc(size_t size) ATTR_MALLOC;
+char *auto_strdup(const char *str) ATTR_MALLOC;
+mame_bitmap *auto_bitmap_alloc(int width,int height);
+mame_bitmap *auto_bitmap_alloc_depth(int width,int height,int depth);
+
+/*
+  Save a screen shot of the game display. It is suggested to use the core
+  function save_screen_snapshot() or save_screen_snapshot_as(), so the format
+  of the screen shots will be consistent across ports. This hook is provided
+  only to allow the display of a file requester to let the user choose the
+  file name. This isn't scrictly necessary, so you can just call
+  save_screen_snapshot() to let the core automatically pick a default name.
+*/
+void save_screen_snapshot_as(mame_file *fp, mame_bitmap *bitmap);
+void save_screen_snapshot(mame_bitmap *bitmap);
+
+/* Movie recording */
+void record_movie_toggle(void);
+void record_movie_stop(void);
+void record_movie_frame(mame_bitmap *bitmap);
+
+/* disk handling */
+chd_file *get_disk_handle(int diskindex);
+
+/* ROM processing */
+int rom_load(const rom_entry *romp);
+const rom_entry *rom_first_region(const game_driver *drv);
+const rom_entry *rom_next_region(const rom_entry *romp);
+const rom_entry *rom_first_file(const rom_entry *romp);
+const rom_entry *rom_next_file(const rom_entry *romp);
+const rom_entry *rom_first_chunk(const rom_entry *romp);
+const rom_entry *rom_next_chunk(const rom_entry *romp);
+
+
+
+#endif	/* __COMMON_H__ */
