@@ -1415,6 +1415,7 @@ INLINE uint EA_SIY(void)   {return MAKE_UINT_16(read_16_SIY(REG_S + OPER_8_IMM()
 #define OP_MVN()															\
 			DST = OPER_8_IMM()<<16;											\
 			SRC = OPER_8_IMM()<<16;											\
+			REG_DB = DST;	\
 			REG_A |= REG_B;													\
 			CLK((REG_A+1)<<3);												\
 			for(;(int)REG_A >= 0;REG_A--)									\
@@ -1434,6 +1435,7 @@ INLINE uint EA_SIY(void)   {return MAKE_UINT_16(read_16_SIY(REG_S + OPER_8_IMM()
 #define OP_MVN()															\
 			DST = OPER_8_IMM()<<16;											\
 			SRC = OPER_8_IMM()<<16;											\
+			REG_DB = DST;	\
 			REG_A |= REG_B;													\
 			CLK((REG_A+1)<<3);												\
 			for(;(int)REG_A >= 0;REG_A--)									\
@@ -1457,6 +1459,7 @@ INLINE uint EA_SIY(void)   {return MAKE_UINT_16(read_16_SIY(REG_S + OPER_8_IMM()
 #define OP_MVP()															\
 			DST = OPER_8_IMM()<<16;											\
 			SRC = OPER_8_IMM()<<16;											\
+			REG_DB = DST;	\
 			REG_A |= REG_B;													\
 			CLK((REG_A+1)<<3);												\
 			for(;(int)REG_A >= 0;REG_A--)									\
@@ -1476,6 +1479,7 @@ INLINE uint EA_SIY(void)   {return MAKE_UINT_16(read_16_SIY(REG_S + OPER_8_IMM()
 #define OP_MVP()															\
 			DST = OPER_8_IMM()<<16;											\
 			SRC = OPER_8_IMM()<<16;											\
+			REG_DB = DST;	\
 			REG_A |= REG_B;													\
 			CLK((REG_A+1)<<3);												\
 			for(;(int)REG_A >= 0;REG_A--)									\
@@ -2577,6 +2581,7 @@ OP(192, OP_STB   ( DI          ) ) /* STB di  (C) */
 OP(193, OP_STB   ( SIY         ) ) /* STB siy (G) */
 OP(195, OP_STB   ( DX          ) ) /* STB dx      */
 OP(197, OP_STB   ( DLIY        ) ) /* STB dliy(G) */
+OP(198, OP_TXB   ( REG_Y       ) ) /* TYB         */
 OP(199, OP_STB   ( AY          ) ) /* STB ay      */
 OP(19d, OP_STB   ( AX          ) ) /* STB ax      */
 OP(19f, OP_STB   ( ALX         ) ) /* STB alx (G) */
@@ -2673,7 +2678,7 @@ TABLE_OPCODES2 =
 	O(200),O(181),O(200),O(183),O(200),O(185),O(200),O(187),	/* 80 */
 	O(200),O(200),O(18a),O(200),O(200),O(18d),O(200),O(18f),
 	O(200),O(191),O(192),O(193),O(200),O(195),O(200),O(197),	/* 90 */
-	O(200),O(199),O(200),O(200),O(200),O(19d),O(200),O(19f),
+	O(198),O(199),O(200),O(200),O(200),O(19d),O(200),O(19f),
 	O(200),O(1a1),O(200),O(200),O(200),O(1a5),O(200),O(200),	/* a0 */
 	O(1a8),O(1a9),O(1aa),O(200),O(200),O(1ad),O(200),O(200),
 	O(200),O(200),O(1b2),O(200),O(200),O(1b5),O(200),O(200),	/* b0 */
