@@ -305,6 +305,8 @@ int cpu_init(void)
 		state_save_register_UINT8 ("cpu", 0, "nexteatcycles", &cpu[cpunum].nexteatcycles, 1);
 		state_save_register_int   ("cpu", 0, "trigger", &cpu[cpunum].trigger);
 
+		state_save_register_int   ("cpu", 0, "iloops", &cpu[cpunum].iloops);
+
 		state_save_register_UINT64("cpu", 0, "totalcycles", &cpu[cpunum].totalcycles, 1);
 		state_save_register_INT32 ("cpu", 0, "localtime.sec", &cpu[cpunum].localtime.seconds, 1);
 		state_save_register_INT64 ("cpu", 0, "localtime.sub", &cpu[cpunum].localtime.subseconds, 1);
@@ -321,7 +323,11 @@ int cpu_init(void)
 
 		/* if no state registered for saving, we can't save */
 		if (num_regs == 0)
+		{
 			logerror("CPU #%d (%s) did not register any state to save!\n", cpunum, cputype_name(cputype));
+			if (Machine->gamedrv->flags & GAME_SUPPORTS_SAVE)
+				osd_die("CPU #%d (%s) did not register any state to save!\n", cpunum, cputype_name(cputype));
+		}
 
 		/* pop the state tag */
 		state_save_pop_tag();
@@ -473,10 +479,17 @@ void cpu_run(void)
 			/* otherwise, just pump video updates through */
 			else
 			{
-				time_to_quit = updatescreen();
+				time_to_quit |= updatescreen();
 				reset_partial_updates();
 			}
 
+			/* if we're autosaving on exit, and it's time to quit, schedule the save */
+			if (time_to_quit && options.auto_save && (Machine->gamedrv->flags & GAME_SUPPORTS_SAVE))
+			{
+				cpu_loadsave_schedule_file(LOADSAVE_SAVE_AND_EXIT, Machine->gamedrv->name);
+				time_to_quit = FALSE;
+			}
+
 			profiler_mark(PROFILER_END);
 		}
 
@@ -603,6 +616,10 @@ static void handle_save(void)
 		/* finish and close */
 		state_save_save_finish();
 		mame_fclose(file);
+
+		/* pop a warning if the game doesn't support saves */
+		if (!(Machine->gamedrv->flags & GAME_SUPPORTS_SAVE))
+			ui_popup("State successfully saved.\nWarning: Save states are not officially supported for this game.");
 	}
 	else
 		ui_popup("Error: Failed to save state");
@@ -624,6 +641,19 @@ static void handle_load(void)
 	mame_file *file;
 	int cpunum;
 
+	/* if there are anonymous timers, we can't load just yet because the timers might */
+	/* overwrite data we have loaded */
+	if (timer_count_anonymous() > 0)
+	{
+		/* if more than a second has passed, we're probably screwed */
+		if (sub_mame_times(mame_timer_get_time(), loadsave_schedule_time).seconds > 0)
+		{
+			ui_popup("Unable to load due to pending anonymous timers. See error.log for details.");
+			cpu_loadsave_reset();
+		}
+		return;
+	}
+
 	/* open the file */
 	file = mame_fopen(Machine->gamedrv->name, loadsave_schedule_name, FILETYPE_STATE, 0);
 
@@ -651,6 +681,9 @@ static void handle_load(void)
 				state_save_load_continue();
 				state_save_pop_tag();
 
+				/* make sure banking is set */
+				activecpu_reset_banking();
+
 				cpuintrf_pop_context();
 			}
 
@@ -691,6 +724,15 @@ static void handle_loadsave(void)
 			handle_save();
 			break;
 
+		case LOADSAVE_SAVE_AND_EXIT:
+			handle_save();
+			if (loadsave_schedule == LOADSAVE_NONE)
+			{
+				time_to_quit = TRUE;
+				options.auto_save = FALSE;
+			}
+			break;
+
 		case LOADSAVE_LOAD:
 			file = mame_fopen(Machine->gamedrv->name, loadsave_schedule_name, FILETYPE_STATE, 0);
 			if (file)
@@ -1916,7 +1958,7 @@ static void cpu_vblankcallback(int param)
 	{
 		/* do we update the screen now? */
 		if (!(Machine->drv->video_attributes & VIDEO_UPDATE_AFTER_VBLANK))
-			time_to_quit = updatescreen();
+			time_to_quit |= updatescreen();
 
 		/* Set the timer to update the screen */
 		mame_timer_adjust(update_timer, double_to_mame_time(TIME_IN_USEC(Machine->drv->vblank_duration)), 0, time_zero);
@@ -1946,7 +1988,7 @@ static void cpu_updatecallback(int param)
 {
 	/* update the screen if we didn't before */
 	if (Machine->drv->video_attributes & VIDEO_UPDATE_AFTER_VBLANK)
-		time_to_quit = updatescreen();
+		time_to_quit |= updatescreen();
 	vblank = 0;
 
 	/* update IPT_VBLANK input ports */
