@@ -447,7 +447,7 @@ void debug_view_set_property(struct debug_view *view, int property, const void *
 
 		case DVP_UPDATE_CALLBACK:
 			debug_view_begin_update(view);
-			view->update_func = (void (*)(struct debug_view *)) (genf *) value;
+			memcpy(&view->update_func, &value, sizeof(view->update_func));
 			view->update_pending = 1;
 			debug_view_end_update(view);
 			break;
@@ -1043,8 +1043,10 @@ static offs_t disasm_back_up(int cpunum, const struct debug_cpu_info *cpuinfo, o
 {
 	int minlen = BYTE2ADDR(activecpu_min_instruction_bytes(), cpuinfo, ADDRESS_SPACE_PROGRAM);
 	int maxlen = BYTE2ADDR(activecpu_max_instruction_bytes(), cpuinfo, ADDRESS_SPACE_PROGRAM);
+	int use_new_dasm = (activecpu_get_info_fct(CPUINFO_PTR_DISASSEMBLE_NEW) != NULL);
 	UINT32 addrmask = BYTE2ADDR(0xffffffff, cpuinfo, ADDRESS_SPACE_PROGRAM);
-	offs_t curpc, lastgoodpc = startpc;
+	offs_t curpc, lastgoodpc = startpc, temppc;
+	UINT8 opbuf[1024], argbuf[1024];
 	char dasmbuffer[100];
 
 	/* compute the increment */
@@ -1056,10 +1058,18 @@ static offs_t disasm_back_up(int cpunum, const struct debug_cpu_info *cpuinfo, o
 	if (curpc > startpc)
 		curpc = 0;
 
+	/* if using the new disassembler, prefetch the opcode bytes */
+	if (use_new_dasm)
+		for (temppc = curpc; temppc < startpc; temppc++)
+		{
+			opbuf[1000 + temppc - startpc] = debug_read_opcode(temppc, 1, FALSE);
+			argbuf[1000 + temppc - startpc] = debug_read_opcode(temppc, 1, TRUE);
+		}
+
 	/* loop until we hit it */
 	while (1)
 	{
-		offs_t testpc, instlen, instcount = 0;
+		offs_t testpc, nextcurpc, instlen, instcount = 0;
 
 		/* loop until we get past the target instruction */
 		for (testpc = curpc; testpc < startpc; testpc += instlen)
@@ -1068,13 +1078,16 @@ static offs_t disasm_back_up(int cpunum, const struct debug_cpu_info *cpuinfo, o
 			offs_t pcbyte = ADDR2BYTE(testpc, cpuinfo, ADDRESS_SPACE_PROGRAM);
 
 			/* get the disassembly, but only if mapped */
-			if (memory_get_read_ptr(cpunum, ADDRESS_SPACE_PROGRAM, pcbyte) != NULL)
-			{
-				memory_set_opbase(pcbyte);
-				instlen = activecpu_dasm(dasmbuffer, testpc & addrmask) & DASMFLAG_LENGTHMASK;
-			}
-			else
-				instlen = 1;
+			instlen = 1;
+			if (!cpuinfo->translate || (*cpuinfo->translate)(ADDRESS_SPACE_PROGRAM, &pcbyte))
+				if (memory_get_read_ptr(cpunum, ADDRESS_SPACE_PROGRAM, pcbyte) != NULL)
+				{
+					memory_set_opbase(pcbyte);
+					if (use_new_dasm)
+						instlen = activecpu_dasm_new(dasmbuffer, testpc & addrmask, &opbuf[1000 + testpc - startpc], &argbuf[1000 + testpc - startpc], startpc - testpc) & DASMFLAG_LENGTHMASK;
+					else
+						instlen = activecpu_dasm(dasmbuffer, testpc & addrmask) & DASMFLAG_LENGTHMASK;
+				}
 
 			/* count this one */
 			instcount++;
@@ -1093,9 +1106,20 @@ static offs_t disasm_back_up(int cpunum, const struct debug_cpu_info *cpuinfo, o
 			break;
 
 		/* back up one more and try again */
-		curpc -= minlen;
-		if (curpc > startpc)
-			curpc = 0;
+		nextcurpc = curpc - minlen;
+		if (nextcurpc > startpc)
+			nextcurpc = 0;
+
+		/* if using the new disassembler, prefetch the opcode bytes */
+		if (use_new_dasm)
+			for (temppc = nextcurpc; temppc < curpc; temppc++)
+			{
+				opbuf[1000 + temppc - startpc] = debug_read_opcode(temppc, 1, FALSE);
+				argbuf[1000 + temppc - startpc] = debug_read_opcode(temppc, 1, TRUE);
+			}
+
+		/* update curpc once we're done fetching */
+		curpc = nextcurpc;
 	}
 
 	return lastgoodpc;
@@ -1116,32 +1140,32 @@ static void disasm_generate_bytes(offs_t pcbyte, int numbytes, const struct debu
 	{
 		case 1:
 			if (maxchars >= 2)
-				offset = sprintf(string, "%02X", (UINT32)debug_read_opcode(pcbyte, 1));
+				offset = sprintf(string, "%02X", (UINT32)debug_read_opcode(pcbyte, 1, FALSE));
 			for (byte = 1; byte < numbytes && offset + 3 < maxchars; byte++)
-				offset += sprintf(&string[offset], " %02X", (UINT32)debug_read_opcode(pcbyte + byte, 1));
+				offset += sprintf(&string[offset], " %02X", (UINT32)debug_read_opcode(pcbyte + byte, 1, FALSE));
 			break;
 
 		case 2:
 			if (maxchars >= 4)
-				offset = sprintf(string, "%04X", (UINT32)debug_read_opcode(pcbyte, 2));
+				offset = sprintf(string, "%04X", (UINT32)debug_read_opcode(pcbyte, 2, FALSE));
 			for (byte = 2; byte < numbytes && offset + 5 < maxchars; byte += 2)
-				offset += sprintf(&string[offset], " %04X", (UINT32)debug_read_opcode(pcbyte + byte, 2));
+				offset += sprintf(&string[offset], " %04X", (UINT32)debug_read_opcode(pcbyte + byte, 2, FALSE));
 			break;
 
 		case 4:
 			if (maxchars >= 8)
-				offset = sprintf(string, "%08X", (UINT32)debug_read_opcode(pcbyte, 4));
+				offset = sprintf(string, "%08X", (UINT32)debug_read_opcode(pcbyte, 4, FALSE));
 			for (byte = 4; byte < numbytes && offset + 9 < maxchars; byte += 4)
-				offset += sprintf(&string[offset], " %08X", (UINT32)debug_read_opcode(pcbyte + byte, 4));
+				offset += sprintf(&string[offset], " %08X", (UINT32)debug_read_opcode(pcbyte + byte, 4, FALSE));
 			break;
 
 		case 8:
-			val = debug_read_opcode(pcbyte, 8);
+			val = debug_read_opcode(pcbyte, 8, FALSE);
 			if (maxchars >= 16)
 				offset = sprintf(string, "%08X%08X", (UINT32)(val >> 32), (UINT32)val);
 			for (byte = 8; byte < numbytes && offset + 17 < maxchars; byte += 8)
 			{
-				val = debug_read_opcode(pcbyte + byte, 8);
+				val = debug_read_opcode(pcbyte + byte, 8, FALSE);
 				offset += sprintf(&string[offset], " %08X%08X", (UINT32)(val >> 32), (UINT32)val);
 			}
 			break;
@@ -1159,22 +1183,23 @@ static void disasm_generate_bytes(offs_t pcbyte, int numbytes, const struct debu
 
 
 /*-------------------------------------------------
-    disasm_recompute - recompute all info
+    disasm_recompute - recompute selected info
     for the disassembly view
 -------------------------------------------------*/
 
-static void disasm_recompute(struct debug_view *view)
+static void disasm_recompute(struct debug_view *view, offs_t pc, int startline, int lines)
 {
 	const struct debug_cpu_info *cpuinfo = debug_get_cpu_info(view->cpunum);
 	struct debug_view_disasm *dasmdata = view->extra_data;
-	int chunksize, minbytes, maxbytes;
+	int chunksize, minbytes, maxbytes, maxbytes_clamped;
+	int use_new_dasm;
 	UINT32 addrmask;
-	int instr;
-	offs_t pc;
+	int line;
 
 	/* switch to the context of the CPU in question */
 	cpuintrf_push_context(view->cpunum);
 	addrmask = BYTE2ADDR(0xffffffff, cpuinfo, ADDRESS_SPACE_PROGRAM);
+	use_new_dasm = (activecpu_get_info_fct(CPUINFO_PTR_DISASSEMBLE_NEW) != NULL);
 
 	/* determine how many characters we need for an address and set the divider */
 	dasmdata->divider1 = 1 + cpuinfo->space[ADDRESS_SPACE_PROGRAM].addrchars + 1;
@@ -1186,41 +1211,65 @@ static void disasm_recompute(struct debug_view *view)
 	chunksize = activecpu_databus_width(ADDRESS_SPACE_PROGRAM) / 8;
 	minbytes = activecpu_min_instruction_bytes();
 	maxbytes = activecpu_max_instruction_bytes();
-	if (maxbytes > DASM_MAX_BYTES)
-		maxbytes = DASM_MAX_BYTES;
-	view->total_cols = dasmdata->divider2 + 1 + 2 * maxbytes + (maxbytes / minbytes - 1) + 1;
+	maxbytes_clamped = maxbytes;
+	if (maxbytes_clamped > DASM_MAX_BYTES)
+		maxbytes_clamped = DASM_MAX_BYTES;
+	view->total_cols = dasmdata->divider2 + 1 + 2 * maxbytes_clamped + (maxbytes_clamped / minbytes - 1) + 1;
 	view->total_rows = DASM_LINES;
-	view->top_row = 0;
-	view->left_col = 0;
 
-	/* determine the addresses of what we will display */
-	pc = (UINT32)dasmdata->last_result;
-	pc = disasm_back_up(view->cpunum, cpuinfo, pc, 3);
-	for (instr = 0; instr < DASM_LINES; instr++)
+	for (line = 0; line < lines; line++)
 	{
+		offs_t pcbyte, tempaddr;
 		UINT64 dummyreadop;
 		char buffer[100];
-		offs_t pcbyte;
 		int numbytes;
+		int instr = startline + line;
 
 		/* convert PC to a byte offset */
 		pcbyte = ADDR2BYTE(pc, cpuinfo, ADDRESS_SPACE_PROGRAM);
 
 		/* convert back and set the address of this instruction */
 		dasmdata->address[instr] = pcbyte;
-		sprintf(&dasmdata->dasm[instr][0], " %0*X  ", cpuinfo->space[ADDRESS_SPACE_PROGRAM].addrchars, pc);
+		sprintf(&dasmdata->dasm[instr][0], " %0*X  ", cpuinfo->space[ADDRESS_SPACE_PROGRAM].addrchars, BYTE2ADDR(pcbyte, cpuinfo, ADDRESS_SPACE_PROGRAM));
 
-		/* get the disassembly, but only if mapped */
-		if (memory_get_op_ptr(view->cpunum, pcbyte) != NULL || (cpuinfo->readop && (*cpuinfo->readop)(pcbyte, 1, &dummyreadop)))
+		/* make sure we can translate the address */
+		tempaddr = pcbyte;
+		if (!cpuinfo->translate || (*cpuinfo->translate)(ADDRESS_SPACE_PROGRAM, &tempaddr))
 		{
-			memory_set_opbase(pcbyte);
-			pc += numbytes = activecpu_dasm(buffer, pc & addrmask) & DASMFLAG_LENGTHMASK;
+			/* if we can use new disassembly, do it */
+			if (use_new_dasm)
+			{
+				UINT8 opbuf[64], argbuf[64];
+
+				/* fetch the bytes up to the maximum */
+				for (numbytes = 0; numbytes < maxbytes; numbytes++)
+				{
+					opbuf[numbytes] = debug_read_opcode(pcbyte + numbytes, 1, FALSE);
+					argbuf[numbytes] = debug_read_opcode(pcbyte + numbytes, 1, TRUE);
+				}
+
+				/* disassemble the result */
+				pc += numbytes = activecpu_dasm_new(buffer, pc & addrmask, opbuf, argbuf, maxbytes) & DASMFLAG_LENGTHMASK;
+			}
+
+			/* otherwise, we need to use the old, risky way */
+			else
+			{
+				/* get the disassembly, but only if mapped */
+				if (memory_get_op_ptr(view->cpunum, pcbyte) != NULL || (cpuinfo->readop && (*cpuinfo->readop)(pcbyte, 1, &dummyreadop)))
+				{
+					memory_set_opbase(pcbyte);
+					pc += numbytes = activecpu_dasm(buffer, pc & addrmask) & DASMFLAG_LENGTHMASK;
+				}
+				else
+				{
+					sprintf(buffer, "<unmapped>");
+					pc += numbytes = 1;
+				}
+			}
 		}
 		else
-		{
 			sprintf(buffer, "<unmapped>");
-			pc += numbytes = 1;
-		}
 		sprintf(&dasmdata->dasm[instr][dasmdata->divider1 + 1], "%-*s  ", DASM_WIDTH, buffer);
 
 		/* get the bytes */
@@ -1238,7 +1287,7 @@ static void disasm_recompute(struct debug_view *view)
 
 	/* reset the opcode base */
 	if (view->cpunum == cpu_getactivecpu())
-		memory_set_opbase(activecpu_get_pc_byte());
+		memory_set_opbase(activecpu_get_physical_pc_byte());
 }
 
 
@@ -1250,7 +1299,8 @@ static void disasm_recompute(struct debug_view *view)
 static void disasm_update(struct debug_view *view)
 {
 	const struct debug_cpu_info *cpuinfo = debug_get_cpu_info(view->cpunum);
-	offs_t pcbyte = ADDR2BYTE(cpunum_get_reg(view->cpunum, REG_PC), cpuinfo, ADDRESS_SPACE_PROGRAM);
+	offs_t pc = cpunum_get_reg(view->cpunum, REG_PC);
+	offs_t pcbyte = ADDR2BYTE(pc, cpuinfo, ADDRESS_SPACE_PROGRAM);
 	struct debug_view_disasm *dasmdata = view->extra_data;
 	struct debug_view_char *dest = view->viewdata;
 	UINT8 need_to_recompute = 0;
@@ -1316,7 +1366,16 @@ static void disasm_update(struct debug_view *view)
 
 	/* if we need to recompute, do it */
 	if (need_to_recompute)
-		disasm_recompute(view);
+	{
+		/* determine the addresses of what we will display */
+		pc = (UINT32)dasmdata->last_result;
+		pc = disasm_back_up(view->cpunum, cpuinfo, pc, 3);
+
+		view->top_row = 0;
+		view->left_col = 0;
+
+		disasm_recompute(view, pc, 0, DASM_LINES);
+	}
 
 	/* loop over visible rows */
 	for (row = 0; row < view->visible_rows; row++)
@@ -1330,7 +1389,11 @@ static void disasm_update(struct debug_view *view)
 		if (effrow < view->total_rows)
 		{
 			if (pcbyte == dasmdata->address[effrow])
+			{
 				attrib = DCA_CURRENT;
+				if (!need_to_recompute)
+					disasm_recompute(view, pc, effrow, 1);
+			}
 			else
 				for (bp = cpuinfo->first_bp; bp; bp = bp->next)
 					if (dasmdata->address[effrow] == ADDR2BYTE(bp->address, cpuinfo, ADDRESS_SPACE_PROGRAM))
@@ -1840,17 +1903,35 @@ static void memory_update(struct debug_view *view)
 					default:
 					case 1:
 						for (i = 0; i < 16; i++)
-							len += sprintf(&data[len], "%02X ", debug_read_byte(memdata->spacenum, addrbyte + i));
+						{
+							offs_t curaddr = addrbyte + i;
+							if (!cpuinfo->translate || (*cpuinfo->translate)(memdata->spacenum, &curaddr))
+								len += sprintf(&data[len], "%02X ", debug_read_byte(memdata->spacenum, addrbyte + i));
+							else
+								len += sprintf(&data[len], "** ");
+						}
 						break;
 
 					case 2:
 						for (i = 0; i < 8; i++)
-							len += sprintf(&data[len], " %04X ", debug_read_word(memdata->spacenum, addrbyte + 2 * i));
+						{
+							offs_t curaddr = addrbyte + 2 * i;
+							if (!cpuinfo->translate || (*cpuinfo->translate)(memdata->spacenum, &curaddr))
+								len += sprintf(&data[len], " %04X ", debug_read_word(memdata->spacenum, addrbyte + 2 * i));
+							else
+								len += sprintf(&data[len], " **** ");
+						}
 						break;
 
 					case 4:
 						for (i = 0; i < 4; i++)
-							len += sprintf(&data[len], "  %08X  ", debug_read_dword(memdata->spacenum, addrbyte + 4 * i));
+						{
+							offs_t curaddr = addrbyte + 4 * i;
+							if (!cpuinfo->translate || (*cpuinfo->translate)(memdata->spacenum, &curaddr))
+								len += sprintf(&data[len], "  %08X  ", debug_read_dword(memdata->spacenum, addrbyte + 4 * i));
+							else
+								len += sprintf(&data[len], "  ********  ");
+						}
 						break;
 				}
 				len += sprintf(&data[len], " ");
@@ -1875,17 +1956,35 @@ static void memory_update(struct debug_view *view)
 					default:
 					case 1:
 						for (i = 15; i >= 0; i--)
-							len += sprintf(&data[len], "%02X ", debug_read_byte(memdata->spacenum, addrbyte + i));
+						{
+							offs_t curaddr = addrbyte + i;
+							if (!cpuinfo->translate || (*cpuinfo->translate)(memdata->spacenum, &curaddr))
+								len += sprintf(&data[len], "%02X ", debug_read_byte(memdata->spacenum, addrbyte + i));
+							else
+								len += sprintf(&data[len], "** ");
+						}
 						break;
 
 					case 2:
 						for (i = 7; i >= 0; i--)
-							len += sprintf(&data[len], " %04X ", debug_read_word(memdata->spacenum, addrbyte + 2 * i));
+						{
+							offs_t curaddr = addrbyte + 2 * i;
+							if (!cpuinfo->translate || (*cpuinfo->translate)(memdata->spacenum, &curaddr))
+								len += sprintf(&data[len], " %04X ", debug_read_word(memdata->spacenum, addrbyte + 2 * i));
+							else
+								len += sprintf(&data[len], " **** ");
+						}
 						break;
 
 					case 4:
 						for (i = 3; i >= 0; i--)
-							len += sprintf(&data[len], "  %08X  ", debug_read_dword(memdata->spacenum, addrbyte + 4 * i));
+						{
+							offs_t curaddr = addrbyte + 4 * i;
+							if (!cpuinfo->translate || (*cpuinfo->translate)(memdata->spacenum, &curaddr))
+								len += sprintf(&data[len], "  %08X  ", debug_read_dword(memdata->spacenum, addrbyte + 4 * i));
+							else
+								len += sprintf(&data[len], "  ********  ");
+						}
 						break;
 				}
 				len += sprintf(&data[len], addrformat, BYTE2ADDR(addrbyte, cpuinfo, memdata->spacenum));
