@@ -1,22 +1,20 @@
 /*********************************************************************
 
-  drawgfx.h
+    drawgfx.h
 
-  Generic graphic functions.
+    Generic graphic functions.
 
 *********************************************************************/
 
-#ifndef DRAWGFX_H
-#define DRAWGFX_H
+#pragma once
 
-#ifdef __cplusplus
-extern "C" {
-#endif
+#ifndef __DRAWGFX_H__
+#define __DRAWGFX_H__
 
 #include "palette.h"
 
 #define MAX_GFX_PLANES 8
-#define MAX_GFX_SIZE 64
+#define MAX_GFX_SIZE 256
 
 #define RGN_FRAC(num,den) (0x80000000 | (((num) & 0x0f) << 27) | (((den) & 0x0f) << 23))
 #define IS_FRAC(offset) ((offset) & 0x80000000)
@@ -29,7 +27,7 @@ extern "C" {
 #define STEP16(START,STEP) STEP8(START,STEP),STEP8((START)+8*(STEP),STEP)
 
 
-struct GfxLayout
+struct _gfx_layout
 {
 	UINT16 width,height; /* width and height (in pixels) of chars/sprites */
 	UINT32 total; /* total numer of chars/sprites in the rom */
@@ -37,8 +35,9 @@ struct GfxLayout
 	UINT32 planeoffset[MAX_GFX_PLANES]; /* start of every bitplane (in bits) */
 	UINT32 xoffset[MAX_GFX_SIZE]; /* position of the bit corresponding to the pixel */
 	UINT32 yoffset[MAX_GFX_SIZE]; /* of the given coordinates */
-	UINT16 charincrement; /* distance between two consecutive characters/sprites (in bits) */
+	UINT32 charincrement; /* distance between two consecutive characters/sprites (in bits) */
 };
+typedef struct _gfx_layout gfx_layout;
 
 #define GFX_RAW 0x12345678
 /* When planeoffset[0] is set to GFX_RAW, the gfx data is left as-is, with no conversion.
@@ -56,55 +55,53 @@ struct GfxLayout
    not be prerotated and will rely on GFX_SWAPXY.
 */
 
-struct GfxElement
+struct _gfx_element
 {
-	int width,height;
+	UINT16 width,height;
 
-	unsigned int total_elements;	/* total number of characters/sprites */
-	int color_granularity;	/* number of colors for each color code */
+	UINT32 total_elements;	/* total number of characters/sprites */
+	UINT16 color_granularity;	/* number of colors for each color code */
 							/* (for example, 4 for 2 bitplanes gfx) */
+	UINT32 total_colors;
 	pen_t *colortable;	/* map color codes to screen pens */
-	int total_colors;
 	UINT32 *pen_usage;	/* an array of total_elements entries. */
 						/* It is a table of the pens each character uses */
 						/* (bit 0 = pen 0, and so on). This is used by */
 						/* drawgfgx() to do optimizations like skipping */
 						/* drawing of a totally transparent character */
 	UINT8 *gfxdata;		/* pixel data */
-	int line_modulo;	/* amount to add to get to the next line (usually = width) */
-	int char_modulo;	/* = line_modulo * height */
-	int flags;
+	UINT32 line_modulo;	/* amount to add to get to the next line (usually = width) */
+	UINT32 char_modulo;	/* = line_modulo * height */
+	UINT32 flags;
 };
+typedef struct _gfx_element gfx_element;
 
 #define GFX_PACKED				1	/* two 4bpp pixels are packed in one byte of gfxdata */
 #define GFX_SWAPXY				2	/* characters are mirrored along the top-left/bottom-right diagonal */
 #define GFX_DONT_FREE_GFXDATA	4	/* gfxdata was not malloc()ed, so don't free it on exit */
 
 
-struct GfxDecodeInfo
+struct _gfx_decode
 {
 	int memory_region;	/* memory region where the data resides (usually 1) */
 						/* -1 marks the end of the array */
-	int start;	/* beginning of data to decode */
-	struct GfxLayout *gfxlayout;
-	int color_codes_start;	/* offset in the color lookup table where color codes start */
-	int total_color_codes;	/* total number of color codes */
+	UINT32 start;	/* beginning of data to decode */
+	const gfx_layout *gfxlayout;
+	UINT16 color_codes_start;	/* offset in the color lookup table where color codes start */
+	UINT16 total_color_codes;	/* total number of color codes */
 };
+typedef struct _gfx_decode gfx_decode;
 
 
-struct rectangle
+struct _alpha_cache
 {
-	int min_x,max_x;
-	int min_y,max_y;
-};
-
-struct _alpha_cache {
 	const UINT8 *alphas;
 	const UINT8 *alphad;
 	UINT8 alpha[0x101][0x100];
 };
+typedef struct _alpha_cache alpha_cache;
 
-extern struct _alpha_cache alpha_cache;
+extern struct _alpha_cache drawgfx_alpha_cache;
 
 enum
 {
@@ -121,10 +118,14 @@ enum
 	TRANSPARENCY_BLEND_RAW,		/* blend two bitmaps, shifting the source and ORing to the dest with no remapping */
 	TRANSPARENCY_ALPHAONE,		/* single pen transparency, single pen alpha */
 	TRANSPARENCY_ALPHA,			/* single pen transparency, other pens alpha */
+	TRANSPARENCY_ALPHARANGE,	/* single pen transparency, multiple pens alpha depending on array, see psikyosh.c */
 
 	TRANSPARENCY_MODES			/* total number of modes; must be last */
 };
 
+/* drawing mode case TRANSPARENCY_ALPHARANGE */
+extern UINT8 gfx_alpharange_table[256];
+
 /* drawing mode case TRANSPARENCY_PEN_TABLE */
 extern UINT8 gfx_drawmode_table[256];
 enum
@@ -139,50 +140,42 @@ enum
 extern int pdrawgfx_shadow_lowpri;
 
 
-typedef void (*plot_pixel_proc)(struct mame_bitmap *bitmap,int x,int y,UINT32 pen);
-typedef int  (*read_pixel_proc)(struct mame_bitmap *bitmap,int x,int y);
-typedef void (*plot_box_proc)(struct mame_bitmap *bitmap,int x,int y,int width,int height,UINT32 pen);
-typedef void (*mark_dirty_proc)(int sx,int sy,int ex,int ey);
+/* pointers to pixel functions.  They're set based on depth */
+#define plot_pixel(bm,x,y,p)	(*(bm)->plot)(bm,x,y,p)
+#define read_pixel(bm,x,y)		(*(bm)->read)(bm,x,y)
+#define plot_box(bm,x,y,w,h,p)	(*(bm)->plot_box)(bm,x,y,w,h,p)
 
-
-/* pointers to pixel functions.  They're set based on orientation, depthness and whether
-   dirty rectangle handling is enabled */
-extern plot_pixel_proc plot_pixel;
-extern read_pixel_proc read_pixel;
-extern plot_box_proc plot_box;
-extern mark_dirty_proc mark_dirty;
-
-void decodechar(struct GfxElement *gfx,int num,const unsigned char *src,const struct GfxLayout *gl);
-struct GfxElement *decodegfx(const unsigned char *src,const struct GfxLayout *gl);
-void set_pixel_functions(void);
-void freegfx(struct GfxElement *gfx);
-void drawgfx(struct mame_bitmap *dest,const struct GfxElement *gfx,
+void decodechar(gfx_element *gfx,int num,const unsigned char *src,const gfx_layout *gl);
+gfx_element *decodegfx(const unsigned char *src,const gfx_layout *gl);
+void set_pixel_functions(mame_bitmap *bitmap);
+void freegfx(gfx_element *gfx);
+void drawgfx(mame_bitmap *dest,const gfx_element *gfx,
 		unsigned int code,unsigned int color,int flipx,int flipy,int sx,int sy,
-		const struct rectangle *clip,int transparency,int transparent_color);
-void pdrawgfx(struct mame_bitmap *dest,const struct GfxElement *gfx,
+		const rectangle *clip,int transparency,int transparent_color);
+void pdrawgfx(mame_bitmap *dest,const gfx_element *gfx,
 		unsigned int code,unsigned int color,int flipx,int flipy,int sx,int sy,
-		const struct rectangle *clip,int transparency,int transparent_color,
+		const rectangle *clip,int transparency,int transparent_color,
 		UINT32 priority_mask);
-void mdrawgfx(struct mame_bitmap *dest,const struct GfxElement *gfx,
+void mdrawgfx(mame_bitmap *dest,const gfx_element *gfx,
 		unsigned int code,unsigned int color,int flipx,int flipy,int sx,int sy,
-		const struct rectangle *clip,int transparency,int transparent_color,
+		const rectangle *clip,int transparency,int transparent_color,
 		UINT32 priority_mask);
-void copybitmap(struct mame_bitmap *dest,struct mame_bitmap *src,int flipx,int flipy,int sx,int sy,
-		const struct rectangle *clip,int transparency,int transparent_color);
-void copybitmap_remap(struct mame_bitmap *dest,struct mame_bitmap *src,int flipx,int flipy,int sx,int sy,
-		const struct rectangle *clip,int transparency,int transparent_color);
-void copyscrollbitmap(struct mame_bitmap *dest,struct mame_bitmap *src,
+void copybitmap(mame_bitmap *dest,mame_bitmap *src,int flipx,int flipy,int sx,int sy,
+		const rectangle *clip,int transparency,int transparent_color);
+void copybitmap_remap(mame_bitmap *dest,mame_bitmap *src,int flipx,int flipy,int sx,int sy,
+		const rectangle *clip,int transparency,int transparent_color);
+void copyscrollbitmap(mame_bitmap *dest,mame_bitmap *src,
 		int rows,const int *rowscroll,int cols,const int *colscroll,
-		const struct rectangle *clip,int transparency,int transparent_color);
-void copyscrollbitmap_remap(struct mame_bitmap *dest,struct mame_bitmap *src,
+		const rectangle *clip,int transparency,int transparent_color);
+void copyscrollbitmap_remap(mame_bitmap *dest,mame_bitmap *src,
 		int rows,const int *rowscroll,int cols,const int *colscroll,
-		const struct rectangle *clip,int transparency,int transparent_color);
-void draw_scanline8(struct mame_bitmap *bitmap,int x,int y,int length,const UINT8 *src,pen_t *pens,int transparent_pen);
-void draw_scanline16(struct mame_bitmap *bitmap,int x,int y,int length,const UINT16 *src,pen_t *pens,int transparent_pen);
-void pdraw_scanline8(struct mame_bitmap *bitmap,int x,int y,int length,const UINT8 *src,pen_t *pens,int transparent_pen,UINT32 orient,int pri);
-void pdraw_scanline16(struct mame_bitmap *bitmap,int x,int y,int length,const UINT16 *src,pen_t *pens,int transparent_pen,UINT32 orient,int pri);
-void extract_scanline8(struct mame_bitmap *bitmap,int x,int y,int length,UINT8 *dst);
-void extract_scanline16(struct mame_bitmap *bitmap,int x,int y,int length,UINT16 *dst);
+		const rectangle *clip,int transparency,int transparent_color);
+void draw_scanline8(mame_bitmap *bitmap,int x,int y,int length,const UINT8 *src,pen_t *pens,int transparent_pen);
+void draw_scanline16(mame_bitmap *bitmap,int x,int y,int length,const UINT16 *src,pen_t *pens,int transparent_pen);
+void pdraw_scanline8(mame_bitmap *bitmap,int x,int y,int length,const UINT8 *src,pen_t *pens,int transparent_pen,int pri);
+void pdraw_scanline16(mame_bitmap *bitmap,int x,int y,int length,const UINT16 *src,pen_t *pens,int transparent_pen,int pri);
+void extract_scanline8(mame_bitmap *bitmap,int x,int y,int length,UINT8 *dst);
+void extract_scanline16(mame_bitmap *bitmap,int x,int y,int length,UINT16 *dst);
 
 
 /* Alpha blending functions */
@@ -191,14 +184,14 @@ void alpha_init(void);
 INLINE void alpha_set_level(int level) {
 	if(level == 0)
 		level = -1;
-	alpha_cache.alphas = alpha_cache.alpha[level+1];
-	alpha_cache.alphad = alpha_cache.alpha[255-level];
+	drawgfx_alpha_cache.alphas = drawgfx_alpha_cache.alpha[level+1];
+	drawgfx_alpha_cache.alphad = drawgfx_alpha_cache.alpha[255-level];
 }
 
 INLINE UINT32 alpha_blend16( UINT32 d, UINT32 s )
 {
-	const UINT8 *alphas = alpha_cache.alphas;
-	const UINT8 *alphad = alpha_cache.alphad;
+	const UINT8 *alphas = drawgfx_alpha_cache.alphas;
+	const UINT8 *alphad = drawgfx_alpha_cache.alphad;
 	return (alphas[s & 0x1f] | (alphas[(s>>5) & 0x1f] << 5) | (alphas[(s>>10) & 0x1f] << 10))
 		+ (alphad[d & 0x1f] | (alphad[(d>>5) & 0x1f] << 5) | (alphad[(d>>10) & 0x1f] << 10));
 }
@@ -206,12 +199,28 @@ INLINE UINT32 alpha_blend16( UINT32 d, UINT32 s )
 
 INLINE UINT32 alpha_blend32( UINT32 d, UINT32 s )
 {
-	const UINT8 *alphas = alpha_cache.alphas;
-	const UINT8 *alphad = alpha_cache.alphad;
+	const UINT8 *alphas = drawgfx_alpha_cache.alphas;
+	const UINT8 *alphad = drawgfx_alpha_cache.alphad;
 	return (alphas[s & 0xff] | (alphas[(s>>8) & 0xff] << 8) | (alphas[(s>>16) & 0xff] << 16))
 		+ (alphad[d & 0xff] | (alphad[(d>>8) & 0xff] << 8) | (alphad[(d>>16) & 0xff] << 16));
 }
 
+INLINE UINT32 alpha_blend_r16( UINT32 d, UINT32 s, UINT8 level )
+{
+	const UINT8 *alphas = drawgfx_alpha_cache.alpha[level];
+	const UINT8 *alphad = drawgfx_alpha_cache.alpha[255 - level];
+	return (alphas[s & 0x1f] | (alphas[(s>>5) & 0x1f] << 5) | (alphas[(s>>10) & 0x1f] << 10))
+		+ (alphad[d & 0x1f] | (alphad[(d>>5) & 0x1f] << 5) | (alphad[(d>>10) & 0x1f] << 10));
+}
+
+
+INLINE UINT32 alpha_blend_r32( UINT32 d, UINT32 s, UINT8 level )
+{
+	const UINT8 *alphas = drawgfx_alpha_cache.alpha[level];
+	const UINT8 *alphad = drawgfx_alpha_cache.alpha[255 - level];
+	return (alphas[s & 0xff] | (alphas[(s>>8) & 0xff] << 8) | (alphas[(s>>16) & 0xff] << 16))
+		+ (alphad[d & 0xff] | (alphad[(d>>8) & 0xff] << 8) | (alphad[(d>>16) & 0xff] << 16));
+}
 
 /*
   Copy a bitmap applying rotation, zooming, and arbitrary distortion.
@@ -241,28 +250,25 @@ INLINE UINT32 alpha_blend32( UINT32 d, UINT32 s )
   Optionally the bitmap can be tiled across the screen instead of doing a single
   copy. This is obtained by setting the wraparound parameter to true.
  */
-void copyrozbitmap(struct mame_bitmap *dest,struct mame_bitmap *src,
+void copyrozbitmap(mame_bitmap *dest,mame_bitmap *src,
 		UINT32 startx,UINT32 starty,int incxx,int incxy,int incyx,int incyy,int wraparound,
-		const struct rectangle *clip,int transparency,int transparent_color,UINT32 priority);
+		const rectangle *clip,int transparency,int transparent_color,UINT32 priority);
 
-void fillbitmap(struct mame_bitmap *dest,int pen,const struct rectangle *clip);
-void plot_pixel2(struct mame_bitmap *bitmap1,struct mame_bitmap *bitmap2,int x,int y,int pen);
-void drawgfxzoom( struct mame_bitmap *dest_bmp,const struct GfxElement *gfx,
+void fillbitmap(mame_bitmap *dest,pen_t pen,const rectangle *clip);
+void drawgfxzoom( mame_bitmap *dest_bmp,const gfx_element *gfx,
 		unsigned int code,unsigned int color,int flipx,int flipy,int sx,int sy,
-		const struct rectangle *clip,int transparency,int transparent_color,int scalex,int scaley);
-void pdrawgfxzoom( struct mame_bitmap *dest_bmp,const struct GfxElement *gfx,
+		const rectangle *clip,int transparency,int transparent_color,int scalex,int scaley);
+void pdrawgfxzoom( mame_bitmap *dest_bmp,const gfx_element *gfx,
 		unsigned int code,unsigned int color,int flipx,int flipy,int sx,int sy,
-		const struct rectangle *clip,int transparency,int transparent_color,int scalex,int scaley,
+		const rectangle *clip,int transparency,int transparent_color,int scalex,int scaley,
 		UINT32 priority_mask);
-void mdrawgfxzoom( struct mame_bitmap *dest_bmp,const struct GfxElement *gfx,
+void mdrawgfxzoom( mame_bitmap *dest_bmp,const gfx_element *gfx,
 		unsigned int code,unsigned int color,int flipx,int flipy,int sx,int sy,
-		const struct rectangle *clip,int transparency,int transparent_color,int scalex,int scaley,
+		const rectangle *clip,int transparency,int transparent_color,int scalex,int scaley,
 		UINT32 priority_mask);
 
-void draw_crosshair(struct mame_bitmap *bitmap,int x,int y,const struct rectangle *clip);
+void drawgfx_toggle_crosshair(void);
+void draw_crosshair(mame_bitmap *bitmap,int x,int y,const rectangle *clip,int player);
 
-#ifdef __cplusplus
-}
-#endif
 
-#endif
+#endif	/* __DRAWGFX_H__ */
