@@ -3,7 +3,7 @@
 Battlantis(GX777) (c) 1987 Konami
 
 Preliminary driver by:
-	Manuel Abadia <manu@teleline.es>
+    Manuel Abadia <manu@teleline.es>
 
 ***************************************************************************/
 
@@ -12,34 +12,32 @@ Preliminary driver by:
 #include "vidhrdw/generic.h"
 #include "cpu/z80/z80.h"
 #include "vidhrdw/konamiic.h"
+#include "sound/3812intf.h"
 
 /* from vidhrdw */
-WRITE_HANDLER( battlnts_spritebank_w );
-int battlnts_vh_start(void);
-void battlnts_vh_stop(void);
-void battlnts_vh_screenrefresh(struct mame_bitmap *bitmap,int full_refresh);
+WRITE8_HANDLER( battlnts_spritebank_w );
+VIDEO_START( battlnts );
+VIDEO_UPDATE( battlnts );
 
-static int battlnts_interrupt( void )
+static INTERRUPT_GEN( battlnts_interrupt )
 {
 	if (K007342_is_INT_enabled())
-		return HD6309_INT_IRQ;
-	else
-		return ignore_interrupt();
+		cpunum_set_input_line(0, HD6309_IRQ_LINE, HOLD_LINE);
 }
 
-WRITE_HANDLER( battlnts_sh_irqtrigger_w )
+WRITE8_HANDLER( battlnts_sh_irqtrigger_w )
 {
-	cpu_cause_interrupt(1,0xff);
+	cpunum_set_input_line_and_vector(1, 0, HOLD_LINE, 0xff);
 }
 
-static WRITE_HANDLER( battlnts_bankswitch_w )
+static WRITE8_HANDLER( battlnts_bankswitch_w )
 {
 	unsigned char *RAM = memory_region(REGION_CPU1);
 	int bankaddress;
 
 	/* bits 6 & 7 = bank number */
 	bankaddress = 0x10000 + ((data & 0xc0) >> 6) * 0x4000;
-	cpu_setbank(1,&RAM[bankaddress]);
+	memory_set_bankptr(1,&RAM[bankaddress]);
 
 	/* bits 4 & 5 = coin counters */
 	coin_counter_w(0,data & 0x10);
@@ -48,55 +46,55 @@ static WRITE_HANDLER( battlnts_bankswitch_w )
 	/* other bits unknown */
 }
 
-static MEMORY_READ_START( battlnts_readmem )
-	{ 0x0000, 0x1fff, K007342_r },			/* Color RAM + Video RAM */
-	{ 0x2000, 0x21ff, K007420_r },			/* Sprite RAM */
-	{ 0x2200, 0x23ff, K007342_scroll_r },	/* Scroll RAM */
-	{ 0x2400, 0x24ff, paletteram_r },		/* Palette */
-	{ 0x2e00, 0x2e00, input_port_0_r }, 	/* DIPSW #1 */
-	{ 0x2e01, 0x2e01, input_port_4_r }, 	/* 2P controls */
-	{ 0x2e02, 0x2e02, input_port_3_r }, 	/* 1P controls */
-	{ 0x2e03, 0x2e03, input_port_2_r }, 	/* coinsw, testsw, startsw */
-	{ 0x2e04, 0x2e04, input_port_1_r }, 	/* DISPW #2 */
-	{ 0x4000, 0x7fff, MRA_BANK1 },			/* banked ROM */
-	{ 0x8000, 0xffff, MRA_ROM },			/* ROM 777e02.bin */
-MEMORY_END
+static ADDRESS_MAP_START( battlnts_readmem, ADDRESS_SPACE_PROGRAM, 8 )
+	AM_RANGE(0x0000, 0x1fff) AM_READ(K007342_r)			/* Color RAM + Video RAM */
+	AM_RANGE(0x2000, 0x21ff) AM_READ(K007420_r)			/* Sprite RAM */
+	AM_RANGE(0x2200, 0x23ff) AM_READ(K007342_scroll_r)	/* Scroll RAM */
+	AM_RANGE(0x2400, 0x24ff) AM_READ(paletteram_r)		/* Palette */
+	AM_RANGE(0x2e00, 0x2e00) AM_READ(input_port_0_r) 	/* DIPSW #1 */
+	AM_RANGE(0x2e01, 0x2e01) AM_READ(input_port_4_r) 	/* 2P controls */
+	AM_RANGE(0x2e02, 0x2e02) AM_READ(input_port_3_r) 	/* 1P controls */
+	AM_RANGE(0x2e03, 0x2e03) AM_READ(input_port_2_r) 	/* coinsw, testsw, startsw */
+	AM_RANGE(0x2e04, 0x2e04) AM_READ(input_port_1_r) 	/* DISPW #2 */
+	AM_RANGE(0x4000, 0x7fff) AM_READ(MRA8_BANK1)			/* banked ROM */
+	AM_RANGE(0x8000, 0xffff) AM_READ(MRA8_ROM)			/* ROM 777e02.bin */
+ADDRESS_MAP_END
 
-static MEMORY_WRITE_START( battlnts_writemem )
-	{ 0x0000, 0x1fff, K007342_w },				/* Color RAM + Video RAM */
-	{ 0x2000, 0x21ff, K007420_w },				/* Sprite RAM */
-	{ 0x2200, 0x23ff, K007342_scroll_w },		/* Scroll RAM */
-	{ 0x2400, 0x24ff, paletteram_xBBBBBGGGGGRRRRR_swap_w, &paletteram },/* palette */
-	{ 0x2600, 0x2607, K007342_vreg_w }, 		/* Video Registers */
-	{ 0x2e08, 0x2e08, battlnts_bankswitch_w },	/* bankswitch control */
-	{ 0x2e0c, 0x2e0c, battlnts_spritebank_w },	/* sprite bank select */
-	{ 0x2e10, 0x2e10, watchdog_reset_w },		/* watchdog reset */
-	{ 0x2e14, 0x2e14, soundlatch_w },			/* sound code # */
-	{ 0x2e18, 0x2e18, battlnts_sh_irqtrigger_w },/* cause interrupt on audio CPU */
-	{ 0x4000, 0x7fff, MWA_ROM },				/* banked ROM */
-	{ 0x8000, 0xffff, MWA_ROM },				/* ROM 777e02.bin */
-MEMORY_END
+static ADDRESS_MAP_START( battlnts_writemem, ADDRESS_SPACE_PROGRAM, 8 )
+	AM_RANGE(0x0000, 0x1fff) AM_WRITE(K007342_w)				/* Color RAM + Video RAM */
+	AM_RANGE(0x2000, 0x21ff) AM_WRITE(K007420_w)				/* Sprite RAM */
+	AM_RANGE(0x2200, 0x23ff) AM_WRITE(K007342_scroll_w)		/* Scroll RAM */
+	AM_RANGE(0x2400, 0x24ff) AM_WRITE(paletteram_xBBBBBGGGGGRRRRR_swap_w) AM_BASE(&paletteram)/* palette */
+	AM_RANGE(0x2600, 0x2607) AM_WRITE(K007342_vreg_w) 		/* Video Registers */
+	AM_RANGE(0x2e08, 0x2e08) AM_WRITE(battlnts_bankswitch_w)	/* bankswitch control */
+	AM_RANGE(0x2e0c, 0x2e0c) AM_WRITE(battlnts_spritebank_w)	/* sprite bank select */
+	AM_RANGE(0x2e10, 0x2e10) AM_WRITE(watchdog_reset_w)		/* watchdog reset */
+	AM_RANGE(0x2e14, 0x2e14) AM_WRITE(soundlatch_w)			/* sound code # */
+	AM_RANGE(0x2e18, 0x2e18) AM_WRITE(battlnts_sh_irqtrigger_w)/* cause interrupt on audio CPU */
+	AM_RANGE(0x4000, 0x7fff) AM_WRITE(MWA8_ROM)				/* banked ROM */
+	AM_RANGE(0x8000, 0xffff) AM_WRITE(MWA8_ROM)				/* ROM 777e02.bin */
+ADDRESS_MAP_END
 
-static MEMORY_READ_START( battlnts_readmem_sound )
-	{ 0x0000, 0x7fff, MRA_ROM },				/* ROM 777c01.rom */
-	{ 0x8000, 0x87ff, MRA_RAM },				/* RAM */
-	{ 0xa000, 0xa000, YM3812_status_port_0_r }, /* YM3812 (chip 1) */
-	{ 0xc000, 0xc000, YM3812_status_port_1_r }, /* YM3812 (chip 2) */
-	{ 0xe000, 0xe000, soundlatch_r },			/* soundlatch_r */
-MEMORY_END
+static ADDRESS_MAP_START( battlnts_readmem_sound, ADDRESS_SPACE_PROGRAM, 8 )
+	AM_RANGE(0x0000, 0x7fff) AM_READ(MRA8_ROM)				/* ROM 777c01.rom */
+	AM_RANGE(0x8000, 0x87ff) AM_READ(MRA8_RAM)				/* RAM */
+	AM_RANGE(0xa000, 0xa000) AM_READ(YM3812_status_port_0_r) /* YM3812 (chip 1) */
+	AM_RANGE(0xc000, 0xc000) AM_READ(YM3812_status_port_1_r) /* YM3812 (chip 2) */
+	AM_RANGE(0xe000, 0xe000) AM_READ(soundlatch_r)			/* soundlatch_r */
+ADDRESS_MAP_END
 
-static MEMORY_WRITE_START( battlnts_writemem_sound )
-	{ 0x0000, 0x7fff, MWA_ROM },					/* ROM 777c01.rom */
-	{ 0x8000, 0x87ff, MWA_RAM },					/* RAM */
-	{ 0xa000, 0xa000, YM3812_control_port_0_w },	/* YM3812 (chip 1) */
-	{ 0xa001, 0xa001, YM3812_write_port_0_w },		/* YM3812 (chip 1) */
-	{ 0xc000, 0xc000, YM3812_control_port_1_w },	/* YM3812 (chip 2) */
-	{ 0xc001, 0xc001, YM3812_write_port_1_w },		/* YM3812 (chip 2) */
-MEMORY_END
+static ADDRESS_MAP_START( battlnts_writemem_sound, ADDRESS_SPACE_PROGRAM, 8 )
+	AM_RANGE(0x0000, 0x7fff) AM_WRITE(MWA8_ROM)					/* ROM 777c01.rom */
+	AM_RANGE(0x8000, 0x87ff) AM_WRITE(MWA8_RAM)					/* RAM */
+	AM_RANGE(0xa000, 0xa000) AM_WRITE(YM3812_control_port_0_w)	/* YM3812 (chip 1) */
+	AM_RANGE(0xa001, 0xa001) AM_WRITE(YM3812_write_port_0_w)		/* YM3812 (chip 1) */
+	AM_RANGE(0xc000, 0xc000) AM_WRITE(YM3812_control_port_1_w)	/* YM3812 (chip 2) */
+	AM_RANGE(0xc001, 0xc001) AM_WRITE(YM3812_write_port_1_w)		/* YM3812 (chip 2) */
+ADDRESS_MAP_END
 
 /***************************************************************************
 
-	Input Ports
+    Input Ports
 
 ***************************************************************************/
 
@@ -135,7 +133,7 @@ INPUT_PORTS_START( battlnts )
 	PORT_DIPSETTING(	0xb0, DEF_STR( 1C_5C ) )
 	PORT_DIPSETTING(	0xa0, DEF_STR( 1C_6C ) )
 	PORT_DIPSETTING(	0x90, DEF_STR( 1C_7C ) )
-/*	PORT_DIPSETTING(	0x00, "Invalid" ) */
+/*  PORT_DIPSETTING(    0x00, "Invalid" ) */
 
 	PORT_START	/* DSW #2 */
 	PORT_DIPNAME( 0x03, 0x02, DEF_STR( Lives ) )
@@ -152,8 +150,8 @@ INPUT_PORTS_START( battlnts )
 	PORT_DIPSETTING(	0x08, "40k" )
 	PORT_DIPSETTING(	0x00, "50k" )
 	PORT_DIPNAME( 0x60, 0x40, DEF_STR( Difficulty ) )
-	PORT_DIPSETTING(	0x60, "Easy" )
-	PORT_DIPSETTING(	0x40, "Normal" )
+	PORT_DIPSETTING(	0x60, DEF_STR( Easy ) )
+	PORT_DIPSETTING(	0x40, DEF_STR( Normal ) )
 	PORT_DIPSETTING(	0x20, "Difficult" )
 	PORT_DIPSETTING(	0x00, "Very Difficult" )
 	PORT_DIPNAME( 0x80, 0x00, DEF_STR( Demo_Sounds ) )
@@ -163,23 +161,23 @@ INPUT_PORTS_START( battlnts )
 	PORT_START	/* COINSW */
 	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_COIN1 )
 	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_COIN2 )
-	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_COIN3 )
+	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_SERVICE1 )
 	PORT_BIT( 0x08, IP_ACTIVE_LOW, IPT_START1 )
 	PORT_BIT( 0x10, IP_ACTIVE_LOW, IPT_START2 )
 	PORT_DIPNAME( 0x20, 0x20, DEF_STR( Flip_Screen ) )
 	PORT_DIPSETTING(	0x20, DEF_STR( Off ) )
 	PORT_DIPSETTING(	0x00, DEF_STR( On ) )
 	PORT_DIPNAME( 0x40, 0x40, "Upright Controls" )
-	PORT_DIPSETTING(	0x40, "Single" )
-	PORT_DIPSETTING(	0x00, "Dual" )
+	PORT_DIPSETTING(	0x40, DEF_STR( Single ) )
+	PORT_DIPSETTING(	0x00, DEF_STR( Dual ) )
 	PORT_SERVICE( 0x80, IP_ACTIVE_LOW )
 
 	PORT_START	/* PLAYER 1 INPUTS */
-	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_JOYSTICK_LEFT  | IPF_8WAY | IPF_PLAYER1 )
-	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_JOYSTICK_RIGHT | IPF_8WAY | IPF_PLAYER1 )
-	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_JOYSTICK_UP	  | IPF_8WAY | IPF_PLAYER1 )
-	PORT_BIT( 0x08, IP_ACTIVE_LOW, IPT_JOYSTICK_DOWN  | IPF_8WAY | IPF_PLAYER1 )
-	PORT_BIT( 0x10, IP_ACTIVE_LOW, IPT_BUTTON1 | IPF_PLAYER1 )
+	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_JOYSTICK_LEFT ) PORT_8WAY PORT_PLAYER(1)
+	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_JOYSTICK_RIGHT ) PORT_8WAY PORT_PLAYER(1)
+	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_JOYSTICK_UP	 ) PORT_8WAY PORT_PLAYER(1)
+	PORT_BIT( 0x08, IP_ACTIVE_LOW, IPT_JOYSTICK_DOWN ) PORT_8WAY PORT_PLAYER(1)
+	PORT_BIT( 0x10, IP_ACTIVE_LOW, IPT_BUTTON1 ) PORT_PLAYER(1)
 	PORT_BIT( 0x20, IP_ACTIVE_LOW, IPT_UNKNOWN )
 	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_UNKNOWN )
 	PORT_DIPNAME( 0x80, 0x80, "Continue limit" )
@@ -187,11 +185,11 @@ INPUT_PORTS_START( battlnts )
 	PORT_DIPSETTING(	0x00, "5" )
 
 	PORT_START	/* PLAYER 2 INPUTS */
-	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_JOYSTICK_LEFT  | IPF_8WAY | IPF_PLAYER2 )
-	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_JOYSTICK_RIGHT | IPF_8WAY | IPF_PLAYER2 )
-	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_JOYSTICK_UP	  | IPF_8WAY | IPF_PLAYER2 )
-	PORT_BIT( 0x08, IP_ACTIVE_LOW, IPT_JOYSTICK_DOWN  | IPF_8WAY | IPF_PLAYER2 )
-	PORT_BIT( 0x10, IP_ACTIVE_LOW, IPT_BUTTON1 | IPF_PLAYER2 )
+	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_JOYSTICK_LEFT ) PORT_8WAY PORT_PLAYER(2)
+	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_JOYSTICK_RIGHT ) PORT_8WAY PORT_PLAYER(2)
+	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_JOYSTICK_UP	 ) PORT_8WAY PORT_PLAYER(2)
+	PORT_BIT( 0x08, IP_ACTIVE_LOW, IPT_JOYSTICK_DOWN ) PORT_8WAY PORT_PLAYER(2)
+	PORT_BIT( 0x10, IP_ACTIVE_LOW, IPT_BUTTON1 ) PORT_PLAYER(2)
 	PORT_BIT( 0x20, IP_ACTIVE_LOW, IPT_UNUSED )
 	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_UNUSED )
 	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_UNUSED )
@@ -232,7 +230,7 @@ INPUT_PORTS_START( thehustj )
 	PORT_DIPSETTING(	0xb0, DEF_STR( 1C_5C ) )
 	PORT_DIPSETTING(	0xa0, DEF_STR( 1C_6C ) )
 	PORT_DIPSETTING(	0x90, DEF_STR( 1C_7C ) )
-/*	PORT_DIPSETTING(	0x00, "Invalid" ) */
+/*  PORT_DIPSETTING(    0x00, "Invalid" ) */
 
 	PORT_START	/* DSW #2 */
 	PORT_DIPNAME( 0x03, 0x02, "Balls" )
@@ -250,8 +248,8 @@ INPUT_PORTS_START( thehustj )
 	PORT_DIPSETTING(	0x10, DEF_STR( Off ) )
 	PORT_DIPSETTING(	0x00, DEF_STR( On ) )
 	PORT_DIPNAME( 0x60, 0x40, DEF_STR( Difficulty ) )
-	PORT_DIPSETTING(	0x60, "Easy" )
-	PORT_DIPSETTING(	0x40, "Normal" )
+	PORT_DIPSETTING(	0x60, DEF_STR( Easy ) )
+	PORT_DIPSETTING(	0x40, DEF_STR( Normal ) )
 	PORT_DIPSETTING(	0x20, "Difficult" )
 	PORT_DIPSETTING(	0x00, "Very Difficult" )
 	PORT_DIPNAME( 0x80, 0x00, DEF_STR( Demo_Sounds ) )
@@ -261,7 +259,7 @@ INPUT_PORTS_START( thehustj )
 	PORT_START	/* COINSW */
 	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_COIN1 )
 	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_COIN2 )
-	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_COIN3 )
+	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_SERVICE1 )
 	PORT_BIT( 0x08, IP_ACTIVE_LOW, IPT_START1 )
 	PORT_BIT( 0x10, IP_ACTIVE_LOW, IPT_START2 )
 	PORT_DIPNAME( 0x20, 0x20, DEF_STR( Flip_Screen ) )
@@ -273,30 +271,30 @@ INPUT_PORTS_START( thehustj )
 	PORT_SERVICE( 0x80, IP_ACTIVE_LOW )
 
 	PORT_START	/* PLAYER 1 INPUTS */
-	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_JOYSTICK_LEFT  | IPF_8WAY | IPF_PLAYER1 )
-	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_JOYSTICK_RIGHT | IPF_8WAY | IPF_PLAYER1 )
-	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_JOYSTICK_UP	  | IPF_8WAY | IPF_PLAYER1 )
-	PORT_BIT( 0x08, IP_ACTIVE_LOW, IPT_JOYSTICK_DOWN  | IPF_8WAY | IPF_PLAYER1 )
-	PORT_BIT( 0x10, IP_ACTIVE_LOW, IPT_BUTTON1 | IPF_PLAYER1 )
-	PORT_BIT( 0x20, IP_ACTIVE_LOW, IPT_BUTTON2 | IPF_PLAYER1 )
+	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_JOYSTICK_LEFT ) PORT_8WAY PORT_PLAYER(1)
+	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_JOYSTICK_RIGHT ) PORT_8WAY PORT_PLAYER(1)
+	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_JOYSTICK_UP	 ) PORT_8WAY PORT_PLAYER(1)
+	PORT_BIT( 0x08, IP_ACTIVE_LOW, IPT_JOYSTICK_DOWN ) PORT_8WAY PORT_PLAYER(1)
+	PORT_BIT( 0x10, IP_ACTIVE_LOW, IPT_BUTTON1 ) PORT_PLAYER(1)
+	PORT_BIT( 0x20, IP_ACTIVE_LOW, IPT_BUTTON2 ) PORT_PLAYER(1)
 	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_UNKNOWN )
 	PORT_DIPNAME( 0x80, 0x80, DEF_STR( Unknown ) )
 	PORT_DIPSETTING(	0x80, DEF_STR( Off ) )
 	PORT_DIPSETTING(	0x00, DEF_STR( On ) )
 
 	PORT_START	/* PLAYER 2 INPUTS */
-	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_JOYSTICK_LEFT  | IPF_8WAY | IPF_PLAYER2 )
-	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_JOYSTICK_RIGHT | IPF_8WAY | IPF_PLAYER2 )
-	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_JOYSTICK_UP	  | IPF_8WAY | IPF_PLAYER2 )
-	PORT_BIT( 0x08, IP_ACTIVE_LOW, IPT_JOYSTICK_DOWN  | IPF_8WAY | IPF_PLAYER2 )
-	PORT_BIT( 0x10, IP_ACTIVE_LOW, IPT_BUTTON1 | IPF_PLAYER2 )
-	PORT_BIT( 0x20, IP_ACTIVE_LOW, IPT_BUTTON2 | IPF_PLAYER2 )
+	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_JOYSTICK_LEFT ) PORT_8WAY PORT_PLAYER(2)
+	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_JOYSTICK_RIGHT ) PORT_8WAY PORT_PLAYER(2)
+	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_JOYSTICK_UP	 ) PORT_8WAY PORT_PLAYER(2)
+	PORT_BIT( 0x08, IP_ACTIVE_LOW, IPT_JOYSTICK_DOWN ) PORT_8WAY PORT_PLAYER(2)
+	PORT_BIT( 0x10, IP_ACTIVE_LOW, IPT_BUTTON1 ) PORT_PLAYER(2)
+	PORT_BIT( 0x20, IP_ACTIVE_LOW, IPT_BUTTON2 ) PORT_PLAYER(2)
 	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_UNUSED )
 	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_UNUSED )
 INPUT_PORTS_END
 
 
-static struct GfxLayout charlayout =
+static const gfx_layout charlayout =
 {
 	8,8,			/* 8 x 8 characters */
 	0x40000/32, 	/* 8192 characters */
@@ -307,7 +305,7 @@ static struct GfxLayout charlayout =
 	32*8			/* every character takes 32 consecutive bytes */
 };
 
-static struct GfxLayout spritelayout =
+static const gfx_layout spritelayout =
 {
 	8,8,			/* 8*8 sprites */
 	0x40000/32, /* 8192 sprites */
@@ -319,7 +317,7 @@ static struct GfxLayout spritelayout =
 };
 
 
-static struct GfxDecodeInfo gfxdecodeinfo[] =
+static const gfx_decode gfxdecodeinfo[] =
 {
 	{ REGION_GFX1, 0, &charlayout,		0, 1 }, /* colors  0-15 */
 	{ REGION_GFX2, 0, &spritelayout, 4*16, 1 }, /* colors 64-79 */
@@ -328,60 +326,43 @@ static struct GfxDecodeInfo gfxdecodeinfo[] =
 
 /***************************************************************************
 
-	Machine Driver
+    Machine Driver
 
 ***************************************************************************/
 
-static struct YM3812interface ym3812_interface =
-{
-	2,				/* 2 chips */
-	3000000,		/* ? */
-	{ 50, 50 },
-	{ 0, 0 },
-};
+static MACHINE_DRIVER_START( battlnts )
 
-static const struct MachineDriver machine_driver_battlnts =
-{
 	/* basic machine hardware */
-	{
-		{
-			CPU_HD6309,
-			3000000,		/* ? */
-			battlnts_readmem,battlnts_writemem,0,0,
-			battlnts_interrupt,1
-		},
-		{
-			CPU_Z80 | CPU_AUDIO_CPU,
-			3579545,		/* ? */
-			battlnts_readmem_sound, battlnts_writemem_sound,0,0,
-			ignore_interrupt,0	/* interrupts are triggered by the main CPU */
-		}
-	},
-	60, DEFAULT_60HZ_VBLANK_DURATION,	/* frames per second, vblank duration */
-	1,	/* 1 CPU slice per frame - interleaving is forced when a sound command is written */
-	0,
+	MDRV_CPU_ADD(HD6309, 3000000)		/* ? */
+	MDRV_CPU_PROGRAM_MAP(battlnts_readmem,battlnts_writemem)
+	MDRV_CPU_VBLANK_INT(battlnts_interrupt,1)
+
+	MDRV_CPU_ADD(Z80, 3579545)
+	/* audio CPU */		/* ? */
+	MDRV_CPU_PROGRAM_MAP(battlnts_readmem_sound,battlnts_writemem_sound)
+
+	MDRV_FRAMES_PER_SECOND(60)
+	MDRV_VBLANK_DURATION(DEFAULT_60HZ_VBLANK_DURATION)
 
 	/* video hardware */
-	32*8, 32*8, { 0*8, 32*8-1, 2*8, 30*8-1 },
-	gfxdecodeinfo,
-	128, 0,
-	0,
+	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER)
+	MDRV_SCREEN_SIZE(32*8, 32*8)
+	MDRV_VISIBLE_AREA(0*8, 32*8-1, 2*8, 30*8-1)
+	MDRV_GFXDECODE(gfxdecodeinfo)
+	MDRV_PALETTE_LENGTH(128)
 
-	VIDEO_TYPE_RASTER,
-	0,
-	battlnts_vh_start,
-	battlnts_vh_stop,
-	battlnts_vh_screenrefresh,
+	MDRV_VIDEO_START(battlnts)
+	MDRV_VIDEO_UPDATE(battlnts)
 
 	/* sound hardware */
-	0,0,0,0,
-	{
-		{
-			SOUND_YM3812,
-			&ym3812_interface
-		}
-	}
-};
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+
+	MDRV_SOUND_ADD(YM3812, 3000000)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.0)
+
+	MDRV_SOUND_ADD(YM3812, 3000000)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 1.0)
+MACHINE_DRIVER_END
 
 
 /***************************************************************************
@@ -392,84 +373,84 @@ static const struct MachineDriver machine_driver_battlnts =
 
 ROM_START( battlnts )
 	ROM_REGION( 0x20000, REGION_CPU1, 0 ) /* code + banked roms */
-	ROM_LOAD( "g02.7e",      0x08000, 0x08000, 0xdbd8e17e ) /* fixed ROM */
-	ROM_LOAD( "g03.8e",      0x10000, 0x10000, 0x7bd44fef ) /* banked ROM */
+	ROM_LOAD( "g02.7e",      0x08000, 0x08000, CRC(dbd8e17e) SHA1(586a22b714011c67a915c4a350ceca19ff875635) ) /* fixed ROM */
+	ROM_LOAD( "g03.8e",      0x10000, 0x10000, CRC(7bd44fef) SHA1(308ec5246f5537b34e368535672ac687f456750a) ) /* banked ROM */
 
 	ROM_REGION( 0x10000, REGION_CPU2, 0 ) /* 64k for the sound CPU */
-	ROM_LOAD( "777c01.bin",  0x00000, 0x08000, 0xc21206e9 )
+	ROM_LOAD( "777c01.bin",  0x00000, 0x08000, CRC(c21206e9) SHA1(7b133e04be67dc061a186ab0481d848b69b370d7) )
 
 	ROM_REGION( 0x40000, REGION_GFX1, ROMREGION_DISPOSE )
-	ROM_LOAD( "777c04.bin",  0x00000, 0x40000, 0x45d92347 ) /* tiles */
+	ROM_LOAD( "777c04.bin",  0x00000, 0x40000, CRC(45d92347) SHA1(8537b4ccd0a80ea3260ef82fde177f1d65a49c03) ) /* tiles */
 
 	ROM_REGION( 0x40000, REGION_GFX2, ROMREGION_DISPOSE )
-	ROM_LOAD( "777c05.bin",  0x00000, 0x40000, 0xaeee778c ) /* sprites */
+	ROM_LOAD( "777c05.bin",  0x00000, 0x40000, CRC(aeee778c) SHA1(fc58ada9c97361d13439b7b0918c947d48402445) ) /* sprites */
 ROM_END
 
 ROM_START( battlntj )
 	ROM_REGION( 0x20000, REGION_CPU1, 0 ) /* code + banked roms */
-	ROM_LOAD( "777e02.bin",  0x08000, 0x08000, 0xd631cfcb ) /* fixed ROM */
-	ROM_LOAD( "777e03.bin",  0x10000, 0x10000, 0x5ef1f4ef ) /* banked ROM */
+	ROM_LOAD( "777e02.bin",  0x08000, 0x08000, CRC(d631cfcb) SHA1(7787da0dd8cd218abc27204e517e04d7a1913a3b) ) /* fixed ROM */
+	ROM_LOAD( "777e03.bin",  0x10000, 0x10000, CRC(5ef1f4ef) SHA1(e3e6e1fc5a65328d94c23e2e76eef3504b70e58b) ) /* banked ROM */
 
 	ROM_REGION( 0x10000, REGION_CPU2, 0 ) /* 64k for the sound CPU */
-	ROM_LOAD( "777c01.bin",  0x00000, 0x08000, 0xc21206e9 )
+	ROM_LOAD( "777c01.bin",  0x00000, 0x08000, CRC(c21206e9) SHA1(7b133e04be67dc061a186ab0481d848b69b370d7) )
 
 	ROM_REGION( 0x40000, REGION_GFX1, ROMREGION_DISPOSE )
-	ROM_LOAD( "777c04.bin",  0x00000, 0x40000, 0x45d92347 ) /* tiles */
+	ROM_LOAD( "777c04.bin",  0x00000, 0x40000, CRC(45d92347) SHA1(8537b4ccd0a80ea3260ef82fde177f1d65a49c03) ) /* tiles */
 
 	ROM_REGION( 0x40000, REGION_GFX2, ROMREGION_DISPOSE )
-	ROM_LOAD( "777c05.bin",  0x00000, 0x40000, 0xaeee778c ) /* sprites */
+	ROM_LOAD( "777c05.bin",  0x00000, 0x40000, CRC(aeee778c) SHA1(fc58ada9c97361d13439b7b0918c947d48402445) ) /* sprites */
 ROM_END
 
 ROM_START( thehustl )
 	ROM_REGION( 0x20000, REGION_CPU1, 0 ) /* code + banked roms */
-	ROM_LOAD( "765-m02.7e",  0x08000, 0x08000, 0x934807b9 ) /* fixed ROM */
-	ROM_LOAD( "765-j03.8e",  0x10000, 0x10000, 0xa13fd751 ) /* banked ROM */
+	ROM_LOAD( "765-m02.7e",  0x08000, 0x08000, CRC(934807b9) SHA1(84e13a5c1587ee28330f369f9a1180219edbda9d) ) /* fixed ROM */
+	ROM_LOAD( "765-j03.8e",  0x10000, 0x10000, CRC(a13fd751) SHA1(27ec66835c85b7ac0221a813d38e9cca0d9be3b8) ) /* banked ROM */
 
 	ROM_REGION( 0x10000, REGION_CPU2, 0 ) /* 64k for the sound CPU */
-	ROM_LOAD( "765-j01.10a", 0x00000, 0x08000, 0x77ae753e )
+	ROM_LOAD( "765-j01.10a", 0x00000, 0x08000, CRC(77ae753e) SHA1(9e463a825d31bb79644b083d24b25670d96441c5) )
 
 	ROM_REGION( 0x40000, REGION_GFX1, ROMREGION_DISPOSE )
-	ROM_LOAD( "765-e04.13a", 0x00000, 0x40000, 0x08c2b72e ) /* tiles */
+	ROM_LOAD( "765-e04.13a", 0x00000, 0x40000, CRC(08c2b72e) SHA1(02d9c690da839d6fee75fffdf66a4d3da35a0263) ) /* tiles */
 
 	ROM_REGION( 0x40000, REGION_GFX2, ROMREGION_DISPOSE )
-	ROM_LOAD( "765-e05.13e", 0x00000, 0x40000, 0xef044655 ) /* sprites */
+	ROM_LOAD( "765-e05.13e", 0x00000, 0x40000, CRC(ef044655) SHA1(c8272283eab8fc2899979da398819cb72c92a299) ) /* sprites */
 ROM_END
 
 ROM_START( thehustj )
 	ROM_REGION( 0x20000, REGION_CPU1, 0 ) /* code + banked roms */
-	ROM_LOAD( "765-j02.7e",  0x08000, 0x08000, 0x2ac14c75 ) /* fixed ROM */
-	ROM_LOAD( "765-j03.8e",  0x10000, 0x10000, 0xa13fd751 ) /* banked ROM */
+	ROM_LOAD( "765-j02.7e",  0x08000, 0x08000, CRC(2ac14c75) SHA1(b88f6279ab88719f4207e28486a0022554668382) ) /* fixed ROM */
+	ROM_LOAD( "765-j03.8e",  0x10000, 0x10000, CRC(a13fd751) SHA1(27ec66835c85b7ac0221a813d38e9cca0d9be3b8) ) /* banked ROM */
 
 	ROM_REGION( 0x10000, REGION_CPU2, 0 ) /* 64k for the sound CPU */
-	ROM_LOAD( "765-j01.10a", 0x00000, 0x08000, 0x77ae753e )
+	ROM_LOAD( "765-j01.10a", 0x00000, 0x08000, CRC(77ae753e) SHA1(9e463a825d31bb79644b083d24b25670d96441c5) )
 
 	ROM_REGION( 0x40000, REGION_GFX1, ROMREGION_DISPOSE )
-	ROM_LOAD( "765-e04.13a", 0x00000, 0x40000, 0x08c2b72e ) /* tiles */
+	ROM_LOAD( "765-e04.13a", 0x00000, 0x40000, CRC(08c2b72e) SHA1(02d9c690da839d6fee75fffdf66a4d3da35a0263) ) /* tiles */
 
 	ROM_REGION( 0x40000, REGION_GFX2, ROMREGION_DISPOSE )
-	ROM_LOAD( "765-e05.13e", 0x00000, 0x40000, 0xef044655 ) /* sprites */
+	ROM_LOAD( "765-e05.13e", 0x00000, 0x40000, CRC(ef044655) SHA1(c8272283eab8fc2899979da398819cb72c92a299) ) /* sprites */
 ROM_END
 
 ROM_START( rackemup )
 	ROM_REGION( 0x20000, REGION_CPU1, 0 ) /* code + banked roms */
-	ROM_LOAD( "765l02",      0x08000, 0x08000, 0x3dfc48bd ) /* fixed ROM */
-	ROM_LOAD( "765-j03.8e",  0x10000, 0x10000, 0xa13fd751 ) /* banked ROM */
+	ROM_LOAD( "765l02",      0x08000, 0x08000, CRC(3dfc48bd) SHA1(9ba98e9f27dd0a6efec145bea2a5ae7df8567437) ) /* fixed ROM */
+	ROM_LOAD( "765-j03.8e",  0x10000, 0x10000, CRC(a13fd751) SHA1(27ec66835c85b7ac0221a813d38e9cca0d9be3b8) ) /* banked ROM */
 
 	ROM_REGION( 0x10000, REGION_CPU2, 0 ) /* 64k for the sound CPU */
-	ROM_LOAD( "765-j01.10a", 0x00000, 0x08000, 0x77ae753e )
+	ROM_LOAD( "765-j01.10a", 0x00000, 0x08000, CRC(77ae753e) SHA1(9e463a825d31bb79644b083d24b25670d96441c5) )
 
 	ROM_REGION( 0x40000, REGION_GFX1, ROMREGION_DISPOSE )
-	ROM_LOAD( "765l04",      0x00000, 0x40000, 0xacfbeee2 ) /* tiles */
+	ROM_LOAD( "765l04",      0x00000, 0x40000, CRC(acfbeee2) SHA1(c2bf750892ba33d4610fa4497170f49c101ed4c1) ) /* tiles */
 
 	ROM_REGION( 0x40000, REGION_GFX2, ROMREGION_DISPOSE )
-	ROM_LOAD( "765l05",      0x00000, 0x40000, 0x1bb6855f ) /* sprites */
+	ROM_LOAD( "765l05",      0x00000, 0x40000, CRC(1bb6855f) SHA1(251081564dfede8fa9a422081d58465fe5ca4ed1) ) /* sprites */
 ROM_END
 
 
 /*
-	This recursive function doesn't use additional memory
-	(it could be easily converted into an iterative one).
-	It's called shuffle because it mimics the shuffling of a deck of cards.
+    This recursive function doesn't use additional memory
+    (it could be easily converted into an iterative one).
+    It's called shuffle because it mimics the shuffling of a deck of cards.
 */
 static void shuffle(UINT8 *buf,int len)
 {
@@ -494,7 +475,7 @@ static void shuffle(UINT8 *buf,int len)
 }
 
 
-static void init_rackemup(void)
+static DRIVER_INIT( rackemup )
 {
 	/* rearrange char ROM */
 	shuffle(memory_region(REGION_GFX1),memory_region_length(REGION_GFX1));
@@ -502,9 +483,9 @@ static void init_rackemup(void)
 
 
 
-GAME( 1987, battlnts, 0,		battlnts, battlnts, 0,		  ROT90, "Konami", "Battlantis" )
-GAME( 1987, battlntj, battlnts, battlnts, battlnts, 0,		  ROT90, "Konami", "Battlantis (Japan)" )
-GAME( 1987, thehustl, 0,		battlnts, thehustj, 0,		  ROT90, "Konami", "The Hustler (Japan version M)" )
-GAME( 1987, thehustj, thehustl, battlnts, thehustj, 0,		  ROT90, "Konami", "The Hustler (Japan version J)" )
-GAME( 1987, rackemup, thehustl, battlnts, thehustj, rackemup, ROT90, "Konami", "Rack 'em Up" )
+GAME( 1987, battlnts, 0,		battlnts, battlnts, 0,		  ROT90, "Konami", "Battlantis", 0 )
+GAME( 1987, battlntj, battlnts, battlnts, battlnts, 0,		  ROT90, "Konami", "Battlantis (Japan)", 0 )
+GAME( 1987, thehustl, 0,		battlnts, thehustj, 0,		  ROT90, "Konami", "The Hustler (Japan version M)", GAME_NO_COCKTAIL )
+GAME( 1987, thehustj, thehustl, battlnts, thehustj, 0,		  ROT90, "Konami", "The Hustler (Japan version J)", GAME_NO_COCKTAIL )
+GAME( 1987, rackemup, thehustl, battlnts, thehustj, rackemup, ROT90, "Konami", "Rack 'em Up", GAME_NO_COCKTAIL )
 
