@@ -747,7 +747,7 @@ INPUT_PORTS_END
 
 /**********************************************************************************/
 
-static gfx_layout charlayout =
+static const gfx_layout charlayout =
 {
 	8,8,
 	RGN_FRAC(1,2),
@@ -758,7 +758,7 @@ static gfx_layout charlayout =
 	16*8	/* every char takes 8 consecutive bytes */
 };
 
-static gfx_layout spritelayout =
+static const gfx_layout spritelayout =
 {
 	16,16,
 	RGN_FRAC(1,1),
@@ -771,7 +771,7 @@ static gfx_layout spritelayout =
 	128*8
 };
 
-static gfx_layout tilelayout =
+static const gfx_layout tilelayout =
 {
 	16,16,
 	RGN_FRAC(1,2),
@@ -784,7 +784,7 @@ static gfx_layout tilelayout =
 	64*8
 };
 
-static gfx_layout tilelayout_8bpp =
+static const gfx_layout tilelayout_8bpp =
 {
 	16,16,
 	4096,
@@ -797,7 +797,7 @@ static gfx_layout tilelayout_8bpp =
 	64*8
 };
 
-static gfx_decode gfxdecodeinfo[] =
+static const gfx_decode gfxdecodeinfo[] =
 {
 	{ REGION_GFX1, 0, &charlayout,    0, 32 },	/* Characters 8x8 */
 	{ REGION_GFX2, 0, &tilelayout,    0, 32 },	/* Tiles 16x16 */
@@ -806,7 +806,7 @@ static gfx_decode gfxdecodeinfo[] =
 	{ -1 } /* end of array */
 };
 
-static gfx_decode gfxdecodeinfo_robocop2[] =
+static const gfx_decode gfxdecodeinfo_robocop2[] =
 {
 	{ REGION_GFX1, 0, &charlayout,    0, 32 },	/* Characters 8x8 */
 	{ REGION_GFX2, 0, &tilelayout,    0, 32 },	/* Tiles 16x16 */
@@ -816,7 +816,7 @@ static gfx_decode gfxdecodeinfo_robocop2[] =
 	{ -1 } /* end of array */
 };
 
-static gfx_decode gfxdecodeinfo_mutantf[] =
+static const gfx_decode gfxdecodeinfo_mutantf[] =
 {
 	{ REGION_GFX1, 0, &charlayout,          0, 64 },	/* Characters 8x8 */
 	{ REGION_GFX2, 0, &tilelayout,          0, 64 },	/* Tiles 16x16 */
