@@ -240,7 +240,7 @@ INPUT_PORTS_START( flkatck )
 	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_UNUSED )
 INPUT_PORTS_END
 
-static gfx_layout gfxlayout =
+static const gfx_layout gfxlayout =
 {
 	8,8,
 	0x80000/32,
@@ -251,7 +251,7 @@ static gfx_layout gfxlayout =
 	32*8
 };
 
-static gfx_decode gfxdecodeinfo[] =
+static const gfx_decode gfxdecodeinfo[] =
 {
 	{ REGION_GFX1, 0, &gfxlayout, 0, 32 },
 	{ -1 } /* end of array */
@@ -345,6 +345,6 @@ ROM_END
 
 
 
-GAME( 1987, mx5000,  0, 	 flkatck, flkatck, 0, ROT90, "Konami", "MX5000" )
-GAME( 1987, flkatck, mx5000, flkatck, flkatck, 0, ROT90, "Konami", "Flak Attack (Japan)" )
+GAME( 1987, mx5000,  0, 	 flkatck, flkatck, 0, ROT90, "Konami", "MX5000", 0 )
+GAME( 1987, flkatck, mx5000, flkatck, flkatck, 0, ROT90, "Konami", "Flak Attack (Japan)", 0 )
 
