@@ -151,8 +151,115 @@ Any fixes for this driver should be forwarded to the AGEMAME forum at (http://ww
     -------------------------------------------------
 
 
-    Royal Card
-    ----------
+    Royal Card (set 1)
+    ------------------
+
+    - 1x HM6264LP
+    - 1x HD4650SP
+    - 1x HM6116LP
+    - 1x R65C02P2 (main)
+    - 1x WB5300 (labeled YM8910)(sound)
+    - 1x EF6821P
+    - 1x oscillator 16.000 MHz
+
+    - 1x D27256 (1)
+    - 1x S27C256 (2)
+    - 1x TMS27C256 (r2)
+    - 2x PEEL18CV8 (1 protected)
+    - 1x PALCE16V8H (protected)
+    - 1x PROM N82S147AN
+
+    - 1x 8 switches dip
+    - 1x 22x2 edge connector
+    - 1x 18x2 edge connector
+    - 1x trimmer (volume)
+
+    PEEL18CV8 fuse map:
+
+    Device    PEEL18CV8
+    *
+    QF2696*
+    F0*
+    L000000 111011111111111111111111110111111111*
+    L000036 110111110111111111111111111111111111*
+    L000072 000000000000000000000000000000000000*
+    L000108 000000000000000000000000000000000000*
+    L000144 000000000000000000000000000000000000*
+    L000180 000000000000000000000000000000000000*
+    L000216 000000000000000000000000000000000000*
+    L000252 000000000000000000000000000000000000*
+    L000288 111011111111110111111111111111111111*
+    L000324 110111111111111111110111111111111111*
+    L000360 000000000000000000000000000000000000*
+    L000396 000000000000000000000000000000000000*
+    L000432 000000000000000000000000000000000000*
+    L000468 000000000000000000000000000000000000*
+    L000504 000000000000000000000000000000000000*
+    L000540 000000000000000000000000000000000000*
+    L000576 111011111111111111011111111111111111*
+    L000612 110111111111111111111111111101111111*
+    L000648 000000000000000000000000000000000000*
+    L000684 000000000000000000000000000000000000*
+    L000720 000000000000000000000000000000000000*
+    L000756 000000000000000000000000000000000000*
+    L000792 000000000000000000000000000000000000*
+    L000828 000000000000000000000000000000000000*
+    L000864 111011111111111111111101111111111111*
+    L000900 110111111111011111111111111111111111*
+    L000936 000000000000000000000000000000000000*
+    L000972 000000000000000000000000000000000000*
+    L001008 000000000000000000000000000000000000*
+    L001044 000000000000000000000000000000000000*
+    L001080 000000000000000000000000000000000000*
+    L001116 000000000000000000000000000000000000*
+    L001152 111011111111111111111111111111111111*
+    L001188 111101111111111111111111111111111111*
+    L001224 000000000000000000000000000000000000*
+    L001260 000000000000000000000000000000000000*
+    L001296 000000000000000000000000000000000000*
+    L001332 000000000000000000000000000000000000*
+    L001368 000000000000000000000000000000000000*
+    L001404 000000000000000000000000000000000000*
+    L001440 111011111111111111111111111111011111*
+    L001476 110111111111111101111111111111111111*
+    L001512 000000000000000000000000000000000000*
+    L001548 000000000000000000000000000000000000*
+    L001584 000000000000000000000000000000000000*
+    L001620 000000000000000000000000000000000000*
+    L001656 000000000000000000000000000000000000*
+    L001692 000000000000000000000000000000000000*
+    L001728 111011111111111111111111111111111101*
+    L001764 110111111111111111111111011111111111*
+    L001800 000000000000000000000000000000000000*
+    L001836 000000000000000000000000000000000000*
+    L001872 000000000000000000000000000000000000*
+    L001908 000000000000000000000000000000000000*
+    L001944 000000000000000000000000000000000000*
+    L001980 000000000000000000000000000000000000*
+    L002016 111011111111111111111111111111111111*
+    L002052 111111111111111111111111111111110111*
+    L002088 000000000000000000000000000000000000*
+    L002124 000000000000000000000000000000000000*
+    L002160 000000000000000000000000000000000000*
+    L002196 000000000000000000000000000000000000*
+    L002232 000000000000000000000000000000000000*
+    L002268 000000000000000000000000000000000000*
+    L002304 111111111111111111111111111111111111*
+    L002340 111111111111111111111111111111111111*
+    L002376 000000000000000000000000000000000000*
+    L002412 000000000000000000000000000000000000*
+    L002448 000000000000000000000000000000000000*
+    L002484 000000000000000000000000000000000000*
+    L002520 000000000000000000000000000000000000*
+    L002556 000000000000000000000000000000000000*
+    L002592 000000000000000000000000000000000000*
+    L002628 000000000000000000000000000000000000*
+    L002664 01000100010001000100010001000100*
+    C4E67*
+
+
+    Royal Card (set 2)
+    ------------------
 
     - CPU 1x R65C02P2 (main)
     - 1x MC68B45P (CRT controller)
@@ -445,7 +552,7 @@ INPUT_PORTS_END
 
 /* Graphics Layouts */
 
-static gfx_layout charlayout =
+static const gfx_layout charlayout =
 {
 	4,
 	8,
@@ -457,7 +564,7 @@ static gfx_layout charlayout =
 	8*4*2
 };
 
-static gfx_layout magiccrd_charlayout =
+static const gfx_layout magiccrd_charlayout =
 {
     4,
 	8,
@@ -471,13 +578,13 @@ static gfx_layout magiccrd_charlayout =
 
 /* Graphics Decode Information */
 
-static gfx_decode gfxdecodeinfo[] =
+static const gfx_decode gfxdecodeinfo[] =
 {
 	{ REGION_GFX1, 0x0000, &charlayout, 0, 16 },
 	{ -1 }
 };
 
-static gfx_decode magiccrd_gfxdecodeinfo[] =
+static const gfx_decode magiccrd_gfxdecodeinfo[] =
 {
 	{ REGION_GFX1, 0x0000, &magiccrd_charlayout, 0, 16 },
 	{ -1 }
@@ -583,24 +690,61 @@ ROM_START( jollycrd )
 	ROM_LOAD( "jolycard.ch2", 0x8000, 0x8000, CRC(c512b103) SHA1(1f4e78e97855afaf0332fb75e1b5571aafd01c29) )
 ROM_END
 
-ROM_START( jollypkr )
+ROM_START( jollycdb )
 	ROM_REGION( 0x10000, REGION_CPU1, 0 )
 	ROM_LOAD( "jollypkr.003", 0x8000, 0x8000, CRC(ea7340b4) SHA1(7dd468f28a488a4781521809d06db1d7917048ad) )
 
 	ROM_REGION( 0x10000, REGION_GFX1, ROMREGION_DISPOSE )
-	ROM_LOAD( "jollypkr.001", 0x0000, 0x8000, CRC(0f24f39d) SHA1(ac1f6a8a4a2a37cbc0d45c15187b33c25371bffb) )
-	ROM_LOAD( "jollypkr.002", 0x8000, 0x8000, CRC(c512b103) SHA1(1f4e78e97855afaf0332fb75e1b5571aafd01c29) )
+	ROM_LOAD( "jolycard.ch1", 0x0000, 0x8000, CRC(0f24f39d) SHA1(ac1f6a8a4a2a37cbc0d45c15187b33c25371bffb) )
+	ROM_LOAD( "jolycard.ch2", 0x8000, 0x8000, CRC(c512b103) SHA1(1f4e78e97855afaf0332fb75e1b5571aafd01c29) )
 ROM_END
 
-ROM_START( bonuscrd )
+ROM_START( jollycdc )
+	ROM_REGION( 0x10000, REGION_CPU1, 0 )
+	ROM_LOAD( "jn.bin", 0x8000, 0x8000, CRC(6ae00ed0) SHA1(5921c2882aeb5eadd0e04a477fa505ad35e9d98c) )
+
+	ROM_REGION( 0x10000, REGION_GFX1, ROMREGION_DISPOSE )
+	ROM_LOAD( "1.bin", 0x0000, 0x8000, CRC(43bcb2df) SHA1(5022bc3a0b852a7cd433e25c3c90a720e6328261) )
+	ROM_LOAD( "2.bin", 0x8000, 0x8000, CRC(46805150) SHA1(63687ac44f6ace6d8924b2629536bcc7d3979ed2) )
+ROM_END
+
+ROM_START( jollycdd )
 	ROM_REGION( 0x10000, REGION_CPU1, 0 )
 	ROM_LOAD( "bonucard.cpu", 0x4000, 0x4000, CRC(da342100) SHA1(451fa6074aad19e9efd148c3d18115a20a3d344a) )
 	ROM_CONTINUE(			  0xc000, 0x4000 )
 	ROM_RELOAD( 			  0x8000, 0x4000 )
 
 	ROM_REGION( 0x10000, REGION_GFX1, ROMREGION_DISPOSE )
-	ROM_LOAD( "bonucard.gr2", 0x0000, 0x8000, CRC(0f24f39d) SHA1(ac1f6a8a4a2a37cbc0d45c15187b33c25371bffb) )
-	ROM_LOAD( "bonucard.gr3", 0x8000, 0x8000, CRC(c512b103) SHA1(1f4e78e97855afaf0332fb75e1b5571aafd01c29) )
+	ROM_LOAD( "jolycard.ch1", 0x0000, 0x8000, CRC(0f24f39d) SHA1(ac1f6a8a4a2a37cbc0d45c15187b33c25371bffb) )
+	ROM_LOAD( "jolycard.ch2", 0x8000, 0x8000, CRC(c512b103) SHA1(1f4e78e97855afaf0332fb75e1b5571aafd01c29) )
+ROM_END
+
+ROM_START( jollycde )
+	ROM_REGION( 0x10000, REGION_CPU1, 0 )
+	ROM_LOAD( "ig1poker.run", 0x8000, 0x8000, CRC(c96e6542) SHA1(ed6c0cf9fe8597dba9149b2225320d8d9c39219a) )
+	ROM_RELOAD(				  0x4000, 0x4000 )
+
+	ROM_REGION( 0x10000, REGION_GFX1, ROMREGION_DISPOSE )
+	ROM_LOAD( "jn1poker.ch1", 0x0000, 0x8000, CRC(d0a87f58) SHA1(6b7925557c4e40a1ebe52ecd14391cdd5e00b59a) )
+	ROM_LOAD( "jn1poker.ch2", 0x8000, 0x8000, CRC(8d78e43d) SHA1(15c60f8e0cd88518b0dc72b92aff6d8d4b2149cf) )
+ROM_END
+
+ROM_START( bigdeal )
+	ROM_REGION( 0x10000, REGION_CPU1, 0 )
+	ROM_LOAD( "poker4.001", 0x8000, 0x8000, CRC(bb0198c1) SHA1(6e7d42beb5723a4368ae3788f83b448f86e5653d) )
+
+	ROM_REGION( 0x10000, REGION_GFX1, ROMREGION_DISPOSE )
+	ROM_LOAD( "poker4.002", 0x0000, 0x8000, CRC(5f4e12d8) SHA1(014b2364879faaf4922cdb82ee07692389f20c2d) )
+	ROM_LOAD( "poker4.003", 0x8000, 0x8000, CRC(8c33a15f) SHA1(a1c8451c99a23eeffaedb21d1a1b69f54629f8ab) )
+ROM_END
+
+ROM_START( bigdealb )
+	ROM_REGION( 0x10000, REGION_CPU1, 0 )
+	ROM_LOAD( "poker8.003", 0x8000, 0x8000, CRC(09c93745) SHA1(a64e96ef3489bc37c2c642f49e62cfef371de6f1) )
+
+	ROM_REGION( 0x10000, REGION_GFX1, ROMREGION_DISPOSE )
+	ROM_LOAD( "poker4.002", 0x0000, 0x8000, CRC(5f4e12d8) SHA1(014b2364879faaf4922cdb82ee07692389f20c2d) )
+	ROM_LOAD( "poker4.003", 0x8000, 0x8000, CRC(8c33a15f) SHA1(a1c8451c99a23eeffaedb21d1a1b69f54629f8ab) )
 ROM_END
 
 ROM_START( cuoreuno )
@@ -622,43 +766,27 @@ ROM_START( elephfam )
 ROM_END
 
 ROM_START( royalcrd )
+	ROM_REGION( 0x10000, REGION_CPU1, 0 )
+	ROM_LOAD( "r2.bin", 0x8000, 0x8000, CRC(25dfe0dc) SHA1(1a857a910d0c34b6b5bfc2b6ea2e08ed8ed0cae0) )
+
+	ROM_REGION( 0x10000, REGION_GFX1, ROMREGION_DISPOSE )
+	ROM_LOAD( "1.bin", 0x0000, 0x8000, CRC(41f7a0b3) SHA1(9aff2b8832d2a4f868daa9849a0bfe5e44f88fc0) )
+	ROM_LOAD( "2.bin", 0x8000, 0x8000, CRC(85e77661) SHA1(7d7a765c1bfcfeb9eb91d2519b22d734f20eab24) )
+
+	ROM_REGION( 0x0200, REGION_PROMS, 0 )
+	ROM_LOAD( "n82s147.bin",    0x0000, 0x0200, CRC(8bc86f48) SHA1(4c677ab9314a1f571e35104b22659e6811aeb194) )
+ROM_END
+
+ROM_START( royalcdb )
 	ROM_REGION( 0x18000, REGION_CPU1, 0 )
 	ROM_LOAD( "rc.bin", 0x8000, 0x10000, CRC(8a9a6dd6) SHA1(04c3f9f17d5404ac1414c51ef8f930df54530e72) )
 
 	ROM_REGION( 0x20000, REGION_GFX1, ROMREGION_DISPOSE )
-	ROM_LOAD( "1.bin", 0x0000, 0x10000, CRC(8a66f22c) SHA1(67d6e8f8f5a0fd979dc498ba2cc67cf707ccdf95) )
-	ROM_LOAD( "2.bin", 0x10000, 0x10000, CRC(3af71cf8) SHA1(3a0ce0d0abebf386573c5936545dada1d3558e55) )
+	ROM_LOAD( "1a.bin", 0x0000, 0x10000, CRC(8a66f22c) SHA1(67d6e8f8f5a0fd979dc498ba2cc67cf707ccdf95) )
+	ROM_LOAD( "2a.bin", 0x10000, 0x10000, CRC(3af71cf8) SHA1(3a0ce0d0abebf386573c5936545dada1d3558e55) )
 
 	ROM_REGION( 0x0200, REGION_PROMS, 0 )
-	ROM_LOAD( "prom-am27s29apc.bin",    0x0000, 0x0200, CRC(8bc86f48) SHA1(4c677ab9314a1f571e35104b22659e6811aeb194) )
-ROM_END
-
-ROM_START( poker4 )
-	ROM_REGION( 0x10000, REGION_CPU1, 0 )
-	ROM_LOAD( "poker4.001", 0x8000, 0x8000, CRC(bb0198c1) SHA1(6e7d42beb5723a4368ae3788f83b448f86e5653d) )
-
-	ROM_REGION( 0x10000, REGION_GFX1, ROMREGION_DISPOSE )
-	ROM_LOAD( "poker4.002", 0x0000, 0x8000, CRC(5f4e12d8) SHA1(014b2364879faaf4922cdb82ee07692389f20c2d) )
-	ROM_LOAD( "poker4.003", 0x8000, 0x8000, CRC(8c33a15f) SHA1(a1c8451c99a23eeffaedb21d1a1b69f54629f8ab) )
-ROM_END
-
-ROM_START( poker8 )
-	ROM_REGION( 0x10000, REGION_CPU1, 0 )
-	ROM_LOAD( "poker8.003", 0x8000, 0x8000, CRC(09c93745) SHA1(a64e96ef3489bc37c2c642f49e62cfef371de6f1) )
-
-	ROM_REGION( 0x10000, REGION_GFX1, ROMREGION_DISPOSE )
-	ROM_LOAD( "poker8.001", 0x0000, 0x8000, CRC(5f4e12d8) SHA1(014b2364879faaf4922cdb82ee07692389f20c2d) )
-	ROM_LOAD( "poker8.002", 0x8000, 0x8000, CRC(8c33a15f) SHA1(a1c8451c99a23eeffaedb21d1a1b69f54629f8ab) )
-ROM_END
-
-ROM_START( igpoker )
-	ROM_REGION( 0x10000, REGION_CPU1, 0 )
-	ROM_LOAD( "ig1poker.run", 0x8000, 0x8000, CRC(c96e6542) SHA1(ed6c0cf9fe8597dba9149b2225320d8d9c39219a) )
-	ROM_RELOAD(				  0x4000, 0x4000 )
-
-	ROM_REGION( 0x10000, REGION_GFX1, ROMREGION_DISPOSE )
-	ROM_LOAD( "jn1poker.ch1", 0x0000, 0x8000, CRC(d0a87f58) SHA1(6b7925557c4e40a1ebe52ecd14391cdd5e00b59a) )
-	ROM_LOAD( "jn1poker.ch2", 0x8000, 0x8000, CRC(8d78e43d) SHA1(15c60f8e0cd88518b0dc72b92aff6d8d4b2149cf) )
+	ROM_LOAD( "n82s147.bin",    0x0000, 0x0200, CRC(8bc86f48) SHA1(4c677ab9314a1f571e35104b22659e6811aeb194) )
 ROM_END
 
 ROM_START( magiccrd )
@@ -682,13 +810,15 @@ static DRIVER_INIT( funworld )
 /* Game Drivers */
 
 /*    YEAR  NAME      PARENT    MACHINE   INPUT     INIT            COMPANY        FULLNAME */
-GAMEX( 1985, jollycrd, 0, 		funworld, funworld, funworld, ROT0, "TAB-Austria", "Jolly Card (Austria)", GAME_WRONG_COLORS )
-GAMEX( 1993, jollypkr, 0,		jollypkr, funworld, funworld, ROT0, "Soft Design", "Jolly Poker (Croatia)", GAME_WRONG_COLORS )
-GAMEX( 1986, bonuscrd, 0,		bonuscrd, funworld, funworld, ROT0, "Fun World",   "Bonus Card? (Austria)", GAME_WRONG_COLORS )
-GAMEX( 1997, cuoreuno, 0, 		funworld, funworld, funworld, ROT0, "bootleg?",    "Cuore Uno (Italia)", GAME_WRONG_COLORS )
-GAMEX( 1997, elephfam, 0, 		funworld, funworld, funworld, ROT0, "bootleg?",    "Elephant Family (Italia)", GAME_WRONG_COLORS )
-GAMEX( 1997, royalcrd, 0, 		funworld, funworld, funworld, ROT0, "TAB-Austria", "Royal Card (Austria)", GAME_WRONG_COLORS )
-GAMEX( 1986, poker4,   0,		bonuscrd, funworld, funworld, ROT0, "Fun World",   "Jolly Card (Hungary)", GAME_WRONG_COLORS )
-GAMEX( 1986, poker8,   0,		bonuscrd, funworld, funworld, ROT0, "Fun World",   "Jolly Card (bad dump?) (Hungary)", GAME_WRONG_COLORS )
-GAMEX( 1990, igpoker,  0, 		funworld, funworld, funworld, ROT0, "Inter Games", "Inter Game Poker?", GAME_NOT_WORKING )
-GAMEX( 1996, magiccrd, 0, 		magiccrd, magiccrd, funworld, ROT0, "Impera", 	   "Magic Card II (Bulgaria)", GAME_WRONG_COLORS )
+GAME( 1985, jollycrd, 0, 		funworld, funworld, funworld, ROT0, "TAB-Austria", "Jolly Card (Austria)", GAME_WRONG_COLORS )
+GAME( 1993, jollycdb, jollycrd,	jollypkr, funworld, funworld, ROT0, "Soft Design", "Jolly Card (Croatia)", GAME_WRONG_COLORS )
+GAME( 199?, jollycdc, jollycrd,	funworld, funworld, funworld, ROT0, "bootleg?",    "Jolly Card (Italia, bad dump?)", GAME_WRONG_COLORS | GAME_NOT_WORKING )
+GAME( 1986, jollycdd, jollycrd,	bonuscrd, funworld, funworld, ROT0, "Fun World",   "Jolly Card (Austria, Fun World)", GAME_WRONG_COLORS )
+GAME( 1990, jollycde, jollycrd, funworld, funworld, funworld, ROT0, "Inter Games", "Jolly Card (Austria, Fun World, bootleg)", GAME_WRONG_COLORS | GAME_NOT_WORKING )
+GAME( 1986, bigdeal,  0,		bonuscrd, funworld, funworld, ROT0, "Fun World",   "Big Deal (Hungary, set 1)", GAME_WRONG_COLORS )
+GAME( 1986, bigdealb, bigdeal,	bonuscrd, funworld, funworld, ROT0, "Fun World",   "Big Deal (Hungary, set 2)", GAME_WRONG_COLORS )
+GAME( 1997, cuoreuno, 0, 		funworld, funworld, funworld, ROT0, "bootleg?",    "Cuore Uno (Italia)", GAME_WRONG_COLORS | GAME_NOT_WORKING )
+GAME( 1997, elephfam, 0, 		funworld, funworld, funworld, ROT0, "bootleg?",    "Elephant Family (Italia)", GAME_WRONG_COLORS | GAME_NOT_WORKING )
+GAME( 1991, royalcrd, 0, 		funworld, funworld, funworld, ROT0, "TAB-Austria", "Royal Card (Austria, set 1)", GAME_WRONG_COLORS | GAME_NOT_WORKING )
+GAME( 1991, royalcdb, royalcrd, funworld, funworld, funworld, ROT0, "TAB-Austria", "Royal Card (Austria, set 2)", GAME_WRONG_COLORS | GAME_NOT_WORKING )
+GAME( 1996, magiccrd, 0, 		magiccrd, magiccrd, funworld, ROT0, "Impera", 	   "Magic Card II (Bulgaria)", GAME_WRONG_COLORS )
