@@ -21,7 +21,7 @@ extern UINT16 *gaelco_spriteram;
 WRITE16_HANDLER( gaelco_vram_w );
 
 
-#define TILELAYOUT8(NUM) static gfx_layout tilelayout8_##NUM =	\
+#define TILELAYOUT8(NUM) static const gfx_layout tilelayout8_##NUM =	\
 {																		\
 	8,8,									/* 8x8 tiles */				\
 	NUM/8,									/* number of tiles */		\
@@ -32,7 +32,7 @@ WRITE16_HANDLER( gaelco_vram_w );
 	8*8																	\
 }
 
-#define TILELAYOUT16(NUM) static gfx_layout tilelayout16_##NUM =				\
+#define TILELAYOUT16(NUM) static const gfx_layout tilelayout16_##NUM =				\
 {																					\
 	16,16,									/* 16x16 tiles */						\
 	NUM/32,									/* number of tiles */					\
@@ -43,7 +43,7 @@ WRITE16_HANDLER( gaelco_vram_w );
 	32*8																			\
 }
 
-#define GFXDECODEINFO(NUM,ENTRIES) static gfx_decode gfxdecodeinfo_##NUM[] =	\
+#define GFXDECODEINFO(NUM,ENTRIES) static const gfx_decode gfxdecodeinfo_##NUM[] =	\
 {																						\
 	{ REGION_GFX1, 0x000000, &tilelayout8_##NUM,0,	ENTRIES },							\
 	{ REGION_GFX1, 0x000000, &tilelayout16_##NUM,0,	ENTRIES },							\
@@ -623,8 +623,8 @@ ROM_START( thoop )
 	ROM_LOAD( "sound", 0x000000, 0x100000, CRC(99f80961) SHA1(de3a514a8f46dffd5f762e52aac1f4c3b08e2e18) )
 ROM_END
 
-GAME( 1991, bigkarnk, 0,        bigkarnk, bigkarnk, 0, ROT0, "Gaelco", "Big Karnak" )
-GAME( 1995, biomtoy,  0,        maniacsq, biomtoy,  0, ROT0, "Gaelco", "Biomechanical Toy (unprotected)" )
-GAME( 1996, maniacsp, maniacsq, maniacsq, maniacsq, 0, ROT0, "Gaelco", "Maniac Square (prototype)" )
-GAMEX(1992, squash,   0,		squash,   bigkarnk, 0, ROT0, "Gaelco", "Squash (Ver. 1.0)", GAME_NOT_WORKING | GAME_UNEMULATED_PROTECTION )
-GAMEX(1992, thoop,    0,		squash,   bigkarnk, 0, ROT0, "Gaelco", "Thunder Hoop",      GAME_NOT_WORKING | GAME_UNEMULATED_PROTECTION )
+GAME( 1991, bigkarnk, 0,        bigkarnk, bigkarnk, 0, ROT0, "Gaelco", "Big Karnak", 0 )
+GAME( 1995, biomtoy,  0,        maniacsq, biomtoy,  0, ROT0, "Gaelco", "Biomechanical Toy (unprotected)", 0 )
+GAME( 1996, maniacsp, maniacsq, maniacsq, maniacsq, 0, ROT0, "Gaelco", "Maniac Square (prototype)", 0 )
+GAME( 1992, squash,   0,		squash,   bigkarnk, 0, ROT0, "Gaelco", "Squash (Ver. 1.0)", GAME_NOT_WORKING | GAME_UNEMULATED_PROTECTION )
+GAME( 1992, thoop,    0,		squash,   bigkarnk, 0, ROT0, "Gaelco", "Thunder Hoop",      GAME_NOT_WORKING | GAME_UNEMULATED_PROTECTION )
