@@ -88,6 +88,7 @@ static UINT16 coin_word, frame_counter=0;
 static UINT16 port_sel = 0;
 extern UINT16 groundfx_rotate_ctrl[8];
 static UINT32 *groundfx_ram;
+static UINT16 *sound_ram;
 
 /***********************************************************
                 COLOR RAM
@@ -307,7 +308,7 @@ ADDRESS_MAP_END
 /******************************************************************************/
 
 static ADDRESS_MAP_START( sound_readmem, ADDRESS_SPACE_PROGRAM, 16 )
-	AM_RANGE(0x000000, 0x07ffff) AM_READ(MRA16_RAM)
+	AM_RANGE(0x000000, 0x07ffff) AM_READ(MRA16_RAM) AM_BASE(&sound_ram)
 	AM_RANGE(0x140000, 0x140fff) AM_READ(f3_68000_share_r)
 	AM_RANGE(0x200000, 0x20001f) AM_READ(ES5505_data_0_r)
 	AM_RANGE(0x260000, 0x2601ff) AM_READ(es5510_dsp_r)
@@ -382,7 +383,7 @@ INPUT_PORTS_END
                 GFX DECODING
 **********************************************************/
 
-static gfx_layout tile16x16_layout =
+static const gfx_layout tile16x16_layout =
 {
 	16,16,	/* 16*16 sprites */
 	RGN_FRAC(1,2),
@@ -394,7 +395,7 @@ static gfx_layout tile16x16_layout =
 	64*16	/* every sprite takes 128 consecutive bytes */
 };
 
-static gfx_layout charlayout =
+static const gfx_layout charlayout =
 {
 	16,16,    /* 16*16 characters */
 	RGN_FRAC(1,1),
@@ -405,7 +406,7 @@ static gfx_layout charlayout =
 	128*8     /* every sprite takes 128 consecutive bytes */
 };
 
-static gfx_layout pivlayout =
+static const gfx_layout pivlayout =
 {
 	8,8,    /* 8*8 characters */
 	RGN_FRAC(1,2),
@@ -416,7 +417,7 @@ static gfx_layout pivlayout =
 	32*8    /* every sprite takes 32 consecutive bytes */
 };
 
-static gfx_decode groundfx_gfxdecodeinfo[] =
+static const gfx_decode groundfx_gfxdecodeinfo[] =
 {
 	{ REGION_GFX2, 0x0, &tile16x16_layout,  4096, 512 },
 	{ REGION_GFX1, 0x0, &charlayout,        0, 512 },
@@ -432,13 +433,13 @@ static gfx_decode groundfx_gfxdecodeinfo[] =
 static MACHINE_INIT( groundfx )
 {
 	/* Sound cpu program loads to 0xc00000 so we use a bank */
-	UINT16 *RAM = (UINT16 *)memory_region(REGION_CPU2);
-	memory_set_bankptr(1,&RAM[0x80000]);
+	UINT16 *ROM = (UINT16 *)memory_region(REGION_CPU2);
+	memory_set_bankptr(1,&ROM[0x80000]);
 
-	RAM[0]=RAM[0x80000]; /* Stack and Reset vectors */
-	RAM[1]=RAM[0x80001];
-	RAM[2]=RAM[0x80002];
-	RAM[3]=RAM[0x80003];
+	sound_ram[0]=ROM[0x80000]; /* Stack and Reset vectors */
+	sound_ram[1]=ROM[0x80001];
+	sound_ram[2]=ROM[0x80002];
+	sound_ram[3]=ROM[0x80003];
 
 	f3_68681_reset();
 }
@@ -526,7 +527,7 @@ ROM_START( groundfx )
 	ROM_REGION16_LE( 0x80000, REGION_USER1, 0 )
 	ROM_LOAD16_WORD( "d51-13.7", 0x00000,  0x80000,  CRC(36921b8b) SHA1(2130120f78a3b984618a53054fc937cf727177b9) )	/* STY, spritemap */
 
-	ROM_REGION16_BE( 0x1000000, REGION_SOUND1, ROMREGION_SOUNDONLY | ROMREGION_ERASE00 )
+	ROM_REGION16_BE( 0x1000000, REGION_SOUND1, ROMREGION_ERASE00 )
 	ROM_LOAD16_BYTE( "d51-01.73", 0x000000, 0x200000, CRC(92f09155) SHA1(8015e1997818bb480174394eb43840bf26679bcf) )	/* Ensoniq samples */
 	ROM_LOAD16_BYTE( "d51-02.74", 0xc00000, 0x200000, CRC(20a9428f) SHA1(c9033d02a49c72f704808f5f899101617d5814e5) )
 ROM_END
