@@ -1178,7 +1178,7 @@ INPUT_PORTS_END
 /**************************************************************************/
 
 
-static gfx_layout char_layout =
+static const gfx_layout char_layout =
 {
 	8,8,
 	RGN_FRAC(1,1),
@@ -1189,14 +1189,14 @@ static gfx_layout char_layout =
 	32*8
 };
 
-static gfx_decode mrokumei_gfxdecodeinfo[] =
+static const gfx_decode mrokumei_gfxdecodeinfo[] =
 {
 	{ REGION_GFX1, 0, &char_layout, 0x6000, 0x100 },
 	{ REGION_GFX2, 0, &char_layout, 0x7000, 0x100 },
 	{ -1 }
 };
 
-static gfx_layout tile_layout =
+static const gfx_layout tile_layout =
 {
 	8,8,
 	RGN_FRAC(1,1),
@@ -1207,7 +1207,7 @@ static gfx_layout tile_layout =
 	64*8
 };
 
-static gfx_decode reikaids_gfxdecodeinfo[] =
+static const gfx_decode reikaids_gfxdecodeinfo[] =
 {
 	{ REGION_GFX1, 0, &tile_layout, 0x6000, 0x20 },
 	{ REGION_GFX2, 0, &tile_layout, 0x4000, 0x20 },
@@ -1216,14 +1216,14 @@ static gfx_decode reikaids_gfxdecodeinfo[] =
 	{ -1 }
 };
 
-static gfx_decode pteacher_gfxdecodeinfo[] =
+static const gfx_decode pteacher_gfxdecodeinfo[] =
 {
 	{ REGION_GFX1, 0, &tile_layout, 0x0000, 0x40 },
 	{ REGION_GFX2, 0, &tile_layout, 0x4000, 0x40 },
 	{ -1 }
 };
 
-static gfx_layout tile_layout_4bpp_hi =
+static const gfx_layout tile_layout_4bpp_hi =
 {
 	8,8,
 	RGN_FRAC(1,1),
@@ -1234,7 +1234,7 @@ static gfx_layout tile_layout_4bpp_hi =
 	64*8
 };
 
-static gfx_layout tile_layout_4bpp_lo =
+static const gfx_layout tile_layout_4bpp_lo =
 {
 	8,8,
 	RGN_FRAC(1,1),
@@ -1245,7 +1245,7 @@ static gfx_layout tile_layout_4bpp_lo =
 	64*8
 };
 
-static gfx_decode lemnangl_gfxdecodeinfo[] =
+static const gfx_decode lemnangl_gfxdecodeinfo[] =
 {
 	{ REGION_GFX1, 0, &tile_layout_4bpp_hi, 0x0000, 0x200 },
 	{ REGION_GFX1, 0, &tile_layout_4bpp_lo, 0x2000, 0x200 },
@@ -1846,23 +1846,23 @@ static DRIVER_INIT( battlcry )
 	homedata_priority=1; /* priority and initial value for bank write */
 }
 
-GAMEX(1987, hourouki, 0, mrokumei, mjhokite, 0,          ROT0, "Home Data", "Mahjong Hourouki Part 1 - Seisyun Hen (Japan)", GAME_IMPERFECT_GRAPHICS )
-GAME( 1987, mhgaiden, 0, mrokumei, mjhokite, 0,          ROT0, "Home Data", "Mahjong Hourouki Gaiden (Japan)" )
-GAME( 1988, mjhokite, 0, mrokumei, mjhokite, 0,          ROT0, "Home Data", "Mahjong Hourouki Okite (Japan)" )
-GAME( 1988, mjclinic, 0, mrokumei, mjhokite, 0,          ROT0, "Home Data", "Mahjong Clinic (Japan)" )
-GAMEX(1988, mrokumei, 0, mrokumei, mjhokite, 0,          ROT0, "Home Data", "Mahjong Rokumeikan (Japan)", GAME_IMPERFECT_GRAPHICS )
+GAME( 1987, hourouki, 0, mrokumei, mjhokite, 0,          ROT0, "Home Data", "Mahjong Hourouki Part 1 - Seisyun Hen (Japan)", GAME_IMPERFECT_GRAPHICS )
+GAME( 1987, mhgaiden, 0, mrokumei, mjhokite, 0,          ROT0, "Home Data", "Mahjong Hourouki Gaiden (Japan)", 0 )
+GAME( 1988, mjhokite, 0, mrokumei, mjhokite, 0,          ROT0, "Home Data", "Mahjong Hourouki Okite (Japan)", 0 )
+GAME( 1988, mjclinic, 0, mrokumei, mjhokite, 0,          ROT0, "Home Data", "Mahjong Clinic (Japan)", 0 )
+GAME( 1988, mrokumei, 0, mrokumei, mjhokite, 0,          ROT0, "Home Data", "Mahjong Rokumeikan (Japan)", GAME_IMPERFECT_GRAPHICS )
 
-GAME( 1988, reikaids, 0, reikaids, reikaids, reikaids,   ROT0, "Home Data", "Reikai Doushi (Japan)" )
-GAMEX(1991, battlcry, 0, reikaids, battlcry, battlcry,   ROT0, "Home Data", "Battlecry", GAME_IMPERFECT_GRAPHICS  )
-GAME( 1989, mjkojink, 0, pteacher, pteacher, 0,          ROT0, "Home Data", "Mahjong Kojinkyouju (Private Teacher) (Japan)" )
-GAME( 1989, vitaminc, 0, pteacher, pteacher, 0,          ROT0, "Home Data", "Mahjong Vitamin C (Japan)" )
-GAME( 1989, mjyougo,  0, pteacher, pteacher, 0,          ROT0, "Home Data", "Mahjong-yougo no Kisotairyoku (Japan)" )
-GAME( 1991, mjkinjas, 0, mjkinjas, pteacher, 0,          ROT0, "Home Data", "Mahjong Kinjirareta Asobi (Japan)" )
-GAME( 1992?,jogakuen, 0, pteacher, jogakuen, jogakuen,   ROT0, "Windom",    "Mahjong Jogakuen (Japan)" )
+GAME( 1988, reikaids, 0, reikaids, reikaids, reikaids,   ROT0, "Home Data", "Reikai Doushi (Japan)", 0 )
+GAME( 1991, battlcry, 0, reikaids, battlcry, battlcry,   ROT0, "Home Data", "Battlecry", GAME_IMPERFECT_GRAPHICS  )
+GAME( 1989, mjkojink, 0, pteacher, pteacher, 0,          ROT0, "Home Data", "Mahjong Kojinkyouju (Private Teacher) (Japan)", 0 )
+GAME( 1989, vitaminc, 0, pteacher, pteacher, 0,          ROT0, "Home Data", "Mahjong Vitamin C (Japan)", 0 )
+GAME( 1989, mjyougo,  0, pteacher, pteacher, 0,          ROT0, "Home Data", "Mahjong-yougo no Kisotairyoku (Japan)", 0 )
+GAME( 1991, mjkinjas, 0, mjkinjas, pteacher, 0,          ROT0, "Home Data", "Mahjong Kinjirareta Asobi (Japan)", 0 )
+GAME( 1992?,jogakuen, 0, pteacher, jogakuen, jogakuen,   ROT0, "Windom",    "Mahjong Jogakuen (Japan)", 0 )
 
-GAME( 1990, lemnangl, 0, lemnangl, pteacher, 0,          ROT0, "Home Data", "Mahjong Lemon Angel (Japan)" )
+GAME( 1990, lemnangl, 0, lemnangl, pteacher, 0,          ROT0, "Home Data", "Mahjong Lemon Angel (Japan)", 0 )
 
-GAMEX(1991?,mjikaga,  0, lemnangl, mjikaga,  mjikaga,    ROT0, "Mitchell",  "Mahjong Ikaga Desu ka (Japan)", GAME_NOT_WORKING | GAME_NO_SOUND )
+GAME( 1991?,mjikaga,  0, lemnangl, mjikaga,  mjikaga,    ROT0, "Mitchell",  "Mahjong Ikaga Desu ka (Japan)", GAME_NOT_WORKING | GAME_NO_SOUND )
 
 
 
