@@ -505,7 +505,7 @@ INPUT_PORTS_END
 
 
 
-static gfx_layout charlayout =
+static const gfx_layout charlayout =
 {
 	8,8,    /* 8x8 characters */
 	1024,	/* 1024 characters */
@@ -516,7 +516,7 @@ static gfx_layout charlayout =
 	32*8   	/* every char takes 32 consecutive bytes */
 };
 
-static gfx_layout spritelayout =
+static const gfx_layout spritelayout =
 {
 	16,16,  /* 16x16 characters */
 	1024,	/* 1024 characters */
@@ -527,7 +527,7 @@ static gfx_layout spritelayout =
 	128*8	/* every char takes 128 consecutive bytes */
 };
 
-static gfx_decode gfxdecodeinfo[] =
+static const gfx_decode gfxdecodeinfo[] =
 {
 	{ REGION_GFX1, 0, &spritelayout,  0*16, 16 },
 	{ REGION_GFX2, 0, &spritelayout, 16*16, 16 },
