@@ -148,16 +148,14 @@
 
 static ADDRESS_MAP_START( readmem, ADDRESS_SPACE_PROGRAM, 8 )
 	AM_RANGE(0x0000, 0xbfff) AM_READ(MRA8_ROM)
-	AM_RANGE(0xc800, 0xcfff) AM_READ(MRA8_RAM)
-	AM_RANGE(0xe000, 0xefff) AM_READ(MRA8_RAM)
-	AM_RANGE(0xd000, 0xdfff) AM_READ(MRA8_RAM)			/* sound ram */
+	AM_RANGE(0xc800, 0xcfff) AM_READ(MRA8_RAM) AM_BASE(&sega_mainram)
+	AM_RANGE(0xd000, 0xdfff) AM_READ(MRA8_RAM) AM_BASE(&sega_soundram)    /* sound ram */
+	AM_RANGE(0xe000, 0xefff) AM_READ(MRA8_RAM) AM_BASE(&vectorram) AM_SIZE(&vectorram_size)
 ADDRESS_MAP_END
 
 
 static ADDRESS_MAP_START( writemem, ADDRESS_SPACE_PROGRAM, 8 )
-	AM_RANGE(0x0000, 0xffff) AM_WRITE(sega_w) AM_BASE(&sega_mem)
-	AM_RANGE(0xe000, 0xefff) AM_WRITE(MWA8_RAM) AM_BASE(&vectorram) AM_SIZE(&vectorram_size)	/* handled by the above, */
-												/* here only to initialize the pointer */
+	AM_RANGE(0x0000, 0xffff) AM_WRITE(sega_w)
 ADDRESS_MAP_END
 
 static READ8_HANDLER( sega_sh_r )
@@ -1365,14 +1363,14 @@ DRIVER_INIT( tacscan )
  *
  *************************************/
 
-GAME( 1981, spacfury, 0,        spacfury, spacfury, spacfury, ROT0,   "Sega", "Space Fury (revision C)" )
-GAME( 1981, spacfura, spacfury, spacfury, spacfury, spacfury, ROT0,   "Sega", "Space Fury (revision A)" )
-GAME( 1982, zektor,   0,        zektor,   zektor,   zektor,   ROT0,   "Sega", "Zektor (revision B)" )
-GAME( 1982, tacscan,  0,        tacscan,  tacscan,  tacscan,  ROT270, "Sega", "Tac/Scan" )
-GAME( 1981, elim2,	  0,        elim2,    elim2,    elim2,    ROT0,   "Gremlin", "Eliminator (2 Players, set 1)" )
-GAME( 1981, elim2a,   elim2,    elim2,    elim2,    elim2,    ROT0,   "Gremlin", "Eliminator (2 Players, set 2)" )
-GAME( 1981, elim2c,	  elim2,	elim2,	  elim2c,	elim2,	  ROT0,	  "Gremlin", "Eliminator (2 Players, cocktail)" )
-GAME( 1981, elim4,	  elim2,    elim2,    elim4,    elim4,    ROT0,   "Gremlin", "Eliminator (4 Players)" )
-GAME( 1981, elim4p,	  elim2,	elim2,	  elim4,	elim4,	  ROT0,	  "Gremlin", "Eliminator (4 Players, prototype)" )
-GAME( 1982, startrek, 0,        startrek, startrek, startrek, ROT0,   "Sega", "Star Trek" )
+GAME( 1981, spacfury, 0,        spacfury, spacfury, spacfury, ROT0,   "Sega", "Space Fury (revision C)", 0 )
+GAME( 1981, spacfura, spacfury, spacfury, spacfury, spacfury, ROT0,   "Sega", "Space Fury (revision A)", 0 )
+GAME( 1982, zektor,   0,        zektor,   zektor,   zektor,   ROT0,   "Sega", "Zektor (revision B)", 0 )
+GAME( 1982, tacscan,  0,        tacscan,  tacscan,  tacscan,  ROT270, "Sega", "Tac/Scan", 0 )
+GAME( 1981, elim2,	  0,        elim2,    elim2,    elim2,    ROT0,   "Gremlin", "Eliminator (2 Players, set 1)", 0 )
+GAME( 1981, elim2a,   elim2,    elim2,    elim2,    elim2,    ROT0,   "Gremlin", "Eliminator (2 Players, set 2)", 0 )
+GAME( 1981, elim2c,	  elim2,	elim2,	  elim2c,	elim2,	  ROT0,	  "Gremlin", "Eliminator (2 Players, cocktail)", 0 )
+GAME( 1981, elim4,	  elim2,    elim2,    elim4,    elim4,    ROT0,   "Gremlin", "Eliminator (4 Players)", 0 )
+GAME( 1981, elim4p,	  elim2,	elim2,	  elim4,	elim4,	  ROT0,	  "Gremlin", "Eliminator (4 Players, prototype)", 0 )
+GAME( 1982, startrek, 0,        startrek, startrek, startrek, ROT0,   "Sega", "Star Trek", 0 )
 
