@@ -362,10 +362,11 @@ static UINT32 *taitojc_char_ram;
 static UINT32 *taitojc_tile_ram;
 static int taitojc_char_dirty = 1;
 static tilemap *taitojc_tilemap;
+static UINT16 *sound_ram;
 
 #define TAITOJC_NUM_TILES		0x180
 
-static gfx_layout taitojc_char_layout =
+static const gfx_layout taitojc_char_layout =
 {
 	16,16,
 	TAITOJC_NUM_TILES,
@@ -529,7 +530,7 @@ static ADDRESS_MAP_START( sound_readmem, ADDRESS_SPACE_PROGRAM, 16 )
 ADDRESS_MAP_END
 
 static ADDRESS_MAP_START( sound_writemem, ADDRESS_SPACE_PROGRAM, 16 )
-	AM_RANGE(0x000000, 0x03ffff) AM_WRITE(MWA16_RAM)
+	AM_RANGE(0x000000, 0x03ffff) AM_WRITE(MWA16_RAM) AM_BASE(&sound_ram)
 	AM_RANGE(0x140000, 0x140fff) AM_WRITE(f3_68000_share_w)
 	AM_RANGE(0x200000, 0x20001f) AM_WRITE(ES5505_data_0_w)
 	AM_RANGE(0x260000, 0x2601ff) AM_WRITE(es5510_dsp_w)
@@ -553,7 +554,7 @@ INPUT_PORTS_END
 
 
 
-static gfx_decode gfxdecodeinfo[] =
+static const gfx_decode gfxdecodeinfo[] =
 {
 	{ -1 } /* end of array */
 };
@@ -561,15 +562,15 @@ static gfx_decode gfxdecodeinfo[] =
 static MACHINE_INIT( jc )
 {
 	/* Sound cpu program loads to 0xc00000 so we use a bank */
-	UINT16 *RAM = (UINT16 *)memory_region(REGION_CPU2);
-	memory_set_bankptr(1,&RAM[0x80000]);
-	memory_set_bankptr(2,&RAM[0x90000]);
-	memory_set_bankptr(3,&RAM[0xa0000]);
+	UINT16 *ROM = (UINT16 *)memory_region(REGION_CPU2);
+	memory_set_bankptr(1,&ROM[0x80000]);
+	memory_set_bankptr(2,&ROM[0x90000]);
+	memory_set_bankptr(3,&ROM[0xa0000]);
 
-	RAM[0]=RAM[0x80000]; /* Stack and Reset vectors */
-	RAM[1]=RAM[0x80001];
-	RAM[2]=RAM[0x80002];
-	RAM[3]=RAM[0x80003];
+	sound_ram[0]=ROM[0x80000]; /* Stack and Reset vectors */
+	sound_ram[1]=ROM[0x80001];
+	sound_ram[2]=ROM[0x80002];
+	sound_ram[3]=ROM[0x80003];
 
 	cpunum_set_input_line(1, INPUT_LINE_RESET, ASSERT_LINE);
 /* do not let the 68k start up until f3_shared_ram points to valid RAM */
@@ -950,10 +951,10 @@ ROM_END
 
 
 
-GAMEX( 1997, dendeg,  0,      taitojc, taitojc, 0, ROT0, "Taito", "Densya De Go", GAME_NOT_WORKING|GAME_NO_SOUND )
-GAMEX( 1997, dendegx, dendeg, taitojc, taitojc, 0, ROT0, "Taito", "Densya De Go Ex", GAME_NOT_WORKING|GAME_NO_SOUND )
-GAMEX( 1997, dendeg2, 0,      taitojc, taitojc, 0, ROT0, "Taito", "Densya De Go 2", GAME_NOT_WORKING|GAME_NO_SOUND )
-GAMEX( 1997, dendeg2x,dendeg2,taitojc, taitojc, 0, ROT0, "Taito", "Densya De Go 2 Ex", GAME_NOT_WORKING|GAME_NO_SOUND )
-GAMEX( 1997, sidebs,  0,      taitojc, taitojc, 0, ROT0, "Taito", "Side By Side", GAME_NOT_WORKING|GAME_NO_SOUND )
-GAMEX( 1997, sidebs2, 0,      taitojc, taitojc, 0, ROT0, "Taito", "Side By Side 2", GAME_NOT_WORKING|GAME_NO_SOUND )
-GAMEX( 1997, landgear,0,      taitojc, taitojc, 0, ROT0, "Taito", "Landing Gear", GAME_NOT_WORKING|GAME_NO_SOUND )
+GAME( 1997, dendeg,  0,      taitojc, taitojc, 0, ROT0, "Taito", "Densya De Go", GAME_NOT_WORKING|GAME_NO_SOUND )
+GAME( 1997, dendegx, dendeg, taitojc, taitojc, 0, ROT0, "Taito", "Densya De Go Ex", GAME_NOT_WORKING|GAME_NO_SOUND )
+GAME( 1997, dendeg2, 0,      taitojc, taitojc, 0, ROT0, "Taito", "Densya De Go 2", GAME_NOT_WORKING|GAME_NO_SOUND )
+GAME( 1997, dendeg2x,dendeg2,taitojc, taitojc, 0, ROT0, "Taito", "Densya De Go 2 Ex", GAME_NOT_WORKING|GAME_NO_SOUND )
+GAME( 1997, sidebs,  0,      taitojc, taitojc, 0, ROT0, "Taito", "Side By Side", GAME_NOT_WORKING|GAME_NO_SOUND )
+GAME( 1997, sidebs2, 0,      taitojc, taitojc, 0, ROT0, "Taito", "Side By Side 2", GAME_NOT_WORKING|GAME_NO_SOUND )
+GAME( 1997, landgear,0,      taitojc, taitojc, 0, ROT0, "Taito", "Landing Gear", GAME_NOT_WORKING|GAME_NO_SOUND )
