@@ -304,7 +304,7 @@ INPUT_PORTS_END
  *
  *************************************/
 
-static gfx_layout anlayout =
+static const gfx_layout anlayout =
 {
 	8,8,
 	RGN_FRAC(1,1),
@@ -316,7 +316,7 @@ static gfx_layout anlayout =
 };
 
 
-static gfx_layout pfmolayout =
+static const gfx_layout pfmolayout =
 {
 	8,8,
 	RGN_FRAC(1,4),
@@ -328,7 +328,7 @@ static gfx_layout pfmolayout =
 };
 
 
-static gfx_decode gfxdecodeinfo[] =
+static const gfx_decode gfxdecodeinfo[] =
 {
 	{ REGION_GFX1, 0, &pfmolayout,  512,  96 },	/* sprites & playfield */
 	{ REGION_GFX2, 0, &pfmolayout,  256, 112 },	/* sprites & playfield */
@@ -472,4 +472,4 @@ static DRIVER_INIT( thunderj )
  *
  *************************************/
 
-GAME( 1990, thunderj, 0, thunderj, thunderj, thunderj, ROT0, "Atari Games", "ThunderJaws" )
+GAME( 1990, thunderj, 0, thunderj, thunderj, thunderj, ROT0, "Atari Games", "ThunderJaws", 0 )
