@@ -465,7 +465,7 @@ INPUT_PORTS_START( buccanra )
 INPUT_PORTS_END
 
 
-static gfx_layout text_layout =
+static const gfx_layout text_layout =
 {
 	8,8, /* tile size */
 	RGN_FRAC(1,2), /* number of tiles */
@@ -476,7 +476,7 @@ static gfx_layout text_layout =
 	128
 };
 
-static gfx_layout sprite_layout =
+static const gfx_layout sprite_layout =
 {
 	16,16,	/* tile size */
 	RGN_FRAC(1,2),	/* number of sprites ($1000) */
@@ -497,7 +497,7 @@ static gfx_layout sprite_layout =
 	0x40*8
 };
 
-static gfx_layout sprite_layout_buccanrs =
+static const gfx_layout sprite_layout_buccanrs =
 {
 	16,16,	/* tile size */
 	RGN_FRAC(1,2),	/* number of sprites ($1000) */
@@ -519,7 +519,7 @@ static gfx_layout sprite_layout_buccanrs =
 };
 
 
-static gfx_layout back_layout =
+static const gfx_layout back_layout =
 {
 	32,1, /* tile size */
 	RGN_FRAC(1,1), /* number of tiles */
@@ -532,7 +532,7 @@ static gfx_layout back_layout =
 	16*8
 };
 
-static gfx_layout buccaneer_back_layout =
+static const gfx_layout buccaneer_back_layout =
 {
 	32,1, /* tile size */
 	RGN_FRAC(1,1), /* number of tiles */
@@ -545,7 +545,7 @@ static gfx_layout buccaneer_back_layout =
 	16*8
 };
 
-static gfx_decode vigilant_gfxdecodeinfo[] =
+static const gfx_decode vigilant_gfxdecodeinfo[] =
 {
 	{ REGION_GFX1, 0, &text_layout,   256, 16 },	/* colors 256-511 */
 	{ REGION_GFX2, 0, &sprite_layout,   0, 16 },	/* colors   0-255 */
@@ -555,7 +555,7 @@ static gfx_decode vigilant_gfxdecodeinfo[] =
 	{ -1 } /* end of array */
 };
 
-static gfx_decode buccanrs_gfxdecodeinfo[] =
+static const gfx_decode buccanrs_gfxdecodeinfo[] =
 {
 	{ REGION_GFX1, 0, &text_layout,   256, 16 },	/* colors 256-511 */
 	{ REGION_GFX2, 0, &sprite_layout_buccanrs,   0, 16 },	/* colors   0-255 */
@@ -565,7 +565,7 @@ static gfx_decode buccanrs_gfxdecodeinfo[] =
 	{ -1 } /* end of array */
 };
 
-static gfx_decode kikcubic_gfxdecodeinfo[] =
+static const gfx_decode kikcubic_gfxdecodeinfo[] =
 {
 	{ REGION_GFX1, 0, &text_layout,   0, 16 },
 	{ REGION_GFX2, 0, &sprite_layout, 0, 16 },
@@ -955,10 +955,10 @@ ROM_START( buccanra )
 	ROM_LOAD( "prom2.u99",  0x0300, 0x0100, CRC(e0aa8869) SHA1(ac8bdfeba69420ba56ec561bf3d0f1229d02cea2) )
 ROM_END
 
-GAMEX( 1988, vigilant, 0,        vigilant, vigilant, 0, ROT0, "Irem", "Vigilante (World)", GAME_NO_COCKTAIL )
-GAMEX( 1988, vigilntu, vigilant, vigilant, vigilant, 0, ROT0, "Irem (Data East USA license)", "Vigilante (US)", GAME_NO_COCKTAIL )
-GAMEX( 1988, vigilntj, vigilant, vigilant, vigilant, 0, ROT0, "Irem", "Vigilante (Japan)", GAME_NO_COCKTAIL )
-GAMEX( 1988, kikcubic, 0,        kikcubic, kikcubic, 0, ROT0, "Irem", "Meikyu Jima (Japan)", GAME_NO_COCKTAIL )	/* English title is Kickle Cubicle */
-GAMEX( 1988, kikcubib, kikcubic, kikcubic, kikcubic, 0, ROT0, "bootleg", "Kickle Cubele", GAME_NO_COCKTAIL )
-GAMEX( 1989, buccanrs, 0,        buccanrs, buccanrs, 0, ROT0, "Duintronic", "Buccaneers (set 1)", GAME_NO_COCKTAIL )
-GAMEX( 1989, buccanra, buccanrs, buccanrs, buccanra, 0, ROT0, "Duintronic", "Buccaneers (set 2)", GAME_NO_COCKTAIL )
+GAME( 1988, vigilant, 0,        vigilant, vigilant, 0, ROT0, "Irem", "Vigilante (World)", GAME_NO_COCKTAIL )
+GAME( 1988, vigilntu, vigilant, vigilant, vigilant, 0, ROT0, "Irem (Data East USA license)", "Vigilante (US)", GAME_NO_COCKTAIL )
+GAME( 1988, vigilntj, vigilant, vigilant, vigilant, 0, ROT0, "Irem", "Vigilante (Japan)", GAME_NO_COCKTAIL )
+GAME( 1988, kikcubic, 0,        kikcubic, kikcubic, 0, ROT0, "Irem", "Meikyu Jima (Japan)", GAME_NO_COCKTAIL )	/* English title is Kickle Cubicle */
+GAME( 1988, kikcubib, kikcubic, kikcubic, kikcubic, 0, ROT0, "bootleg", "Kickle Cubele", GAME_NO_COCKTAIL )
+GAME( 1989, buccanrs, 0,        buccanrs, buccanrs, 0, ROT0, "Duintronic", "Buccaneers (set 1)", GAME_NO_COCKTAIL )
+GAME( 1989, buccanra, buccanrs, buccanrs, buccanra, 0, ROT0, "Duintronic", "Buccaneers (set 2)", GAME_NO_COCKTAIL )
