@@ -37,22 +37,25 @@ Notes:
 #include "vidhrdw/generic.h"
 #include "machine/6821pia.h"
 #include "machine/8255ppi.h"
+#include "sound/ay8910.h"
+#include "sound/dac.h"
+#include "sound/5220intf.h"
 
 
-extern data8_t *zaccaria_videoram,*zaccaria_attributesram;
+extern UINT8 *zaccaria_videoram,*zaccaria_attributesram;
 
-void zaccaria_vh_convert_color_prom(unsigned char *palette, unsigned short *colortable,const unsigned char *color_prom);
-int zaccaria_vh_start(void);
-WRITE_HANDLER( zaccaria_videoram_w );
-WRITE_HANDLER( zaccaria_attributes_w );
-WRITE_HANDLER( zaccaria_flip_screen_x_w );
-WRITE_HANDLER( zaccaria_flip_screen_y_w );
-void zaccaria_vh_screenrefresh(struct mame_bitmap *bitmap,int full_refresh);
+PALETTE_INIT( zaccaria );
+VIDEO_START( zaccaria );
+WRITE8_HANDLER( zaccaria_videoram_w );
+WRITE8_HANDLER( zaccaria_attributes_w );
+WRITE8_HANDLER( zaccaria_flip_screen_x_w );
+WRITE8_HANDLER( zaccaria_flip_screen_y_w );
+VIDEO_UPDATE( zaccaria );
 
 
 static int dsw;
 
-static WRITE_HANDLER( zaccaria_dsw_sel_w )
+static WRITE8_HANDLER( zaccaria_dsw_sel_w )
 {
 	switch (data & 0xf0)
 	{
@@ -69,19 +72,19 @@ static WRITE_HANDLER( zaccaria_dsw_sel_w )
 			break;
 
 		default:
-logerror("PC %04x: portsel = %02x\n",cpu_get_pc(),data);
+logerror("PC %04x: portsel = %02x\n",activecpu_get_pc(),data);
 			break;
 	}
 }
 
-static READ_HANDLER( zaccaria_dsw_r )
+static READ8_HANDLER( zaccaria_dsw_r )
 {
 	return readinputport(dsw);
 }
 
 
 
-static WRITE_HANDLER( ay8910_port0a_w )
+static WRITE8_HANDLER( ay8910_port0a_w )
 {
 	/* bits 0-2 go to a weird kind of DAC ?? */
 	/* bits 3-4 control the analog drum emulation on 8910 #0 ch. A */
@@ -97,12 +100,12 @@ static WRITE_HANDLER( ay8910_port0a_w )
 }
 
 
-void zaccaria_irq0a(int state) { cpu_set_nmi_line(1,  state ? ASSERT_LINE : CLEAR_LINE); }
-void zaccaria_irq0b(int state) { cpu_set_irq_line(1,0,state ? ASSERT_LINE : CLEAR_LINE); }
+void zaccaria_irq0a(int state) { cpunum_set_input_line(1, INPUT_LINE_NMI, state ? ASSERT_LINE : CLEAR_LINE); }
+void zaccaria_irq0b(int state) { cpunum_set_input_line(1,0,state ? ASSERT_LINE : CLEAR_LINE); }
 
 static int active_8910,port0a,acs;
 
-static READ_HANDLER( zaccaria_port0a_r )
+static READ8_HANDLER( zaccaria_port0a_r )
 {
 	if (active_8910 == 0)
 		return AY8910_read_port_0_r(0);
@@ -110,12 +113,12 @@ static READ_HANDLER( zaccaria_port0a_r )
 		return AY8910_read_port_1_r(0);
 }
 
-static WRITE_HANDLER( zaccaria_port0a_w )
+static WRITE8_HANDLER( zaccaria_port0a_w )
 {
 	port0a = data;
 }
 
-static WRITE_HANDLER( zaccaria_port0b_w )
+static WRITE8_HANDLER( zaccaria_port0b_w )
 {
 	static int last;
 
@@ -154,32 +157,30 @@ static WRITE_HANDLER( zaccaria_port0b_w )
 	last = data;
 }
 
-static int zaccaria_cb1_toggle(void)
+static INTERRUPT_GEN( zaccaria_cb1_toggle )
 {
 	static int toggle;
 
 	pia_0_cb1_w(0,toggle & 1);
 	toggle ^= 1;
-
-	return ignore_interrupt();
 }
 
 
 
 static int port1a,port1b;
 
-static READ_HANDLER( zaccaria_port1a_r )
+static READ8_HANDLER( zaccaria_port1a_r )
 {
 	if (~port1b & 1) return tms5220_status_r(0);
 	else return port1a;
 }
 
-static WRITE_HANDLER( zaccaria_port1a_w )
+static WRITE8_HANDLER( zaccaria_port1a_w )
 {
 	port1a = data;
 }
 
-static WRITE_HANDLER( zaccaria_port1b_w )
+static WRITE8_HANDLER( zaccaria_port1b_w )
 {
 	port1b = data;
 
@@ -195,10 +196,10 @@ static WRITE_HANDLER( zaccaria_port1b_w )
 	set_led_status(0,~data & 0x10);
 }
 
-static READ_HANDLER( zaccaria_ca2_r )
+static READ8_HANDLER( zaccaria_ca2_r )
 {
 /* TODO: this doesn't work, why? */
-/*	return !tms5220_ready_r(); */
+/*  return !tms5220_ready_r(); */
 
 static int counter;
 counter = (counter+1) & 0x0f;
@@ -241,7 +242,7 @@ static ppi8255_interface ppi8255_intf =
 };
 
 
-static void zaccaria_init_machine(void)
+static MACHINE_INIT( zaccaria )
 {
 	ppi8255_init(&ppi8255_intf);
 
@@ -252,27 +253,27 @@ static void zaccaria_init_machine(void)
 }
 
 
-static WRITE_HANDLER( sound_command_w )
+static WRITE8_HANDLER( sound_command_w )
 {
 	soundlatch_w(0,data);
-	cpu_set_irq_line(2,0,(data & 0x80) ? CLEAR_LINE : ASSERT_LINE);
+	cpunum_set_input_line(2,0,(data & 0x80) ? CLEAR_LINE : ASSERT_LINE);
 }
 
-static WRITE_HANDLER( sound1_command_w )
+static WRITE8_HANDLER( sound1_command_w )
 {
 	pia_0_ca1_w(0,data & 0x80);
 	soundlatch2_w(0,data);
 }
 
-static WRITE_HANDLER( mc1408_data_w )
+static WRITE8_HANDLER( mc1408_data_w )
 {
 	DAC_data_w(1,data);
 }
 
 
-struct GameDriver monymony_driver;
+game_driver monymony_driver;
 
-static READ_HANDLER( zaccaria_prot1_r )
+static READ8_HANDLER( zaccaria_prot1_r )
 {
 	switch (offset)
 	{
@@ -292,7 +293,7 @@ static READ_HANDLER( zaccaria_prot1_r )
 	}
 }
 
-static READ_HANDLER( zaccaria_prot2_r )
+static READ8_HANDLER( zaccaria_prot2_r )
 {
 	switch (offset)
 	{
@@ -314,93 +315,93 @@ static READ_HANDLER( zaccaria_prot2_r )
 }
 
 
-static WRITE_HANDLER( coin_w )
+static WRITE8_HANDLER( coin_w )
 {
 	coin_counter_w(0,data & 1);
 }
 
-static WRITE_HANDLER( nmienable_w )
+static WRITE8_HANDLER( nmienable_w )
 {
 	interrupt_enable_w(0,data & 1);
 }
 
 
 
-static MEMORY_READ_START( readmem )
-	{ 0x0000, 0x5fff, MRA_ROM },
-	{ 0x6000, 0x63ff, MRA_RAM },
-	{ 0x6400, 0x6407, zaccaria_prot1_r },
-	{ 0x6c00, 0x6c07, zaccaria_prot2_r },
-	{ 0x6e00, 0x6e00, zaccaria_dsw_r },
-	{ 0x7000, 0x77ff, MRA_RAM },
-	{ 0x7800, 0x7803, ppi8255_0_r },
-	{ 0x7c00, 0x7c00, watchdog_reset_r },
-	{ 0x8000, 0xdfff, MRA_ROM },
-MEMORY_END
+static ADDRESS_MAP_START( readmem, ADDRESS_SPACE_PROGRAM, 8 )
+	AM_RANGE(0x0000, 0x5fff) AM_READ(MRA8_ROM)
+	AM_RANGE(0x6000, 0x63ff) AM_READ(MRA8_RAM)
+	AM_RANGE(0x6400, 0x6407) AM_READ(zaccaria_prot1_r)
+	AM_RANGE(0x6c00, 0x6c07) AM_READ(zaccaria_prot2_r)
+	AM_RANGE(0x6e00, 0x6e00) AM_READ(zaccaria_dsw_r)
+	AM_RANGE(0x7000, 0x77ff) AM_READ(MRA8_RAM)
+	AM_RANGE(0x7800, 0x7803) AM_READ(ppi8255_0_r)
+	AM_RANGE(0x7c00, 0x7c00) AM_READ(watchdog_reset_r)
+	AM_RANGE(0x8000, 0xdfff) AM_READ(MRA8_ROM)
+ADDRESS_MAP_END
 
-static MEMORY_WRITE_START( writemem )
-	{ 0x0000, 0x5fff, MWA_ROM },
-	{ 0x6000, 0x67ff, zaccaria_videoram_w, &zaccaria_videoram },	/* 6400-67ff is 4 bits wide */
-	{ 0x6800, 0x683f, zaccaria_attributes_w, &zaccaria_attributesram },
-	{ 0x6840, 0x685f, MWA_RAM, &spriteram, &spriteram_size },
-	{ 0x6881, 0x68bc, MWA_RAM, &spriteram_2, &spriteram_2_size },
-	{ 0x6c00, 0x6c00, zaccaria_flip_screen_x_w },
-	{ 0x6c01, 0x6c01, zaccaria_flip_screen_y_w },
-	{ 0x6c02, 0x6c02, MWA_NOP },    /* sound reset */
-	{ 0x6e00, 0x6e00, sound_command_w },
-	{ 0x6c06, 0x6c06, coin_w },
-	{ 0x6c07, 0x6c07, nmienable_w },
-	{ 0x7000, 0x77ff, MWA_RAM },
-	{ 0x7800, 0x7803, ppi8255_0_w },
-	{ 0x8000, 0xdfff, MWA_ROM },
-MEMORY_END
+static ADDRESS_MAP_START( writemem, ADDRESS_SPACE_PROGRAM, 8 )
+	AM_RANGE(0x0000, 0x5fff) AM_WRITE(MWA8_ROM)
+	AM_RANGE(0x6000, 0x67ff) AM_WRITE(zaccaria_videoram_w) AM_BASE(&zaccaria_videoram)	/* 6400-67ff is 4 bits wide */
+	AM_RANGE(0x6800, 0x683f) AM_WRITE(zaccaria_attributes_w) AM_BASE(&zaccaria_attributesram)
+	AM_RANGE(0x6840, 0x685f) AM_WRITE(MWA8_RAM) AM_BASE(&spriteram) AM_SIZE(&spriteram_size)
+	AM_RANGE(0x6881, 0x68bc) AM_WRITE(MWA8_RAM) AM_BASE(&spriteram_2) AM_SIZE(&spriteram_2_size)
+	AM_RANGE(0x6c00, 0x6c00) AM_WRITE(zaccaria_flip_screen_x_w)
+	AM_RANGE(0x6c01, 0x6c01) AM_WRITE(zaccaria_flip_screen_y_w)
+	AM_RANGE(0x6c02, 0x6c02) AM_WRITE(MWA8_NOP)    /* sound reset */
+	AM_RANGE(0x6e00, 0x6e00) AM_WRITE(sound_command_w)
+	AM_RANGE(0x6c06, 0x6c06) AM_WRITE(coin_w)
+	AM_RANGE(0x6c07, 0x6c07) AM_WRITE(nmienable_w)
+	AM_RANGE(0x7000, 0x77ff) AM_WRITE(MWA8_RAM)
+	AM_RANGE(0x7800, 0x7803) AM_WRITE(ppi8255_0_w)
+	AM_RANGE(0x8000, 0xdfff) AM_WRITE(MWA8_ROM)
+ADDRESS_MAP_END
 
-static MEMORY_READ_START( sound_readmem1 )
-	{ 0x0000, 0x007f, MRA_RAM },
-	{ 0x500c, 0x500f, pia_0_r },
-	{ 0xa000, 0xbfff, MRA_ROM },
-	{ 0xe000, 0xffff, MRA_ROM },
-MEMORY_END
+static ADDRESS_MAP_START( sound_readmem1, ADDRESS_SPACE_PROGRAM, 8 )
+	AM_RANGE(0x0000, 0x007f) AM_READ(MRA8_RAM)
+	AM_RANGE(0x500c, 0x500f) AM_READ(pia_0_r)
+	AM_RANGE(0xa000, 0xbfff) AM_READ(MRA8_ROM)
+	AM_RANGE(0xe000, 0xffff) AM_READ(MRA8_ROM)
+ADDRESS_MAP_END
 
-static MEMORY_WRITE_START( sound_writemem1 )
-	{ 0x0000, 0x007f, MWA_RAM },
-	{ 0x500c, 0x500f, pia_0_w },
-	{ 0xa000, 0xbfff, MWA_ROM },
-	{ 0xe000, 0xffff, MWA_ROM },
-MEMORY_END
+static ADDRESS_MAP_START( sound_writemem1, ADDRESS_SPACE_PROGRAM, 8 )
+	AM_RANGE(0x0000, 0x007f) AM_WRITE(MWA8_RAM)
+	AM_RANGE(0x500c, 0x500f) AM_WRITE(pia_0_w)
+	AM_RANGE(0xa000, 0xbfff) AM_WRITE(MWA8_ROM)
+	AM_RANGE(0xe000, 0xffff) AM_WRITE(MWA8_ROM)
+ADDRESS_MAP_END
 
-static MEMORY_READ_START( sound_readmem2 )
-	{ 0x0000, 0x007f, MRA_RAM },
-	{ 0x0090, 0x0093, pia_1_r },
-	{ 0x1800, 0x1800, soundlatch_r },
-	{ 0xa000, 0xbfff, MRA_ROM },
-	{ 0xe000, 0xffff, MRA_ROM },
-MEMORY_END
+static ADDRESS_MAP_START( sound_readmem2, ADDRESS_SPACE_PROGRAM, 8 )
+	AM_RANGE(0x0000, 0x007f) AM_READ(MRA8_RAM)
+	AM_RANGE(0x0090, 0x0093) AM_READ(pia_1_r)
+	AM_RANGE(0x1800, 0x1800) AM_READ(soundlatch_r)
+	AM_RANGE(0xa000, 0xbfff) AM_READ(MRA8_ROM)
+	AM_RANGE(0xe000, 0xffff) AM_READ(MRA8_ROM)
+ADDRESS_MAP_END
 
-static MEMORY_WRITE_START( sound_writemem2 )
-	{ 0x0000, 0x007f, MWA_RAM },
-	{ 0x0090, 0x0093, pia_1_w },
-	{ 0x1000, 0x1000, mc1408_data_w },	/* MC1408 */
-	{ 0x1400, 0x1400, sound1_command_w },
-	{ 0xa000, 0xbfff, MWA_ROM },
-	{ 0xe000, 0xffff, MWA_ROM },
-MEMORY_END
+static ADDRESS_MAP_START( sound_writemem2, ADDRESS_SPACE_PROGRAM, 8 )
+	AM_RANGE(0x0000, 0x007f) AM_WRITE(MWA8_RAM)
+	AM_RANGE(0x0090, 0x0093) AM_WRITE(pia_1_w)
+	AM_RANGE(0x1000, 0x1000) AM_WRITE(mc1408_data_w)	/* MC1408 */
+	AM_RANGE(0x1400, 0x1400) AM_WRITE(sound1_command_w)
+	AM_RANGE(0xa000, 0xbfff) AM_WRITE(MWA8_ROM)
+	AM_RANGE(0xe000, 0xffff) AM_WRITE(MWA8_ROM)
+ADDRESS_MAP_END
 
 
 
 INPUT_PORTS_START( monymony )
-	PORT_START
+	PORT_START_TAG("IN0")
 	PORT_DIPNAME( 0x03, 0x01, DEF_STR( Lives ) )
 	PORT_DIPSETTING(    0x00, "2" )
 	PORT_DIPSETTING(    0x01, "3" )
 	PORT_DIPSETTING(    0x02, "4" )
 	PORT_DIPSETTING(    0x03, "5" )
-	PORT_BITX(    0x04, 0x00, IPT_DIPSWITCH_NAME | IPF_CHEAT, "Infinite Lives", IP_KEY_NONE, IP_JOY_NONE )
+	PORT_DIPNAME( 0x04, 0x00, "Infinite Lives (Cheat)")
 	PORT_DIPSETTING(    0x00, DEF_STR( Off ) )
 	PORT_DIPSETTING(    0x04, DEF_STR( On ) )
 	PORT_DIPNAME( 0x08, 0x00, DEF_STR( Difficulty ) )
-	PORT_DIPSETTING(    0x00, "Easy" )
-	PORT_DIPSETTING(    0x08, "Hard" )
+	PORT_DIPSETTING(    0x00, DEF_STR( Easy ) )
+	PORT_DIPSETTING(    0x08, DEF_STR( Hard ) )
 	PORT_DIPNAME( 0x10, 0x00, DEF_STR( Cabinet ) )
 	PORT_DIPSETTING(    0x00, DEF_STR( Upright ) )
 	PORT_DIPSETTING(    0x10, DEF_STR( Cocktail ) )
@@ -414,12 +415,12 @@ INPUT_PORTS_START( monymony )
 	PORT_DIPSETTING(    0x80, DEF_STR( Off ) )
 	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
 
-	PORT_START
+	PORT_START_TAG("DSW0")
 	PORT_DIPNAME( 0x03, 0x01, DEF_STR( Bonus_Life ) )
 	PORT_DIPSETTING(    0x01, "200000" )
 	PORT_DIPSETTING(    0x02, "300000" )
 	PORT_DIPSETTING(    0x03, "400000" )
-	PORT_DIPSETTING(    0x00, "None" )
+	PORT_DIPSETTING(    0x00, DEF_STR( None ) )
 	PORT_DIPNAME( 0x04, 0x00, "Table Title" )
 	PORT_DIPSETTING(    0x00, "Todays High Scores" )
 	PORT_DIPSETTING(    0x04, "High Scores" )
@@ -437,7 +438,7 @@ INPUT_PORTS_START( monymony )
 	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
 	PORT_SERVICE( 0x80, IP_ACTIVE_HIGH )
 
-	PORT_START
+	PORT_START_TAG("DSW1")
 	PORT_DIPNAME( 0x03, 0x02, DEF_STR( Coin_A ) )
 	PORT_DIPSETTING(    0x03, DEF_STR( 2C_1C ) )
 	PORT_DIPSETTING(    0x02, DEF_STR( 1C_1C ) )
@@ -462,34 +463,34 @@ INPUT_PORTS_START( monymony )
 	PORT_DIPSETTING(    0x10, DEF_STR( 1C_5C ) )
 	PORT_DIPSETTING(    0x00, DEF_STR( 1C_7C ) )
 
-	PORT_START
-	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_JOYSTICK_LEFT | IPF_8WAY )
-	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_JOYSTICK_RIGHT | IPF_8WAY )
+	PORT_START_TAG("IN1")
+	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_JOYSTICK_LEFT ) PORT_8WAY
+	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_JOYSTICK_RIGHT ) PORT_8WAY
 	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_UNKNOWN )
 	PORT_BIT( 0x08, IP_ACTIVE_LOW, IPT_UNKNOWN )
 	PORT_BIT( 0x10, IP_ACTIVE_LOW, IPT_BUTTON1 )
-	PORT_BIT( 0x20, IP_ACTIVE_LOW, IPT_JOYSTICK_UP | IPF_8WAY )
-	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_JOYSTICK_DOWN | IPF_8WAY )
+	PORT_BIT( 0x20, IP_ACTIVE_LOW, IPT_JOYSTICK_UP ) PORT_8WAY
+	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_JOYSTICK_DOWN ) PORT_8WAY
 	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_UNKNOWN )
 
-	PORT_START
-	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_JOYSTICK_LEFT | IPF_8WAY | IPF_COCKTAIL )
-	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_JOYSTICK_RIGHT | IPF_8WAY | IPF_COCKTAIL )
+	PORT_START_TAG("IN2")
+	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_JOYSTICK_LEFT ) PORT_8WAY PORT_COCKTAIL
+	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_JOYSTICK_RIGHT ) PORT_8WAY PORT_COCKTAIL
 	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_UNKNOWN )
 	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_UNKNOWN )
-	PORT_BIT( 0x10, IP_ACTIVE_LOW, IPT_BUTTON1 | IPF_COCKTAIL )
-	PORT_BIT( 0x20, IP_ACTIVE_LOW, IPT_JOYSTICK_UP | IPF_8WAY | IPF_COCKTAIL )
-	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_JOYSTICK_DOWN | IPF_8WAY | IPF_COCKTAIL )
+	PORT_BIT( 0x10, IP_ACTIVE_LOW, IPT_BUTTON1 ) PORT_COCKTAIL
+	PORT_BIT( 0x20, IP_ACTIVE_LOW, IPT_JOYSTICK_UP ) PORT_8WAY PORT_COCKTAIL
+	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_JOYSTICK_DOWN ) PORT_8WAY PORT_COCKTAIL
 	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_UNKNOWN )
 
-	PORT_START
+	PORT_START_TAG("IN3")
 	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_START1 )
 	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_START2 )
 	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_TILT )
 	PORT_BIT( 0x08, IP_ACTIVE_LOW, IPT_UNKNOWN )
 	/* other bits are outputs */
 
-	PORT_START
+	PORT_START_TAG("IN4")
 	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_COIN1 )
 	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_COIN2 )
 	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_COIN3 )
@@ -498,13 +499,13 @@ INPUT_PORTS_START( monymony )
 INPUT_PORTS_END
 
 INPUT_PORTS_START( jackrabt )
-	PORT_START
+	PORT_START_TAG("IN0")
 	PORT_DIPNAME( 0x03, 0x01, DEF_STR( Lives ) )
 	PORT_DIPSETTING(    0x00, "2" )
 	PORT_DIPSETTING(    0x01, "3" )
 	PORT_DIPSETTING(    0x02, "4" )
 	PORT_DIPSETTING(    0x03, "5" )
-	PORT_BITX(    0x04, 0x00, IPT_DIPSWITCH_NAME | IPF_CHEAT, "Infinite Lives", IP_KEY_NONE, IP_JOY_NONE )
+	PORT_DIPNAME( 0x04, 0x00, "Infinite Lives (Cheat)")
 	PORT_DIPSETTING(    0x00, DEF_STR( Off ) )
 	PORT_DIPSETTING(    0x04, DEF_STR( On ) )
 	PORT_DIPNAME( 0x08, 0x00, DEF_STR( Unknown ) )
@@ -523,7 +524,7 @@ INPUT_PORTS_START( jackrabt )
 	PORT_DIPSETTING(    0x80, DEF_STR( Off ) )
 	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
 
-	PORT_START
+	PORT_START_TAG("DSW0")
 	PORT_DIPNAME( 0x01, 0x00, DEF_STR( Unknown ) )
 	PORT_DIPSETTING(    0x01, DEF_STR( Off ) )
 	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
@@ -547,7 +548,7 @@ INPUT_PORTS_START( jackrabt )
 	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
 	PORT_SERVICE( 0x80, IP_ACTIVE_HIGH )
 
-	PORT_START
+	PORT_START_TAG("DSW1")
 	PORT_DIPNAME( 0x03, 0x02, DEF_STR( Coin_A ) )
 	PORT_DIPSETTING(    0x03, DEF_STR( 2C_1C ) )
 	PORT_DIPSETTING(    0x02, DEF_STR( 1C_1C ) )
@@ -572,34 +573,34 @@ INPUT_PORTS_START( jackrabt )
 	PORT_DIPSETTING(    0x10, DEF_STR( 1C_5C ) )
 	PORT_DIPSETTING(    0x00, DEF_STR( 1C_7C ) )
 
-	PORT_START
-	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_JOYSTICK_LEFT | IPF_8WAY )
-	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_JOYSTICK_RIGHT | IPF_8WAY )
+	PORT_START_TAG("IN1")
+	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_JOYSTICK_LEFT ) PORT_8WAY
+	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_JOYSTICK_RIGHT ) PORT_8WAY
 	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_UNKNOWN )
 	PORT_BIT( 0x08, IP_ACTIVE_LOW, IPT_UNKNOWN )
 	PORT_BIT( 0x10, IP_ACTIVE_LOW, IPT_BUTTON1 )
-	PORT_BIT( 0x20, IP_ACTIVE_LOW, IPT_JOYSTICK_UP | IPF_8WAY )
-	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_JOYSTICK_DOWN | IPF_8WAY )
+	PORT_BIT( 0x20, IP_ACTIVE_LOW, IPT_JOYSTICK_UP ) PORT_8WAY
+	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_JOYSTICK_DOWN ) PORT_8WAY
 	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_UNKNOWN )
 
-	PORT_START
-	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_JOYSTICK_LEFT | IPF_8WAY | IPF_COCKTAIL )
-	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_JOYSTICK_RIGHT | IPF_8WAY | IPF_COCKTAIL )
+	PORT_START_TAG("IN2")
+	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_JOYSTICK_LEFT ) PORT_8WAY PORT_COCKTAIL
+	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_JOYSTICK_RIGHT ) PORT_8WAY PORT_COCKTAIL
 	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_UNKNOWN )
 	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_UNKNOWN )
-	PORT_BIT( 0x10, IP_ACTIVE_LOW, IPT_BUTTON1 | IPF_COCKTAIL )
-	PORT_BIT( 0x20, IP_ACTIVE_LOW, IPT_JOYSTICK_UP | IPF_8WAY | IPF_COCKTAIL )
-	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_JOYSTICK_DOWN | IPF_8WAY | IPF_COCKTAIL )
+	PORT_BIT( 0x10, IP_ACTIVE_LOW, IPT_BUTTON1 ) PORT_COCKTAIL
+	PORT_BIT( 0x20, IP_ACTIVE_LOW, IPT_JOYSTICK_UP ) PORT_8WAY PORT_COCKTAIL
+	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_JOYSTICK_DOWN ) PORT_8WAY PORT_COCKTAIL
 	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_UNKNOWN )
 
-	PORT_START
+	PORT_START_TAG("IN3")
 	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_START1 )
 	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_START2 )
 	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_TILT )
 	PORT_BIT( 0x08, IP_ACTIVE_LOW, IPT_UNKNOWN )
 	/* other bits are outputs */
 
-	PORT_START
+	PORT_START_TAG("IN4")
 	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_COIN1 )
 	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_COIN2 )
 	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_COIN3 )
@@ -609,7 +610,7 @@ INPUT_PORTS_END
 
 
 
-static struct GfxLayout charlayout =
+static const gfx_layout charlayout =
 {
 	8,8,
 	RGN_FRAC(1,3),
@@ -620,7 +621,7 @@ static struct GfxLayout charlayout =
 	8*8
 };
 
-static struct GfxLayout spritelayout =
+static const gfx_layout spritelayout =
 {
 	16,16,
 	RGN_FRAC(1,3),
@@ -633,7 +634,7 @@ static struct GfxLayout spritelayout =
 	32*8
 };
 
-static struct GfxDecodeInfo gfxdecodeinfo[] =
+static const gfx_decode gfxdecodeinfo[] =
 {
 	{ REGION_GFX1, 0, &charlayout,      0, 32 },
 	{ REGION_GFX1, 0, &spritelayout, 32*8, 32 },
@@ -643,87 +644,72 @@ static struct GfxDecodeInfo gfxdecodeinfo[] =
 
 struct AY8910interface ay8910_interface =
 {
-	2,	/* 2 chips */
-	3580000/2,
-	{ 15, 15 },
-	{ 0, 0 },
-	{ soundlatch2_r, 0 },
-	{ ay8910_port0a_w, 0 },
-	{ 0, 0 }
-};
-
-static struct DACinterface dac_interface =
-{
-	2,
-	{ 0,80 }	/* I'm leaving the first DAC(?) off because it sounds awful */
+	0,
+	soundlatch2_r,
+	ay8910_port0a_w,
+	0
 };
 
 static struct TMS5220interface tms5220_interface =
 {
-	640000,				/* clock speed (80*samplerate) */
-	80,					/* volume */
 	tms5220_irq_handler	/* IRQ handler */
 };
 
 
 
-static const struct MachineDriver machine_driver_zaccaria =
-{
+static MACHINE_DRIVER_START( zaccaria )
+
 	/* basic machine hardware */
-	{
-		{
-			CPU_Z80,
-			18432000/6,	/* 3.072 MHz */
-			readmem,writemem,0,0,
-			nmi_interrupt,1
-		},
-		{
-			CPU_M6802 | CPU_AUDIO_CPU,
-			3580000/4,	/* 895 kHz */
-			sound_readmem1,sound_writemem1,0,0,
-			ignore_interrupt,0,	/* IRQ and NMI triggered by the PIA */
-			zaccaria_cb1_toggle,3580000/4096
-		},
-		{
-			CPU_M6802 | CPU_AUDIO_CPU,
-			3580000/4,	/* 895 kHz */
-			sound_readmem2,sound_writemem2,0,0,
-			ignore_interrupt,0	/* IRQ triggered by the main CPU */
-		}
-	},
-	60, DEFAULT_60HZ_VBLANK_DURATION,   /* frames per second, vblank duration */
-	1,  /* 1 CPU slice per frame - interleaving is forced when a sound command is written */
-	zaccaria_init_machine,
+	MDRV_CPU_ADD(Z80,18432000/6)	/* 3.072 MHz */
+	MDRV_CPU_PROGRAM_MAP(readmem,writemem)
+	MDRV_CPU_VBLANK_INT(nmi_line_pulse,1)
+
+	MDRV_CPU_ADD(M6802,3580000/4)
+	/* audio CPU */	/* 895 kHz */
+	MDRV_CPU_PROGRAM_MAP(sound_readmem1,sound_writemem1)
+	MDRV_CPU_PERIODIC_INT(zaccaria_cb1_toggle,TIME_IN_HZ(3580000/4096))
+
+	MDRV_CPU_ADD(M6802,3580000/4)
+	/* audio CPU */	/* 895 kHz */
+	MDRV_CPU_PROGRAM_MAP(sound_readmem2,sound_writemem2)
+
+	MDRV_FRAMES_PER_SECOND(60)
+	MDRV_VBLANK_DURATION(DEFAULT_60HZ_VBLANK_DURATION)
+
+	MDRV_MACHINE_INIT(zaccaria)
 
 	/* video hardware */
-	32*8, 32*8, { 0*8, 32*8-1, 2*8, 30*8-1 },
-	gfxdecodeinfo,
-	512, 32*8+32*8,
-	zaccaria_vh_convert_color_prom,
+	MDRV_VIDEO_ATTRIBUTES(VIDEO_TYPE_RASTER)
+	MDRV_SCREEN_SIZE(32*8, 32*8)
+	MDRV_VISIBLE_AREA(0*8, 32*8-1, 2*8, 30*8-1)
+	MDRV_GFXDECODE(gfxdecodeinfo)
+	MDRV_PALETTE_LENGTH(512)
+	MDRV_COLORTABLE_LENGTH(32*8+32*8)
 
-	VIDEO_TYPE_RASTER,
-	0,
-	zaccaria_vh_start,
-	0,
-	zaccaria_vh_screenrefresh,
+	MDRV_PALETTE_INIT(zaccaria)
+	MDRV_VIDEO_START(zaccaria)
+	MDRV_VIDEO_UPDATE(zaccaria)
 
 	/* sound hardware */
-	0,0,0,0,
-	{
-		{
-			SOUND_AY8910,
-			&ay8910_interface
-		},
-		{
-			SOUND_DAC,
-			&dac_interface
-		},
-		{
-			SOUND_TMS5220,
-			&tms5220_interface
-		}
-	}
-};
+	MDRV_SPEAKER_STANDARD_MONO("mono")
+
+	MDRV_SOUND_ADD(AY8910, 3580000/2)
+	MDRV_SOUND_CONFIG(ay8910_interface)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.15)
+
+	MDRV_SOUND_ADD(AY8910, 3580000/2)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.15)
+
+	MDRV_SOUND_ADD(DAC, 0)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.0)		/* first DAC sounds awful */
+
+	MDRV_SOUND_ADD(DAC, 0)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.80)
+
+	MDRV_SOUND_ADD(TMS5220, 640000)
+	MDRV_SOUND_CONFIG(tms5220_interface)
+	MDRV_SOUND_ROUTE(ALL_OUTPUTS, "mono", 0.80)
+MACHINE_DRIVER_END
 
 
 
@@ -735,147 +721,147 @@ static const struct MachineDriver machine_driver_zaccaria =
 
 ROM_START( monymony )
 	ROM_REGION( 0x10000, REGION_CPU1, 0 )     /* 64k for code */
-	ROM_LOAD( "1a",           0x0000, 0x1000, 0x13c227ca )
+	ROM_LOAD( "cpu1.1a",           0x0000, 0x1000, CRC(13c227ca) SHA1(be305d112917904dd130b08f6b5186e3fbcb858a) )
 	ROM_CONTINUE(             0x8000, 0x1000 )
-	ROM_LOAD( "1b",           0x1000, 0x1000, 0x87372545 )
+	ROM_LOAD( "cpu2.1b",           0x1000, 0x1000, CRC(87372545) SHA1(04618d007a93b3f6706f56b10bdf39727d7d748d) )
 	ROM_CONTINUE(             0x9000, 0x1000 )
-	ROM_LOAD( "1c",           0x2000, 0x1000, 0x6aea9c01 )
+	ROM_LOAD( "cpu3.1c",           0x2000, 0x1000, CRC(6aea9c01) SHA1(36a57f4dfae52d674dcf55d2b93dbacf734866b1) )
 	ROM_CONTINUE(             0xa000, 0x1000 )
-	ROM_LOAD( "1d",           0x3000, 0x1000, 0x5fdec451 )
+	ROM_LOAD( "cpu4.1d",           0x3000, 0x1000, CRC(5fdec451) SHA1(0f955c907e0a61a725a951018fdf5cc321139863) )
 	ROM_CONTINUE(             0xb000, 0x1000 )
-	ROM_LOAD( "2a",           0x4000, 0x1000, 0xaf830e3c )
+	ROM_LOAD( "cpu5.2a",           0x4000, 0x1000, CRC(af830e3c) SHA1(bed57c341ae3500f147efe31bcf01f81466ec1c0) )
 	ROM_CONTINUE(             0xc000, 0x1000 )
-	ROM_LOAD( "2c",           0x5000, 0x1000, 0x31da62b1 )
+	ROM_LOAD( "cpu6.2c",           0x5000, 0x1000, CRC(31da62b1) SHA1(486f07087244f8537510afacb64ddd59eb512a4d) )
 	ROM_CONTINUE(             0xd000, 0x1000 )
 
 	ROM_REGION( 0x10000, REGION_CPU2, 0 ) /* 64k for first 6802 */
-	ROM_LOAD( "2g",           0xa000, 0x2000, 0x78b01b98 )
-	ROM_LOAD( "1i",           0xe000, 0x2000, 0x94e3858b )
+	ROM_LOAD( "snd13.2g",           0xa000, 0x2000, CRC(78b01b98) SHA1(2aabed56cdae9463deb513c0c5021f6c8dfd271e) )
+	ROM_LOAD( "snd9.1i",           0xe000, 0x2000, CRC(94e3858b) SHA1(04961f67b95798b530bd83355dec612389f22255) )
 
 	ROM_REGION( 0x10000, REGION_CPU3, 0 ) /* 64k for second 6802 */
-	ROM_LOAD( "1h",           0xa000, 0x1000, 0xaad76193 )
+	ROM_LOAD( "snd8.1h",           0xa000, 0x1000, CRC(aad76193) SHA1(e08fc184efced392ee902c4cc9daaaf3310cdfe2) )
 	ROM_CONTINUE(             0xe000, 0x1000 )
-	ROM_LOAD( "1g",           0xb000, 0x1000, 0x1e8ffe3e )
+	ROM_LOAD( "snd7.1g",           0xb000, 0x1000, CRC(1e8ffe3e) SHA1(858ee7abe88d5801237e519cae2b50ae4bf33a58) )
 	ROM_CONTINUE(             0xf000, 0x1000 )
 
 	ROM_REGION( 0x6000, REGION_GFX1, ROMREGION_DISPOSE )
-	ROM_LOAD( "2d",           0x0000, 0x2000, 0x82ab4d1a )
-	ROM_LOAD( "1f",           0x2000, 0x2000, 0x40d4e4d1 )
-	ROM_LOAD( "1e",           0x4000, 0x2000, 0x36980455 )
+	ROM_LOAD( "bg1.2d",           0x0000, 0x2000, CRC(82ab4d1a) SHA1(5aaf42a508df236f2e7c844d377132d73053907b) )
+	ROM_LOAD( "bg2.1f",           0x2000, 0x2000, CRC(40d4e4d1) SHA1(79cbade30f1c9269e70ddb9c4332cfe1e8dc50a9) )
+	ROM_LOAD( "bg3.1e",           0x4000, 0x2000, CRC(36980455) SHA1(4140b0cd4137c8f209124b12d9c0eb3b04f91991) )
 
 	ROM_REGION( 0x0400, REGION_PROMS, 0 )
-	ROM_LOAD( "monymony.9g",  0x0000, 0x0200, 0xfc9a0f21 )
-	ROM_LOAD( "monymony.9f",  0x0200, 0x0200, 0x93106704 )
+	ROM_LOAD( "9g",  0x0000, 0x0200, CRC(fc9a0f21) SHA1(2a93d684645ee1b70315386127223151582ab370) )
+	ROM_LOAD( "9f",  0x0200, 0x0200, CRC(93106704) SHA1(d3b8281c87d253a2ed40ff400438e879ca40c2b7) )
 ROM_END
 
 ROM_START( jackrabt )
 	ROM_REGION( 0x10000, REGION_CPU1, 0 )     /* 64k for code */
-	ROM_LOAD( "cpu-01.1a",    0x0000, 0x1000, 0x499efe97 )
+	ROM_LOAD( "cpu-01.1a",    0x0000, 0x1000, CRC(499efe97) SHA1(f0efc910a5343001b27637779e1d4de218d44a4e) )
 	ROM_CONTINUE(             0x8000, 0x1000 )
-	ROM_LOAD( "cpu-01.2l",    0x1000, 0x1000, 0x4772e557 )
-	ROM_LOAD( "cpu-01.3l",    0x2000, 0x1000, 0x1e844228 )
-	ROM_LOAD( "cpu-01.4l",    0x3000, 0x1000, 0xebffcc38 )
-	ROM_LOAD( "cpu-01.5l",    0x4000, 0x1000, 0x275e0ed6 )
-	ROM_LOAD( "cpu-01.6l",    0x5000, 0x1000, 0x8a20977a )
-	ROM_LOAD( "cpu-01.2h",    0x9000, 0x1000, 0x21f2be2a )
-	ROM_LOAD( "cpu-01.3h",    0xa000, 0x1000, 0x59077027 )
-	ROM_LOAD( "cpu-01.4h",    0xb000, 0x1000, 0x0b9db007 )
-	ROM_LOAD( "cpu-01.5h",    0xc000, 0x1000, 0x785e1a01 )
-	ROM_LOAD( "cpu-01.6h",    0xd000, 0x1000, 0xdd5979cf )
+	ROM_LOAD( "cpu-01.2l",    0x1000, 0x1000, CRC(4772e557) SHA1(71c1eb49c978799294e732e65a77eba330d8da9b) )
+	ROM_LOAD( "cpu-01.3l",    0x2000, 0x1000, CRC(1e844228) SHA1(0525fe95a0f90c50b54c0bf618eb083ccf20e6c4) )
+	ROM_LOAD( "cpu-01.4l",    0x3000, 0x1000, CRC(ebffcc38) SHA1(abaf0e96d92f9c828a95446af6d5301053416f3d) )
+	ROM_LOAD( "cpu-01.5l",    0x4000, 0x1000, CRC(275e0ed6) SHA1(c0789007a4de1aa848b7e5d26cf9fe847cc5d8a4) )
+	ROM_LOAD( "cpu-01.6l",    0x5000, 0x1000, CRC(8a20977a) SHA1(ba15f4c62f600372390e56c2067b4a8ab1f2dba9) )
+	ROM_LOAD( "cpu-01.2h",    0x9000, 0x1000, CRC(21f2be2a) SHA1(7d10489ca7325eebfa309ae4ffd4962a4310c403) )
+	ROM_LOAD( "cpu-01.3h",    0xa000, 0x1000, CRC(59077027) SHA1(d6c2e68b4b2f1dce8a2141ec259812e732c1c69c) )
+	ROM_LOAD( "cpu-01.4h",    0xb000, 0x1000, CRC(0b9db007) SHA1(836f8cacf2a097fd80d5c045bdc49b3a3174b89e) )
+	ROM_LOAD( "cpu-01.5h",    0xc000, 0x1000, CRC(785e1a01) SHA1(a748d300be9455cad4f912e01c2279bb8465edfe) )
+	ROM_LOAD( "cpu-01.6h",    0xd000, 0x1000, CRC(dd5979cf) SHA1(e9afe7002b2258a1c3132bdd951c6e20d473fb6a) )
 
 	ROM_REGION( 0x10000, REGION_CPU2, 0 ) /* 64k for first 6802 */
-	ROM_LOAD( "13snd.2g",     0xa000, 0x2000, 0xfc05654e )
-	ROM_LOAD( "9snd.1i",      0xe000, 0x2000, 0x3dab977f )
+	ROM_LOAD( "13snd.2g",     0xa000, 0x2000, CRC(fc05654e) SHA1(ed9c66672fe89c41e320e1d27b53f5efa92dce9c) )
+	ROM_LOAD( "9snd.1i",      0xe000, 0x2000, CRC(3dab977f) SHA1(3e79c06d2e70b050f01b7ac58be5127ba87904b0) )
 
 	ROM_REGION( 0x10000, REGION_CPU3, 0 ) /* 64k for second 6802 */
-	ROM_LOAD( "8snd.1h",      0xa000, 0x1000, 0xf4507111 )
+	ROM_LOAD( "8snd.1h",      0xa000, 0x1000, CRC(f4507111) SHA1(0513f0831b94aeda84aa4f3b4a7c60dfc5113b2d) )
 	ROM_CONTINUE(             0xe000, 0x1000 )
-	ROM_LOAD( "7snd.1g",      0xb000, 0x1000, 0xc722eff8 )
+	ROM_LOAD( "7snd.1g",      0xb000, 0x1000, CRC(c722eff8) SHA1(d8d1c091ab80ea2d6616e4dc030adc9905c0a496) )
 	ROM_CONTINUE(             0xf000, 0x1000 )
 
 	ROM_REGION( 0x6000, REGION_GFX1, ROMREGION_DISPOSE )
-	ROM_LOAD( "1bg.2d",       0x0000, 0x2000, 0x9f880ef5 )
-	ROM_LOAD( "2bg.1f",       0x2000, 0x2000, 0xafc04cd7 )
-	ROM_LOAD( "3bg.1e",       0x4000, 0x2000, 0x14f23cdd )
+	ROM_LOAD( "1bg.2d",       0x0000, 0x2000, CRC(9f880ef5) SHA1(0ee20fb7c794f6dafdaf2c9ee8456221c9d668c5) )
+	ROM_LOAD( "2bg.1f",       0x2000, 0x2000, CRC(afc04cd7) SHA1(f4349e86b9caee71c9bf9faf68b86603417d9a2b) )
+	ROM_LOAD( "3bg.1e",       0x4000, 0x2000, CRC(14f23cdd) SHA1(e5f3dac52288c56f2fd2940b397bb6c896131a26) )
 
 	ROM_REGION( 0x0400, REGION_PROMS, 0 )
-	ROM_LOAD( "jr-ic9g",      0x0000, 0x0200, 0x85577107 )
-	ROM_LOAD( "jr-ic9f",      0x0200, 0x0200, 0x085914d1 )
+	ROM_LOAD( "jr-ic9g",      0x0000, 0x0200, CRC(85577107) SHA1(76575fa68b66130b18dfe7374d1a03740963cc73) )
+	ROM_LOAD( "jr-ic9f",      0x0200, 0x0200, CRC(085914d1) SHA1(3d6f9318f5a9f08ce89e4184e3efb9881f671fa7) )
 ROM_END
 
 ROM_START( jackrab2 )
 	ROM_REGION( 0x10000, REGION_CPU1, 0 )     /* 64k for code */
-	ROM_LOAD( "1cpu2.1a",     0x0000, 0x1000, 0xf9374113 )
+	ROM_LOAD( "1cpu2.1a",     0x0000, 0x1000, CRC(f9374113) SHA1(521f293f1894bcaf21e44bc7841a20ae29232da3) )
 	ROM_CONTINUE(             0x8000, 0x1000 )
-	ROM_LOAD( "2cpu2.1b",     0x1000, 0x1000, 0x0a0eea4a )
+	ROM_LOAD( "2cpu2.1b",     0x1000, 0x1000, CRC(0a0eea4a) SHA1(4dfd9b2511d480bb5cc918f7d91013205911d377) )
 	ROM_CONTINUE(             0x9000, 0x1000 )
-	ROM_LOAD( "3cpu2.1c",     0x2000, 0x1000, 0x291f5772 )
+	ROM_LOAD( "3cpu2.1c",     0x2000, 0x1000, CRC(291f5772) SHA1(958c2601d43de3c95ed5e3d79737199703263a6a) )
 	ROM_CONTINUE(             0xa000, 0x1000 )
-	ROM_LOAD( "4cpu2.1d",     0x3000, 0x1000, 0x10972cfb )
+	ROM_LOAD( "4cpu2.1d",     0x3000, 0x1000, CRC(10972cfb) SHA1(30dd473b3416ee37f887d930ba0017b5b694398e) )
 	ROM_CONTINUE(             0xb000, 0x1000 )
-	ROM_LOAD( "5cpu2.2a",     0x4000, 0x1000, 0xaa95d06d )
+	ROM_LOAD( "5cpu2.2a",     0x4000, 0x1000, CRC(aa95d06d) SHA1(2216effe6cacd02a5320e71a85842087dda5f85a) )
 	ROM_CONTINUE(             0xc000, 0x1000 )
-	ROM_LOAD( "6cpu2.2c",     0x5000, 0x1000, 0x404496eb )
+	ROM_LOAD( "6cpu2.2c",     0x5000, 0x1000, CRC(404496eb) SHA1(44381e27e540fe9d8cacab4c3b1fe9a4f20d26a8) )
 	ROM_CONTINUE(             0xd000, 0x1000 )
 
 	ROM_REGION( 0x10000, REGION_CPU2, 0 ) /* 64k for first 6802 */
-	ROM_LOAD( "13snd.2g",     0xa000, 0x2000, 0xfc05654e )
-	ROM_LOAD( "9snd.1i",      0xe000, 0x2000, 0x3dab977f )
+	ROM_LOAD( "13snd.2g",     0xa000, 0x2000, CRC(fc05654e) SHA1(ed9c66672fe89c41e320e1d27b53f5efa92dce9c) )
+	ROM_LOAD( "9snd.1i",      0xe000, 0x2000, CRC(3dab977f) SHA1(3e79c06d2e70b050f01b7ac58be5127ba87904b0) )
 
 	ROM_REGION( 0x10000, REGION_CPU3, 0 ) /* 64k for second 6802 */
-	ROM_LOAD( "8snd.1h",      0xa000, 0x1000, 0xf4507111 )
+	ROM_LOAD( "8snd.1h",      0xa000, 0x1000, CRC(f4507111) SHA1(0513f0831b94aeda84aa4f3b4a7c60dfc5113b2d) )
 	ROM_CONTINUE(             0xe000, 0x1000 )
-	ROM_LOAD( "7snd.1g",      0xb000, 0x1000, 0xc722eff8 )
+	ROM_LOAD( "7snd.1g",      0xb000, 0x1000, CRC(c722eff8) SHA1(d8d1c091ab80ea2d6616e4dc030adc9905c0a496) )
 	ROM_CONTINUE(             0xf000, 0x1000 )
 
 	ROM_REGION( 0x6000, REGION_GFX1, ROMREGION_DISPOSE )
-	ROM_LOAD( "1bg.2d",       0x0000, 0x2000, 0x9f880ef5 )
-	ROM_LOAD( "2bg.1f",       0x2000, 0x2000, 0xafc04cd7 )
-	ROM_LOAD( "3bg.1e",       0x4000, 0x2000, 0x14f23cdd )
+	ROM_LOAD( "1bg.2d",       0x0000, 0x2000, CRC(9f880ef5) SHA1(0ee20fb7c794f6dafdaf2c9ee8456221c9d668c5) )
+	ROM_LOAD( "2bg.1f",       0x2000, 0x2000, CRC(afc04cd7) SHA1(f4349e86b9caee71c9bf9faf68b86603417d9a2b) )
+	ROM_LOAD( "3bg.1e",       0x4000, 0x2000, CRC(14f23cdd) SHA1(e5f3dac52288c56f2fd2940b397bb6c896131a26) )
 
 	ROM_REGION( 0x0400, REGION_PROMS, 0 )
-	ROM_LOAD( "jr-ic9g",      0x0000, 0x0200, 0x85577107 )
-	ROM_LOAD( "jr-ic9f",      0x0200, 0x0200, 0x085914d1 )
+	ROM_LOAD( "jr-ic9g",      0x0000, 0x0200, CRC(85577107) SHA1(76575fa68b66130b18dfe7374d1a03740963cc73) )
+	ROM_LOAD( "jr-ic9f",      0x0200, 0x0200, CRC(085914d1) SHA1(3d6f9318f5a9f08ce89e4184e3efb9881f671fa7) )
 ROM_END
 
 ROM_START( jackrabs )
 	ROM_REGION( 0x10000, REGION_CPU1, 0 )     /* 64k for code */
-	ROM_LOAD( "1cpu.1a",      0x0000, 0x1000, 0x6698dc65 )
+	ROM_LOAD( "1cpu.1a",      0x0000, 0x1000, CRC(6698dc65) SHA1(33e3518846e88dc34f4b6c4e9ca9f8999c0460c8) )
 	ROM_CONTINUE(             0x8000, 0x1000 )
-	ROM_LOAD( "2cpu.1b",      0x1000, 0x1000, 0x42b32929 )
+	ROM_LOAD( "2cpu.1b",      0x1000, 0x1000, CRC(42b32929) SHA1(5b400d434ce903c74f58780a422a8c2594af90be) )
 	ROM_CONTINUE(             0x9000, 0x1000 )
-	ROM_LOAD( "3cpu.1c",      0x2000, 0x1000, 0x89b50c9a )
+	ROM_LOAD( "3cpu.1c",      0x2000, 0x1000, CRC(89b50c9a) SHA1(5ab56247de013b5196c1c5765ead4361a5df53e0) )
 	ROM_CONTINUE(             0xa000, 0x1000 )
-	ROM_LOAD( "4cpu.1d",      0x3000, 0x1000, 0xd5520665 )
+	ROM_LOAD( "4cpu.1d",      0x3000, 0x1000, CRC(d5520665) SHA1(69b34d87d50e6d6e8d365ba0479405380ba3cf11) )
 	ROM_CONTINUE(             0xb000, 0x1000 )
-	ROM_LOAD( "5cpu.2a",      0x4000, 0x1000, 0x0f9a093c )
+	ROM_LOAD( "5cpu.2a",      0x4000, 0x1000, CRC(0f9a093c) SHA1(7fba0d2b8d5d4d1597decec96ed93b997c721d99) )
 	ROM_CONTINUE(             0xc000, 0x1000 )
-	ROM_LOAD( "6cpu.2c",      0x5000, 0x1000, 0xf53d6356 )
+	ROM_LOAD( "6cpu.2c",      0x5000, 0x1000, CRC(f53d6356) SHA1(9b167edca59cf81a2468368a372bab132f15e2ea) )
 	ROM_CONTINUE(             0xd000, 0x1000 )
 
 	ROM_REGION( 0x10000, REGION_CPU2, 0 ) /* 64k for first 6802 */
-	ROM_LOAD( "13snd.2g",     0xa000, 0x2000, 0xfc05654e )
-	ROM_LOAD( "9snd.1i",      0xe000, 0x2000, 0x3dab977f )
+	ROM_LOAD( "13snd.2g",     0xa000, 0x2000, CRC(fc05654e) SHA1(ed9c66672fe89c41e320e1d27b53f5efa92dce9c) )
+	ROM_LOAD( "9snd.1i",      0xe000, 0x2000, CRC(3dab977f) SHA1(3e79c06d2e70b050f01b7ac58be5127ba87904b0) )
 
 	ROM_REGION( 0x10000, REGION_CPU3, 0 ) /* 64k for second 6802 */
-	ROM_LOAD( "8snd.1h",      0xa000, 0x1000, 0xf4507111 )
+	ROM_LOAD( "8snd.1h",      0xa000, 0x1000, CRC(f4507111) SHA1(0513f0831b94aeda84aa4f3b4a7c60dfc5113b2d) )
 	ROM_CONTINUE(             0xe000, 0x1000 )
-	ROM_LOAD( "7snd.1g",      0xb000, 0x1000, 0xc722eff8 )
+	ROM_LOAD( "7snd.1g",      0xb000, 0x1000, CRC(c722eff8) SHA1(d8d1c091ab80ea2d6616e4dc030adc9905c0a496) )
 	ROM_CONTINUE(             0xf000, 0x1000 )
 
 	ROM_REGION( 0x6000, REGION_GFX1, ROMREGION_DISPOSE )
-	ROM_LOAD( "1bg.2d",       0x0000, 0x2000, 0x9f880ef5 )
-	ROM_LOAD( "2bg.1f",       0x2000, 0x2000, 0xafc04cd7 )
-	ROM_LOAD( "3bg.1e",       0x4000, 0x2000, 0x14f23cdd )
+	ROM_LOAD( "1bg.2d",       0x0000, 0x2000, CRC(9f880ef5) SHA1(0ee20fb7c794f6dafdaf2c9ee8456221c9d668c5) )
+	ROM_LOAD( "2bg.1f",       0x2000, 0x2000, CRC(afc04cd7) SHA1(f4349e86b9caee71c9bf9faf68b86603417d9a2b) )
+	ROM_LOAD( "3bg.1e",       0x4000, 0x2000, CRC(14f23cdd) SHA1(e5f3dac52288c56f2fd2940b397bb6c896131a26) )
 
 	ROM_REGION( 0x0400, REGION_PROMS, 0 )
-	ROM_LOAD( "jr-ic9g",      0x0000, 0x0200, 0x85577107 )
-	ROM_LOAD( "jr-ic9f",      0x0200, 0x0200, 0x085914d1 )
+	ROM_LOAD( "jr-ic9g",      0x0000, 0x0200, CRC(85577107) SHA1(76575fa68b66130b18dfe7374d1a03740963cc73) )
+	ROM_LOAD( "jr-ic9f",      0x0200, 0x0200, CRC(085914d1) SHA1(3d6f9318f5a9f08ce89e4184e3efb9881f671fa7) )
 ROM_END
 
 
 
-GAMEX( 1983, monymony, 0,        zaccaria, monymony, 0, ROT90, "Zaccaria", "Money Money", GAME_IMPERFECT_SOUND )
-GAMEX( 1984, jackrabt, 0,        zaccaria, jackrabt, 0, ROT90, "Zaccaria", "Jack Rabbit (set 1)", GAME_IMPERFECT_SOUND )
-GAMEX( 1984, jackrab2, jackrabt, zaccaria, jackrabt, 0, ROT90, "Zaccaria", "Jack Rabbit (set 2)", GAME_IMPERFECT_SOUND )
-GAMEX( 1984, jackrabs, jackrabt, zaccaria, jackrabt, 0, ROT90, "Zaccaria", "Jack Rabbit (special)", GAME_IMPERFECT_SOUND )
+GAME( 1983, monymony, 0,        zaccaria, monymony, 0, ROT90, "Zaccaria", "Money Money", GAME_IMPERFECT_SOUND )
+GAME( 1984, jackrabt, 0,        zaccaria, jackrabt, 0, ROT90, "Zaccaria", "Jack Rabbit (set 1)", GAME_IMPERFECT_SOUND )
+GAME( 1984, jackrab2, jackrabt, zaccaria, jackrabt, 0, ROT90, "Zaccaria", "Jack Rabbit (set 2)", GAME_IMPERFECT_SOUND )
+GAME( 1984, jackrabs, jackrabt, zaccaria, jackrabt, 0, ROT90, "Zaccaria", "Jack Rabbit (special)", GAME_IMPERFECT_SOUND )
