@@ -15,7 +15,9 @@ extern enum namcos22_gametype
 	NAMCOS22_RIDGE_RACER2,
 	NAMCOS22_TIME_CRISIS,
 	NAMCOS22_VICTORY_LAP,
-	NAMCOS22_ACE_DRIVER
+	NAMCOS22_ACE_DRIVER,
+	NAMCOS22_ALPINE_RACER_2,
+	NAMCOS22_ALPINE_SURFER
 } namcos22_gametype;
 
 #define NAMCOS22_NUM_ROWS 30
