@@ -1,3 +1,11 @@
+/***************************************************************************
+
+    info.c
+
+    Dumps the MAME internal data as an XML file.
+
+***************************************************************************/
+
 #include <ctype.h>
 
 #include "driver.h"
@@ -17,6 +25,11 @@
 #define XML_TOP "game"
 #endif
 
+#ifdef MESS
+void print_game_device(FILE* out, const game_driver* game);
+void print_game_ramoptions(FILE* out, const game_driver* game);
+#endif /* MESS */
+
 extern game_driver driver_0;
 
 /* Print a free format string */
@@ -77,7 +90,7 @@ static void print_game_switch(FILE* out, const game_driver* game)
 
 	begin_resource_tracking();
 
-	input = input_port_allocate(game->construct_ipt);
+	input = input_port_allocate(game->construct_ipt, NULL);
 
 	while (input->type != IPT_END)
 	{
@@ -125,7 +138,7 @@ static void print_game_input(FILE* out, const game_driver* game)
 
 	begin_resource_tracking();
 
-	input = input_port_allocate(game->construct_ipt);
+	input = input_port_allocate(game->construct_ipt, NULL);
 
 	while (input->type != IPT_END)
 	{
@@ -470,8 +483,6 @@ static void print_game_rom(FILE* out, const game_driver* game)
 		{
 			if (ROMREGION_GETFLAGS(region) & ROMREGION_DISPOSE)
 				fprintf(out, " dispose=\"yes\"");
-			if (ROMREGION_GETFLAGS(region) & ROMREGION_SOUNDONLY)
-				fprintf(out, " soundonly=\"yes\"");
 
 			fprintf(out, " offset=\"%x\"", offset);
 			fprintf(out, "/>\n");
@@ -752,43 +763,6 @@ static void print_game_driver(FILE* out, const game_driver* game)
 	fprintf(out, "/>\n");
 }
 
-#ifdef MESS
-static void print_game_device(FILE* out, const game_driver* game)
-{
-	const struct IODevice* dev;
-
-	begin_resource_tracking();
-
-	dev = devices_allocate(game);
-	if (dev)
-	{
-		while(dev->type < IO_COUNT)
-		{
-		fprintf(out, "\t\t<device");
-		fprintf(out, " name=\"%s\"", normalize_string(device_typename(dev->type)));
-		fprintf(out, ">\n");
-
-		if (dev->file_extensions) {
-			const char* ext = dev->file_extensions;
-			while (*ext) {
-				fprintf(out, "\t\t\t<extension");
-				fprintf(out, " name=\"%s\"", normalize_string(ext));
-				fprintf(out, "/>\n");
-				ext += strlen(ext) + 1;
-			}
-		}
-
-		fprintf(out, "\t\t</device>\n");
-
-			dev++;
-		}
-	}
-	end_resource_tracking();
-}
-#endif /* MESS */
-
-
-
 /* Print the MAME info record for a game */
 static void print_game_info(FILE* out, const game_driver* game)
 {
@@ -836,6 +810,7 @@ static void print_game_info(FILE* out, const game_driver* game)
 	print_game_driver(out, game);
 #ifdef MESS
 	print_game_device(out, game);
+	print_game_ramoptions(out, game);
 #endif
 
 	fprintf(out, "\t</" XML_TOP ">\n");
@@ -941,6 +916,7 @@ void print_mame_xml(FILE* out, const game_driver* games[])
 		"<?xml version=\"1.0\"?>\n"
 		"<!DOCTYPE " XML_ROOT " [\n"
 		"<!ELEMENT " XML_ROOT " (" XML_TOP "+)>\n"
+		"\t<!ATTLIST " XML_ROOT " build CDATA #IMPLIED>\n"
 #ifdef MESS
 		"\t<!ELEMENT " XML_TOP " (description, year?, manufacturer, history?, biosset*, rom*, disk*, sample*, chip*, video?, sound?, input?, dipswitch*, driver?, device*)>\n"
 #else
@@ -972,7 +948,6 @@ void print_mame_xml(FILE* out, const game_driver* games[])
 		"\t\t\t<!ATTLIST rom offset CDATA #IMPLIED>\n"
 		"\t\t\t<!ATTLIST rom status (baddump|nodump|good) \"good\">\n"
 		"\t\t\t<!ATTLIST rom dispose (yes|no) \"no\">\n"
-		"\t\t\t<!ATTLIST rom soundonly (yes|no) \"no\">\n"
 		"\t\t<!ELEMENT disk EMPTY>\n"
 		"\t\t\t<!ATTLIST disk name CDATA #REQUIRED>\n"
 		"\t\t\t<!ATTLIST disk md5 CDATA #IMPLIED>\n"
@@ -986,7 +961,6 @@ void print_mame_xml(FILE* out, const game_driver* games[])
 		"\t\t<!ELEMENT chip EMPTY>\n"
 		"\t\t\t<!ATTLIST chip name CDATA #REQUIRED>\n"
 		"\t\t\t<!ATTLIST chip type (cpu|audio) #REQUIRED>\n"
-		"\t\t\t<!ATTLIST chip soundonly (yes|no) \"no\">\n"
 		"\t\t\t<!ATTLIST chip clock CDATA #IMPLIED>\n"
 		"\t\t<!ELEMENT video EMPTY>\n"
 		"\t\t\t<!ATTLIST video screen (raster|vector) #REQUIRED>\n"
@@ -1018,7 +992,8 @@ void print_mame_xml(FILE* out, const game_driver* games[])
 		"\t\t\t<!ATTLIST driver graphic (good|imperfect|preliminary) #REQUIRED>\n"
 		"\t\t\t<!ATTLIST driver cocktail (good|imperfect|preliminary) #IMPLIED>\n"
 		"\t\t\t<!ATTLIST driver protection (good|imperfect|preliminary) #IMPLIED>\n"
-		"\t\t\t<!ATTLIST driver palettesize CDATA #REQUIRED>\n"
+		"\t\t\t<!ATTLIST driver savestate (supported|unsupported) #REQUIRED>\n"
+ 		"\t\t\t<!ATTLIST driver palettesize CDATA #REQUIRED>\n"
 #ifdef MESS
 		"\t\t<!ELEMENT device (extension*)>\n"
 		"\t\t\t<!ATTLIST device name CDATA #REQUIRED>\n"
@@ -1026,7 +1001,8 @@ void print_mame_xml(FILE* out, const game_driver* games[])
 		"\t\t\t\t<!ATTLIST extension name CDATA #REQUIRED>\n"
 #endif
 		"]>\n\n"
-		"<" XML_ROOT ">\n"
+		"<" XML_ROOT " build=\"%s\">\n",
+		normalize_string(build_version)
 	);
 
 	print_mame_data(out, games);
