@@ -1,9 +1,9 @@
 /**********************************************************************
 
-	Motorola 6821 PIA interface and emulation
+    Motorola 6821 PIA interface and emulation
 
-	This function emulates all the functionality of up to 8 M6821
-	peripheral interface adapters.
+    This function emulates all the functionality of up to 8 M6821
+    peripheral interface adapters.
 
 **********************************************************************/
 
@@ -50,6 +50,7 @@ struct pia6821
 	UINT8 irq_b1;
 	UINT8 irq_b2;
 	UINT8 irq_b_state;
+	UINT8 in_set; /* which input ports are set */
 };
 
 
@@ -77,8 +78,12 @@ struct pia6821
 #define C2_OUTPUT(c)			(c & 0x20)
 #define C2_INPUT(c)				(!(c & 0x20))
 
-
-
+#define PIA_IN_SET_A   0x01
+#define PIA_IN_SET_CA1 0x02
+#define PIA_IN_SET_CA2 0x04
+#define PIA_IN_SET_B   0x08
+#define PIA_IN_SET_CB1 0x10
+#define PIA_IN_SET_CB2 0x20
 
 /******************* static variables *******************/
 
@@ -88,72 +93,6 @@ static const UINT8 swizzle_address[4] = { 0, 2, 1, 3 };
 
 
 
-/******************* stave state *******************/
-
-static void update_6821_interrupts(struct pia6821 *p);
-/*
-static void pia_postload(int which)
-{
-	struct pia6821 *p = pia + which;
-	update_6821_interrupts(p);
-	if (p->intf->out_a_func && p->ddr_a) p->intf->out_a_func(0, p->out_a & p->ddr_a);
-	if (p->intf->out_b_func && p->ddr_b) p->intf->out_b_func(0, p->out_b & p->ddr_b);
-	if (p->intf->out_ca2_func) p->intf->out_ca2_func(0, p->out_ca2);
-	if (p->intf->out_cb2_func) p->intf->out_cb2_func(0, p->out_cb2);
-}
-
-static void pia_postload_0(void)
-{
-	pia_postload(0);
-}
-
-static void pia_postload_1(void)
-{
-	pia_postload(1);
-}
-
-static void pia_postload_2(void)
-{
-	pia_postload(2);
-}
-
-static void pia_postload_3(void)
-{
-	pia_postload(3);
-}
-
-static void pia_postload_4(void)
-{
-	pia_postload(4);
-}
-
-static void pia_postload_5(void)
-{
-	pia_postload(5);
-}
-
-static void pia_postload_6(void)
-{
-	pia_postload(6);
-}
-
-static void pia_postload_7(void)
-{
-	pia_postload(7);
-}
-
-static void (*pia_postload_funcs[MAX_PIA])(void) =
-{
-	pia_postload_0,
-	pia_postload_1,
-	pia_postload_2,
-	pia_postload_3,
-	pia_postload_4,
-	pia_postload_5,
-	pia_postload_6,
-	pia_postload_7
-};
-*/
 /******************* un-configuration *******************/
 
 void pia_unconfig(void)
@@ -166,29 +105,37 @@ void pia_unconfig(void)
 
 void pia_config(int which, int addressing, const struct pia6821_interface *intf)
 {
-	if (which >= MAX_PIA) return;
+	if (which >= MAX_PIA)
+		osd_die("pia_config called on an invalid PIA!");
+	if (!intf)
+		osd_die("pia_config called with an invalid interface!");
+
+	memset(&pia[which], 0, sizeof(pia[0]));
+
 	pia[which].intf = intf;
 	pia[which].addr = addressing;
-/*
-	state_save_register_UINT8("6821pia", which, "in_a",		&pia[which].in_a, 1);
-	state_save_register_UINT8("6821pia", which, "in_ca1",	&pia[which].in_ca1, 1);
-	state_save_register_UINT8("6821pia", which, "in_ca2",	&pia[which].in_ca2, 1);
-	state_save_register_UINT8("6821pia", which, "out_a",	&pia[which].out_a, 1);
-	state_save_register_UINT8("6821pia", which, "out_ca2",	&pia[which].out_ca2, 1);
-	state_save_register_UINT8("6821pia", which, "ddr_a",	&pia[which].ddr_a, 1);
-	state_save_register_UINT8("6821pia", which, "ctl_a",	&pia[which].ctl_a, 1);
-	state_save_register_UINT8("6821pia", which, "irq_a1",	&pia[which].irq_a1, 1);
-	state_save_register_UINT8("6821pia", which, "irq_a2",	&pia[which].irq_a2, 1);
-	state_save_register_UINT8("6821pia", which, "in_b",		&pia[which].in_b, 1);
-	state_save_register_UINT8("6821pia", which, "in_cb1",	&pia[which].in_cb1, 1);
-	state_save_register_UINT8("6821pia", which, "in_cb2",	&pia[which].in_cb2, 1);
-	state_save_register_UINT8("6821pia", which, "out_b",	&pia[which].out_b, 1);
-	state_save_register_UINT8("6821pia", which, "out_cb2",	&pia[which].out_cb2, 1);
-	state_save_register_UINT8("6821pia", which, "ddr_b",	&pia[which].ddr_b, 1);
-	state_save_register_UINT8("6821pia", which, "ctl_b",	&pia[which].ctl_b, 1);
-	state_save_register_UINT8("6821pia", which, "irq_b1",	&pia[which].irq_b1, 1);
-	state_save_register_UINT8("6821pia", which, "irq_b2",	&pia[which].irq_b2, 1);
-	state_save_register_func_postload(pia_postload_funcs[which]);*/
+
+	state_save_register_UINT8("6821pia", which, "in_a",			&pia[which].in_a, 1);
+	state_save_register_UINT8("6821pia", which, "in_ca1",		&pia[which].in_ca1, 1);
+	state_save_register_UINT8("6821pia", which, "in_ca2",		&pia[which].in_ca2, 1);
+	state_save_register_UINT8("6821pia", which, "out_a",		&pia[which].out_a, 1);
+	state_save_register_UINT8("6821pia", which, "out_ca2",		&pia[which].out_ca2, 1);
+	state_save_register_UINT8("6821pia", which, "ddr_a",		&pia[which].ddr_a, 1);
+	state_save_register_UINT8("6821pia", which, "ctl_a",		&pia[which].ctl_a, 1);
+	state_save_register_UINT8("6821pia", which, "irq_a1",		&pia[which].irq_a1, 1);
+	state_save_register_UINT8("6821pia", which, "irq_a2",		&pia[which].irq_a2, 1);
+	state_save_register_UINT8("6821pia", which, "irq_a_state", 	&pia[which].irq_a_state, 1);
+	state_save_register_UINT8("6821pia", which, "in_b",			&pia[which].in_b, 1);
+	state_save_register_UINT8("6821pia", which, "in_cb1",		&pia[which].in_cb1, 1);
+	state_save_register_UINT8("6821pia", which, "in_cb2",		&pia[which].in_cb2, 1);
+	state_save_register_UINT8("6821pia", which, "out_b",		&pia[which].out_b, 1);
+	state_save_register_UINT8("6821pia", which, "out_cb2",		&pia[which].out_cb2, 1);
+	state_save_register_UINT8("6821pia", which, "ddr_b",		&pia[which].ddr_b, 1);
+	state_save_register_UINT8("6821pia", which, "ctl_b",		&pia[which].ctl_b, 1);
+	state_save_register_UINT8("6821pia", which, "irq_b1",		&pia[which].irq_b1, 1);
+	state_save_register_UINT8("6821pia", which, "irq_b2",		&pia[which].irq_b2, 1);
+	state_save_register_UINT8("6821pia", which, "irq_b_state",	&pia[which].irq_b_state, 1);
+	state_save_register_UINT8("6821pia", which, "in_set",		&pia[which].in_set, 1);
 }
 
 
@@ -202,12 +149,50 @@ void pia_reset(void)
 	for (i = 0; i < MAX_PIA; i++)
 	{
 		const struct pia6821_interface *intf = pia[i].intf;
-		UINT8 addr = pia[i].addr;
+		int addressing = pia[i].addr;
 
 		memset(&pia[i], 0, sizeof(pia[i]));
 
 		pia[i].intf = intf;
-		pia[i].addr = addr;
+		pia[i].addr = addressing;
+
+		/* set default read values. */
+		/* Ports A,CA1,CA2 default to 1 */
+		/* Ports B,CB1,CB2 are three-state and undefined (set to 0) */
+		pia[i].in_a = pia[i].in_ca1 = pia[i].in_ca2 = 0xff;
+		if (intf)
+		{
+			if ((intf->in_a_func) && ((FPTR)(intf->in_a_func) <= 0x100))
+			{
+				pia[i].in_a = ((FPTR)(intf->in_a_func) - 1);
+				pia[i].in_set |= PIA_IN_SET_A;
+			}
+			if ((intf->in_b_func) && ((FPTR)(intf->in_b_func) <= 0x100))
+			{
+				pia[i].in_b = ((FPTR)(intf->in_b_func) - 1);
+				pia[i].in_set |= PIA_IN_SET_B;
+			}
+			if ((intf->in_ca1_func) && ((FPTR)(intf->in_ca1_func) <= 0x100))
+			{
+				pia[i].in_ca1 = ((FPTR)(intf->in_ca1_func) - 1);
+				pia[i].in_set |= PIA_IN_SET_CA1;
+			}
+			if ((intf->in_ca2_func) && ((FPTR)(intf->in_ca2_func) <= 0x100))
+			{
+				pia[i].in_ca2 = ((FPTR)(intf->in_ca2_func) - 1);
+				pia[i].in_set |= PIA_IN_SET_CA2;
+			}
+			if ((intf->in_cb1_func) && ((FPTR)(intf->in_cb1_func) <= 0x100))
+			{
+				pia[i].in_cb1 = ((FPTR)(intf->in_cb1_func) - 1);
+				pia[i].in_set |= PIA_IN_SET_CB1;
+			}
+			if ((intf->in_cb2_func) && ((FPTR)(intf->in_cb2_func) <= 0x100))
+			{
+				pia[i].in_cb2 = ((FPTR)(intf->in_cb2_func) - 1);
+				pia[i].in_set |= PIA_IN_SET_CB2;
+			}
+		}
 	}
 }
 
@@ -288,7 +273,15 @@ int pia_read(int which, int offset)
 			if (OUTPUT_SELECTED(p->ctl_a))
 			{
 				/* update the input */
-				if (p->intf->in_a_func) p->in_a = p->intf->in_a_func(0);
+				if ((FPTR)(p->intf->in_a_func) > 0x100)
+					p->in_a = p->intf->in_a_func(0);
+#ifdef MAME_DEBUG
+				else if ((p->ddr_a ^ 0xff) && !(p->in_set & PIA_IN_SET_A)) {
+					logerror("PIA%d: Warning! no port A read handler. Assuming pins %02x not connected\n",
+					         which, p->ddr_a ^ 0xff);
+					p->in_set |= PIA_IN_SET_A; /* disable logging */
+				}
+#endif /* MAME_DEBUG */
 
 				/* combine input and output values */
 				val = (p->out_a & p->ddr_a) + (p->in_a & ~p->ddr_a);
@@ -313,14 +306,14 @@ int pia_read(int which, int offset)
 					}
 				}
 
-				LOG(("%04x: PIA%d read port A = %02X\n", cpu_getpreviouspc(),  which, val));
+				LOG(("%04x: PIA%d read port A = %02X\n", activecpu_get_previouspc(),  which, val));
 			}
 
 			/* read DDR register */
 			else
 			{
 				val = p->ddr_a;
-				LOG(("%04x: PIA%d read DDR A = %02X\n", cpu_getpreviouspc(), which, val));
+				LOG(("%04x: PIA%d read DDR A = %02X\n", activecpu_get_previouspc(), which, val));
 			}
 			break;
 
@@ -331,23 +324,45 @@ int pia_read(int which, int offset)
 			if (OUTPUT_SELECTED(p->ctl_b))
 			{
 				/* update the input */
-				if (p->intf->in_b_func) p->in_b = p->intf->in_b_func(0);
+				if ((FPTR)(p->intf->in_b_func) > 0x100)
+					p->in_b = p->intf->in_b_func(0);
+#ifdef MAME_DEBUG
+				else if ((p->ddr_b ^ 0xff) && !(p->in_set & PIA_IN_SET_B)) {
+					logerror("PIA%d: Error! no port B read handler. Three-state pins %02x are undefined\n",
+					         which, p->ddr_b ^ 0xff);
+					p->in_set |= PIA_IN_SET_B; /* disable logging */
+				}
+#endif /* MAME_DEBUG */
 
 				/* combine input and output values */
 				val = (p->out_b & p->ddr_b) + (p->in_b & ~p->ddr_b);
 
+				/* This read will implicitly clear the IRQ B1 flag.  If CB2 is in write-strobe
+                   output mode with CB1 restore, and a CB1 active transition set the flag,
+                   clearing it will cause CB2 to go high again.  Note that this is different
+                   from what happens with port A. */
+				if (p->irq_b1 && C2_OUTPUT(p->ctl_b) && C2_STROBE_MODE(p->ctl_b) && STROBE_C1_RESET(p->ctl_b))
+				{
+					/* call the CB2 output function */
+					if (!p->out_cb2)
+						if (p->intf->out_cb2_func) p->intf->out_cb2_func(0, 1);
+
+					/* clear CB2 */
+					p->out_cb2 = 1;
+				}
+
 				/* IRQ flags implicitly cleared by a read */
 				p->irq_b1 = p->irq_b2 = 0;
 				update_6821_interrupts(p);
 
-				LOG(("%04x: PIA%d read port B = %02X\n", cpu_getpreviouspc(), which, val));
+				LOG(("%04x: PIA%d read port B = %02X\n", activecpu_get_previouspc(), which, val));
 			}
 
 			/* read DDR register */
 			else
 			{
 				val = p->ddr_b;
-				LOG(("%04x: PIA%d read DDR B = %02X\n", cpu_getpreviouspc(), which, val));
+				LOG(("%04x: PIA%d read DDR B = %02X\n", activecpu_get_previouspc(), which, val));
 			}
 			break;
 
@@ -355,8 +370,22 @@ int pia_read(int which, int offset)
 		case PIA_CTLA:
 
 			/* Update CA1 & CA2 if callback exists, these in turn may update IRQ's */
-			if (p->intf->in_ca1_func) pia_set_input_ca1(which, p->intf->in_ca1_func(0));
-			if (p->intf->in_ca2_func) pia_set_input_ca2(which, p->intf->in_ca2_func(0));
+			if ((FPTR)(p->intf->in_ca1_func) > 0x100)
+				pia_set_input_ca1(which, p->intf->in_ca1_func(0));
+#ifdef MAME_DEBUG
+			else if (!(p->in_set & PIA_IN_SET_CA1)) {
+				logerror("PIA%d: Warning! no CA1 read handler. Assuming pin not connected\n",which);
+				p->in_set |= PIA_IN_SET_CA1; /* disable logging */
+			}
+#endif /* MAME_DEBUG */
+			if ((FPTR)(p->intf->in_ca2_func) > 0x100)
+				pia_set_input_ca2(which, p->intf->in_ca2_func(0));
+#ifdef MAME_DEBUG
+			else if (C2_INPUT(p->ctl_a) && !(p->in_set & PIA_IN_SET_CA2)) {
+				logerror("PIA%d: Warning! no CA2 read handler. Assuming pin not connected\n",which);
+				p->in_set |= PIA_IN_SET_CA2; /* disable logging */
+			}
+#endif /* MAME_DEBUG */
 
 			/* read control register */
 			val = p->ctl_a;
@@ -365,15 +394,29 @@ int pia_read(int which, int offset)
 			if (p->irq_a1) val |= PIA_IRQ1;
 			if (p->irq_a2 && C2_INPUT(p->ctl_a)) val |= PIA_IRQ2;
 
-			LOG(("%04x: PIA%d read control A = %02X\n", cpu_getpreviouspc(), which, val));
+			LOG(("%04x: PIA%d read control A = %02X\n", activecpu_get_previouspc(), which, val));
 			break;
 
 		/******************* port B control read *******************/
 		case PIA_CTLB:
 
 			/* Update CB1 & CB2 if callback exists, these in turn may update IRQ's */
-			if (p->intf->in_cb1_func) pia_set_input_cb1(which, p->intf->in_cb1_func(0));
-			if (p->intf->in_cb2_func) pia_set_input_cb2(which, p->intf->in_cb2_func(0));
+			if ((FPTR)(p->intf->in_cb1_func) > 0x100)
+				pia_set_input_cb1(which, p->intf->in_cb1_func(0));
+#ifdef MAME_DEBUG
+			else if (!(p->in_set & PIA_IN_SET_CB1)) {
+				logerror("PIA%d: Error! no CB1 read handler. Three-state pin is undefined\n",which);
+				p->in_set |= PIA_IN_SET_CB1; /* disable logging */
+			}
+#endif /* MAME_DEBUG */
+			if ((FPTR)(p->intf->in_cb2_func) > 0x100)
+				pia_set_input_cb2(which, p->intf->in_cb2_func(0));
+#ifdef MAME_DEBUG
+			else if (C2_INPUT(p->ctl_b) && !(p->in_set & PIA_IN_SET_CB2)) {
+				logerror("PIA%d: Error! no CB2 read handler. Three-state pin is undefined\n",which);
+				p->in_set |= PIA_IN_SET_CB2; /* disable logging */
+			}
+#endif /* MAME_DEBUG */
 
 			/* read control register */
 			val = p->ctl_b;
@@ -382,7 +425,7 @@ int pia_read(int which, int offset)
 			if (p->irq_b1) val |= PIA_IRQ1;
 			if (p->irq_b2 && C2_INPUT(p->ctl_b)) val |= PIA_IRQ2;
 
-			LOG(("%04x: PIA%d read control B = %02X\n", cpu_getpreviouspc(), which, val));
+			LOG(("%04x: PIA%d read control B = %02X\n", activecpu_get_previouspc(), which, val));
 			break;
 	}
 
@@ -408,7 +451,7 @@ void pia_write(int which, int offset, int data)
 			/* write output register */
 			if (OUTPUT_SELECTED(p->ctl_a))
 			{
-				LOG(("%04x: PIA%d port A write = %02X\n", cpu_getpreviouspc(), which, data));
+				LOG(("%04x: PIA%d port A write = %02X\n", activecpu_get_previouspc(), which, data));
 
 				/* update the output value */
 				p->out_a = data;/* & p->ddr_a; */	/* NS990130 - don't mask now, DDR could change later */
@@ -420,7 +463,7 @@ void pia_write(int which, int offset, int data)
 			/* write DDR register */
 			else
 			{
-				LOG(("%04x: PIA%d DDR A write = %02X\n", cpu_getpreviouspc(), which, data));
+				LOG(("%04x: PIA%d DDR A write = %02X\n", activecpu_get_previouspc(), which, data));
 
 				if (p->ddr_a != data)
 				{
@@ -439,7 +482,7 @@ void pia_write(int which, int offset, int data)
 			/* write output register */
 			if (OUTPUT_SELECTED(p->ctl_b))
 			{
-				LOG(("%04x: PIA%d port B write = %02X\n", cpu_getpreviouspc(), which, data));
+				LOG(("%04x: PIA%d port B write = %02X\n", activecpu_get_previouspc(), which, data));
 
 				/* update the output value */
 				p->out_b = data;/* & p->ddr_b */	/* NS990130 - don't mask now, DDR could change later */
@@ -467,7 +510,7 @@ void pia_write(int which, int offset, int data)
 			/* write DDR register */
 			else
 			{
-				LOG(("%04x: PIA%d DDR B write = %02X\n", cpu_getpreviouspc(), which, data));
+				LOG(("%04x: PIA%d DDR B write = %02X\n", activecpu_get_previouspc(), which, data));
 
 				if (p->ddr_b != data)
 				{
@@ -488,18 +531,26 @@ void pia_write(int which, int offset, int data)
 			data &= 0x3f;
 
 
-			LOG(("%04x: PIA%d control A write = %02X\n", cpu_getpreviouspc(), which, data));
+			LOG(("%04x: PIA%d control A write = %02X\n", activecpu_get_previouspc(), which, data));
 
-			/* CA2 is configured as output and in set/reset mode */
-			/* 10/22/98 - MAB/FMP - any C2_OUTPUT should affect CA2 */
-/*			if (C2_OUTPUT(data) && C2_SET_MODE(data)) */
+			/* CA2 is configured as output */
 			if (C2_OUTPUT(data))
 			{
-				/* determine the new value */
-				int temp = SET_C2(data) ? 1 : 0;
+				int temp;
 
-				/* if this creates a transition, call the CA2 output function */
-				if (p->out_ca2 ^ temp)
+				if (C2_SET_MODE(data))
+				{
+					/* set/reset mode--bit value determines the new output */
+					temp = SET_C2(data) ? 1 : 0;
+				}
+				else {
+					/* strobe mode--output is always high unless strobed. */
+					temp = 1;
+				}
+
+				/* if we're going from input to output mode, or we're already in output mode
+                   and this change creates a transition, call the CA2 output function */
+				if (C2_INPUT(p->ctl_a) || (C2_OUTPUT(p->ctl_a) && (p->out_ca2 ^ temp)))
 					if (p->intf->out_ca2_func) p->intf->out_ca2_func(0, temp);
 
 				/* set the new value */
@@ -520,18 +571,26 @@ void pia_write(int which, int offset, int data)
 
 			data &= 0x3f;
 
-			LOG(("%04x: PIA%d control B write = %02X\n", cpu_getpreviouspc(), which, data));
+			LOG(("%04x: PIA%d control B write = %02X\n", activecpu_get_previouspc(), which, data));
 
-			/* CB2 is configured as output and in set/reset mode */
-			/* 10/22/98 - MAB/FMP - any C2_OUTPUT should affect CB2 */
-/*			if (C2_OUTPUT(data) && C2_SET_MODE(data)) */
+			/* CB2 is configured as output */
 			if (C2_OUTPUT(data))
 			{
-				/* determine the new value */
-				int temp = SET_C2(data) ? 1 : 0;
+				int temp;
 
-				/* if this creates a transition, call the CA2 output function */
-				if (p->out_cb2 ^ temp)
+				if (C2_SET_MODE(data))
+				{
+					/* set/reset mode--bit value determines the new output */
+					temp = SET_C2(data) ? 1 : 0;
+				}
+				else {
+					/* strobe mode--output is always high unless strobed. */
+					temp = 1;
+				}
+
+				/* if we're going from input to output mode, or we're already in output mode
+                   and this change creates a transition, call the CB2 output function */
+				if (C2_INPUT(p->ctl_b) || (C2_OUTPUT(p->ctl_b) && (p->out_cb2 ^ temp)))
 					if (p->intf->out_cb2_func) p->intf->out_cb2_func(0, temp);
 
 				/* set the new value */
@@ -556,6 +615,7 @@ void pia_set_input_a(int which, int data)
 
 	/* set the input, what could be easier? */
 	p->in_a = data;
+	p->in_set |= PIA_IN_SET_A;
 }
 
 
@@ -596,6 +656,7 @@ void pia_set_input_ca1(int which, int data)
 
 	/* set the new value for CA1 */
 	p->in_ca1 = data;
+	p->in_set |= PIA_IN_SET_CA1;
 }
 
 
@@ -629,6 +690,7 @@ void pia_set_input_ca2(int which, int data)
 
 	/* set the new value for CA2 */
 	p->in_ca2 = data;
+	p->in_set |= PIA_IN_SET_CA2;
 }
 
 
@@ -641,6 +703,7 @@ void pia_set_input_b(int which, int data)
 
 	/* set the input, what could be easier? */
 	p->in_b = data;
+    p->in_set |= PIA_IN_SET_B;
 }
 
 
@@ -666,25 +729,16 @@ void pia_set_input_cb1(int which, int data)
 			/* update externals */
 			update_6821_interrupts(p);
 
-			/* CB2 is configured as output and in write strobe mode and cleared by a CA1 transition */
-			if (C2_OUTPUT(p->ctl_b) && C2_STROBE_MODE(p->ctl_b) && STROBE_C1_RESET(p->ctl_b))
-			{
-				/* the IRQ1 flag must have also been cleared */
-				if (!p->irq_b1)
-				{
-					/* call the CB2 output function */
-					if (!p->out_cb2)
-						if (p->intf->out_cb2_func) p->intf->out_cb2_func(0, 1);
-
-					/* clear CB2 */
-					p->out_cb2 = 1;
-				}
-			}
+			/* If CB2 is configured as a write-strobe output which is reset by a CB1
+               transition, this reset will only happen when a read from port B implicitly
+               clears the IRQ B1 flag.  So we handle the CB2 reset there.  Note that this
+               is different from what happens with port A. */
 		}
 	}
 
 	/* set the new value for CB1 */
 	p->in_cb1 = data;
+	p->in_set |= PIA_IN_SET_CB1;
 }
 
 
@@ -718,29 +772,48 @@ void pia_set_input_cb2(int which, int data)
 
 	/* set the new value for CA2 */
 	p->in_cb2 = data;
+	p->in_set |= PIA_IN_SET_CB2;
+}
+
+
+
+/******************* interface retrieving DDR *******************/
+
+UINT8 pia_get_ddr_a(int which)
+{
+	struct pia6821 *p = pia + which;
+	return p->ddr_a;
+}
+
+
+
+UINT8 pia_get_ddr_b(int which)
+{
+	struct pia6821 *p = pia + which;
+	return p->ddr_b;
 }
 
 
 
 /******************* Standard 8-bit CPU interfaces, D0-D7 *******************/
 
-READ_HANDLER( pia_0_r ) { return pia_read(0, offset); }
-READ_HANDLER( pia_1_r ) { return pia_read(1, offset); }
-READ_HANDLER( pia_2_r ) { return pia_read(2, offset); }
-READ_HANDLER( pia_3_r ) { return pia_read(3, offset); }
-READ_HANDLER( pia_4_r ) { return pia_read(4, offset); }
-READ_HANDLER( pia_5_r ) { return pia_read(5, offset); }
-READ_HANDLER( pia_6_r ) { return pia_read(6, offset); }
-READ_HANDLER( pia_7_r ) { return pia_read(7, offset); }
+READ8_HANDLER( pia_0_r ) { return pia_read(0, offset); }
+READ8_HANDLER( pia_1_r ) { return pia_read(1, offset); }
+READ8_HANDLER( pia_2_r ) { return pia_read(2, offset); }
+READ8_HANDLER( pia_3_r ) { return pia_read(3, offset); }
+READ8_HANDLER( pia_4_r ) { return pia_read(4, offset); }
+READ8_HANDLER( pia_5_r ) { return pia_read(5, offset); }
+READ8_HANDLER( pia_6_r ) { return pia_read(6, offset); }
+READ8_HANDLER( pia_7_r ) { return pia_read(7, offset); }
 
-WRITE_HANDLER( pia_0_w ) { pia_write(0, offset, data); }
-WRITE_HANDLER( pia_1_w ) { pia_write(1, offset, data); }
-WRITE_HANDLER( pia_2_w ) { pia_write(2, offset, data); }
-WRITE_HANDLER( pia_3_w ) { pia_write(3, offset, data); }
-WRITE_HANDLER( pia_4_w ) { pia_write(4, offset, data); }
-WRITE_HANDLER( pia_5_w ) { pia_write(5, offset, data); }
-WRITE_HANDLER( pia_6_w ) { pia_write(6, offset, data); }
-WRITE_HANDLER( pia_7_w ) { pia_write(7, offset, data); }
+WRITE8_HANDLER( pia_0_w ) { pia_write(0, offset, data); }
+WRITE8_HANDLER( pia_1_w ) { pia_write(1, offset, data); }
+WRITE8_HANDLER( pia_2_w ) { pia_write(2, offset, data); }
+WRITE8_HANDLER( pia_3_w ) { pia_write(3, offset, data); }
+WRITE8_HANDLER( pia_4_w ) { pia_write(4, offset, data); }
+WRITE8_HANDLER( pia_5_w ) { pia_write(5, offset, data); }
+WRITE8_HANDLER( pia_6_w ) { pia_write(6, offset, data); }
+WRITE8_HANDLER( pia_7_w ) { pia_write(7, offset, data); }
 
 /******************* Standard 16-bit CPU interfaces, D0-D7 *******************/
 
@@ -784,108 +857,108 @@ WRITE16_HANDLER( pia_7_msb_w ) { if (ACCESSING_MSB) pia_write(7, offset, data >>
 
 /******************* 8-bit A/B port interfaces *******************/
 
-WRITE_HANDLER( pia_0_porta_w ) { pia_set_input_a(0, data); }
-WRITE_HANDLER( pia_1_porta_w ) { pia_set_input_a(1, data); }
-WRITE_HANDLER( pia_2_porta_w ) { pia_set_input_a(2, data); }
-WRITE_HANDLER( pia_3_porta_w ) { pia_set_input_a(3, data); }
-WRITE_HANDLER( pia_4_porta_w ) { pia_set_input_a(4, data); }
-WRITE_HANDLER( pia_5_porta_w ) { pia_set_input_a(5, data); }
-WRITE_HANDLER( pia_6_porta_w ) { pia_set_input_a(6, data); }
-WRITE_HANDLER( pia_7_porta_w ) { pia_set_input_a(7, data); }
+WRITE8_HANDLER( pia_0_porta_w ) { pia_set_input_a(0, data); }
+WRITE8_HANDLER( pia_1_porta_w ) { pia_set_input_a(1, data); }
+WRITE8_HANDLER( pia_2_porta_w ) { pia_set_input_a(2, data); }
+WRITE8_HANDLER( pia_3_porta_w ) { pia_set_input_a(3, data); }
+WRITE8_HANDLER( pia_4_porta_w ) { pia_set_input_a(4, data); }
+WRITE8_HANDLER( pia_5_porta_w ) { pia_set_input_a(5, data); }
+WRITE8_HANDLER( pia_6_porta_w ) { pia_set_input_a(6, data); }
+WRITE8_HANDLER( pia_7_porta_w ) { pia_set_input_a(7, data); }
 
-WRITE_HANDLER( pia_0_portb_w ) { pia_set_input_b(0, data); }
-WRITE_HANDLER( pia_1_portb_w ) { pia_set_input_b(1, data); }
-WRITE_HANDLER( pia_2_portb_w ) { pia_set_input_b(2, data); }
-WRITE_HANDLER( pia_3_portb_w ) { pia_set_input_b(3, data); }
-WRITE_HANDLER( pia_4_portb_w ) { pia_set_input_b(4, data); }
-WRITE_HANDLER( pia_5_portb_w ) { pia_set_input_b(5, data); }
-WRITE_HANDLER( pia_6_portb_w ) { pia_set_input_b(6, data); }
-WRITE_HANDLER( pia_7_portb_w ) { pia_set_input_b(7, data); }
+WRITE8_HANDLER( pia_0_portb_w ) { pia_set_input_b(0, data); }
+WRITE8_HANDLER( pia_1_portb_w ) { pia_set_input_b(1, data); }
+WRITE8_HANDLER( pia_2_portb_w ) { pia_set_input_b(2, data); }
+WRITE8_HANDLER( pia_3_portb_w ) { pia_set_input_b(3, data); }
+WRITE8_HANDLER( pia_4_portb_w ) { pia_set_input_b(4, data); }
+WRITE8_HANDLER( pia_5_portb_w ) { pia_set_input_b(5, data); }
+WRITE8_HANDLER( pia_6_portb_w ) { pia_set_input_b(6, data); }
+WRITE8_HANDLER( pia_7_portb_w ) { pia_set_input_b(7, data); }
 
-READ_HANDLER( pia_0_porta_r ) { return pia[0].in_a; }
-READ_HANDLER( pia_1_porta_r ) { return pia[1].in_a; }
-READ_HANDLER( pia_2_porta_r ) { return pia[2].in_a; }
-READ_HANDLER( pia_3_porta_r ) { return pia[3].in_a; }
-READ_HANDLER( pia_4_porta_r ) { return pia[4].in_a; }
-READ_HANDLER( pia_5_porta_r ) { return pia[5].in_a; }
-READ_HANDLER( pia_6_porta_r ) { return pia[6].in_a; }
-READ_HANDLER( pia_7_porta_r ) { return pia[7].in_a; }
+READ8_HANDLER( pia_0_porta_r ) { return pia[0].in_a; }
+READ8_HANDLER( pia_1_porta_r ) { return pia[1].in_a; }
+READ8_HANDLER( pia_2_porta_r ) { return pia[2].in_a; }
+READ8_HANDLER( pia_3_porta_r ) { return pia[3].in_a; }
+READ8_HANDLER( pia_4_porta_r ) { return pia[4].in_a; }
+READ8_HANDLER( pia_5_porta_r ) { return pia[5].in_a; }
+READ8_HANDLER( pia_6_porta_r ) { return pia[6].in_a; }
+READ8_HANDLER( pia_7_porta_r ) { return pia[7].in_a; }
 
-READ_HANDLER( pia_0_portb_r ) { return pia[0].in_b; }
-READ_HANDLER( pia_1_portb_r ) { return pia[1].in_b; }
-READ_HANDLER( pia_2_portb_r ) { return pia[2].in_b; }
-READ_HANDLER( pia_3_portb_r ) { return pia[3].in_b; }
-READ_HANDLER( pia_4_portb_r ) { return pia[4].in_b; }
-READ_HANDLER( pia_5_portb_r ) { return pia[5].in_b; }
-READ_HANDLER( pia_6_portb_r ) { return pia[6].in_b; }
-READ_HANDLER( pia_7_portb_r ) { return pia[7].in_b; }
+READ8_HANDLER( pia_0_portb_r ) { return pia[0].in_b; }
+READ8_HANDLER( pia_1_portb_r ) { return pia[1].in_b; }
+READ8_HANDLER( pia_2_portb_r ) { return pia[2].in_b; }
+READ8_HANDLER( pia_3_portb_r ) { return pia[3].in_b; }
+READ8_HANDLER( pia_4_portb_r ) { return pia[4].in_b; }
+READ8_HANDLER( pia_5_portb_r ) { return pia[5].in_b; }
+READ8_HANDLER( pia_6_portb_r ) { return pia[6].in_b; }
+READ8_HANDLER( pia_7_portb_r ) { return pia[7].in_b; }
 
 /******************* 1-bit CA1/CA2/CB1/CB2 port interfaces *******************/
 
-WRITE_HANDLER( pia_0_ca1_w ) { pia_set_input_ca1(0, data); }
-WRITE_HANDLER( pia_1_ca1_w ) { pia_set_input_ca1(1, data); }
-WRITE_HANDLER( pia_2_ca1_w ) { pia_set_input_ca1(2, data); }
-WRITE_HANDLER( pia_3_ca1_w ) { pia_set_input_ca1(3, data); }
-WRITE_HANDLER( pia_4_ca1_w ) { pia_set_input_ca1(4, data); }
-WRITE_HANDLER( pia_5_ca1_w ) { pia_set_input_ca1(5, data); }
-WRITE_HANDLER( pia_6_ca1_w ) { pia_set_input_ca1(6, data); }
-WRITE_HANDLER( pia_7_ca1_w ) { pia_set_input_ca1(7, data); }
-WRITE_HANDLER( pia_0_ca2_w ) { pia_set_input_ca2(0, data); }
-WRITE_HANDLER( pia_1_ca2_w ) { pia_set_input_ca2(1, data); }
-WRITE_HANDLER( pia_2_ca2_w ) { pia_set_input_ca2(2, data); }
-WRITE_HANDLER( pia_3_ca2_w ) { pia_set_input_ca2(3, data); }
-WRITE_HANDLER( pia_4_ca2_w ) { pia_set_input_ca2(4, data); }
-WRITE_HANDLER( pia_5_ca2_w ) { pia_set_input_ca2(5, data); }
-WRITE_HANDLER( pia_6_ca2_w ) { pia_set_input_ca2(6, data); }
-WRITE_HANDLER( pia_7_ca2_w ) { pia_set_input_ca2(7, data); }
+WRITE8_HANDLER( pia_0_ca1_w ) { pia_set_input_ca1(0, data); }
+WRITE8_HANDLER( pia_1_ca1_w ) { pia_set_input_ca1(1, data); }
+WRITE8_HANDLER( pia_2_ca1_w ) { pia_set_input_ca1(2, data); }
+WRITE8_HANDLER( pia_3_ca1_w ) { pia_set_input_ca1(3, data); }
+WRITE8_HANDLER( pia_4_ca1_w ) { pia_set_input_ca1(4, data); }
+WRITE8_HANDLER( pia_5_ca1_w ) { pia_set_input_ca1(5, data); }
+WRITE8_HANDLER( pia_6_ca1_w ) { pia_set_input_ca1(6, data); }
+WRITE8_HANDLER( pia_7_ca1_w ) { pia_set_input_ca1(7, data); }
+WRITE8_HANDLER( pia_0_ca2_w ) { pia_set_input_ca2(0, data); }
+WRITE8_HANDLER( pia_1_ca2_w ) { pia_set_input_ca2(1, data); }
+WRITE8_HANDLER( pia_2_ca2_w ) { pia_set_input_ca2(2, data); }
+WRITE8_HANDLER( pia_3_ca2_w ) { pia_set_input_ca2(3, data); }
+WRITE8_HANDLER( pia_4_ca2_w ) { pia_set_input_ca2(4, data); }
+WRITE8_HANDLER( pia_5_ca2_w ) { pia_set_input_ca2(5, data); }
+WRITE8_HANDLER( pia_6_ca2_w ) { pia_set_input_ca2(6, data); }
+WRITE8_HANDLER( pia_7_ca2_w ) { pia_set_input_ca2(7, data); }
 
-WRITE_HANDLER( pia_0_cb1_w ) { pia_set_input_cb1(0, data); }
-WRITE_HANDLER( pia_1_cb1_w ) { pia_set_input_cb1(1, data); }
-WRITE_HANDLER( pia_2_cb1_w ) { pia_set_input_cb1(2, data); }
-WRITE_HANDLER( pia_3_cb1_w ) { pia_set_input_cb1(3, data); }
-WRITE_HANDLER( pia_4_cb1_w ) { pia_set_input_cb1(4, data); }
-WRITE_HANDLER( pia_5_cb1_w ) { pia_set_input_cb1(5, data); }
-WRITE_HANDLER( pia_6_cb1_w ) { pia_set_input_cb1(6, data); }
-WRITE_HANDLER( pia_7_cb1_w ) { pia_set_input_cb1(7, data); }
-WRITE_HANDLER( pia_0_cb2_w ) { pia_set_input_cb2(0, data); }
-WRITE_HANDLER( pia_1_cb2_w ) { pia_set_input_cb2(1, data); }
-WRITE_HANDLER( pia_2_cb2_w ) { pia_set_input_cb2(2, data); }
-WRITE_HANDLER( pia_3_cb2_w ) { pia_set_input_cb2(3, data); }
-WRITE_HANDLER( pia_4_cb2_w ) { pia_set_input_cb2(4, data); }
-WRITE_HANDLER( pia_5_cb2_w ) { pia_set_input_cb2(5, data); }
-WRITE_HANDLER( pia_6_cb2_w ) { pia_set_input_cb2(6, data); }
-WRITE_HANDLER( pia_7_cb2_w ) { pia_set_input_cb2(7, data); }
+WRITE8_HANDLER( pia_0_cb1_w ) { pia_set_input_cb1(0, data); }
+WRITE8_HANDLER( pia_1_cb1_w ) { pia_set_input_cb1(1, data); }
+WRITE8_HANDLER( pia_2_cb1_w ) { pia_set_input_cb1(2, data); }
+WRITE8_HANDLER( pia_3_cb1_w ) { pia_set_input_cb1(3, data); }
+WRITE8_HANDLER( pia_4_cb1_w ) { pia_set_input_cb1(4, data); }
+WRITE8_HANDLER( pia_5_cb1_w ) { pia_set_input_cb1(5, data); }
+WRITE8_HANDLER( pia_6_cb1_w ) { pia_set_input_cb1(6, data); }
+WRITE8_HANDLER( pia_7_cb1_w ) { pia_set_input_cb1(7, data); }
+WRITE8_HANDLER( pia_0_cb2_w ) { pia_set_input_cb2(0, data); }
+WRITE8_HANDLER( pia_1_cb2_w ) { pia_set_input_cb2(1, data); }
+WRITE8_HANDLER( pia_2_cb2_w ) { pia_set_input_cb2(2, data); }
+WRITE8_HANDLER( pia_3_cb2_w ) { pia_set_input_cb2(3, data); }
+WRITE8_HANDLER( pia_4_cb2_w ) { pia_set_input_cb2(4, data); }
+WRITE8_HANDLER( pia_5_cb2_w ) { pia_set_input_cb2(5, data); }
+WRITE8_HANDLER( pia_6_cb2_w ) { pia_set_input_cb2(6, data); }
+WRITE8_HANDLER( pia_7_cb2_w ) { pia_set_input_cb2(7, data); }
 
-READ_HANDLER( pia_0_ca1_r ) { return pia[0].in_ca1; }
-READ_HANDLER( pia_1_ca1_r ) { return pia[1].in_ca1; }
-READ_HANDLER( pia_2_ca1_r ) { return pia[2].in_ca1; }
-READ_HANDLER( pia_3_ca1_r ) { return pia[3].in_ca1; }
-READ_HANDLER( pia_4_ca1_r ) { return pia[4].in_ca1; }
-READ_HANDLER( pia_5_ca1_r ) { return pia[5].in_ca1; }
-READ_HANDLER( pia_6_ca1_r ) { return pia[6].in_ca1; }
-READ_HANDLER( pia_7_ca1_r ) { return pia[7].in_ca1; }
-READ_HANDLER( pia_0_ca2_r ) { return pia[0].in_ca2; }
-READ_HANDLER( pia_1_ca2_r ) { return pia[1].in_ca2; }
-READ_HANDLER( pia_2_ca2_r ) { return pia[2].in_ca2; }
-READ_HANDLER( pia_3_ca2_r ) { return pia[3].in_ca2; }
-READ_HANDLER( pia_4_ca2_r ) { return pia[4].in_ca2; }
-READ_HANDLER( pia_5_ca2_r ) { return pia[5].in_ca2; }
-READ_HANDLER( pia_6_ca2_r ) { return pia[6].in_ca2; }
-READ_HANDLER( pia_7_ca2_r ) { return pia[7].in_ca2; }
+READ8_HANDLER( pia_0_ca1_r ) { return pia[0].in_ca1; }
+READ8_HANDLER( pia_1_ca1_r ) { return pia[1].in_ca1; }
+READ8_HANDLER( pia_2_ca1_r ) { return pia[2].in_ca1; }
+READ8_HANDLER( pia_3_ca1_r ) { return pia[3].in_ca1; }
+READ8_HANDLER( pia_4_ca1_r ) { return pia[4].in_ca1; }
+READ8_HANDLER( pia_5_ca1_r ) { return pia[5].in_ca1; }
+READ8_HANDLER( pia_6_ca1_r ) { return pia[6].in_ca1; }
+READ8_HANDLER( pia_7_ca1_r ) { return pia[7].in_ca1; }
+READ8_HANDLER( pia_0_ca2_r ) { return pia[0].in_ca2; }
+READ8_HANDLER( pia_1_ca2_r ) { return pia[1].in_ca2; }
+READ8_HANDLER( pia_2_ca2_r ) { return pia[2].in_ca2; }
+READ8_HANDLER( pia_3_ca2_r ) { return pia[3].in_ca2; }
+READ8_HANDLER( pia_4_ca2_r ) { return pia[4].in_ca2; }
+READ8_HANDLER( pia_5_ca2_r ) { return pia[5].in_ca2; }
+READ8_HANDLER( pia_6_ca2_r ) { return pia[6].in_ca2; }
+READ8_HANDLER( pia_7_ca2_r ) { return pia[7].in_ca2; }
 
-READ_HANDLER( pia_0_cb1_r ) { return pia[0].in_cb1; }
-READ_HANDLER( pia_1_cb1_r ) { return pia[1].in_cb1; }
-READ_HANDLER( pia_2_cb1_r ) { return pia[2].in_cb1; }
-READ_HANDLER( pia_3_cb1_r ) { return pia[3].in_cb1; }
-READ_HANDLER( pia_4_cb1_r ) { return pia[4].in_cb1; }
-READ_HANDLER( pia_5_cb1_r ) { return pia[5].in_cb1; }
-READ_HANDLER( pia_6_cb1_r ) { return pia[6].in_cb1; }
-READ_HANDLER( pia_7_cb1_r ) { return pia[7].in_cb1; }
-READ_HANDLER( pia_0_cb2_r ) { return pia[0].in_cb2; }
-READ_HANDLER( pia_1_cb2_r ) { return pia[1].in_cb2; }
-READ_HANDLER( pia_2_cb2_r ) { return pia[2].in_cb2; }
-READ_HANDLER( pia_3_cb2_r ) { return pia[3].in_cb2; }
-READ_HANDLER( pia_4_cb2_r ) { return pia[4].in_cb2; }
-READ_HANDLER( pia_5_cb2_r ) { return pia[5].in_cb2; }
-READ_HANDLER( pia_6_cb2_r ) { return pia[6].in_cb2; }
-READ_HANDLER( pia_7_cb2_r ) { return pia[7].in_cb2; }
+READ8_HANDLER( pia_0_cb1_r ) { return pia[0].in_cb1; }
+READ8_HANDLER( pia_1_cb1_r ) { return pia[1].in_cb1; }
+READ8_HANDLER( pia_2_cb1_r ) { return pia[2].in_cb1; }
+READ8_HANDLER( pia_3_cb1_r ) { return pia[3].in_cb1; }
+READ8_HANDLER( pia_4_cb1_r ) { return pia[4].in_cb1; }
+READ8_HANDLER( pia_5_cb1_r ) { return pia[5].in_cb1; }
+READ8_HANDLER( pia_6_cb1_r ) { return pia[6].in_cb1; }
+READ8_HANDLER( pia_7_cb1_r ) { return pia[7].in_cb1; }
+READ8_HANDLER( pia_0_cb2_r ) { return pia[0].in_cb2; }
+READ8_HANDLER( pia_1_cb2_r ) { return pia[1].in_cb2; }
+READ8_HANDLER( pia_2_cb2_r ) { return pia[2].in_cb2; }
+READ8_HANDLER( pia_3_cb2_r ) { return pia[3].in_cb2; }
+READ8_HANDLER( pia_4_cb2_r ) { return pia[4].in_cb2; }
+READ8_HANDLER( pia_5_cb2_r ) { return pia[5].in_cb2; }
+READ8_HANDLER( pia_6_cb2_r ) { return pia[6].in_cb2; }
+READ8_HANDLER( pia_7_cb2_r ) { return pia[7].in_cb2; }
