@@ -2,8 +2,8 @@
 #include "vidhrdw/generic.h"
 
 
-static unsigned char *cbasebal_textram,*cbasebal_scrollram;
-static struct tilemap *fg_tilemap,*bg_tilemap;
+static UINT8 *cbasebal_textram,*cbasebal_scrollram;
+static tilemap *fg_tilemap,*bg_tilemap;
 static int tilebank,spritebank;
 static int text_on,bg_on,obj_on;
 static int flipscreen;
@@ -18,7 +18,7 @@ static int flipscreen;
 
 static void get_bg_tile_info(int tile_index)
 {
-	unsigned char attr = cbasebal_scrollram[2*tile_index+1];
+	UINT8 attr = cbasebal_scrollram[2*tile_index+1];
 	SET_TILE_INFO(
 			1,
 			cbasebal_scrollram[2*tile_index] + ((attr & 0x07) << 8) + 0x800 * tilebank,
@@ -28,7 +28,7 @@ static void get_bg_tile_info(int tile_index)
 
 static void get_fg_tile_info(int tile_index)
 {
-	unsigned char attr = cbasebal_textram[tile_index+0x800];
+	UINT8 attr = cbasebal_textram[tile_index+0x800];
 	SET_TILE_INFO(
 			0,
 			cbasebal_textram[tile_index] + ((attr & 0xf0) << 4),
@@ -44,35 +44,18 @@ static void get_fg_tile_info(int tile_index)
 
 ***************************************************************************/
 
-void cbasebal_vh_stop(void)
+VIDEO_START( cbasebal )
 {
-	free(cbasebal_textram);
-	cbasebal_textram = 0;
-	free(cbasebal_scrollram);
-	cbasebal_scrollram = 0;
-}
-
-int cbasebal_vh_start(void)
-{
-	cbasebal_textram = malloc(0x1000);
-	cbasebal_scrollram = malloc(0x1000);
+	cbasebal_textram = auto_malloc(0x1000);
+	cbasebal_scrollram = auto_malloc(0x1000);
 
 	bg_tilemap = tilemap_create(get_bg_tile_info,tilemap_scan_rows,TILEMAP_OPAQUE,   16,16,64,32);
 	fg_tilemap = tilemap_create(get_fg_tile_info,tilemap_scan_rows,TILEMAP_TRANSPARENT,8,8,64,32);
 
 	if (!cbasebal_textram || !cbasebal_scrollram || !bg_tilemap || !fg_tilemap)
-	{
-		cbasebal_vh_stop();
 		return 1;
-	}
 
 	tilemap_set_transparent_pen(fg_tilemap,3);
-
-#define COLORTABLE_START(gfxn,color_code) Machine->drv->gfxdecodeinfo[gfxn].color_codes_start + \
-				color_code * Machine->gfx[gfxn]->color_granularity
-#define GFX_COLOR_CODES(gfxn) Machine->gfx[gfxn]->total_colors
-#define GFX_ELEM_COLORS(gfxn) Machine->gfx[gfxn]->color_granularity
-
 	return 0;
 }
 
@@ -84,35 +67,29 @@ int cbasebal_vh_start(void)
 
 ***************************************************************************/
 
-WRITE_HANDLER( cbasebal_textram_w )
+WRITE8_HANDLER( cbasebal_textram_w )
 {
-	if (cbasebal_textram[offset] != data)
-	{
-		cbasebal_textram[offset] = data;
-		tilemap_mark_tile_dirty(fg_tilemap,offset & 0x7ff);
-	}
+	cbasebal_textram[offset] = data;
+	tilemap_mark_tile_dirty(fg_tilemap,offset & 0x7ff);
 }
 
-READ_HANDLER( cbasebal_textram_r )
+READ8_HANDLER( cbasebal_textram_r )
 {
 	return cbasebal_textram[offset];
 }
 
-WRITE_HANDLER( cbasebal_scrollram_w )
+WRITE8_HANDLER( cbasebal_scrollram_w )
 {
-	if (cbasebal_scrollram[offset] != data)
-	{
-		cbasebal_scrollram[offset] = data;
-		tilemap_mark_tile_dirty(bg_tilemap,offset/2);
-	}
+	cbasebal_scrollram[offset] = data;
+	tilemap_mark_tile_dirty(bg_tilemap,offset/2);
 }
 
-READ_HANDLER( cbasebal_scrollram_r )
+READ8_HANDLER( cbasebal_scrollram_r )
 {
 	return cbasebal_scrollram[offset];
 }
 
-WRITE_HANDLER( cbasebal_gfxctrl_w )
+WRITE8_HANDLER( cbasebal_gfxctrl_w )
 {
 	/* bit 0 is unknown - toggles continuously */
 
@@ -142,17 +119,17 @@ WRITE_HANDLER( cbasebal_gfxctrl_w )
 	/* other bits unknown, but used */
 }
 
-WRITE_HANDLER( cbasebal_scrollx_w )
+WRITE8_HANDLER( cbasebal_scrollx_w )
 {
-	static unsigned char scroll[2];
+	static UINT8 scroll[2];
 
 	scroll[offset] = data;
 	tilemap_set_scrollx(bg_tilemap,0,scroll[0] + 256 * scroll[1]);
 }
 
-WRITE_HANDLER( cbasebal_scrolly_w )
+WRITE8_HANDLER( cbasebal_scrolly_w )
 {
-	static unsigned char scroll[2];
+	static UINT8 scroll[2];
 
 	scroll[offset] = data;
 	tilemap_set_scrolly(bg_tilemap,0,scroll[0] + 256 * scroll[1]);
@@ -166,7 +143,7 @@ WRITE_HANDLER( cbasebal_scrolly_w )
 
 ***************************************************************************/
 
-static void draw_sprites(struct mame_bitmap *bitmap)
+static void draw_sprites(mame_bitmap *bitmap, const rectangle *cliprect)
 {
 	int offs,sx,sy;
 
@@ -195,20 +172,20 @@ static void draw_sprites(struct mame_bitmap *bitmap)
 				color,
 				flipx,flipscreen,
 				sx,sy,
-				&Machine->visible_area,TRANSPARENCY_PEN,15);
+				cliprect,TRANSPARENCY_PEN,15);
 	}
 }
 
-void cbasebal_vh_screenrefresh(struct mame_bitmap *bitmap,int full_refresh)
+VIDEO_UPDATE( cbasebal )
 {
 	if (bg_on)
-		tilemap_draw(bitmap,bg_tilemap,0,0);
+		tilemap_draw(bitmap,cliprect,bg_tilemap,0,0);
 	else
-		fillbitmap(bitmap,Machine->pens[768],&Machine->visible_area);
+		fillbitmap(bitmap,Machine->pens[768],cliprect);
 
 	if (obj_on)
-		draw_sprites(bitmap);
+		draw_sprites(bitmap,cliprect);
 
 	if (text_on)
-		tilemap_draw(bitmap,fg_tilemap,0,0);
+		tilemap_draw(bitmap,cliprect,fg_tilemap,0,0);
 }
