@@ -1,6 +1,6 @@
 /***********************************************************************
 
-	DECO Cassette System vidhrdw
+    DECO Cassette System vidhrdw
 
  ***********************************************************************/
 
@@ -22,12 +22,12 @@ static int part_v_shift;
 static int center_h_shift_space;
 static int center_v_shift;
 
-unsigned char *decocass_charram;
-unsigned char *decocass_fgvideoram;
-unsigned char *decocass_colorram;
-unsigned char *decocass_bgvideoram; /* shares bits D0-3 with tileram! */
-unsigned char *decocass_tileram;
-unsigned char *decocass_objectram;
+UINT8 *decocass_charram;
+UINT8 *decocass_fgvideoram;
+UINT8 *decocass_colorram;
+UINT8 *decocass_bgvideoram; /* shares bits D0-3 with tileram! */
+UINT8 *decocass_tileram;
+UINT8 *decocass_objectram;
 
 size_t decocass_fgvideoram_size;
 size_t decocass_colorram_size;
@@ -35,13 +35,16 @@ size_t decocass_bgvideoram_size;
 size_t decocass_tileram_size;
 size_t decocass_objectram_size;
 
-static struct tilemap *fg_tilemap, *bg_tilemap_l, *bg_tilemap_r;
+static tilemap *fg_tilemap, *bg_tilemap_l, *bg_tilemap_r;
 
 static char *sprite_dirty;
 static char *char_dirty;
 static char *tile_dirty;
 static char object_dirty;
 
+static rectangle bg_tilemap_l_clip;
+static rectangle bg_tilemap_r_clip;
+
 static UINT32 tile_offset[32*32] = {
 	0x078,0x079,0x07a,0x07b,0x07c,0x07d,0x07e,0x07f,0x0ff,0x0fe,0x0fd,0x0fc,0x0fb,0x0fa,0x0f9,0x0f8,0x278,0x279,0x27a,0x27b,0x27c,0x27d,0x27e,0x27f,0x2ff,0x2fe,0x2fd,0x2fc,0x2fb,0x2fa,0x2f9,0x2f8,
 	0x070,0x071,0x072,0x073,0x074,0x075,0x076,0x077,0x0f7,0x0f6,0x0f5,0x0f4,0x0f3,0x0f2,0x0f1,0x0f0,0x270,0x271,0x272,0x273,0x274,0x275,0x276,0x277,0x2f7,0x2f6,0x2f5,0x2f4,0x2f3,0x2f2,0x2f1,0x2f0,
@@ -78,7 +81,26 @@ static UINT32 tile_offset[32*32] = {
 };
 
 /********************************************
-	tilemap callbacks
+    state saving setup
+ ********************************************/
+void decocass_video_state_save_init(void)
+{
+	state_save_register_int("decocass", 0, "watchdog_count", &watchdog_count);
+	state_save_register_int("decocass", 0, "watchdog_flip", &watchdog_flip);
+	state_save_register_int("decocass", 0, "color_missiles", &color_missiles);
+	state_save_register_int("decocass", 0, "color_center_bot", &color_center_bot);
+	state_save_register_int("decocass", 0, "mode_set", &mode_set);
+	state_save_register_int("decocass", 0, "back_h_shift", &back_h_shift);
+	state_save_register_int("decocass", 0, "back_vl_shift", &back_vl_shift);
+	state_save_register_int("decocass", 0, "back_vr_shift", &back_vr_shift);
+	state_save_register_int("decocass", 0, "part_h_shift", &part_h_shift);
+	state_save_register_int("decocass", 0, "part_v_shift", &part_v_shift);
+	state_save_register_int("decocass", 0, "center_h_shift_space", &center_h_shift_space);
+	state_save_register_int("decocass", 0, "center_v_shift", &center_v_shift);
+}
+
+/********************************************
+    tilemap callbacks
  ********************************************/
 
 static UINT32 fgvideoram_scan_cols( UINT32 col, UINT32 row, UINT32 num_cols, UINT32 num_rows )
@@ -115,8 +137,8 @@ static void get_bg_r_tile_info(int tile_index)
 
 static void get_fg_tile_info(int tile_index)
 {
-	unsigned char code = decocass_fgvideoram[tile_index];
-	unsigned char attr = decocass_colorram[tile_index];
+	UINT8 code = decocass_fgvideoram[tile_index];
+	UINT8 attr = decocass_colorram[tile_index];
 	SET_TILE_INFO(
 			0,
 			256 * (attr & 3) + code,
@@ -125,10 +147,10 @@ static void get_fg_tile_info(int tile_index)
 }
 
 /********************************************
-	big object
+    big object
  ********************************************/
 
-static void draw_object(struct mame_bitmap *bitmap)
+static void draw_object(mame_bitmap *bitmap, const rectangle *cliprect)
 {
 	int sx, sy, color;
 
@@ -144,13 +166,13 @@ static void draw_object(struct mame_bitmap *bitmap)
 	else
 		sx = 91 - (part_h_shift & 0x7f);
 
-	drawgfx(bitmap, Machine->gfx[3], 0, color, 0, 0, sx + 64, sy, &Machine->visible_area, TRANSPARENCY_PEN, 0);
-	drawgfx(bitmap, Machine->gfx[3], 1, color, 0, 0, sx, sy, &Machine->visible_area, TRANSPARENCY_PEN, 0);
-	drawgfx(bitmap, Machine->gfx[3], 0, color, 0, 1, sx + 64, sy - 64, &Machine->visible_area, TRANSPARENCY_PEN, 0);
-	drawgfx(bitmap, Machine->gfx[3], 1, color, 0, 1, sx, sy - 64, &Machine->visible_area, TRANSPARENCY_PEN, 0);
+	drawgfx(bitmap, Machine->gfx[3], 0, color, 0, 0, sx + 64, sy, cliprect, TRANSPARENCY_PEN, 0);
+	drawgfx(bitmap, Machine->gfx[3], 1, color, 0, 0, sx, sy, cliprect, TRANSPARENCY_PEN, 0);
+	drawgfx(bitmap, Machine->gfx[3], 0, color, 0, 1, sx + 64, sy - 64, cliprect, TRANSPARENCY_PEN, 0);
+	drawgfx(bitmap, Machine->gfx[3], 1, color, 0, 1, sx, sy - 64, cliprect, TRANSPARENCY_PEN, 0);
 }
 
-static void draw_center(struct mame_bitmap *bitmap)
+static void draw_center(mame_bitmap *bitmap, const rectangle *cliprect)
 {
 	int sx, sy, x, y, color;
 
@@ -168,29 +190,30 @@ static void draw_center(struct mame_bitmap *bitmap)
 	sx = (center_h_shift_space >> 2) & 0x3c;
 
 	for (y = 0; y < 4; y++)
-	{
-		if (((sy + y) & color_center_bot & 3) == (sy & color_center_bot & 3))
-			for (x = 0; x < 256; x++)
-				if (0 != (x & 16) || 0 != (center_h_shift_space & 1))
-					plot_pixel(bitmap, (sx + x) & 255, sy + y, Machine->pens[color]);
-	}
+		if ((sy + y) >= cliprect->min_y && (sy + y) <= cliprect->max_y)
+		{
+			if (((sy + y) & color_center_bot & 3) == (sy & color_center_bot & 3))
+				for (x = 0; x < 256; x++)
+					if (0 != (x & 16) || 0 != (center_h_shift_space & 1))
+						plot_pixel(bitmap, (sx + x) & 255, sy + y, Machine->pens[color]);
+		}
 }
 
 /********************************************
-	memory handlers
+    memory handlers
  ********************************************/
 
-WRITE_HANDLER( decocass_paletteram_w )
+WRITE8_HANDLER( decocass_paletteram_w )
 {
 	/*
-	 * RGB output is inverted and A4 is inverted too
-	 * (ME/ input on 1st paletteram, inverter -> ME/ on 2nd)
-	 */
+     * RGB output is inverted and A4 is inverted too
+     * (ME/ input on 1st paletteram, inverter -> ME/ on 2nd)
+     */
 	offset = (offset & 31) ^ 16;
 	paletteram_BBGGGRRR_w( offset, ~data );
 }
 
-WRITE_HANDLER( decocass_charram_w )
+WRITE8_HANDLER( decocass_charram_w )
 {
 	if (data == decocass_charram[offset])
 		return;
@@ -202,7 +225,7 @@ WRITE_HANDLER( decocass_charram_w )
 }
 
 
-WRITE_HANDLER( decocass_fgvideoram_w )
+WRITE8_HANDLER( decocass_fgvideoram_w )
 {
 	if (data == decocass_fgvideoram[offset])
 		return;
@@ -210,7 +233,7 @@ WRITE_HANDLER( decocass_fgvideoram_w )
 	tilemap_mark_tile_dirty( fg_tilemap, offset );
 }
 
-WRITE_HANDLER( decocass_colorram_w )
+WRITE8_HANDLER( decocass_colorram_w )
 {
 	if (data == decocass_colorram[offset])
 		return;
@@ -226,7 +249,7 @@ static void mark_bg_tile_dirty(offs_t offset)
 		tilemap_mark_tile_dirty( bg_tilemap_l, offset );
 }
 
-WRITE_HANDLER( decocass_tileram_w )
+WRITE8_HANDLER( decocass_tileram_w )
 {
 	if (data == decocass_tileram[offset])
 		return;
@@ -238,7 +261,7 @@ WRITE_HANDLER( decocass_tileram_w )
 		mark_bg_tile_dirty( offset );
 }
 
-WRITE_HANDLER( decocass_objectram_w )
+WRITE8_HANDLER( decocass_objectram_w )
 {
 	if (data == decocass_objectram[offset])
 		return;
@@ -247,7 +270,7 @@ WRITE_HANDLER( decocass_objectram_w )
 	object_dirty = 1;
 }
 
-WRITE_HANDLER( decocass_bgvideoram_w )
+WRITE8_HANDLER( decocass_bgvideoram_w )
 {
 	if (data == decocass_bgvideoram[offset])
 		return;
@@ -255,75 +278,27 @@ WRITE_HANDLER( decocass_bgvideoram_w )
 	mark_bg_tile_dirty( offset );
 }
 
-READ_HANDLER( decocass_mirrorvideoram_r )
-{
-	int x,y;
-
-	/* swap x and y coordinates */
-	x = offset / 32;
-	y = offset % 32;
-	offset = 32 * y + x;
-
-	return decocass_fgvideoram[offset];
-}
-
-READ_HANDLER( decocass_mirrorcolorram_r )
-{
-	int x,y;
-
-	/* swap x and y coordinates */
-	x = offset / 32;
-	y = offset % 32;
-	offset = 32 * y + x;
-
-	return decocass_colorram[offset];
-}
-
-WRITE_HANDLER( decocass_mirrorvideoram_w )
-{
-	int x,y;
-
-	/* swap x and y coordinates */
-	x = offset / 32;
-	y = offset % 32;
-	offset = 32 * y + x;
-
-	decocass_fgvideoram_w(offset,data);
-}
-
-WRITE_HANDLER( decocass_mirrorcolorram_w )
-{
-	int x,y;
-
-	/* swap x and y coordinates */
-	x = offset / 32;
-	y = offset % 32;
-	offset = 32 * y + x;
-
-	decocass_colorram_w(offset,data);
-}
-
 /* The watchdog is a 4bit counter counting down every frame */
-WRITE_HANDLER( decocass_watchdog_count_w )
+WRITE8_HANDLER( decocass_watchdog_count_w )
 {
 	LOG(1,("decocass_watchdog_count_w: $%02x\n", data));
 	watchdog_count = data & 0x0f;
 }
 
-WRITE_HANDLER( decocass_watchdog_flip_w )
+WRITE8_HANDLER( decocass_watchdog_flip_w )
 {
 	LOG(1,("decocass_watchdog_flip_w: $%02x\n", data));
 	watchdog_flip = data;
 }
 
-WRITE_HANDLER( decocass_color_missiles_w )
+WRITE8_HANDLER( decocass_color_missiles_w )
 {
 	LOG(1,("decocass_color_missiles_w: $%02x\n", data));
 	/* only bits D0-D2 and D4-D6 are connected to
-	 * the color RAM demux:
-	 * D0-D2 to the IC0 inputs
-	 * D4-D6 to the IC1 inputs
-	 */
+     * the color RAM demux:
+     * D0-D2 to the IC0 inputs
+     * D4-D6 to the IC1 inputs
+     */
 	color_missiles = data & 0x77;
 }
 
@@ -337,7 +312,7 @@ WRITE_HANDLER( decocass_color_missiles_w )
  * D6 - tunnel
  * D7 - part h enable
  */
-WRITE_HANDLER( decocass_mode_set_w )
+WRITE8_HANDLER( decocass_mode_set_w )
 {
 	if (data == mode_set)
 		return;
@@ -354,25 +329,25 @@ WRITE_HANDLER( decocass_mode_set_w )
 	set_vh_global_attribute( &mode_set, data );
 }
 
-WRITE_HANDLER( decocass_color_center_bot_w )
+WRITE8_HANDLER( decocass_color_center_bot_w )
 {
 	if (data == color_center_bot)
 		return;
 	LOG(1,("decocass_color_center_bot_w: $%02x (color:%d, center_bot:%d)\n", data, data&3, data>>4));
 	/*
-	 * D7	CL3/4 (swap 2+4)
-	 * D6	CL1
-	 * D5	CL2
-	 * D4	CL4
-	 * D3	nc
-	 * D2	nc
-	 * D1	CLD4
-	 * D0	CLD3
-	 */
+     * D7   CL3/4 (swap 2+4)
+     * D6   CL1
+     * D5   CL2
+     * D4   CL4
+     * D3   nc
+     * D2   nc
+     * D1   CLD4
+     * D0   CLD3
+     */
 	set_vh_global_attribute( &color_center_bot, data);
 }
 
-WRITE_HANDLER( decocass_back_h_shift_w )
+WRITE8_HANDLER( decocass_back_h_shift_w )
 {
 	if (data == back_h_shift)
 		return;
@@ -380,7 +355,7 @@ WRITE_HANDLER( decocass_back_h_shift_w )
 	back_h_shift = data;
 }
 
-WRITE_HANDLER( decocass_back_vl_shift_w )
+WRITE8_HANDLER( decocass_back_vl_shift_w )
 {
 	if (data == back_vl_shift)
 		return;
@@ -388,7 +363,7 @@ WRITE_HANDLER( decocass_back_vl_shift_w )
 	back_vl_shift = data;
 }
 
-WRITE_HANDLER( decocass_back_vr_shift_w )
+WRITE8_HANDLER( decocass_back_vr_shift_w )
 {
 	if (data == back_vr_shift)
 		return;
@@ -396,7 +371,7 @@ WRITE_HANDLER( decocass_back_vr_shift_w )
 	back_vr_shift = data;
 }
 
-WRITE_HANDLER( decocass_part_h_shift_w )
+WRITE8_HANDLER( decocass_part_h_shift_w )
 {
 	if (data == part_v_shift )
 		return;
@@ -404,7 +379,7 @@ WRITE_HANDLER( decocass_part_h_shift_w )
 	part_h_shift = data;
 }
 
-WRITE_HANDLER( decocass_part_v_shift_w )
+WRITE8_HANDLER( decocass_part_v_shift_w )
 {
 	if (data == part_v_shift )
 		return;
@@ -412,7 +387,7 @@ WRITE_HANDLER( decocass_part_v_shift_w )
 	part_v_shift = data;
 }
 
-WRITE_HANDLER( decocass_center_h_shift_space_w )
+WRITE8_HANDLER( decocass_center_h_shift_space_w )
 {
 	if (data == center_h_shift_space)
 		return;
@@ -420,19 +395,19 @@ WRITE_HANDLER( decocass_center_h_shift_space_w )
 	center_h_shift_space = data;
 }
 
-WRITE_HANDLER( decocass_center_v_shift_w )
+WRITE8_HANDLER( decocass_center_v_shift_w )
 {
 	LOG(1,("decocass_center_v_shift_w: $%02x\n", data));
 	center_v_shift = data;
 }
 
 /********************************************
-	memory handlers
+    memory handlers
  ********************************************/
 
-static void draw_sprites(struct mame_bitmap *bitmap, int color,
+static void draw_sprites(mame_bitmap *bitmap, const rectangle *cliprect, int color,
 						int sprite_y_adjust, int sprite_y_adjust_flip_screen,
-						unsigned char *sprite_ram, int interleave)
+						UINT8 *sprite_ram, int interleave)
 {
 	int i,offs;
 
@@ -466,7 +441,7 @@ static void draw_sprites(struct mame_bitmap *bitmap, int color,
 				color,
 				flipx,flipy,
 				sx,sy,
-				&Machine->visible_area, TRANSPARENCY_PEN, 0);
+				cliprect, TRANSPARENCY_PEN, 0);
 
 		sy += (flip_screen ? -256 : 256);
 
@@ -476,19 +451,19 @@ static void draw_sprites(struct mame_bitmap *bitmap, int color,
 				color,
 				flipx,flipy,
 				sx,sy,
-				&Machine->visible_area, TRANSPARENCY_PEN, 0);
+				cliprect, TRANSPARENCY_PEN, 0);
 	}
 }
 
 
-static void draw_missiles(struct mame_bitmap *bitmap,
+static void draw_missiles(mame_bitmap *bitmap, const rectangle *cliprect,
 						int missile_y_adjust, int missile_y_adjust_flip_screen,
-						unsigned char *missile_ram, int interleave)
+						UINT8 *missile_ram, int interleave)
 {
 	int i,offs;
 
 	/* Draw the missiles (16 of them) seemingly with alternating colors
-	 * from the E302 latch (color_missiles) */
+     * from the E302 latch (color_missiles) */
 	for (i = 0, offs = 0; i < 8; i++, offs += 4*interleave)
 	{
 		int sx,sy;
@@ -503,7 +478,7 @@ static void draw_missiles(struct mame_bitmap *bitmap,
 		sy -= missile_y_adjust;
 		drawgfx(bitmap,Machine->gfx[4],
 				0,32 + ((color_missiles >> 4) & 7), 0,0, sx,sy,
-				&Machine->visible_area, TRANSPARENCY_PEN, 0);
+				cliprect, TRANSPARENCY_PEN, 0);
 
 		sy = 255 - missile_ram[offs + 1*interleave];
 		sx = 255 - missile_ram[offs + 3*interleave];
@@ -515,12 +490,12 @@ static void draw_missiles(struct mame_bitmap *bitmap,
 		sy -= missile_y_adjust;
 		drawgfx(bitmap,Machine->gfx[4],
 				0,32 + (color_missiles & 7), 0,0, sx,sy,
-				&Machine->visible_area, TRANSPARENCY_PEN, 0);
+				cliprect, TRANSPARENCY_PEN, 0);
 	}
 }
 
 
-static void decode_modified(unsigned char *sprite_ram, int interleave)
+static void decode_modified(UINT8 *sprite_ram, int interleave)
 {
 	int i,offs;
 
@@ -592,13 +567,11 @@ static void decode_modified(unsigned char *sprite_ram, int interleave)
 	}
 }
 
-int decocass_vh_start (void)
+VIDEO_START( decocass )
 {
-	struct rectangle clip;
-
-	if (NULL == (sprite_dirty = malloc(256)) ||
-		NULL == (char_dirty = malloc(1024)) ||
-		NULL == (tile_dirty = malloc(16)))
+	if (NULL == (sprite_dirty = auto_malloc(256)) ||
+		NULL == (char_dirty = auto_malloc(1024)) ||
+		NULL == (tile_dirty = auto_malloc(16)))
 		return 1;
 
 	bg_tilemap_l = tilemap_create( get_bg_l_tile_info, bgvideoram_scan_cols, TILEMAP_TRANSPARENT, 16, 16, 32, 32 );
@@ -612,53 +585,26 @@ int decocass_vh_start (void)
 	tilemap_set_transparent_pen( bg_tilemap_r, 0 );
 	tilemap_set_transparent_pen( fg_tilemap, 0 );
 
-	clip = Machine->visible_area;
-	clip.max_y = Machine->drv->screen_height / 2;
-	tilemap_set_clip(bg_tilemap_l, &clip);
+	bg_tilemap_l_clip = Machine->visible_area;
+	bg_tilemap_l_clip.max_y = Machine->drv->screen_height / 2;
 
-	clip = Machine->visible_area;
-	clip.min_y = Machine->drv->screen_height / 2;
-	tilemap_set_clip(bg_tilemap_r, &clip);
+	bg_tilemap_r_clip = Machine->visible_area;
+	bg_tilemap_r_clip.min_y = Machine->drv->screen_height / 2;
 
 	/* background videroam bits D0-D3 are shared with the tileram */
 	decocass_bgvideoram = decocass_tileram;
 	decocass_bgvideoram_size = 0x0400;	/* d000-d3ff */
 
-	state_save_register_int("decocass", 0, "watchdog_count", &watchdog_count);
-	state_save_register_int("decocass", 0, "watchdog_flip", &watchdog_flip);
-	state_save_register_int("decocass", 0, "color_missiles", &color_missiles);
-	state_save_register_int("decocass", 0, "color_center_bot", &color_center_bot);
-	state_save_register_int("decocass", 0, "mode_set", &mode_set);
-	state_save_register_int("decocass", 0, "back_h_shift", &back_h_shift);
-	state_save_register_int("decocass", 0, "back_vl_shift", &back_vl_shift);
-	state_save_register_int("decocass", 0, "back_vr_shift", &back_vr_shift);
-	state_save_register_int("decocass", 0, "part_h_shift", &part_h_shift);
-	state_save_register_int("decocass", 0, "part_v_shift", &part_v_shift);
-	state_save_register_int("decocass", 0, "center_h_shift_space", &center_h_shift_space);
-	state_save_register_int("decocass", 0, "center_v_shift", &center_v_shift);
-
 	return 0;
 }
 
-void decocass_vh_stop (void)
-{
-	if (tile_dirty)
-		free(tile_dirty);
-	tile_dirty = NULL;
-	if (char_dirty)
-		free(char_dirty);
-	char_dirty = NULL;
-	if (sprite_dirty)
-		free(sprite_dirty);
-	sprite_dirty = NULL;
-}
-
-void decocass_vh_screenrefresh(struct mame_bitmap *bitmap,int full_refresh)
+VIDEO_UPDATE( decocass )
 {
 	int scrollx, scrolly_l, scrolly_r;
+	rectangle clip;
 
 	if (0xc0 != (input_port_2_r(0) & 0xc0))  /* coin slots assert an NMI */
-		cpu_set_nmi_line(0, ASSERT_LINE);
+		cpunum_set_input_line(0, INPUT_LINE_NMI, ASSERT_LINE);
 
 	if (0 == (watchdog_flip & 0x04))
 		watchdog_reset_w (0,0);
@@ -673,7 +619,7 @@ void decocass_vh_screenrefresh(struct mame_bitmap *bitmap,int full_refresh)
 			tape_time = 0.0;
 		else if (tape_time > 999.9)
 			tape_time = 999.9;
-		usrintf_showmessage("%c%c [%05.1fs] %c%c",
+		ui_popup("%c%c [%05.1fs] %c%c",
 			(tape_dir < 0 && tape_speed) ? '<' : ' ',
 			(tape_dir < 0) ? '<' : ' ',
 			tape_time,
@@ -687,7 +633,7 @@ void decocass_vh_screenrefresh(struct mame_bitmap *bitmap,int full_refresh)
 		if (code_pressed_memory(KEYCODE_I))
 			showmsg ^= 1;
 		if (showmsg)
-			usrintf_showmessage_secs(1, "mode:$%02x cm:$%02x ccb:$%02x h:$%02x vl:$%02x vr:$%02x ph:$%02x pv:$%02x ch:$%02x cv:$%02x",
+			ui_popup_time(1, "mode:$%02x cm:$%02x ccb:$%02x h:$%02x vl:$%02x vr:$%02x ph:$%02x pv:$%02x ch:$%02x cv:$%02x",
 				mode_set,
 				color_missiles,
 				color_center_bot,
@@ -701,7 +647,7 @@ void decocass_vh_screenrefresh(struct mame_bitmap *bitmap,int full_refresh)
 	}
 #endif
 
-	fillbitmap( bitmap, Machine->pens[0], &Machine->visible_area );
+	fillbitmap( bitmap, Machine->pens[0], cliprect );
 
 	decode_modified( decocass_fgvideoram, 0x20 );
 
@@ -733,24 +679,34 @@ void decocass_vh_screenrefresh(struct mame_bitmap *bitmap,int full_refresh)
 	{
 		if (mode_set & 0x08)	/* bkg_ena on ? */
 		{
-			tilemap_draw(bitmap, bg_tilemap_l, 0, 0);
-			tilemap_draw(bitmap, bg_tilemap_r, 0, 0);
+			clip = bg_tilemap_l_clip;
+			sect_rect(&clip,cliprect);
+			tilemap_draw(bitmap,&clip, bg_tilemap_l, 0, 0);
+
+			clip = bg_tilemap_r_clip;
+			sect_rect(&clip,cliprect);
+			tilemap_draw(bitmap,&clip, bg_tilemap_r, 0, 0);
 		}
-		draw_object(bitmap);
-		draw_center(bitmap);
+		draw_object(bitmap,cliprect);
+		draw_center(bitmap,cliprect);
 	}
 	else
 	{
-		draw_object(bitmap);
-		draw_center(bitmap);
+		draw_object(bitmap,cliprect);
+		draw_center(bitmap,cliprect);
 		if (mode_set & 0x08)	/* bkg_ena on ? */
 		{
-			tilemap_draw(bitmap, bg_tilemap_l, 0, 0);
-			tilemap_draw(bitmap, bg_tilemap_r, 0, 0);
+			clip = bg_tilemap_l_clip;
+			sect_rect(&clip,cliprect);
+			tilemap_draw(bitmap,&clip, bg_tilemap_l, 0, 0);
+
+			clip = bg_tilemap_r_clip;
+			sect_rect(&clip,cliprect);
+			tilemap_draw(bitmap,&clip, bg_tilemap_r, 0, 0);
 		}
 	}
-	tilemap_draw(bitmap, fg_tilemap, 0, 0);
-	draw_sprites(bitmap, (color_center_bot >> 1) & 1, 0, 0, decocass_fgvideoram, 0x20);
-	draw_missiles(bitmap, 1, 0, decocass_colorram, 0x20);
+	tilemap_draw(bitmap,cliprect, fg_tilemap, 0, 0);
+	draw_sprites(bitmap,cliprect, (color_center_bot >> 1) & 1, 0, 0, decocass_fgvideoram, 0x20);
+	draw_missiles(bitmap,cliprect, 1, 0, decocass_colorram, 0x20);
 }
 
