@@ -1,41 +1,43 @@
 /***************************************************************************
 
-							-= Kaneko 16 Bit Games =-
+                            -= Kaneko 16 Bit Games =-
 
-					driver by	Luca Elia (l.elia@tin.it)
+                    driver by   Luca Elia (l.elia@tin.it)
 
 
-Note:	if MAME_DEBUG is defined, pressing:
+Note:   if MAME_DEBUG is defined, pressing:
 
-		Q  with  X/C/V/B/ Z   shows Layer 0 (tiles with priority 0/1/2/3/ All)
-		W  with  X/C/V/B/ Z   shows Layer 1 (tiles with priority 0/1/2/3/ All)
-		E  with  X/C/V/B/ Z   shows Layer 2 (tiles with priority 0/1/2/3/ All)
-		R  with  X/C/V/B/ Z   shows Layer 3 (tiles with priority 0/1/2/3/ All)
-		A  with  X/C/V/B/ Z   shows Sprites (tiles with priority 0/1/2/3/ All)
+        Q  with  X/C/V/B/ Z   shows Layer 0 (tiles with priority 0/1/2/3/ All)
+        W  with  X/C/V/B/ Z   shows Layer 1 (tiles with priority 0/1/2/3/ All)
+        E  with  X/C/V/B/ Z   shows Layer 2 (tiles with priority 0/1/2/3/ All)
+        R  with  X/C/V/B/ Z   shows Layer 3 (tiles with priority 0/1/2/3/ All)
+        A  with  X/C/V/B/ Z   shows Sprites (tiles with priority 0/1/2/3/ All)
 
-		Keys can be used together!
+        Keys can be used together!
 
-	[ 1 High Color Layer ]
+    [ 1 High Color Layer ]
 
-		In ROM	(Optional)
+        In ROM  (Optional)
 
-	[ Scrolling Layers ]
+    [ Scrolling Layers ]
 
-		Each VIEW2 chip generates 2 layers. Up to 2 chips are used
-		(4 layers)
+        Each VIEW2 chip generates 2 layers. Up to 2 chips are used
+        (4 layers)
 
-		Layer Size:				512 x 512
-		Tiles:					16 x 16 x 4
+        Layer Size:             512 x 512
+        Tiles:                  16 x 16 x 4
 
-		Line scroll is supported by the chip: each layer has RAM
-		for 512 horizontal scroll offsets (one per tilemap line)
-		that are added to the global scroll values.
-		See e.g. blazeon (2nd demo level), mgcrystl, sandscrp.
+        Line scroll is supported by the chip: each layer has RAM
+        for 512 horizontal scroll offsets (one per tilemap line)
+        that are added to the global scroll values.
+        See e.g. blazeon (2nd demo level), mgcrystl, sandscrp.
 
-	[ 1024 Sprites ]
+    [ 1024 Sprites ]
 
-		Sprites are 16 x 16 x 4 in the older games, 16 x 16 x 8 in
-		gtmr & gtmr2
+        Sprites are 16 x 16 x 4 in the older games, 16 x 16 x 8 in
+        gtmr & gtmr2.
+        Sprites types 0 and 2 can also have a simple effect keeping
+        sprites on the screen
 
 
 **************************************************************************/
@@ -43,22 +45,28 @@ Note:	if MAME_DEBUG is defined, pressing:
 #include "vidhrdw/generic.h"
 #include "kaneko16.h"
 
-struct tilemap *kaneko16_tmap_0, *kaneko16_tmap_1;
-struct tilemap *kaneko16_tmap_2, *kaneko16_tmap_3;
-data16_t *kaneko16_vram_0,    *kaneko16_vram_1,    *kaneko16_layers_0_regs;
-data16_t *kaneko16_vscroll_0, *kaneko16_vscroll_1;
-data16_t *kaneko16_vram_2,    *kaneko16_vram_3,    *kaneko16_layers_1_regs;
-data16_t *kaneko16_vscroll_2, *kaneko16_vscroll_3;
+
+UINT16 kaneko16_disp_enable = 1; /* default enabled for games not using it */
+
+
+tilemap *kaneko16_tmap_0, *kaneko16_tmap_1;
+tilemap *kaneko16_tmap_2, *kaneko16_tmap_3;
+UINT16 *kaneko16_vram_0,    *kaneko16_vram_1,    *kaneko16_layers_0_regs;
+UINT16 *kaneko16_vscroll_0, *kaneko16_vscroll_1;
+UINT16 *kaneko16_vram_2,    *kaneko16_vram_3,    *kaneko16_layers_1_regs;
+UINT16 *kaneko16_vscroll_2, *kaneko16_vscroll_3;
 
 
 int kaneko16_sprite_type;
-data16_t kaneko16_sprite_xoffs, kaneko16_sprite_flipx;
-data16_t kaneko16_sprite_yoffs, kaneko16_sprite_flipy;
-data16_t *kaneko16_sprites_regs;
+int kaneko16_keep_sprites = 0; /* default disabled for games not using it */
+UINT16 kaneko16_sprite_xoffs, kaneko16_sprite_flipx;
+UINT16 kaneko16_sprite_yoffs, kaneko16_sprite_flipy;
+UINT16 *kaneko16_sprites_regs;
 
 
-data16_t *kaneko16_bg15_select, *kaneko16_bg15_reg;
-static struct mame_bitmap *kaneko16_bg15_bitmap;
+UINT16 *kaneko16_bg15_select, *kaneko16_bg15_reg;
+static mame_bitmap *kaneko16_bg15_bitmap;
+static mame_bitmap *sprites_bitmap; /* bitmap used for to keep sprites on screen (mgcrystl 1st boss)*/
 
 struct tempsprite
 {
@@ -78,22 +86,27 @@ struct
 kaneko16_priority_t kaneko16_priority;
 
 
+WRITE16_HANDLER( kaneko16_display_enable )
+{
+	COMBINE_DATA(&kaneko16_disp_enable);
+}
+
 /***************************************************************************
 
-						Callbacks for the TileMap code
+                        Callbacks for the TileMap code
 
-							  [ Tiles Format ]
+                              [ Tiles Format ]
 
 Offset:
 
-0000.w			fedc ba-- ---- ----		unused?
-				---- --9- ---- ----		High Priority (vs Sprites)
-				---- ---8 ---- ----		High Priority (vs Tiles)
-				---- ---- 7654 32--		Color
-				---- ---- ---- --1-		Flip X
-				---- ---- ---- ---0		Flip Y
+0000.w          fedc ba-- ---- ----     unused?
+                ---- --9- ---- ----     High Priority (vs Sprites)
+                ---- ---8 ---- ----     High Priority (vs Tiles)
+                ---- ---- 7654 32--     Color
+                ---- ---- ---- --1-     Flip X
+                ---- ---- ---- ---0     Flip Y
 
-0002.w									Code
+0002.w                                  Code
 
 ***************************************************************************/
 
@@ -101,16 +114,16 @@ Offset:
 #define KANEKO16_LAYER(_N_) \
 static void get_tile_info_##_N_(int tile_index) \
 { \
-	data16_t code_hi = kaneko16_vram_##_N_[ 2 * tile_index + 0]; \
-	data16_t code_lo = kaneko16_vram_##_N_[ 2 * tile_index + 1]; \
+	UINT16 code_hi = kaneko16_vram_##_N_[ 2 * tile_index + 0]; \
+	UINT16 code_lo = kaneko16_vram_##_N_[ 2 * tile_index + 1]; \
 	SET_TILE_INFO(1 + _N_/2, code_lo, (code_hi >> 2) & 0x3f, TILE_FLIPXY( code_hi & 3 )); \
 	tile_info.priority	=	(code_hi >> 8) & 3; \
 } \
 \
 WRITE16_HANDLER( kaneko16_vram_##_N_##_w ) \
 { \
-	data16_t old_data	=	kaneko16_vram_##_N_[offset]; \
-	data16_t new_data	=	COMBINE_DATA(&kaneko16_vram_##_N_[offset]); \
+	UINT16 old_data	=	kaneko16_vram_##_N_[offset]; \
+	UINT16 new_data	=	COMBINE_DATA(&kaneko16_vram_##_N_[offset]); \
 	if (old_data != new_data)	tilemap_mark_tile_dirty(kaneko16_tmap_##_N_, offset/2); \
 }
 
@@ -120,10 +133,10 @@ KANEKO16_LAYER(1)
 KANEKO16_LAYER(2)
 KANEKO16_LAYER(3)
 
-int kaneko16_vh_start_sprites(void)
+VIDEO_START( kaneko16_sprites )
 {
 	/* 0x400 sprites max */
-	spritelist.first_sprite = (struct tempsprite *)malloc(0x400 * sizeof(spritelist.first_sprite[0]));
+	spritelist.first_sprite = (struct tempsprite *)auto_malloc(0x400 * sizeof(spritelist.first_sprite[0]));
 
 	if (	!spritelist.first_sprite	)
 		return 1;
@@ -131,9 +144,9 @@ int kaneko16_vh_start_sprites(void)
 	return 0;
 }
 
-int kaneko16_vh_start_1xVIEW2(void)
+VIDEO_START( kaneko16_1xVIEW2 )
 {
-	if (	kaneko16_vh_start_sprites()	)
+	if (	video_start_kaneko16_sprites()	)
 		return 1;
 
 	kaneko16_tmap_0 = tilemap_create(	get_tile_info_0, tilemap_scan_rows,
@@ -145,6 +158,9 @@ int kaneko16_vh_start_1xVIEW2(void)
 
 	kaneko16_tmap_3 = 0;
 
+	if ((sprites_bitmap = auto_bitmap_alloc(Machine->drv->screen_width,Machine->drv->screen_height)) == 0)
+		return 1;
+
 	if (	!kaneko16_tmap_0 || !kaneko16_tmap_1	)
 		return 1;
 
@@ -181,9 +197,9 @@ int kaneko16_vh_start_1xVIEW2(void)
 	}
 }
 
-int kaneko16_vh_start_2xVIEW2(void)
+VIDEO_START( kaneko16_2xVIEW2 )
 {
-	if (	kaneko16_vh_start_1xVIEW2()	)
+	if (	video_start_kaneko16_1xVIEW2()	)
 		return 1;
 
 	kaneko16_tmap_2 = tilemap_create(	get_tile_info_2, tilemap_scan_rows,
@@ -226,9 +242,9 @@ int kaneko16_vh_start_2xVIEW2(void)
 	}
 }
 
-int sandscrp_vh_start_1xVIEW2(void)
+VIDEO_START( sandscrp_1xVIEW2 )
 {
-	if (	kaneko16_vh_start_1xVIEW2()	)
+	if (	video_start_kaneko16_1xVIEW2()	)
 		return 1;
 
 	tilemap_set_scrolldy( kaneko16_tmap_0, 0, 256 - 1 );
@@ -237,17 +253,9 @@ int sandscrp_vh_start_1xVIEW2(void)
 }
 
 
-void kaneko16_vh_stop(void)
-{
-	if (spritelist.first_sprite)
-		free(spritelist.first_sprite);
-	spritelist.first_sprite = 0;		/* multisession safety */
-}
-
-
 /* Berlwall has an additional hi-color background */
 
-void berlwall_init_palette(unsigned char *obsolete,unsigned short *colortable,const unsigned char *color_prom)
+PALETTE_INIT( berlwall )
 {
 	int i;
 
@@ -270,19 +278,19 @@ void berlwall_init_palette(unsigned char *obsolete,unsigned short *colortable,co
 	}
 }
 
-int berlwall_vh_start(void)
+VIDEO_START( berlwall )
 {
 	int sx, x,y;
 	unsigned char *RAM	=	memory_region(REGION_GFX3);
 
 	/* Render the hi-color static backgrounds held in the ROMs */
 
-	if ((kaneko16_bg15_bitmap = bitmap_alloc_depth(256 * 32, 256 * 1, 16)) == 0)
+	if ((kaneko16_bg15_bitmap = auto_bitmap_alloc_depth(256 * 32, 256 * 1, 16)) == 0)
 		return 1;
 
 /*
-	8aba is used as background color
-	8aba/2 = 455d = 10001 01010 11101 = $11 $0a $1d
+    8aba is used as background color
+    8aba/2 = 455d = 10001 01010 11101 = $11 $0a $1d
 */
 
 	for (sx = 0 ; sx < 32 ; sx++)	/* horizontal screens */
@@ -316,85 +324,75 @@ int berlwall_vh_start(void)
 						Machine->pens[2048 + ((g << 10) | (r << 5) | b)] );
 	  }
 
-	return kaneko16_vh_start_1xVIEW2();
+	return video_start_kaneko16_1xVIEW2();
 }
 
-void berlwall_vh_stop(void)
-{
-	if (kaneko16_bg15_bitmap)
-		bitmap_free(kaneko16_bg15_bitmap);
-
-	kaneko16_bg15_bitmap = 0;	/* multisession safety */
-	kaneko16_vh_stop();
-}
-
-
 
 /***************************************************************************
 
-								Sprites Drawing
+                                Sprites Drawing
 
-	Sprite data is layed out in RAM in different ways for different games
-	(type 0,1,2,etc.). This basically involves the bits in the attribute
-	word to be shuffled around and/or the words being in different order.
+    Sprite data is layed out in RAM in different ways for different games
+    (type 0,1,2,etc.). This basically involves the bits in the attribute
+    word to be shuffled around and/or the words being in different order.
 
-	Each sprite is always stuffed in 4 words. There may be some extra
-	padding words though (e.g. type 2 sprites are like type 0 but the
-	data is held in the last 8 bytes of every 16). Examples are:
+    Each sprite is always stuffed in 4 words. There may be some extra
+    padding words though (e.g. type 2 sprites are like type 0 but the
+    data is held in the last 8 bytes of every 16). Examples are:
 
-	Type 0: shogwarr, blazeon, bakubrkr.
-	Type 1: gtmr.
-	Type 2: berlwall
+    Type 0: shogwarr, blazeon, bakubrkr.
+    Type 1: gtmr.
+    Type 2: berlwall
 
-Offset:			Format:						Value:
+Offset:         Format:                     Value:
 
-0000.w			Attribute (type 0 & 2)
+0000.w          Attribute (type 0 & 2)
 
-					f--- ---- ---- ----		Multisprite: Use Latched Code + 1
-					-e-- ---- ---- ----		Multisprite: Use Latched Color (And Flip?)
-					--d- ---- ---- ----		Multisprite: Use Latched X,Y As Offsets
-					---c ba-- ---- ----
-					---- --9- ---- ----		High Priority (vs FG Tiles Of High Priority)
-					---- ---8 ---- ----		High Priority (vs BG Tiles Of High Priority)
-					---- ---- 7654 32--		Color
-					---- ---- ---- --1-		X Flip
-					---- ---- ---- ---0		Y Flip
+                    f--- ---- ---- ----     Multisprite: Use Latched Code + 1
+                    -e-- ---- ---- ----     Multisprite: Use Latched Color (And Flip?)
+                    --d- ---- ---- ----     Multisprite: Use Latched X,Y As Offsets
+                    ---c ba-- ---- ----
+                    ---- --9- ---- ----     High Priority (vs FG Tiles Of High Priority)
+                    ---- ---8 ---- ----     High Priority (vs BG Tiles Of High Priority)
+                    ---- ---- 7654 32--     Color
+                    ---- ---- ---- --1-     X Flip
+                    ---- ---- ---- ---0     Y Flip
 
-				Attribute (type 1)
+                Attribute (type 1)
 
-					f--- ---- ---- ----		Multisprite: Use Latched Code + 1
-					-e-- ---- ---- ----		Multisprite: Use Latched Color (And Flip?)
-					--d- ---- ---- ----		Multisprite: Use Latched X,Y As Offsets
-					---c ba-- ---- ----
-					---- --9- ---- ----		X Flip
-					---- ---8 ---- ----		Y Flip
-					---- ---- 7--- ----		High Priority (vs FG Tiles Of High Priority)
-					---- ---- -6-- ----		High Priority (vs BG Tiles Of High Priority)
-					---- ---- --54 3210		Color
+                    f--- ---- ---- ----     Multisprite: Use Latched Code + 1
+                    -e-- ---- ---- ----     Multisprite: Use Latched Color (And Flip?)
+                    --d- ---- ---- ----     Multisprite: Use Latched X,Y As Offsets
+                    ---c ba-- ---- ----
+                    ---- --9- ---- ----     X Flip
+                    ---- ---8 ---- ----     Y Flip
+                    ---- ---- 7--- ----     High Priority (vs FG Tiles Of High Priority)
+                    ---- ---- -6-- ----     High Priority (vs BG Tiles Of High Priority)
+                    ---- ---- --54 3210     Color
 
-0002.w										Code
-0004.w										X Position << 6
-0006.w										Y Position << 6
+0002.w                                      Code
+0004.w                                      X Position << 6
+0006.w                                      Y Position << 6
 
-	Type 3: sandscrp
+    Type 3: sandscrp
 
-Offset:			Format:				Value:
+Offset:         Format:             Value:
 
-07.b			7654 ----			Color
-				---- 3---
-				---- -2--			Multi Sprite
-				---- --1-			Y (High Bit)
-				---- ---0			X (High Bit)
+07.b            7654 ----           Color
+                ---- 3---
+                ---- -2--           Multi Sprite
+                ---- --1-           Y (High Bit)
+                ---- ---0           X (High Bit)
 
-09.b								X (Low Bits)
+09.b                                X (Low Bits)
 
-0B.b								Y (Low Bits)
+0B.b                                Y (Low Bits)
 
-0D.b								Code (Low Bits)
+0D.b                                Code (Low Bits)
 
-0F.b			7--- ----			Flip X
-				-6-- ----			Flip Y
-				--54 3210			Code (High Bits)
+0F.b            7--- ----           Flip X
+                -6-- ----           Flip Y
+                --54 3210           Code (High Bits)
 
 ***************************************************************************/
 
@@ -422,6 +420,7 @@ int kaneko16_parse_sprite_type012(int i, struct tempsprite *s)
 	s->priority		=		(attr & 0x00c0) >> 6;
 	s->flipy		=		(attr & 0x0100);
 	s->flipx		=		(attr & 0x0200);
+	s->code			+=		(s->y & 1) << 16;	/* bloodwar */
 	}
 	else
 	{
@@ -483,16 +482,16 @@ int kaneko16_parse_sprite_type3(int i, struct tempsprite *s)
 
 /* Build a list of sprites to display & draw them */
 
-void kaneko16_draw_sprites(struct mame_bitmap *bitmap, int pri)
+void kaneko16_draw_sprites(mame_bitmap *bitmap, const rectangle *cliprect, int pri)
 {
 	/* Sprites *must* be parsed from the first in RAM to the last,
-	   because of the multisprite feature. But they *must* be drawn
-	   from the last in RAM (frontmost) to the firtst in order to
-	   cope with priorities using pdrawgfx.
+       because of the multisprite feature. But they *must* be drawn
+       from the last in RAM (frontmost) to the firtst in order to
+       cope with priorities using pdrawgfx.
 
-	   Hence we parse them from first to last and put the result
-	   in a temp buffer, then draw the buffer's contents from last
-	   to first. */
+       Hence we parse them from first to last and put the result
+       in a temp buffer, then draw the buffer's contents from last
+       to first. */
 
 	int max	=	(Machine->drv->screen_width > 0x100) ? (0x200<<6) : (0x100<<6);
 
@@ -579,7 +578,7 @@ void kaneko16_draw_sprites(struct mame_bitmap *bitmap, int pri)
 
 
 	/* Let's finally draw the sprites we buffered, in reverse order
-	   (for pdrawgfx) */
+       (for pdrawgfx) */
 
 	for (s--; s >= spritelist.first_sprite; s--)
 	{
@@ -595,18 +594,16 @@ void kaneko16_draw_sprites(struct mame_bitmap *bitmap, int pri)
 					s->color,
 					s->flipx, s->flipy,
 					s->x, s->y,
-					&Machine->visible_area,TRANSPARENCY_PEN,0,
+					cliprect,TRANSPARENCY_PEN,0,
 					primask );
 #ifdef MAME_DEBUG
 #if 0
-if (keyboard_pressed(KEYCODE_Z))
+if (code_pressed(KEYCODE_Z))
 {	/* Display some info on each sprite */
-	struct DisplayText dt[2];	char buf[10];
+	char buf[10];
 	sprintf(buf, "%X",s->priority);
-	dt[0].text = buf;	dt[0].color = UI_COLOR_NORMAL;
-	dt[0].x = s->x;		dt[0].y = s->y;
-	dt[1].text = 0;	/* terminate array */
-	displaytext(Machine->scrbitmap,dt);		}
+	ui_draw_text(buf, s->x, s->y);
+}
 #endif
 #endif
 	}
@@ -617,32 +614,33 @@ if (keyboard_pressed(KEYCODE_Z))
 /***************************************************************************
 
 
-							Sprites Registers
+                            Sprites Registers
 
-	Offset:			Format:						Value:
+    Offset:         Format:                     Value:
 
-	0000.w			f--- ---- ---- ----			Sprites Disable?? (see blazeon)
-					-edc ba98 7654 32--
-					---- ---- ---- --1-			Flip X
-					---- ---- ---- ---0			Flip Y
+    0000.w          f--- ---- ---- ----         Sprites Disable?? (see blazeon)
+                    -edc ba98 7654 3---
+                    ---- ---- ---- -2--         Keep sprites on screen (only sprites types 0 and 2)
+                    ---- ---- ---- --1-         Flip X
+                    ---- ---- ---- ---0         Flip Y
 
-	0002.w										Y Offset << 6 (Global)
+    0002.w                                      Y Offset << 6 (Global)
 
 
-	0004..000e.w								?
+    0004..000e.w                                ?
 
 
-	0010.w										X Offset << 6 #0
-	0012.w										Y Offset << 6 #0
+    0010.w                                      X Offset << 6 #0
+    0012.w                                      Y Offset << 6 #0
 
-	0014.w										X Offset << 6 #1
-	0016.w										Y Offset << 6 #1
+    0014.w                                      X Offset << 6 #1
+    0016.w                                      Y Offset << 6 #1
 
-	0018.w										X Offset << 6 #2
-	001a.w										Y Offset << 6 #2
+    0018.w                                      X Offset << 6 #2
+    001a.w                                      Y Offset << 6 #2
 
-	001c.w										X Offset << 6 #3
-	001e.w										Y Offset << 6 #3
+    001c.w                                      X Offset << 6 #3
+    001e.w                                      Y Offset << 6 #3
 
 ***************************************************************************/
 
@@ -650,35 +648,35 @@ if (keyboard_pressed(KEYCODE_Z))
 [gtmr]
 
 Initial self test:
-600000: 4BC0 94C0 4C40 94C0-0404 0002 0000 0000		(Layers 1 regs)
-680000: 4BC0 94C0 4C40 94C0-1C1C 0002 0000 0000		(Layers 2 regs)
+600000: 4BC0 94C0 4C40 94C0-0404 0002 0000 0000     (Layers 1 regs)
+680000: 4BC0 94C0 4C40 94C0-1C1C 0002 0000 0000     (Layers 2 regs)
 Race start:
-600000: DC00 7D00 DC80 7D00-0404 0002 0000 0000		(Layers 1 regs)
-680000: DC00 7D00 DC80 7D00-1C1C 0002 0000 0000		(Layers 2 regs)
+600000: DC00 7D00 DC80 7D00-0404 0002 0000 0000     (Layers 1 regs)
+680000: DC00 7D00 DC80 7D00-1C1C 0002 0000 0000     (Layers 2 regs)
 
 [gtmr]
-700000: 0040 0000 0001 0180-0000 0000 0000 0000		(Sprites  regs)
-700010: 0040 0000 0040 0000-0040 0000 2840 1E00		; 1,0 .. a1,78
-													; a0*2=screenx/2
-													; 78*2=screeny/2
+700000: 0040 0000 0001 0180-0000 0000 0000 0000     (Sprites  regs)
+700010: 0040 0000 0040 0000-0040 0000 2840 1E00     ; 1,0 .. a1,78
+                                                    ; a0*2=screenx/2
+                                                    ; 78*2=screeny/2
 FLIP ON:
-700000: 0043 FFC0 0001 0180-0000 0000 0000 0000		(Sprites  regs)
-700010: 2FC0 4400 2FC0 4400-2FC0 4400 57C0 6200		; bf,110 .. 15f,188
-													; 15f-bf=a0! 188-110=78!
+700000: 0043 FFC0 0001 0180-0000 0000 0000 0000     (Sprites  regs)
+700010: 2FC0 4400 2FC0 4400-2FC0 4400 57C0 6200     ; bf,110 .. 15f,188
+                                                    ; 15f-bf=a0! 188-110=78!
 
 [berlwall]
-600000: 48CC 03C0 0001 0100-0000 0000 0000 0000		(Sprites  regs)
+600000: 48CC 03C0 0001 0100-0000 0000 0000 0000     (Sprites  regs)
 600010: 0000 0000 0000 0000-0000 0000 0000 0000
 FLIP ON:
-600000: 48CF FC00 0001 0100-0000 0000 0000 0000		(Sprites  regs)
+600000: 48CF FC00 0001 0100-0000 0000 0000 0000     (Sprites  regs)
 600010: 0000 0000 0000 0000-0000 0000 0000 0000
 
 [mgcrystl]
-900000: 4FCC 0000 0040 00C0-xxxx 0001 0001 0001		(Sprites  regs)
+900000: 4FCC 0000 0040 00C0-xxxx 0001 0001 0001     (Sprites  regs)
 900010: 0000 FC40 A000 9C40-1E00 1A40 0000 FC40
 FLIP ON:
-900000: 4FCF 0000 0040 00C0-xxxx 0001 0001 0001		(Sprites  regs)
-900010: 0000 0400 A000 A400-1E00 2200 0000 0400		; +1f<<6 on y
+900000: 4FCF 0000 0040 00C0-xxxx 0001 0001 0001     (Sprites  regs)
+900010: 0000 0400 A000 A400-1E00 2200 0000 0400     ; +1f<<6 on y
 */
 
 READ16_HANDLER( kaneko16_sprites_regs_r )
@@ -688,7 +686,7 @@ READ16_HANDLER( kaneko16_sprites_regs_r )
 
 WRITE16_HANDLER( kaneko16_sprites_regs_w )
 {
-	data16_t new_data;
+	UINT16 new_data;
 
 	COMBINE_DATA(&kaneko16_sprites_regs[offset]);
 	new_data  = kaneko16_sprites_regs[offset];
@@ -700,64 +698,67 @@ WRITE16_HANDLER( kaneko16_sprites_regs_w )
 			{
 				kaneko16_sprite_flipx = new_data & 2;
 				kaneko16_sprite_flipy = new_data & 1;
+
+				if(kaneko16_sprite_type == 0 || kaneko16_sprite_type == 2)
+					kaneko16_keep_sprites = ~new_data & 4;
 			}
 
 			break;
 	}
 
-/*	logerror("CPU #0 PC %06X : Warning, sprites reg %04X <- %04X\n",cpu_get_pc(),offset*2,data); */
+/*  logerror("CPU #0 PC %06X : Warning, sprites reg %04X <- %04X\n",activecpu_get_pc(),offset*2,data); */
 }
 
 
 /***************************************************************************
 
-							Layers Registers
+                            Layers Registers
 
 
-	Offset:			Format:						Value:
+    Offset:         Format:                     Value:
 
-	0000.w										FG Scroll X
-	0002.w										FG Scroll Y
+    0000.w                                      FG Scroll X
+    0002.w                                      FG Scroll Y
 
-	0004.w										BG Scroll X
-	0006.w										BG Scroll Y
+    0004.w                                      BG Scroll X
+    0006.w                                      BG Scroll Y
 
-	0008.w			Layers Control
+    0008.w          Layers Control
 
-					fed- ---- ---- ----
-					---c ---- ---- ----		BG Disable
-					---- b--- ---- ----		Line Scroll (Always 1 in berlwall & bakubrkr)
-					---- -a-- ---- ----		? Always 1 in gtmr     & bakubrkr ?
-					---- --9- ---- ----		BG Flip X
-					---- ---8 ---- ----		BG Flip Y
+                    fed- ---- ---- ----
+                    ---c ---- ---- ----     BG Disable
+                    ---- b--- ---- ----     Line Scroll (Always 1 in berlwall & bakubrkr)
+                    ---- -a-- ---- ----     ? Always 1 in gtmr     & bakubrkr ?
+                    ---- --9- ---- ----     BG Flip X
+                    ---- ---8 ---- ----     BG Flip Y
 
-					---- ---- 765- ----
-					---- ---- ---4 ----		FG Disable
-					---- ---- ---- 3---		Line Scroll (Always 1 in berlwall & bakubrkr)
-					---- ---- ---- -2--		? Always 1 in gtmr     & bakubrkr ?
-					---- ---- ---- --1-		FG Flip X
-					---- ---- ---- ---0		FG Flip Y
+                    ---- ---- 765- ----
+                    ---- ---- ---4 ----     FG Disable
+                    ---- ---- ---- 3---     Line Scroll (Always 1 in berlwall & bakubrkr)
+                    ---- ---- ---- -2--     ? Always 1 in gtmr     & bakubrkr ?
+                    ---- ---- ---- --1-     FG Flip X
+                    ---- ---- ---- ---0     FG Flip Y
 
-	000a.w										? always 0x0002 ?
+    000a.w                                      ? always 0x0002 ?
 
 There are more!
 
 ***************************************************************************/
 
-/*	[gtmr]
+/*  [gtmr]
 
-	car select screen scroll values:
-	Flipscreen off:
-		$6x0000: $72c0 ; $fbc0 ; 7340 ; 0
-		$72c0/$40 = $1cb = $200-$35	/	$7340/$40 = $1cd = $1cb+2
+    car select screen scroll values:
+    Flipscreen off:
+        $6x0000: $72c0 ; $fbc0 ; 7340 ; 0
+        $72c0/$40 = $1cb = $200-$35 /   $7340/$40 = $1cd = $1cb+2
 
-		$fbc0/$40 = -$11
+        $fbc0/$40 = -$11
 
-	Flipscreen on:
-		$6x0000: $5d00 ; $3780 ; $5c80 ; $3bc0
-		$5d00/$40 = $174 = $200-$8c	/	$5c80/$40 = $172 = $174-2
+    Flipscreen on:
+        $6x0000: $5d00 ; $3780 ; $5c80 ; $3bc0
+        $5d00/$40 = $174 = $200-$8c /   $5c80/$40 = $172 = $174-2
 
-		$3780/$40 = $de	/	$3bc0/$40 = $ef
+        $3780/$40 = $de /   $3bc0/$40 = $ef
 
 */
 
@@ -800,19 +801,19 @@ WRITE16_HANDLER( kaneko16_bg15_reg_w )
 /***************************************************************************
 
 
-								Screen Drawing
+                                Screen Drawing
 
 
 ***************************************************************************/
 
-void kaneko16_vh_screenrefresh(struct mame_bitmap *bitmap,int full_refresh)
+VIDEO_UPDATE( kaneko16 )
 {
 	int layers_flip_0, layers_flip_1 = 0;
 	int layers_ctrl = -1;
 	int i,flag;
 
-	data16_t layer0_scrollx, layer0_scrolly;
-	data16_t layer1_scrollx, layer1_scrolly;
+	UINT16 layer0_scrollx, layer0_scrolly;
+	UINT16 layer1_scrollx, layer1_scrolly;
 
 	layers_flip_0 = kaneko16_layers_0_regs[ 4 ];
 	if (kaneko16_tmap_2)
@@ -853,7 +854,7 @@ void kaneko16_vh_screenrefresh(struct mame_bitmap *bitmap,int full_refresh)
 
 	for (i=0; i<0x200; i++)
 	{
-		data16_t scroll;
+		UINT16 scroll;
 		scroll = (layers_flip_0 & 0x0800) ? kaneko16_vscroll_0[i] : 0;
 		tilemap_set_scrollx(kaneko16_tmap_0,i,(layer0_scrollx + scroll) >> 6 );
 		scroll = (layers_flip_0 & 0x0008) ? kaneko16_vscroll_1[i] : 0;
@@ -872,7 +873,7 @@ void kaneko16_vh_screenrefresh(struct mame_bitmap *bitmap,int full_refresh)
 
 	for (i=0; i<0x200; i++)
 	{
-		data16_t scroll;
+		UINT16 scroll;
 		scroll = (layers_flip_1 & 0x0800) ? kaneko16_vscroll_2[i] : 0;
 		tilemap_set_scrollx(kaneko16_tmap_2,i,(layer0_scrollx + scroll) >> 6 );
 		scroll = (layers_flip_1 & 0x0008) ? kaneko16_vscroll_3[i] : 0;
@@ -881,27 +882,27 @@ void kaneko16_vh_screenrefresh(struct mame_bitmap *bitmap,int full_refresh)
 	}
 
 #ifdef MAME_DEBUG
-if ( keyboard_pressed(KEYCODE_Z) ||
-	 keyboard_pressed(KEYCODE_X) || keyboard_pressed(KEYCODE_C) ||
-     keyboard_pressed(KEYCODE_V) || keyboard_pressed(KEYCODE_B) )
+if ( code_pressed(KEYCODE_Z) ||
+	 code_pressed(KEYCODE_X) || code_pressed(KEYCODE_C) ||
+     code_pressed(KEYCODE_V) || code_pressed(KEYCODE_B) )
 {	int msk = 0, val = 0;
 
-	if (keyboard_pressed(KEYCODE_X))	val = 1;	/* priority 0 only */
-	if (keyboard_pressed(KEYCODE_C))	val = 2;	/* ""       1 */
-	if (keyboard_pressed(KEYCODE_V))	val = 4;	/* ""       2 */
-	if (keyboard_pressed(KEYCODE_B))	val = 8;	/* ""       3 */
+	if (code_pressed(KEYCODE_X))	val = 1;	/* priority 0 only */
+	if (code_pressed(KEYCODE_C))	val = 2;	/* ""       1 */
+	if (code_pressed(KEYCODE_V))	val = 4;	/* ""       2 */
+	if (code_pressed(KEYCODE_B))	val = 8;	/* ""       3 */
 
-	if (keyboard_pressed(KEYCODE_Z))	val = 1|2|4|8;	/* All of the above priorities */
+	if (code_pressed(KEYCODE_Z))	val = 1|2|4|8;	/* All of the above priorities */
 
-	if (keyboard_pressed(KEYCODE_Q))	msk |= val << 0;	/* for tmap 0 */
-	if (keyboard_pressed(KEYCODE_W))	msk |= val << 4;	/* ""       1 */
-	if (keyboard_pressed(KEYCODE_E))	msk |= val << 8;	/* ""       2 */
-	if (keyboard_pressed(KEYCODE_R))	msk |= val << 12;	/* ""       3 */
-	if (keyboard_pressed(KEYCODE_A))	msk |= val << 16;	/* for sprites */
+	if (code_pressed(KEYCODE_Q))	msk |= val << 0;	/* for tmap 0 */
+	if (code_pressed(KEYCODE_W))	msk |= val << 4;	/* ""       1 */
+	if (code_pressed(KEYCODE_E))	msk |= val << 8;	/* ""       2 */
+	if (code_pressed(KEYCODE_R))	msk |= val << 12;	/* ""       3 */
+	if (code_pressed(KEYCODE_A))	msk |= val << 16;	/* for sprites */
 	if (msk != 0) layers_ctrl &= msk;
 
 #if 0
-	usrintf_showmessage(
+	ui_popup(
 		"%04X %04X %04X %04X %04X %04X %04X %04X - %04X %04X %04X %04X %04X %04X %04X %04X",
 		kaneko16_layers_0_regs[0x0],kaneko16_layers_0_regs[0x1],
 		kaneko16_layers_0_regs[0x2],kaneko16_layers_0_regs[0x3],
@@ -923,7 +924,7 @@ if ( keyboard_pressed(KEYCODE_Z) ||
 	if (kaneko16_bg15_bitmap)
 	{
 		int select	=	kaneko16_bg15_select[ 0 ];
-/*		int reg		=	kaneko16_bg15_reg[ 0 ]; */
+/*      int reg     =   kaneko16_bg15_reg[ 0 ]; */
 		int flip	=	select & 0x20;
 		int sx, sy;
 
@@ -936,41 +937,55 @@ if ( keyboard_pressed(KEYCODE_Z) ||
 			bitmap, kaneko16_bg15_bitmap,
 			flip, flip,
 			-sx, -sy,
-			&Machine->visible_area, TRANSPARENCY_NONE,0 );
+			cliprect, TRANSPARENCY_NONE,0 );
 
 		flag = 0;
 	}
 
 	/* Fill the bitmap with pen 0. This is wrong, but will work most of
-	   the times. To do it right, each pixel should be drawn with pen 0
-	   of the bottomost tile that covers it (which is pretty tricky to do) */
+       the times. To do it right, each pixel should be drawn with pen 0
+       of the bottomost tile that covers it (which is pretty tricky to do) */
 
-	if (flag!=0)	fillbitmap(bitmap,Machine->pens[0],&Machine->visible_area);
+	if (flag!=0)	fillbitmap(bitmap,Machine->pens[0],cliprect);
 
-	fillbitmap(priority_bitmap,0,NULL);
+	fillbitmap(priority_bitmap,0,cliprect);
+
+	if (!kaneko16_disp_enable) return;
 
 	if (kaneko16_tmap_2)
 	{
 	/*
-		The only working game using a 2nd VIEW2 chip is mgcrystl, where
-		its tilemaps seem to always be below every sprite. Hence we can
-		draw them with priority 0. To treat more complex cases, however,
-		we need tilemap.c to handle 8 "layers" (4 priorities x 2 chips)
-	*/
-		for ( i = 0; i < 4; i++ )	if (layers_ctrl&(1<<(i+ 8)))	tilemap_draw(bitmap, kaneko16_tmap_2, i, 0);
-		for ( i = 0; i < 4; i++ )	if (layers_ctrl&(1<<(i+12)))	tilemap_draw(bitmap, kaneko16_tmap_3, i, 0);
+        The only working game using a 2nd VIEW2 chip is mgcrystl, where
+        its tilemaps seem to always be below every sprite. Hence we can
+        draw them with priority 0. To treat more complex cases, however,
+        we need tilemap.c to handle 8 "layers" (4 priorities x 2 chips)
+    */
+		for ( i = 0; i < 4; i++ )	if (layers_ctrl&(1<<(i+ 8)))	tilemap_draw(bitmap,cliprect, kaneko16_tmap_2, i, 0);
+		for ( i = 0; i < 4; i++ )	if (layers_ctrl&(1<<(i+12)))	tilemap_draw(bitmap,cliprect, kaneko16_tmap_3, i, 0);
 	}
 
 	for ( i = 0; i < 4; i++ )
 	{
 		int tile = kaneko16_priority.tile[i];
-		if (layers_ctrl&(1<<(tile+0)))	tilemap_draw(bitmap, kaneko16_tmap_0, tile, 1<<i );
-		if (layers_ctrl&(1<<(tile+4)))	tilemap_draw(bitmap, kaneko16_tmap_1, tile, 1<<i );
+		if (layers_ctrl&(1<<(tile+0)))	tilemap_draw(bitmap,cliprect, kaneko16_tmap_0, tile, 1<<i );
+		if (layers_ctrl&(1<<(tile+4)))	tilemap_draw(bitmap,cliprect, kaneko16_tmap_1, tile, 1<<i );
 	}
 
 	/* Sprites last (rendered with pdrawgfx, so they can slip
-	   in between the layers) */
+       in between the layers) */
 
 	if (layers_ctrl & (0xf<<16))
-		kaneko16_draw_sprites(bitmap, (layers_ctrl >> 16) & 0xf);
+	{
+		if(kaneko16_keep_sprites)
+		{
+			/* keep sprites on screen */
+			kaneko16_draw_sprites(sprites_bitmap,cliprect, (layers_ctrl >> 16) & 0xf);
+			copybitmap(bitmap,sprites_bitmap,0,0,0,0,cliprect,TRANSPARENCY_PEN,0);
+		}
+		else
+		{
+			fillbitmap(sprites_bitmap,Machine->pens[0],cliprect);
+			kaneko16_draw_sprites(bitmap,cliprect, (layers_ctrl >> 16) & 0xf);
+		}
+	}
 }
