@@ -1,16 +1,16 @@
 /*
-	Video Hardware for Shoot Out
-	prom GB09.K6 may be related to background tile-sprite priority
+    Video Hardware for Shoot Out
+    prom GB09.K6 may be related to background tile-sprite priority
 */
 
 #include "driver.h"
 #include "vidhrdw/generic.h"
 
-static struct tilemap *background, *foreground;
+static tilemap *background, *foreground;
 extern unsigned char *shootout_textram;
 
 
-void shootout_vh_convert_color_prom(unsigned char *obsolete,unsigned short *colortable,const unsigned char *color_prom)
+PALETTE_INIT( shootout )
 {
 	int i;
 
@@ -63,20 +63,20 @@ static void get_fg_tile_info(int tile_index){
 			0)
 }
 
-WRITE_HANDLER( shootout_videoram_w ){
+WRITE8_HANDLER( shootout_videoram_w ){
 	if( videoram[offset]!=data ){
 		videoram[offset] = data;
 		tilemap_mark_tile_dirty( background, offset&0x3ff );
 	}
 }
-WRITE_HANDLER( shootout_textram_w ){
+WRITE8_HANDLER( shootout_textram_w ){
 	if( shootout_textram[offset]!=data ){
 		shootout_textram[offset] = data;
 		tilemap_mark_tile_dirty( foreground, offset&0x3ff );
 	}
 }
 
-int shootout_vh_start( void ){
+VIDEO_START( shootout ){
 	background = tilemap_create(get_bg_tile_info,tilemap_scan_rows,TILEMAP_OPAQUE,8,8,32,32);
 	foreground = tilemap_create(get_fg_tile_info,tilemap_scan_rows,TILEMAP_TRANSPARENT,8,8,32,32);
 	if( background && foreground ){
@@ -86,10 +86,9 @@ int shootout_vh_start( void ){
 	return 1; /* error */
 }
 
-static void draw_sprites( struct mame_bitmap *bitmap, int bank_bits ){
+static void draw_sprites( mame_bitmap *bitmap, const rectangle *cliprect, int bank_bits ){
 	static int bFlicker;
-	const struct GfxElement *gfx = Machine->gfx[1];
-	const struct rectangle *clip = &Machine->visible_area;
+	const gfx_element *gfx = Machine->gfx[1];
 	const UINT8 *source = spriteram+127*4;
 	int count;
 
@@ -98,43 +97,65 @@ static void draw_sprites( struct mame_bitmap *bitmap, int bank_bits ){
 	for( count=0; count<128; count++ ){
 		int attributes = source[1];
 		/*
-		    76543210
-			xxx-----	bank
-			---x----	vertical size
-			----x---	priority
-			-----x--	horizontal flip
-			------x-	flicker
-			-------x	enable
-		*/
+            76543210
+            xxx-----    bank
+            ---x----    vertical size
+            ----x---    priority
+            -----x--    horizontal flip
+            ------x-    flicker
+            -------x    enable
+        */
 		if ( attributes & 0x01 ){ /* visible */
 			if( bFlicker || (attributes&0x02)==0 ){
-				int priority_mask = (attributes&0x08)?0xaa:0;
+				int priority_mask = (attributes&0x08)?0x2:0;
 				int sx = (240 - source[2])&0xff;
 				int sy = (240 - source[0])&0xff;
+				int vx, vy;
 				int number = source[3] | ((attributes<<bank_bits)&0x700);
 				int flipx = (attributes & 0x04);
+				int flipy = 0;
+
+				if (flip_screen) {
+					flipx = !flipx;
+					flipy = !flipy;
+				}
 
 				if( attributes & 0x10 ){ /* double height */
 					number = number&(~1);
 					sy -= 16;
+
+					vx = sx;
+					vy = sy;
+					if (flip_screen) {
+						vx = 240 - vx;
+						vy = 240 - vy;
+					}
+
 					pdrawgfx(bitmap,gfx,
 						number,
 						0 /*color*/,
-						flipx,0 /*flipy*/,
-						sx,sy,
-						clip,TRANSPARENCY_PEN,0,
+						flipx,flipy,
+						vx,vy,
+						cliprect,TRANSPARENCY_PEN,0,
 						priority_mask);
 
 					number++;
 					sy += 16;
 				}
 
+				vx = sx;
+				vy = sy;
+				if (flip_screen) {
+					vx = 240 - vx;
+					vy = 240 - vy;
+				}
+
 				pdrawgfx(bitmap,gfx,
 						number,
 						0 /*color*/,
-						flipx,0 /*flipy*/,
-						sx,sy,
-						clip,TRANSPARENCY_PEN,0,
+						flipx,flipy,
+						vx,vy,
+						cliprect,TRANSPARENCY_PEN,0,
 						priority_mask);
 				}
 		}
@@ -142,20 +163,20 @@ static void draw_sprites( struct mame_bitmap *bitmap, int bank_bits ){
 	}
 }
 
-void shootout_vh_screenrefresh(struct mame_bitmap *bitmap,int full_refresh)
+VIDEO_UPDATE( shootout )
 {
-	fillbitmap(priority_bitmap,0,NULL);
+	fillbitmap(priority_bitmap,0,cliprect);
 
-	tilemap_draw(bitmap,background,0,0);
-	tilemap_draw(bitmap,foreground,0,1);
-	draw_sprites( bitmap,3/*bank bits */ );
+	tilemap_draw(bitmap,cliprect,background,0,0);
+	tilemap_draw(bitmap,cliprect,foreground,0,1);
+	draw_sprites(bitmap,cliprect,3/*bank bits */);
 }
 
-void shootouj_vh_screenrefresh(struct mame_bitmap *bitmap,int full_refresh)
+VIDEO_UPDATE( shootouj )
 {
-	fillbitmap(priority_bitmap,0,NULL);
+	fillbitmap(priority_bitmap,0,cliprect);
 
-	tilemap_draw(bitmap,background,0,1);
-	tilemap_draw(bitmap,foreground,0,2);
-	draw_sprites( bitmap,2/*bank bits*/ );
+	tilemap_draw(bitmap,cliprect,background,0,0);
+	tilemap_draw(bitmap,cliprect,foreground,0,1);
+	draw_sprites(bitmap,cliprect,2/*bank bits*/);
 }
